@@ -12,11 +12,11 @@ __email__ = "david.waroquiers@gmail.com"
 __date__ = "Feb 20, 2016"
 
 if __name__ == "__main__":
-    allcg = AllCoordinationGeometries()
+    all_cg = AllCoordinationGeometries()
 
     cg_symbol = "I:12"
     all_plane_points = []
-    cg = allcg[cg_symbol]
+    cg = all_cg[cg_symbol]
 
     # I:12
     if cg_symbol == "I:12":
@@ -25,7 +25,7 @@ if __name__ == "__main__":
         for edge in edges:
             opposite_edge = [opposite_points[edge[0]], opposite_points[edge[1]]]
             equiv_plane = list(edge)
-            equiv_plane.extend(opposite_edge)
+            equiv_plane += opposite_edge
             equiv_plane.sort()
             all_plane_points.append(tuple(equiv_plane))
         all_plane_points = [tuple(equiv_plane) for equiv_plane in set(all_plane_points)]
