@@ -2,7 +2,7 @@
 """
 This script regenerates the enum values in pymatgen.core.libxc_func.py.
 It requires in input the path of the `libxc_docs.txt` file contained in libxc/src
-The script parses this file, creates a new json file inside pymatgen.core
+The script parses this file, creates a new JSON file inside pymatgen.core
 and update the enum values declared in LibxcFunc.
 The script must be executed inside pymatgen/dev_scripts.
 """
@@ -16,10 +16,7 @@ from copy import deepcopy
 
 
 def parse_libxc_docs(path):
-    """
-    Parse libxc_docs.txt file, return dictionary with mapping:
-    libxc_id --> info_dict.
-    """
+    """Parse libxc_docs.txt file, return dictionary {libxc_id: info_dict}."""
 
     def parse_section(section):
         dct = {}
@@ -34,39 +31,39 @@ def parse_libxc_docs(path):
         section = []
         for line in file:
             if not line.startswith("-"):
-                section.append(line)
+                section += [line]
             else:
                 num, entry = parse_section(section)
                 assert num not in dct
                 dct[num] = entry
                 section = []
-        assert not section
+        assert section == []
 
     return dct
 
 
-def write_libxc_docs_json(xcfuncs, jpath):
-    """Write json file with libxc metadata to path jpath."""
-    xcfuncs = deepcopy(xcfuncs)
+def write_libxc_docs_json(xc_funcs, json_path):
+    """Write JSON file with libxc metadata to path jpath."""
+    xc_funcs = deepcopy(xc_funcs)
 
     # Remove XC_FAMILY from Family and XC_ from Kind to make strings more human-readable.
-    for d in xcfuncs.values():
-        d["Family"] = d["Family"].replace("XC_FAMILY_", "", 1)
-        d["Kind"] = d["Kind"].replace("XC_", "", 1)
+    for dct in xc_funcs.values():
+        dct["Family"] = dct["Family"].replace("XC_FAMILY_", "", 1)
+        dct["Kind"] = dct["Kind"].replace("XC_", "", 1)
 
     # Build lightweight version with a subset of keys.
-    for num, d in xcfuncs.items():
-        xcfuncs[num] = {key: d[key] for key in ("Family", "Kind", "References")}
+    for num, dct in xc_funcs.items():
+        xc_funcs[num] = {key: dct[key] for key in ("Family", "Kind", "References")}
         # Descriptions are optional
         for opt in ("Description 1", "Description 2"):
-            desc = d.get(opt)
+            desc = dct.get(opt)
             if desc is not None:
-                xcfuncs[num][opt] = desc
+                xc_funcs[num][opt] = desc
 
-    with open(jpath, mode="w") as file:
-        json.dump(xcfuncs, file)
+    with open(json_path, "w") as fh:
+        json.dump(xc_funcs, fh)
 
-    return xcfuncs
+    return xc_funcs
 
 
 def main():
@@ -85,7 +82,7 @@ def main():
 
     xc_funcs = parse_libxc_docs(path)
 
-    # Generate new json file in pycore
+    # Generate new JSON file in pycore
     pmg_core = os.path.abspath("../pymatgen/core/")
     json_path = f"{pmg_core}/libxc_docs.json"
     write_libxc_docs_json(xc_funcs, json_path)
@@ -95,7 +92,7 @@ def main():
     for num, d in xc_funcs.items():
         # Remove XC_ from codename
         codename = d["Codename"][3:]
-        enum_list.append(f"    {codename} = {num}")
+        enum_list += [f"    {codename} = {num}"]
     enum_list = "\n".join(enum_list) + "\n"
 
     # Re-generate enumerations.
@@ -111,11 +108,11 @@ def main():
     del lines[start + 1 : stop]
 
     # [2] write new py module
-    with open(xc_funcpy_path, mode="w") as file:
+    with open(xc_funcpy_path, mode="w", encoding="utf-8") as file:
         file.writelines(lines)
 
     print("Files have been regenerated")
-    print("Remember to update libxc_version in libxcfuncs.py!")
+    print("Remember to update __version__ in libxcfuncs.py!")
 
     return 0
 
