@@ -8,7 +8,7 @@ from __future__ import annotations
 import datetime
 import json
 import re
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING
 from warnings import warn
 
 from monty.json import MSONable, jsanitize
@@ -17,16 +17,20 @@ from pymatgen.core.structure import Structure
 from pymatgen.io.cif import CifParser
 from pymatgen.io.vasp.inputs import Poscar
 from pymatgen.io.vasp.sets import MPRelaxSet, VaspInputSet
+from pymatgen.transformations.transformation_abc import AbstractTransformation
 from pymatgen.util.provenance import StructureNL
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence
+    from typing import Any
+
+    from typing_extensions import Self
+
     from pymatgen.alchemy.filters import AbstractStructureFilter
-    from pymatgen.transformations.transformation_abc import AbstractTransformation
 
 
 class TransformedStructure(MSONable):
-    """Container object for new structures that include history of
-    transformations.
+    """Container for new structures that include history of transformations.
 
     Each transformed structure is made up of a sequence of structures with
     associated transformation history.
@@ -35,16 +39,15 @@ class TransformedStructure(MSONable):
     def __init__(
         self,
         structure: Structure,
-        transformations: list[AbstractTransformation] | None = None,
+        transformations: AbstractTransformation | Sequence[AbstractTransformation] | None = None,
         history: list[AbstractTransformation | dict[str, Any]] | None = None,
         other_parameters: dict[str, Any] | None = None,
     ) -> None:
-        """Initializes a transformed structure from a structure.
+        """Initialize a transformed structure from a structure.
 
         Args:
             structure (Structure): Input structure
-            transformations (list[Transformation]): List of transformations to
-                apply.
+            transformations (list[Transformation]): List of transformations to apply.
             history (list[Transformation]): Previous history.
             other_parameters (dict): Additional parameters to be added.
         """
@@ -53,6 +56,8 @@ class TransformedStructure(MSONable):
         self.other_parameters = other_parameters or {}
         self._undone: list[tuple[AbstractTransformation | dict[str, Any], Structure]] = []
 
+        if isinstance(transformations, AbstractTransformation):
+            transformations = [transformations]
         transformations = transformations or []
         for trafo in transformations:
             self.append_transformation(trafo)
@@ -82,12 +87,13 @@ class TransformedStructure(MSONable):
         """
         if len(self._undone) == 0:
             raise IndexError("No more changes to redo")
-        h, s = self._undone.pop()
-        self.history.append(h)
-        self.final_structure = s
+        hist, struct = self._undone.pop()
+        self.history.append(hist)
+        self.final_structure = struct
 
-    def __getattr__(self, name) -> Any:
-        struct = object.__getattribute__(self, "final_structure")
+    def __getattr__(self, name: str) -> Any:
+        # Don't use getattr(self.final_structure, name) here to avoid infinite recursion if name = "final_structure"
+        struct = self.__getattribute__("final_structure")
         return getattr(struct, name)
 
     def __len__(self) -> int:
@@ -96,7 +102,7 @@ class TransformedStructure(MSONable):
     def append_transformation(
         self, transformation, return_alternatives: bool = False, clear_redo: bool = True
     ) -> list[TransformedStructure] | None:
-        """Appends a transformation to the TransformedStructure.
+        """Append a transformation to the TransformedStructure.
 
         Args:
             transformation: Transformation to append
@@ -151,7 +157,7 @@ class TransformedStructure(MSONable):
         return None
 
     def append_filter(self, structure_filter: AbstractStructureFilter) -> None:
-        """Adds a filter.
+        """Add a filter.
 
         Args:
             structure_filter (StructureFilter): A filter implementing the
@@ -162,9 +168,11 @@ class TransformedStructure(MSONable):
         self.history.append(h_dict)
 
     def extend_transformations(
-        self, transformations: list[AbstractTransformation], return_alternatives: bool = False
+        self,
+        transformations: list[AbstractTransformation],
+        return_alternatives: bool = False,
     ) -> None:
-        """Extends a sequence of transformations to the TransformedStructure.
+        """Extend a sequence of transformations to the TransformedStructure.
 
         Args:
             transformations: Sequence of Transformations
@@ -177,7 +185,7 @@ class TransformedStructure(MSONable):
             self.append_transformation(trafo, return_alternatives=return_alternatives)
 
     def get_vasp_input(self, vasp_input_set: type[VaspInputSet] = MPRelaxSet, **kwargs) -> dict[str, Any]:
-        """Returns VASP input as a dict of VASP objects.
+        """Get VASP input as a dict of VASP objects.
 
         Args:
             vasp_input_set (VaspInputSet): input set
@@ -195,7 +203,7 @@ class TransformedStructure(MSONable):
         create_directory: bool = True,
         **kwargs,
     ) -> None:
-        """Writes VASP input to an output_dir.
+        """Write VASP input to an output_dir.
 
         Args:
             vasp_input_set: pymatgen.io.vasp.sets.VaspInputSet like object that creates vasp input files from
@@ -206,26 +214,37 @@ class TransformedStructure(MSONable):
             **kwargs: All keyword args supported by the VASP input set.
         """
         vasp_input_set(self.final_structure, **kwargs).write_input(output_dir, make_dir_if_not_present=create_directory)
-        with open(f"{output_dir}/transformations.json", mode="w") as file:
+        with open(f"{output_dir}/transformations.json", mode="w", encoding="utf-8") as file:
             json.dump(self.as_dict(), file)
 
     def __str__(self) -> str:
-        output = ["Current structure", "------------", str(self.final_structure), "\nHistory", "------------"]
+        output = [
+            "Current structure",
+            "------------",
+            str(self.final_structure),
+            "\nHistory",
+            "------------",
+        ]
         for hist in self.history:
             hist.pop("input_structure", None)
             output.append(str(hist))
-        output.extend(("\nOther parameters", "------------", str(self.other_parameters)))
+        output += ("\nOther parameters", "------------", str(self.other_parameters))
         return "\n".join(output)
 
-    def set_parameter(self, key: str, value: Any) -> None:
-        """Sets a parameter.
+    def set_parameter(self, key: str, value: Any) -> TransformedStructure:
+        """Set a parameter.
 
         Args:
             key (str): The string key.
             value (Any): The value.
+
+        Returns:
+            TransformedStructure
         """
         self.other_parameters[key] = value
 
+        return self
+
     @property
     def was_modified(self) -> bool:
         """Boolean describing whether the last transformation on the structure
@@ -250,8 +269,8 @@ class TransformedStructure(MSONable):
         transformations: list[AbstractTransformation] | None = None,
         primitive: bool = True,
         occupancy_tolerance: float = 1.0,
-    ) -> TransformedStructure:
-        """Generates TransformedStructure from a cif string.
+    ) -> Self:
+        """Generate TransformedStructure from a cif string.
 
         Args:
             cif_string (str): Input cif string. Should contain only one
@@ -262,7 +281,7 @@ class TransformedStructure(MSONable):
             primitive (bool): Option to set if the primitive cell should be
                 extracted. Defaults to True. However, there are certain
                 instances where you might want to use a non-primitive cell,
-                e.g., if you are trying to generate all possible orderings of
+                e.g. if you are trying to generate all possible orderings of
                 partial removals or order a disordered structure. Defaults to True.
             occupancy_tolerance (float): If total occupancy of a site is
                 between 1 and occupancy_tolerance, the occupancies will be
@@ -272,7 +291,7 @@ class TransformedStructure(MSONable):
             TransformedStructure
         """
         parser = CifParser.from_str(cif_string, occupancy_tolerance=occupancy_tolerance)
-        raw_string = re.sub(r"'", '"', cif_string)
+        raw_str = re.sub(r"'", '"', cif_string)
         cif_dict = parser.as_dict()
         cif_keys = list(cif_dict)
         struct = parser.parse_structures(primitive=primitive)[0]
@@ -284,16 +303,18 @@ class TransformedStructure(MSONable):
         source_info = {
             "source": source,
             "datetime": str(datetime.datetime.now()),
-            "original_file": raw_string,
+            "original_file": raw_str,
             "cif_data": cif_dict[cif_keys[0]],
         }
         return cls(struct, transformations, history=[source_info])
 
     @classmethod
     def from_poscar_str(
-        cls, poscar_string: str, transformations: list[AbstractTransformation] | None = None
-    ) -> TransformedStructure:
-        """Generates TransformedStructure from a poscar string.
+        cls,
+        poscar_string: str,
+        transformations: list[AbstractTransformation] | None = None,
+    ) -> Self:
+        """Generate TransformedStructure from a poscar string.
 
         Args:
             poscar_string (str): Input POSCAR string.
@@ -305,12 +326,12 @@ class TransformedStructure(MSONable):
             raise ValueError(
                 "Transformation can be created only from POSCAR strings with proper VASP5 element symbols."
             )
-        raw_string = re.sub(r"'", '"', poscar_string)
+        raw_str = re.sub(r"'", '"', poscar_string)
         struct = poscar.structure
         source_info = {
             "source": "POSCAR",
             "datetime": str(datetime.datetime.now()),
-            "original_file": raw_string,
+            "original_file": raw_str,
         }
         return cls(struct, transformations, history=[source_info])
 
@@ -320,24 +341,25 @@ class TransformedStructure(MSONable):
         dct["@module"] = type(self).__module__
         dct["@class"] = type(self).__name__
         dct["history"] = jsanitize(self.history)
-        dct["last_modified"] = str(datetime.datetime.utcnow())
+        dct["last_modified"] = str(datetime.datetime.now(datetime.timezone.utc))
         dct["other_parameters"] = jsanitize(self.other_parameters)
         return dct
 
     @classmethod
-    def from_dict(cls, dct) -> TransformedStructure:
-        """Creates a TransformedStructure from a dict."""
+    def from_dict(cls, dct: dict) -> Self:
+        """Create a TransformedStructure from a dict."""
         struct = Structure.from_dict(dct)
         return cls(struct, history=dct["history"], other_parameters=dct.get("other_parameters"))
 
-    def to_snl(self, authors, **kwargs) -> StructureNL:
-        """Generate SNL from TransformedStructure.
+    def to_snl(self, authors: list[str], **kwargs) -> StructureNL:
+        """Generate a StructureNL from TransformedStructure.
 
-        :param authors: List of authors
-        :param **kwargs: All kwargs supported by StructureNL.
+        Args:
+            authors (List[str]): List of authors contributing to the generated StructureNL.
+            **kwargs (Any): All kwargs supported by StructureNL.
 
         Returns:
-            StructureNL
+            StructureNL: The generated StructureNL object.
         """
         if self.other_parameters:
             warn("Data in TransformedStructure.other_parameters discarded during type conversion to SNL")
@@ -355,7 +377,7 @@ class TransformedStructure(MSONable):
         return StructureNL(self.final_structure, authors, history=history, **kwargs)
 
     @classmethod
-    def from_snl(cls, snl: StructureNL) -> TransformedStructure:
+    def from_snl(cls, snl: StructureNL) -> Self:
         """Create TransformedStructure from SNL.
 
         Args:
