@@ -24,7 +24,11 @@ from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.util.coord import in_coord_list_pbc
 
 if TYPE_CHECKING:
+    import matplotlib.pyplot as plt
     from numpy.typing import ArrayLike
+    from typing_extensions import Self
+
+    from pymatgen.core.surface import Slab
 
 __author__ = "Joseph Montoya"
 __copyright__ = "Copyright 2016, The Materials Project"
@@ -54,7 +58,7 @@ class AdsorbateSiteFinder:
     """
 
     def __init__(
-        self, slab, selective_dynamics: bool = False, height: float = 0.9, mi_vec: ArrayLike | None = None
+        self, slab: Slab, selective_dynamics: bool = False, height: float = 0.9, mi_vec: ArrayLike | None = None
     ) -> None:
         """Create an AdsorbateSiteFinder object.
 
@@ -88,8 +92,8 @@ class AdsorbateSiteFinder:
         center_slab=True,
         selective_dynamics=False,
         undercoord_threshold=0.09,
-    ):
-        """This method constructs the adsorbate site finder from a bulk
+    ) -> Self:
+        """Construct the adsorbate site finder from a bulk
         structure and a miller index, which allows the surface sites to be
         determined from the difference in bulk and slab coordination, as
         opposed to the height threshold.
@@ -132,29 +136,26 @@ class AdsorbateSiteFinder:
 
         vnn_surface = VoronoiNN(tol=0.05, allow_pathological=True)
 
-        surf_props, undercoords = [], []
+        surf_props, under_coords = [], []
         this_mi_vec = get_mi_vec(this_slab)
         mi_mags = [np.dot(this_mi_vec, site.coords) for site in this_slab]
-        average_mi_mag = np.average(mi_mags)
+        average_mi_mag = np.mean(mi_mags)
         for n, site in enumerate(this_slab):
             bulk_coord = this_slab.site_properties["bulk_coordinations"][n]
             slab_coord = len(vnn_surface.get_nn(this_slab, n))
             mi_mag = np.dot(this_mi_vec, site.coords)
-            undercoord = (bulk_coord - slab_coord) / bulk_coord
-            undercoords += [undercoord]
-            if undercoord > undercoord_threshold and mi_mag > average_mi_mag:
+            under_coord = (bulk_coord - slab_coord) / bulk_coord
+            under_coords += [under_coord]
+            if under_coord > undercoord_threshold and mi_mag > average_mi_mag:
                 surf_props += ["surface"]
             else:
                 surf_props += ["subsurface"]
-        new_site_properties = {
-            "surface_properties": surf_props,
-            "undercoords": undercoords,
-        }
+        new_site_properties = {"surface_properties": surf_props, "undercoords": under_coords}
         new_slab = this_slab.copy(site_properties=new_site_properties)
         return cls(new_slab, selective_dynamics)
 
-    def find_surface_sites_by_height(self, slab, height=0.9, xy_tol=0.05):
-        """This method finds surface sites by determining which sites are
+    def find_surface_sites_by_height(self, slab: Slab, height=0.9, xy_tol=0.05):
+        """Find surface sites by determining which sites are
         within a threshold value in height from the topmost site in a list of
         sites.
 
@@ -179,7 +180,8 @@ class AdsorbateSiteFinder:
             # sort surface sites by height
             surf_sites = [s for (h, s) in zip(m_projs[mask], surf_sites)]
             surf_sites.reverse()
-            unique_sites, unique_perp_fracs = [], []
+            unique_sites: list = []
+            unique_perp_fracs: list = []
             for site in surf_sites:
                 this_perp = site.coords - np.dot(site.coords, self.mvec)
                 this_perp_frac = slab.lattice.get_fractional_coords(this_perp)
@@ -190,8 +192,8 @@ class AdsorbateSiteFinder:
 
         return surf_sites
 
-    def assign_site_properties(self, slab, height=0.9):
-        """Assigns site properties."""
+    def assign_site_properties(self, slab: Slab, height=0.9):
+        """Assign site properties."""
         if "surface_properties" in slab.site_properties:
             return slab
 
@@ -200,7 +202,7 @@ class AdsorbateSiteFinder:
         return slab.copy(site_properties={"surface_properties": surf_props})
 
     def get_extended_surface_mesh(self, repeat=(5, 5, 1)):
-        """Gets an extended surface mesh for to use for adsorption site finding
+        """Get an extended surface mesh for to use for adsorption site finding
         by constructing supercell of surface sites.
 
         Args:
@@ -228,7 +230,7 @@ class AdsorbateSiteFinder:
         positions=("ontop", "bridge", "hollow"),
         no_obtuse_hollow=True,
     ):
-        """Finds surface sites according to the above algorithm. Returns a list
+        """Find surface sites according to the above algorithm. Returns a list
         of corresponding Cartesian coordinates.
 
         Args:
@@ -260,8 +262,8 @@ class AdsorbateSiteFinder:
             ads_sites["subsurface"] = ss_sites
         if "bridge" in positions or "hollow" in positions:
             mesh = self.get_extended_surface_mesh()
-            sop = get_rot(self.slab)
-            dt = Delaunay([sop.operate(m.coords)[:2] for m in mesh])
+            symm_op = get_rot(self.slab)
+            dt = Delaunay([symm_op.operate(m.coords)[:2] for m in mesh])
             # TODO: refactor below to properly account for >3-fold
             for v in dt.simplices:
                 if -1 not in v:
@@ -298,11 +300,11 @@ class AdsorbateSiteFinder:
             sites = [site + distance * np.asarray(self.mvec) for site in sites]
 
             ads_sites[key] = sites
-        ads_sites["all"] = sum(ads_sites.values(), [])
+        ads_sites["all"] = sum(ads_sites.values(), [])  # noqa: RUF017
         return ads_sites
 
     def symm_reduce(self, coords_set, threshold=1e-6):
-        """Reduces the set of adsorbate sites by finding removing symmetrically
+        """Reduce the set of adsorbate sites by finding removing symmetrically
         equivalent duplicates.
 
         Args:
@@ -327,7 +329,7 @@ class AdsorbateSiteFinder:
         return [self.slab.lattice.get_cartesian_coords(coords) for coords in unique_coords]
 
     def near_reduce(self, coords_set, threshold=1e-4):
-        """Prunes coordinate set for coordinates that are within threshold.
+        """Prune coordinate set for coordinates that are within threshold.
 
         Args:
             coords_set (Nx3 array-like): list or array of coordinates
@@ -342,7 +344,7 @@ class AdsorbateSiteFinder:
 
     @classmethod
     def ensemble_center(cls, site_list, indices, cartesian=True):
-        """Finds the center of an ensemble of sites selected from a list of
+        """Find the center of an ensemble of sites selected from a list of
         sites. Helper method for the find_adsorption_sites algorithm.
 
         Args:
@@ -353,12 +355,12 @@ class AdsorbateSiteFinder:
                 Cartesian coordinate
         """
         if cartesian:
-            return np.average([site_list[idx].coords for idx in indices], axis=0)
+            return np.mean([site_list[idx].coords for idx in indices], axis=0)
 
-        return np.average([site_list[idx].frac_coords for idx in indices], axis=0)
+        return np.mean([site_list[idx].frac_coords for idx in indices], axis=0)
 
     def add_adsorbate(self, molecule: Molecule, ads_coord, repeat=None, translate=True, reorient=True):
-        """Adds an adsorbate at a particular coordinate. Adsorbate represented
+        """Add an adsorbate at a particular coordinate. Adsorbate represented
         by a Molecule object and is translated to (0, 0, 0) if translate is
         True, or positioned relative to the input adsorbate coordinate if
         translate is False.
@@ -383,8 +385,8 @@ class AdsorbateSiteFinder:
             molecule.translate_sites(vector=[-x, -y, -z])
         if reorient:
             # Reorient the molecule along slab m_index
-            sop = get_rot(self.slab)
-            molecule.apply_operation(sop.inverse)
+            symm_op = get_rot(self.slab)
+            molecule.apply_operation(symm_op.inverse)
         struct = self.slab.copy()
         if repeat:
             struct.make_supercell(repeat)
@@ -427,7 +429,7 @@ class AdsorbateSiteFinder:
         reorient=True,
         find_args=None,
     ):
-        """Function that generates all adsorption structures for a given
+        """Generate all adsorption structures for a given
         molecular adsorbate. Can take repeat argument or minimum length/width
         of precursor slab as an input.
 
@@ -471,7 +473,7 @@ class AdsorbateSiteFinder:
         reorient=True,
         find_args=None,
     ):
-        """Function that generates all adsorption structures for a given
+        """Generate all adsorption structures for a given
         molecular adsorbate on both surfaces of a slab. This is useful for
         calculating surface energy where both surfaces need to be equivalent or
         if we want to calculate nonpolar systems.
@@ -533,7 +535,7 @@ class AdsorbateSiteFinder:
         range_tol=1e-2,
         dist_from_surf=0,
     ):
-        """Function that performs substitution-type doping on the surface and
+        """Perform substitution-type doping on the surface and
         returns all possible configurations where one dopant is substituted per
         surface. Can substitute one surface or both.
 
@@ -553,20 +555,20 @@ class AdsorbateSiteFinder:
         sym_slab = SpacegroupAnalyzer(self.slab).get_symmetrized_structure()
 
         # Define a function for substituting a site
-        def substitute(site, i):
+        def substitute(site, idx):
             slab = self.slab.copy()
             props = self.slab.site_properties
             if sub_both_sides:
                 # Find an equivalent site on the other surface
-                eq_indices = next(indices for indices in sym_slab.equivalent_indices if i in indices)
+                eq_indices = next(indices for indices in sym_slab.equivalent_indices if idx in indices)
                 for ii in eq_indices:
                     if f"{sym_slab[ii].frac_coords[2]:.6f}" != f"{site.frac_coords[2]:.6f}":
                         props["surface_properties"][ii] = "substitute"
                         slab.replace(ii, atom)
                         break
 
-            props["surface_properties"][i] = "substitute"
-            slab.replace(i, atom)
+            props["surface_properties"][idx] = "substitute"
+            slab.replace(idx, atom)
             slab.add_site_property("surface_properties", props["surface_properties"])
             return slab
 
@@ -598,8 +600,8 @@ def get_mi_vec(slab):
     return mvec / np.linalg.norm(mvec)
 
 
-def get_rot(slab):
-    """Gets the transformation to rotate the z axis into the miller index."""
+def get_rot(slab: Slab) -> SymmOp:
+    """Get the transformation to rotate the z axis into the miller index."""
     new_z = get_mi_vec(slab)
     a, _b, _c = slab.lattice.matrix
     new_x = a / np.linalg.norm(a)
@@ -611,18 +613,18 @@ def get_rot(slab):
 
 
 def put_coord_inside(lattice, cart_coordinate):
-    """Converts a Cartesian coordinate such that it is inside the unit cell."""
+    """Convert a Cartesian coordinate such that it is inside the unit cell."""
     fc = lattice.get_fractional_coords(cart_coordinate)
     return lattice.get_cartesian_coords([c - np.floor(c) for c in fc])
 
 
 def reorient_z(structure):
-    """Reorients a structure such that the z axis is concurrent with the normal
+    """Reorient a structure such that the z axis is concurrent with the normal
     to the A-B plane.
     """
     struct = structure.copy()
-    sop = get_rot(struct)
-    struct.apply_operation(sop)
+    symm_op = get_rot(struct)
+    struct.apply_operation(symm_op)
     return struct
 
 
@@ -632,8 +634,8 @@ color_dict = {el: [j / 256.001 for j in colors["Jmol"][el]] for el in colors["Jm
 
 
 def plot_slab(
-    slab,
-    ax,
+    slab: Slab,
+    ax: plt.Axes,
     scale=0.8,
     repeat=5,
     window=1.5,
@@ -642,8 +644,7 @@ def plot_slab(
     adsorption_sites=True,
     inverse=False,
 ):
-    """Function that helps visualize the slab in a 2-D plot, for convenient
-    viewing of output of AdsorbateSiteFinder.
+    """Help visualize the slab in a 2-D plot, for convenient viewing of output of AdsorbateSiteFinder.
 
     Args:
         slab (slab): Slab object to be visualized
@@ -667,27 +668,27 @@ def plot_slab(
     alphas = alphas.clip(min=0)
     corner = [0, 0, slab.lattice.get_fractional_coords(coords[-1])[-1]]
     corner = slab.lattice.get_cartesian_coords(corner)[:2]
-    verts = orig_cell[:2, :2]
-    lattsum = verts[0] + verts[1]
+    vertices = orig_cell[:2, :2]
+    lattice_sum = vertices[0] + vertices[1]
     # inverse coords, sites, alphas, to show other side of slab
     if inverse:
         alphas = np.array(reversed(alphas))
         sites = list(reversed(sites))
         coords = np.array(reversed(coords))
     # Draw circles at sites and stack them accordingly
-    for n, coord in enumerate(coords):
-        r = sites[n].species.elements[0].atomic_radius * scale
-        ax.add_patch(patches.Circle(coord[:2] - lattsum * (repeat // 2), r, color="w", zorder=2 * n))
-        color = color_dict[sites[n].species.elements[0].symbol]
+    for idx, coord in enumerate(coords):
+        radius = sites[idx].species.elements[0].atomic_radius * scale
+        ax.add_patch(patches.Circle(coord[:2] - lattice_sum * (repeat // 2), radius, color="w", zorder=2 * idx))
+        color = color_dict[sites[idx].species.elements[0].symbol]
         ax.add_patch(
             patches.Circle(
-                coord[:2] - lattsum * (repeat // 2),
-                r,
+                coord[:2] - lattice_sum * (repeat // 2),
+                radius,
                 facecolor=color,
-                alpha=alphas[n],
+                alpha=alphas[idx],
                 edgecolor="k",
                 lw=0.3,
-                zorder=2 * n + 1,
+                zorder=2 * idx + 1,
             )
         )
     # Adsorption sites
@@ -698,22 +699,22 @@ def plot_slab(
             inverse_slab.make_supercell([1, 1, -1])
             asf = AdsorbateSiteFinder(inverse_slab)
         ads_sites = asf.find_adsorption_sites()["all"]
-        sop = get_rot(orig_slab)
-        ads_sites = [sop.operate(ads_site)[:2].tolist() for ads_site in ads_sites]
+        symm_op = get_rot(orig_slab)
+        ads_sites = [symm_op.operate(ads_site)[:2].tolist() for ads_site in ads_sites]
         ax.plot(*zip(*ads_sites), color="k", marker="x", markersize=10, mew=1, linestyle="", zorder=10000)
     # Draw unit cell
     if draw_unit_cell:
-        verts = np.insert(verts, 1, lattsum, axis=0).tolist()
-        verts += [[0.0, 0.0]]
-        verts = [[0.0, 0.0], *verts]
+        vertices = np.insert(vertices, 1, lattice_sum, axis=0).tolist()
+        vertices += [[0.0, 0.0]]
+        vertices = [[0.0, 0.0], *vertices]
         codes = [Path.MOVETO, Path.LINETO, Path.LINETO, Path.LINETO, Path.CLOSEPOLY]
-        verts = [(np.array(vert) + corner).tolist() for vert in verts]
-        path = Path(verts, codes)
-        patch = patches.PathPatch(path, facecolor="none", lw=2, alpha=0.5, zorder=2 * n + 2)
+        vertices = [(np.array(vert) + corner).tolist() for vert in vertices]
+        path = Path(vertices, codes)
+        patch = patches.PathPatch(path, facecolor="none", lw=2, alpha=0.5, zorder=2 * len(coords) + 2)
         ax.add_patch(patch)
     ax.set_aspect("equal")
-    center = corner + lattsum / 2.0
-    extent = np.max(lattsum)
+    center = corner + lattice_sum / 2.0
+    extent = np.max(lattice_sum)
     lim_array = [center - extent * window, center + extent * window]
     x_lim = [ele[0] for ele in lim_array]
     y_lim = [ele[1] for ele in lim_array]
