@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import logging
 import time
+from typing import TYPE_CHECKING
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -20,6 +21,9 @@ from pymatgen.analysis.chemenv.utils.math_utils import normal_cdf_step
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Structure
 
+if TYPE_CHECKING:
+    from typing_extensions import Self
+
 __author__ = "David Waroquiers"
 __copyright__ = "Copyright 2012, The Materials Project"
 __credits__ = "Geoffroy Hautier"
@@ -29,9 +33,8 @@ __email__ = "david.waroquiers@gmail.com"
 __date__ = "Feb 20, 2016"
 
 
-def from_bson_voronoi_list2(bson_nb_voro_list2, structure):
-    """
-    Returns the voronoi_list needed for the VoronoiContainer object from a bson-encoded voronoi_list.
+def from_bson_voronoi_list2(bson_nb_voro_list2: list[PeriodicSite], structure: Structure):
+    """Get the voronoi_list needed for the VoronoiContainer object from a BSON-encoded voronoi_list.
 
     Args:
         bson_nb_voro_list2: List of periodic sites involved in the Voronoi.
@@ -41,26 +44,27 @@ def from_bson_voronoi_list2(bson_nb_voro_list2, structure):
         The voronoi_list needed for the VoronoiContainer (with PeriodicSites as keys of the dictionary - not
         allowed in the BSON format).
     """
-    voronoi_list = [None] * len(bson_nb_voro_list2)
-    for isite, voro in enumerate(bson_nb_voro_list2):
-        if voro is None or voro == "None":
+    voronoi_list: list[list[dict] | None] = [None] * len(bson_nb_voro_list2)
+
+    for idx, voro in enumerate(bson_nb_voro_list2):
+        if voro in (None, "None"):
             continue
-        voronoi_list[isite] = []
+
+        voronoi_list[idx] = []
         for psd, dct in voro:
             struct_site = structure[dct["index"]]
-            periodic_site = PeriodicSite(
+            dct["site"] = PeriodicSite(
                 struct_site._species,
                 struct_site.frac_coords + psd[1],
                 struct_site._lattice,
                 properties=struct_site.properties,
             )
-            dct["site"] = periodic_site
-            voronoi_list[isite].append(dct)
+            voronoi_list[idx].append(dct)  # type: ignore[union-attr]
     return voronoi_list
 
 
 class DetailedVoronoiContainer(MSONable):
-    """Class used to store the full Voronoi of a given structure."""
+    """Store the full Voronoi of a given structure."""
 
     AC = AdditionalConditions()
     default_voronoi_cutoff = 10.0
@@ -122,8 +126,7 @@ class DetailedVoronoiContainer(MSONable):
         logging.debug(f"Neighbors distances and angles set up in {t2 - t1:.2f} seconds")
 
     def setup_voronoi_list(self, indices, voronoi_cutoff):
-        """
-        Set up of the voronoi list of neighbors by calling qhull.
+        """Set up of the voronoi list of neighbors by calling qhull.
 
         Args:
             indices: indices of the sites for which the Voronoi is needed.
@@ -141,8 +144,8 @@ class DetailedVoronoiContainer(MSONable):
             logging.debug("Please consider increasing voronoi_distance_cutoff")
         t1 = time.process_time()
         logging.debug("Setting up Voronoi list :")
-        for jj, isite in enumerate(indices):
-            logging.debug(f"  - Voronoi analysis for site #{isite} ({jj + 1}/{len(indices)})")
+        for jj, isite in enumerate(indices, start=1):
+            logging.debug(f"  - Voronoi analysis for site #{isite} ({jj}/{len(indices)})")
             site = self.structure[isite]
             neighbors1 = [(site, 0.0, isite)]
             neighbors1.extend(struct_neighbors[isite])
@@ -190,8 +193,7 @@ class DetailedVoronoiContainer(MSONable):
         logging.debug(f"Voronoi list set up in {t2 - t1:.2f} seconds")
 
     def setup_neighbors_distances_and_angles(self, indices):
-        """
-        Initializes the angle and distance separations.
+        """Initialize the angle and distance separations.
 
         Args:
             indices: Indices of the sites for which the Voronoi is needed.
@@ -406,8 +408,7 @@ class DetailedVoronoiContainer(MSONable):
     #     return {'i_distfactor': idist, 'i_angfactor': iang, 'i_additional_condition': i_additional_condition}
 
     def neighbors_surfaces(self, isite, surface_calculation_type=None, max_dist=2.0):
-        """
-        Get the different surfaces corresponding to the different distance-angle cutoffs for a given site.
+        """Get the different surfaces corresponding to the different distance-angle cutoffs for a given site.
 
         Args:
             isite: Index of the site
@@ -431,8 +432,7 @@ class DetailedVoronoiContainer(MSONable):
         return surfaces
 
     def neighbors_surfaces_bounded(self, isite, surface_calculation_options=None):
-        """
-        Get the different surfaces (using boundaries) corresponding to the different distance-angle cutoffs
+        """Get the different surfaces (using boundaries) corresponding to the different distance-angle cutoffs
         for a given site.
 
         Args:
@@ -485,8 +485,8 @@ class DetailedVoronoiContainer(MSONable):
             dp2 = distance_bounds[idp + 1]
             if dp2 < mindist or dp1 > maxdist:
                 continue
-            d1 = mindist if dp1 < mindist else dp1
-            d2 = maxdist if dp2 > maxdist else dp2
+            d1 = max(dp1, mindist)
+            d2 = min(dp2, maxdist)
             for iap in range(len(angle_bounds) - 1):
                 ap1 = angle_bounds[iap]
                 ap2 = angle_bounds[iap + 1]
@@ -537,8 +537,7 @@ class DetailedVoronoiContainer(MSONable):
         max_dist=2.0,
         additional_conditions=None,
     ):
-        """
-        Get the different surfaces and their cn_map corresponding to the different distance-angle cutoffs
+        """Get the different surfaces and their cn_map corresponding to the different distance-angle cutoffs
         for a given site.
 
         Args:
@@ -576,8 +575,7 @@ class DetailedVoronoiContainer(MSONable):
         return maps_and_surfaces
 
     def maps_and_surfaces_bounded(self, isite, surface_calculation_options=None, additional_conditions=None):
-        """
-        Get the different surfaces (using boundaries) and their cn_map corresponding to the different
+        """Get the different surfaces (using boundaries) and their cn_map corresponding to the different
         distance-angle cutoffs for a given site.
 
         Args:
@@ -610,8 +608,7 @@ class DetailedVoronoiContainer(MSONable):
         return maps_and_surfaces
 
     def neighbors(self, isite, distfactor, angfactor, additional_condition=None):
-        """
-        Get the neighbors of a given site corresponding to a given distance and angle factor.
+        """Get the neighbors of a given site corresponding to a given distance and angle factor.
 
         Args:
             isite: Index of the site.
@@ -646,8 +643,7 @@ class DetailedVoronoiContainer(MSONable):
         ]
 
     def voronoi_parameters_bounds_and_limits(self, isite, plot_type, max_dist):
-        """
-        Get the different boundaries and limits of the distance and angle factors for the given site.
+        """Get the different boundaries and limits of the distance and angle factors for the given site.
 
         Args:
             isite: Index of the site.
@@ -778,8 +774,7 @@ class DetailedVoronoiContainer(MSONable):
         return True
 
     def get_rdf_figure(self, isite, normalized=True, figsize=None, step_function=None):
-        """
-        Get the Radial Distribution Figure for a given site.
+        """Get the Radial Distribution Figure for a given site.
 
         Args:
             isite: Index of the site.
@@ -828,8 +823,7 @@ class DetailedVoronoiContainer(MSONable):
         return fig
 
     def get_sadf_figure(self, isite, normalized=True, figsize=None, step_function=None):
-        """
-        Get the Solid Angle Distribution Figure for a given site.
+        """Get the Solid Angle Distribution Figure for a given site.
 
         Args:
             isite: Index of the site.
@@ -908,7 +902,7 @@ class DetailedVoronoiContainer(MSONable):
             #  'index': myindex}
             for nb_dict in voro:
                 site = nb_dict["site"]
-                site_dict = {key: val for key, val in nb_dict.items() if key not in ["site"]}
+                site_dict = {key: val for key, val in nb_dict.items() if key != "site"}
                 # site_voro.append([ps.as_dict(), dd]) [float(c) for c in self.frac_coords]
                 diff = site.frac_coords - self.structure[nb_dict["index"]].frac_coords
                 site_voro.append([[nb_dict["index"], [float(c) for c in diff]], site_dict])
@@ -938,7 +932,7 @@ class DetailedVoronoiContainer(MSONable):
         }
 
     @classmethod
-    def from_dict(cls, dct):
+    def from_dict(cls, dct: dict) -> Self:
         """
         Reconstructs the VoronoiContainer object from a dict representation of the VoronoiContainer created using
         the as_dict method.
@@ -953,6 +947,7 @@ class DetailedVoronoiContainer(MSONable):
         voronoi_list2 = from_bson_voronoi_list2(dct["bson_nb_voro_list2"], structure)
         maximum_distance_factor = dct.get("maximum_distance_factor")
         minimum_angle_factor = dct.get("minimum_angle_factor")
+
         return cls(
             structure=structure,
             voronoi_list2=voronoi_list2,
