@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 import math
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING
 
 import numpy as np
 from numpy.linalg import norm
@@ -14,7 +14,10 @@ from scipy.spatial import ConvexHull
 from pymatgen.analysis.chemenv.utils.chemenv_errors import SolidAngleError
 
 if TYPE_CHECKING:
+    from typing import Callable
+
     from numpy.typing import ArrayLike
+    from typing_extensions import Self
 
 __author__ = "David Waroquiers"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -28,7 +31,9 @@ __date__ = "Feb 20, 2016"
 def get_lower_and_upper_f(surface_calculation_options):
     """Get the lower and upper functions defining a surface in the distance-angle space of neighbors.
 
-    :param surface_calculation_options: Options for the surface.
+    Args:
+        surface_calculation_options: Options for the surface.
+
     Returns:
         Dictionary containing the "lower" and "upper" functions for the surface.
     """
@@ -335,17 +340,17 @@ def rectangle_surface_intersection(
         raise NotImplementedError("Bounds should be given right now ...")
     if x2 < bounds_lower[0] or x1 > bounds_lower[1]:
         return 0.0, 0.0
-    xmin = bounds_lower[0] if x1 < bounds_lower[0] else x1
-    xmax = bounds_lower[1] if x2 > bounds_lower[1] else x2
+    xmin = max(x1, bounds_lower[0])
+    xmax = min(x2, bounds_lower[1])
 
     def diff(x):
-        flwx = f_lower(x)
-        fupx = f_upper(x)
-        minup = np.min([fupx, y2 * np.ones_like(fupx)], axis=0)
-        maxlw = np.max([flwx, y1 * np.ones_like(flwx)], axis=0)
-        zeros = np.zeros_like(fupx)
-        upper = np.where(y2 >= flwx, np.where(y1 <= fupx, minup, zeros), zeros)
-        lower = np.where(y1 <= fupx, np.where(y2 >= flwx, maxlw, zeros), zeros)
+        f_low_x = f_lower(x)
+        f_up_x = f_upper(x)
+        min_up = np.min([f_up_x, y2 * np.ones_like(f_up_x)], axis=0)
+        max_lw = np.max([f_low_x, y1 * np.ones_like(f_low_x)], axis=0)
+        zeros = np.zeros_like(f_up_x)
+        upper = np.where(y2 >= f_low_x, np.where(y1 <= f_up_x, min_up, zeros), zeros)
+        lower = np.where(y1 <= f_up_x, np.where(y2 >= f_low_x, max_lw, zeros), zeros)
         return upper - lower
 
     return quad(diff, xmin, xmax)
@@ -356,25 +361,28 @@ def solid_angle(center, coords):
     Helper method to calculate the solid angle of a set of coords from the center.
 
     Args:
-        center:
-            Center to measure solid angle from.
-        coords:
-            List of coords to determine solid angle.
+        center: Center to measure solid angle from.
+        coords: List of coords to determine solid angle.
 
     Returns:
         The solid angle.
     """
-    o = np.array(center)
-    r = [np.array(c) - o for c in coords]
+    origin = np.array(center)
+    r = [np.array(c) - origin for c in coords]
     r.append(r[0])
-    n = [np.cross(r[i + 1], r[i]) for i in range(len(r) - 1)]
-    n.append(np.cross(r[1], r[0]))
+    cross_products = [np.cross(r[i + 1], r[i]) for i in range(len(r) - 1)]
+    cross_products.append(np.cross(r[1], r[0]))
     phi = 0.0
-    for idx in range(len(n) - 1):
+    for idx in range(len(cross_products) - 1):
         try:
-            value = math.acos(-np.dot(n[idx], n[idx + 1]) / (np.linalg.norm(n[idx]) * np.linalg.norm(n[idx + 1])))
+            value = math.acos(
+                -np.dot(cross_products[idx], cross_products[idx + 1])
+                / (np.linalg.norm(cross_products[idx]) * np.linalg.norm(cross_products[idx + 1]))
+            )
         except ValueError:
-            cos = -np.dot(n[idx], n[idx + 1]) / (np.linalg.norm(n[idx]) * np.linalg.norm(n[idx + 1]))
+            cos = -np.dot(cross_products[idx], cross_products[idx + 1]) / (
+                np.linalg.norm(cross_products[idx]) * np.linalg.norm(cross_products[idx + 1])
+            )
             if 0.999999999999 < cos < 1.000000000001:
                 value = math.acos(1.0)
             elif -0.999999999999 > cos > -1.000000000001:
@@ -388,8 +396,10 @@ def solid_angle(center, coords):
 def vectorsToMatrix(aa, bb):
     """
     Performs the vector multiplication of the elements of two vectors, constructing the 3x3 matrix.
-    :param aa: One vector of size 3
-    :param bb: Another vector of size 3
+
+    Args:
+        aa: One vector of size 3
+        bb: Another vector of size 3
 
     Returns:
         A 3x3 matrix M composed of the products of the elements of aa and bb : M_ij = aa_i * bb_j.
@@ -403,9 +413,9 @@ def vectorsToMatrix(aa, bb):
 
 def matrixTimesVector(MM, aa):
     """
-
-    :param MM: A matrix of size 3x3
-    :param aa: A vector of size 3
+    Args:
+        MM: A matrix of size 3x3
+        aa: A vector of size 3
 
     Returns:
         A vector of size 3 which is the product of the matrix by the vector
@@ -419,8 +429,10 @@ def matrixTimesVector(MM, aa):
 def rotateCoords(coords, R):
     """
     Rotate the list of points using rotation matrix R
-    :param coords: List of points to be rotated
-    :param R: Rotation matrix
+
+    Args:
+        coords: List of points to be rotated
+        R: Rotation matrix
 
     Returns:
         List of rotated points.
@@ -435,8 +447,10 @@ def rotateCoords(coords, R):
 def rotateCoordsOpt(coords, R):
     """
     Rotate the list of points using rotation matrix R
-    :param coords: List of points to be rotated
-    :param R: Rotation matrix
+
+    Args:
+        coords: List of points to be rotated
+        R: Rotation matrix
 
     Returns:
         List of rotated points.
@@ -445,13 +459,14 @@ def rotateCoordsOpt(coords, R):
 
 
 def changebasis(uu, vv, nn, pps):
-    """
-    For a list of points given in standard coordinates (in terms of e1, e2 and e3), returns the same list
+    """For a list of points given in standard coordinates (in terms of e1, e2 and e3), returns the same list
     expressed in the basis (uu, vv, nn), which is supposed to be orthonormal.
-    :param uu: First vector of the basis
-    :param vv: Second vector of the basis
-    :param nn: Third vector of the basis
-    :param pps: List of points in basis (e1, e2, e3)
+
+    Args:
+        uu: First vector of the basis
+        vv: Second vector of the basis
+        nn: Third vector of the basis
+        pps: List of points in basis (e1, e2, e3)
     Returns:
         List of points in basis (uu, vv, nn).
     """
@@ -474,10 +489,13 @@ def collinear(p1, p2, p3=None, tolerance=0.25):
     triangle is less than (tolerance x largest_triangle), then the three points are considered collinear. The
     largest_triangle is defined as the right triangle whose legs are the two smallest distances between the three
      points ie, its area is : 0.5 x (min(|p2-p1|,|p3-p1|,|p3-p2|) x second_min(|p2-p1|,|p3-p1|,|p3-p2|))
-    :param p1: First point
-    :param p2: Second point
-    :param p3: Third point (origin [0.0, 0.0, 0.0 if not given])
-    :param tolerance: Area tolerance for the collinearity test (0.25 gives about 0.125 deviation from the line)
+
+    Args:
+        p1: First point
+        p2: Second point
+        p3: Third point (origin [0.0, 0.0, 0.0 if not given])
+        tolerance: Area tolerance for the collinearity test (0.25 gives about 0.125 deviation from the line)
+
     Returns:
         bool: True if the three points are considered as collinear within the given tolerance.
     """
@@ -494,7 +512,9 @@ def collinear(p1, p2, p3=None, tolerance=0.25):
 def anticlockwise_sort(pps):
     """
     Sort a list of 2D points in anticlockwise order
-    :param pps: List of points to be sorted
+
+    Args:
+        pps: List of points to be sorted
 
     Returns:
         Sorted list of points.
@@ -510,9 +530,10 @@ def anticlockwise_sort(pps):
 
 
 def anticlockwise_sort_indices(pps):
-    """
-    Returns the indices that would sort a list of 2D points in anticlockwise order
-    :param pps: List of points to be sorted
+    """Get the indices that would sort a list of 2D points in anticlockwise order
+
+    Args:
+        pps: List of points to be sorted
 
     Returns:
         Indices of the sorted list of points.
@@ -526,7 +547,9 @@ def anticlockwise_sort_indices(pps):
 def sort_separation(separation):
     """Sort a separation.
 
-    :param separation: Initial separation.
+    Args:
+        separation: Initial separation.
+
     Returns:
         Sorted list of separation.
     """
@@ -538,7 +561,8 @@ def sort_separation(separation):
 def sort_separation_tuple(separation):
     """Sort a separation.
 
-    :param separation: Initial separation
+    Args:
+        separation: Initial separation
 
     Returns:
         Sorted tuple of separation
@@ -559,8 +583,10 @@ def sort_separation_tuple(separation):
 def separation_in_list(separation_indices, separation_indices_list):
     """
     Checks if the separation indices of a plane are already in the list
-    :param separation_indices: list of separation indices (three arrays of integers)
-    :param separation_indices_list: list of the list of separation indices to be compared to
+
+    Args:
+        separation_indices: list of separation indices (three arrays of integers)
+        separation_indices_list: list of the list of separation indices to be compared to
 
     Returns:
         bool: True if the separation indices are already in the list.
@@ -575,9 +601,11 @@ def separation_in_list(separation_indices, separation_indices_list):
 def is_anion_cation_bond(valences, ii, jj) -> bool:
     """
     Checks if two given sites are an anion and a cation.
-    :param valences: list of site valences
-    :param ii: index of a site
-    :param jj: index of another site
+
+    Args:
+        valences: list of site valences
+        ii: index of a site
+        jj: index of another site
 
     Returns:
         bool: True if one site is an anion and the other is a cation (based on valences).
@@ -590,7 +618,7 @@ def is_anion_cation_bond(valences, ii, jj) -> bool:
 
 
 class Plane:
-    """Class used to describe a plane."""
+    """Describe a plane."""
 
     TEST_2D_POINTS = (
         np.array([0, 0], float),
@@ -617,9 +645,10 @@ class Plane:
     )
 
     def __init__(self, coefficients, p1=None, p2=None, p3=None):
-        """
-        Initializes a plane from the 4 coefficients a, b, c and d of ax + by + cz + d = 0
-        :param coefficients: abcd coefficients of the plane.
+        """Initialize a plane from the 4 coefficients a, b, c and d of ax + by + cz + d = 0
+
+        Args:
+            coefficients: abcd coefficients of the plane.
         """
         # Initializes the normal vector
         self.normal_vector = np.array([coefficients[0], coefficients[1], coefficients[2]], float)
@@ -631,12 +660,12 @@ class Plane:
             raise ValueError("Normal vector is equal to 0.0")
         if self.normal_vector[non_zeros[0]] < 0.0:
             self.normal_vector = -self.normal_vector
-            dd = -np.float_(coefficients[3]) / norm_v
+            dd = -np.float64(coefficients[3]) / norm_v
         else:
-            dd = np.float_(coefficients[3]) / norm_v
+            dd = np.float64(coefficients[3]) / norm_v
         self._coefficients = np.array(
             [self.normal_vector[0], self.normal_vector[1], self.normal_vector[2], dd],
-            np.float_,
+            np.float64,
         )
         self._crosses_origin = np.isclose(dd, 0.0, atol=1e-7, rtol=0.0)
         self.p1 = p1
@@ -652,8 +681,9 @@ class Plane:
     def init_3points(self, non_zeros, zeros):
         """Initialize three random points on this plane.
 
-        :param non_zeros: Indices of plane coefficients ([a, b, c]) that are not zero.
-        :param zeros: Indices of plane coefficients ([a, b, c]) that are equal to zero.
+        Args:
+            non_zeros: Indices of plane coefficients ([a, b, c]) that are not zero.
+            zeros: Indices of plane coefficients ([a, b, c]) that are equal to zero.
         """
         if len(non_zeros) == 3:
             self.p1 = np.array([-self.d / self.a, 0.0, 0.0], float)
@@ -675,12 +705,7 @@ class Plane:
             self.p3[zeros[1]] = 1.0
 
     def __str__(self):
-        """
-        String representation of the Plane object
-
-        Returns:
-            String representation of the Plane object.
-        """
+        """String representation of the Plane."""
         return (
             f"Plane object\n  => Normal vector : {self.normal_vector}\n  => Equation of the plane"
             f" ax + by + cz + d = 0\n     with a = {self._coefficients[0]}\n          "
@@ -690,8 +715,10 @@ class Plane:
     def is_in_plane(self, pp, dist_tolerance) -> bool:
         """
         Determines if point pp is in the plane within the tolerance dist_tolerance
-        :param pp: point to be tested
-        :param dist_tolerance: tolerance on the distance to the plane within which point pp is considered in the plane
+
+        Args:
+            pp: point to be tested
+            dist_tolerance: tolerance on the distance to the plane within which point pp is considered in the plane
 
         Returns:
             bool: True if pp is in the plane.
@@ -701,7 +728,9 @@ class Plane:
     def is_same_plane_as(self, plane) -> bool:
         """
         Checks whether the plane is identical to another Plane "plane"
-        :param plane: Plane to be compared to
+
+        Args:
+            plane: Plane to be compared to
 
         Returns:
             bool: True if the two facets are identical.
@@ -711,7 +740,9 @@ class Plane:
     def is_in_list(self, plane_list) -> bool:
         """
         Checks whether the plane is identical to one of the Planes in the plane_list list of Planes
-        :param plane_list: List of Planes to be compared to
+
+        Args:
+            plane_list: List of Planes to be compared to
 
         Returns:
             bool: True if the plane is in the list.
@@ -719,13 +750,14 @@ class Plane:
         return any(self.is_same_plane_as(plane) for plane in plane_list)
 
     def indices_separate(self, points, dist_tolerance):
-        """
-        Returns three lists containing the indices of the points lying on one side of the plane, on the plane
+        """Get three lists containing the indices of the points lying on one side of the plane, on the plane
         and on the other side of the plane. The dist_tolerance parameter controls the tolerance to which a point
         is considered to lie on the plane or not (distance to the plane)
-        :param points: list of points
-        :param dist_tolerance: tolerance to which a point is considered to lie on the plane
-            or not (distance to the plane)
+
+        Args:
+            points: list of points
+            dist_tolerance: tolerance to which a point is considered to lie on the plane
+                or not (distance to the plane)
 
         Returns:
             The lists of indices of the points on one side of the plane, on the plane and
@@ -744,9 +776,10 @@ class Plane:
         return [side1, inplane, side2]
 
     def distance_to_point(self, point):
-        """
-        Computes the absolute distance from the plane to the point
-        :param point: Point for which distance is computed
+        """Compute the absolute distance from the plane to the point
+
+        Args:
+            point: Point for which distance is computed
 
         Returns:
             Distance between the plane and the point.
@@ -754,10 +787,11 @@ class Plane:
         return np.abs(np.dot(self.normal_vector, point) + self.d)
 
     def distances(self, points):
-        """
-        Computes the distances from the plane to each of the points. Positive distances are on the side of the
-        normal of the plane while negative distances are on the other side
-        :param points: Points for which distances are computed
+        """Compute the distances from the plane to each of the points. Positive distances are on
+        the side of the normal of the plane while negative distances are on the other side.
+
+        Args:
+            points: Points for which distances are computed
 
         Returns:
             Distances from the plane to the points (positive values on the side of the normal to the plane,
@@ -766,12 +800,13 @@ class Plane:
         return [np.dot(self.normal_vector, pp) + self.d for pp in points]
 
     def distances_indices_sorted(self, points, sign=False):
-        """
-        Computes the distances from the plane to each of the points. Positive distances are on the side of the
-        normal of the plane while negative distances are on the other side. Indices sorting the points from closest
-        to furthest is also computed.
-        :param points: Points for which distances are computed
-        :param sign: Whether to add sign information in the indices sorting the points distances
+        """Compute the distances from the plane to each of the points. Positive distances are
+        on the side of the normal of the plane while negative distances are on the other
+        side. Indices sorting the points from closest to furthest is also computed.
+
+        Args:
+            points: Points for which distances are computed
+            sign: Whether to add sign information in the indices sorting the points distances
 
         Returns:
             Distances from the plane to the points (positive values on the side of the normal to the plane,
@@ -785,17 +820,18 @@ class Plane:
         return distances, indices
 
     def distances_indices_groups(self, points, delta=None, delta_factor=0.05, sign=False):
-        """
-        Computes the distances from the plane to each of the points. Positive distances are on the side of the
+        """Compute the distances from the plane to each of the points. Positive distances are on the side of the
         normal of the plane while negative distances are on the other side. Indices sorting the points from closest
         to furthest is also computed. Grouped indices are also given, for which indices of the distances that are
         separated by less than delta are grouped together. The delta parameter is either set explicitly or taken as
         a fraction (using the delta_factor parameter) of the maximal point distance.
-        :param points: Points for which distances are computed
-        :param delta: Distance interval for which two points are considered in the same group.
-        :param delta_factor: If delta is None, the distance interval is taken as delta_factor times the maximal
+
+        Args:
+            points: Points for which distances are computed
+            delta: Distance interval for which two points are considered in the same group.
+            delta_factor: If delta is None, the distance interval is taken as delta_factor times the maximal
             point distance.
-        :param sign: Whether to add sign information in the indices sorting the points distances
+            sign: Whether to add sign information in the indices sorting the points distances
 
         Returns:
             Distances from the plane to the points (positive values on the side of the normal to the plane,
@@ -819,7 +855,9 @@ class Plane:
     def projectionpoints(self, pps):
         """
         Projects each points in the point list pps on plane and returns the list of projected points
-        :param pps: List of points to project on plane
+
+        Args:
+            pps: List of points to project on plane
 
         Returns:
             List of projected point on plane.
@@ -827,8 +865,7 @@ class Plane:
         return [pp - np.dot(pp - self.p1, self.normal_vector) * self.normal_vector for pp in pps]
 
     def orthonormal_vectors(self):
-        """
-        Returns a list of three orthogonal vectors, the two first being parallel to the plane and the
+        """Get a list of three orthogonal vectors, the two first being parallel to the plane and the
         third one is the normal vector of the plane
 
         Returns:
@@ -845,7 +882,9 @@ class Plane:
         """
         Projects each points in the point list pps on plane and returns the indices that would sort the
         list of projected points in anticlockwise order
-        :param pps: List of points to project on plane
+
+        Args:
+            pps: List of points to project on plane
 
         Returns:
             List of indices that would sort the list of projected points.
@@ -856,7 +895,9 @@ class Plane:
     def project_and_to2dim(self, pps, plane_center):
         """
         Projects the list of points pps to the plane and changes the basis from 3D to the 2D basis of the plane
-        :param pps: List of points to be projected
+
+        Args:
+            pps: List of points to be projected
 
         Returns:
             :raise:
@@ -867,7 +908,7 @@ class Plane:
         xypps = []
         for pp in proj:
             xyzpp = np.dot(pp, PP)
-            xypps.append(xyzpp[0:2])
+            xypps.append(xyzpp[:2])
         if str(plane_center) == "mean":
             mean = np.zeros(2, float)
             for pp in xypps:
@@ -876,15 +917,16 @@ class Plane:
             xypps = [pp - mean for pp in xypps]
         elif plane_center is not None:
             projected_plane_center = self.projectionpoints([plane_center])[0]
-            xy_projected_plane_center = np.dot(projected_plane_center, PP)[0:2]
+            xy_projected_plane_center = np.dot(projected_plane_center, PP)[:2]
             xypps = [pp - xy_projected_plane_center for pp in xypps]
         return xypps
 
     def fit_error(self, points, fit="least_square_distance"):
         """Evaluate the error for a list of points with respect to this plane.
 
-        :param points: List of points.
-        :param fit: Type of fit error.
+        Args:
+            points: List of points.
+            fit: Type of fit error.
 
         Returns:
             Error for a list of points with respect to this plane.
@@ -898,7 +940,8 @@ class Plane:
     def fit_least_square_distance_error(self, points):
         """Evaluate the sum of squared distances error for a list of points with respect to this plane.
 
-        :param points: List of points.
+        Args:
+            points: List of points.
 
         Returns:
             Sum of squared distances error for a list of points with respect to this plane.
@@ -908,7 +951,8 @@ class Plane:
     def fit_maximum_distance_error(self, points):
         """Evaluate the max distance error for a list of points with respect to this plane.
 
-        :param points: List of points.
+        Args:
+            points: List of points.
 
         Returns:
             Max distance error for a list of points with respect to this plane.
@@ -917,26 +961,13 @@ class Plane:
 
     @property
     def coefficients(self):
-        """Return a copy of the plane coefficients.
-
-        Returns:
-            Plane coefficients as a numpy array.
-        """
+        """A copy of the plane coefficients as a numpy array."""
         return np.copy(self._coefficients)
 
     @property
     def abcd(self):
-        """Return a tuple with the plane coefficients.
-
-        Returns:
-            Tuple with the plane coefficients.
-        """
-        return (
-            self._coefficients[0],
-            self._coefficients[1],
-            self._coefficients[2],
-            self._coefficients[3],
-        )
+        """A tuple with the plane coefficients."""
+        return tuple(self._coefficients[:4])
 
     @property
     def a(self):
@@ -969,11 +1000,12 @@ class Plane:
         return self._crosses_origin
 
     @classmethod
-    def from_2points_and_origin(cls, p1, p2):
-        """Initializes plane from two points and the origin.
+    def from_2points_and_origin(cls, p1, p2) -> Self:
+        """Initialize plane from two points and the origin.
 
-        :param p1: First point.
-        :param p2: Second point.
+        Args:
+            p1: First point.
+            p2: Second point.
 
         Returns:
             Plane.
@@ -981,12 +1013,13 @@ class Plane:
         return cls.from_3points(p1, p2, np.zeros(3))
 
     @classmethod
-    def from_3points(cls, p1, p2, p3):
-        """Initializes plane from three points.
+    def from_3points(cls, p1, p2, p3) -> Self:
+        """Initialize plane from three points.
 
-        :param p1: First point.
-        :param p2: Second point.
-        :param p3: Third point.
+        Args:
+            p1: First point.
+            p2: Second point.
+            p3: Third point.
 
         Returns:
             Plane.
@@ -1001,13 +1034,14 @@ class Plane:
         return cls(coefficients, p1=p1, p2=p2, p3=p3)
 
     @classmethod
-    def from_npoints(cls, points, best_fit="least_square_distance"):
-        """Initializes plane from a list of points.
+    def from_npoints(cls, points, best_fit="least_square_distance") -> Self:
+        """Initialize plane from a list of points.
 
         If the number of points is larger than 3, will use a least square fitting or max distance fitting.
 
-        :param points: List of points.
-        :param best_fit: Type of fitting procedure for more than 3 points.
+        Args:
+            points: List of points.
+            best_fit: Type of fitting procedure for more than 3 points.
 
         Returns:
             Plane
@@ -1020,13 +1054,15 @@ class Plane:
             return cls.from_npoints_least_square_distance(points)
         if best_fit == "maximum_distance":
             return cls.from_npoints_maximum_distance(points)
-        return None
+
+        raise ValueError("Cannot initialize Plane.")
 
     @classmethod
-    def from_npoints_least_square_distance(cls, points):
-        """Initializes plane from a list of points using a least square fitting procedure.
+    def from_npoints_least_square_distance(cls, points) -> Self:
+        """Initialize plane from a list of points using a least square fitting procedure.
 
-        :param points: List of points.
+        Args:
+            points: List of points.
 
         Returns:
             Plane.
@@ -1048,14 +1084,15 @@ class Plane:
         return cls(coefficients)
 
     @classmethod
-    def perpendicular_bisector(cls, p1, p2):
+    def perpendicular_bisector(cls, p1, p2) -> Self:
         """Initialize a plane from the perpendicular bisector of two points.
 
         The perpendicular bisector of two points is the plane perpendicular to the vector joining these two points
         and passing through the middle of the segment joining the two points.
 
-        :param p1: First point.
-        :param p2: Second point.
+        Args:
+            p1: First point.
+            p2: Second point.
 
         Returns:
             Plane.
@@ -1066,10 +1103,11 @@ class Plane:
         return cls(np.array([normal_vector[0], normal_vector[1], normal_vector[2], dd], float))
 
     @classmethod
-    def from_npoints_maximum_distance(cls, points):
-        """Initializes plane from a list of points using a max distance fitting procedure.
+    def from_npoints_maximum_distance(cls, points) -> Self:
+        """Initialize plane from a list of points using a max distance fitting procedure.
 
-        :param points: List of points.
+        Args:
+            points: List of points.
 
         Returns:
             Plane.
@@ -1077,8 +1115,8 @@ class Plane:
         convex_hull = ConvexHull(points)
         heights = []
         ipoints_heights = []
-        for isimplex, _simplex in enumerate(convex_hull.simplices):
-            cc = convex_hull.equations[isimplex]
+        for idx, _simplex in enumerate(convex_hull.simplices):
+            cc = convex_hull.equations[idx]
             plane = Plane.from_coefficients(cc[0], cc[1], cc[2], cc[3])
             distances = [plane.distance_to_point(pp) for pp in points]
             ipoint_height = np.argmax(distances)
@@ -1095,13 +1133,14 @@ class Plane:
         return cls(np.array([normal_vector[0], normal_vector[1], normal_vector[2], dd], float))
 
     @classmethod
-    def from_coefficients(cls, a, b, c, d):
+    def from_coefficients(cls, a, b, c, d) -> Self:
         """Initialize plane from its coefficients.
 
-        :param a: a coefficient of the plane.
-        :param b: b coefficient of the plane.
-        :param c: c coefficient of the plane.
-        :param d: d coefficient of the plane.
+        Args:
+            a: a coefficient of the plane.
+            b: b coefficient of the plane.
+            c: c coefficient of the plane.
+            d: d coefficient of the plane.
 
         Returns:
             Plane.
