@@ -2,12 +2,17 @@
 
 from __future__ import annotations
 
+import operator
 from functools import reduce
 from math import sqrt
+from typing import TYPE_CHECKING
 
 import numpy as np
 from scipy.special import erf
 
+if TYPE_CHECKING:
+    from numpy.typing import ArrayLike
+
 __author__ = "David Waroquiers"
 __copyright__ = "Copyright 2012, The Materials Project"
 __credits__ = "Geoffroy Hautier"
@@ -17,7 +22,7 @@ __email__ = "david.waroquiers@gmail.com"
 __date__ = "Feb 20, 2016"
 
 ##############################################################
-# Cartesian product of lists ##################################
+# Cartesian product of lists #################################
 ##############################################################
 
 
@@ -43,8 +48,12 @@ def _cartesian_product(lists):
 
 def prime_factors(n: int) -> list[int]:
     """Lists prime factors of a given natural integer, from greatest to smallest
-    :param n: Natural integer
-    :rtype : list of all prime factors of the given natural n.
+
+    Args:
+        n: Natural integer
+
+    Returns:
+        list of all prime factors of the given natural n.
     """
     idx = 2
     while idx <= sqrt(n):
@@ -56,13 +65,14 @@ def prime_factors(n: int) -> list[int]:
     return [n]  # n is prime
 
 
-def _factor_generator(n):
-    """
-    From a given natural integer, returns the prime factors and their multiplicity
-    :param n: Natural integer
+def _factor_generator(n: int) -> dict[int, int]:
+    """From a given natural integer, returns the prime factors and their multiplicity
+
+    Args:
+        n: Natural integer
     """
     p = prime_factors(n)
-    factors = {}
+    factors: dict[int, int] = {}
     for p1 in p:
         try:
             factors[p1] += 1
@@ -72,9 +82,10 @@ def _factor_generator(n):
 
 
 def divisors(n):
-    """
-    From a given natural integer, returns the list of divisors in ascending order
-    :param n: Natural integer
+    """From a given natural integer, returns the list of divisors in ascending order
+
+    Args:
+        n: Natural integer
 
     Returns:
         List of divisors of n in ascending order.
@@ -83,17 +94,18 @@ def divisors(n):
     _divisors = []
     exponents = [[k**x for x in range(factors[k] + 1)] for k in list(factors)]
     factors = _cartesian_product(exponents)
-    for f in factors:
-        _divisors.append(reduce(lambda x, y: x * y, f, 1))
+    for factor in factors:
+        _divisors.append(reduce(operator.mul, factor, 1))
     _divisors.sort()
     return _divisors
 
 
 def get_center_of_arc(p1, p2, radius):
     """
-    :param p1:
-    :param p2:
-    :param radius:
+    Args:
+        p1:
+        p2:
+        radius:
     """
     dx = p2[0] - p1[0]
     dy = p2[1] - p1[1]
@@ -107,35 +119,37 @@ def get_center_of_arc(p1, p2, radius):
     return (p1[0] + p2[0]) / 2 - tt * dy, (p1[1] + p2[1]) / 2 + tt * dx
 
 
-def get_linearly_independent_vectors(vectors_list):
+def get_linearly_independent_vectors(vectors: list[ArrayLike]) -> list[np.ndarray]:
     """
-    :param vectors_list:
+    Args:
+        vectors (list[ArrayLike]): List of vectors
     """
-    independent_vectors_list = []
-    for vector in vectors_list:
+    independent_vectors: list[np.ndarray] = []
+    for vector in vectors:
         if np.any(vector != 0):
-            if len(independent_vectors_list) == 0:
-                independent_vectors_list.append(np.array(vector))
-            elif len(independent_vectors_list) == 1:
-                rank = np.linalg.matrix_rank(np.array([independent_vectors_list[0], vector, [0, 0, 0]]))
+            if len(independent_vectors) == 0:
+                independent_vectors.append(np.array(vector))
+            elif len(independent_vectors) == 1:
+                rank = np.linalg.matrix_rank(np.array([independent_vectors[0], vector, [0, 0, 0]]))
                 if rank == 2:
-                    independent_vectors_list.append(np.array(vector))
-            elif len(independent_vectors_list) == 2:
-                mm = np.array([independent_vectors_list[0], independent_vectors_list[1], vector])
+                    independent_vectors.append(np.array(vector))
+            elif len(independent_vectors) == 2:
+                mm = np.array([independent_vectors[0], independent_vectors[1], vector])
                 if np.linalg.det(mm) != 0:
-                    independent_vectors_list.append(np.array(vector))
-        if len(independent_vectors_list) == 3:
+                    independent_vectors.append(np.array(vector))
+        if len(independent_vectors) == 3:
             break
-    return independent_vectors_list
+    return independent_vectors
 
 
 def scale_and_clamp(xx, edge0, edge1, clamp0, clamp1):
     """
-    :param xx:
-    :param edge0:
-    :param edge1:
-    :param clamp0:
-    :param clamp1:
+    Args:
+        xx:
+        edge0:
+        edge1:
+        clamp0:
+        clamp1:
     """
     return np.clip((xx - edge0) / (edge1 - edge0), clamp0, clamp1)
 
@@ -143,9 +157,10 @@ def scale_and_clamp(xx, edge0, edge1, clamp0, clamp1):
 # Step function based on the cumulative distribution function of the normal law
 def normal_cdf_step(xx, mean, scale):
     """
-    :param xx:
-    :param mean:
-    :param scale:
+    Args:
+        xx:
+        mean:
+        scale:
     """
     return 0.5 * (1.0 + erf((xx - mean) / (np.sqrt(2.0) * scale)))
 
@@ -159,9 +174,10 @@ def normal_cdf_step(xx, mean, scale):
 
 def smoothstep(xx, edges=None, inverse=False):
     """
-    :param xx:
-    :param edges:
-    :param inverse:
+    Args:
+        xx:
+        edges:
+        inverse:
     """
     if edges is None:
         xx_clipped = np.clip(xx, 0.0, 1.0)
@@ -174,9 +190,10 @@ def smoothstep(xx, edges=None, inverse=False):
 
 def smootherstep(xx, edges=None, inverse=False):
     """
-    :param xx:
-    :param edges:
-    :param inverse:
+    Args:
+        xx:
+        edges:
+        inverse:
     """
     if edges is None:
         xx_clipped = np.clip(xx, 0.0, 1.0)
@@ -189,9 +206,10 @@ def smootherstep(xx, edges=None, inverse=False):
 
 def cosinus_step(xx, edges=None, inverse=False):
     """
-    :param xx:
-    :param edges:
-    :param inverse:
+    Args:
+        xx:
+        edges:
+        inverse:
     """
     if edges is None:
         xx_clipped = np.clip(xx, 0.0, 1.0)
@@ -204,19 +222,21 @@ def cosinus_step(xx, edges=None, inverse=False):
 
 def power3_step(xx, edges=None, inverse=False):
     """
-    :param xx:
-    :param edges:
-    :param inverse:
+    Args:
+        xx:
+        edges:
+        inverse:
     """
     return smoothstep(xx, edges=edges, inverse=inverse)
 
 
 def powern_parts_step(xx, edges=None, inverse=False, nn=2):
     """
-    :param xx:
-    :param edges:
-    :param inverse:
-    :param nn:
+    Args:
+        xx:
+        edges:
+        inverse:
+        nn:
     """
     if edges is None:
         aa = np.power(0.5, 1.0 - nn)
@@ -255,9 +275,10 @@ def powern_parts_step(xx, edges=None, inverse=False, nn=2):
 
 def powern_decreasing(xx, edges=None, nn=2):
     """
-    :param xx:
-    :param edges:
-    :param nn:
+    Args:
+        xx:
+        edges:
+        nn:
     """
     if edges is None:
         aa = 1.0 / np.power(-1.0, nn)
@@ -268,9 +289,10 @@ def powern_decreasing(xx, edges=None, nn=2):
 
 def power2_decreasing_exp(xx, edges=None, alpha=1.0):
     """
-    :param xx:
-    :param edges:
-    :param alpha:
+    Args:
+        xx:
+        edges:
+        alpha:
     """
     if edges is None:
         aa = 1.0 / np.power(-1.0, 2)
@@ -286,9 +308,10 @@ def power2_decreasing_exp(xx, edges=None, alpha=1.0):
 
 def power2_tangent_decreasing(xx, edges=None, prefactor=None):
     """
-    :param xx:
-    :param edges:
-    :param prefactor:
+    Args:
+        xx:
+        edges:
+        prefactor:
     """
     if edges is None:
         aa = 1.0 / np.power(-1.0, 2) if prefactor is None else prefactor
@@ -300,9 +323,10 @@ def power2_tangent_decreasing(xx, edges=None, prefactor=None):
 
 def power2_inverse_decreasing(xx, edges=None, prefactor=None):
     """
-    :param xx:
-    :param edges:
-    :param prefactor:
+    Args:
+        xx:
+        edges:
+        prefactor:
     """
     if edges is None:
         aa = 1.0 / np.power(-1.0, 2) if prefactor is None else prefactor
@@ -314,9 +338,10 @@ def power2_inverse_decreasing(xx, edges=None, prefactor=None):
 
 def power2_inverse_power2_decreasing(xx, edges=None, prefactor=None):
     """
-    :param xx:
-    :param edges:
-    :param prefactor:
+    Args:
+        xx:
+        edges:
+        prefactor:
     """
     if edges is None:
         aa = 1.0 / np.power(-1.0, 2) if prefactor is None else prefactor
@@ -331,10 +356,11 @@ def power2_inverse_power2_decreasing(xx, edges=None, prefactor=None):
 
 def power2_inverse_powern_decreasing(xx, edges=None, prefactor=None, powern=2.0):
     """
-    :param xx:
-    :param edges:
-    :param prefactor:
-    :param powern:
+    Args:
+        xx:
+        edges:
+        prefactor:
+        powern:
     """
     if edges is None:
         aa = 1.0 / np.power(-1.0, 2) if prefactor is None else prefactor
