@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 import abc
-import collections
+from collections import defaultdict
 from typing import TYPE_CHECKING
 
 import matplotlib.pyplot as plt
@@ -68,8 +68,9 @@ class AbstractDiffractionPatternCalculator(abc.ABC):
                 sphere of radius 2 / wavelength.
 
         Returns:
-            (DiffractionPattern)
+            DiffractionPattern
         """
+        raise NotImplementedError
 
     def get_plot(
         self,
@@ -80,8 +81,7 @@ class AbstractDiffractionPatternCalculator(abc.ABC):
         with_labels=True,
         fontsize=16,
     ) -> plt.Axes:
-        """
-        Returns the diffraction plot as a matplotlib Axes.
+        """Get the diffraction plot as a matplotlib Axes.
 
         Args:
             structure: Input structure
@@ -153,8 +153,7 @@ class AbstractDiffractionPatternCalculator(abc.ABC):
         return ax
 
     def show_plot(self, structure: Structure, **kwargs):
-        """
-        Shows the diffraction plot.
+        """Show the diffraction plot.
 
         Args:
             structure (Structure): Input structure
@@ -187,11 +186,11 @@ class AbstractDiffractionPatternCalculator(abc.ABC):
             fontsize: (int) fontsize for peak labels.
         """
 
-        nrows = len(structures)
-        fig, axes = plt.subplots(nrows=nrows, ncols=1, sharex=True, squeeze=False)
+        n_rows = len(structures)
+        fig, axes = plt.subplots(nrows=n_rows, ncols=1, sharex=True, squeeze=False)
 
         for i, (ax, structure) in enumerate(zip(axes.ravel(), structures)):
-            self.get_plot(structure, fontsize=fontsize, ax=ax, with_labels=i == nrows - 1, **kwargs)
+            self.get_plot(structure, fontsize=fontsize, ax=ax, with_labels=i == n_rows - 1, **kwargs)
             spg_symbol, spg_number = structure.get_space_group_info()
             ax.set_title(f"{structure.formula} {spg_symbol} ({spg_number}) ")
 
@@ -199,8 +198,7 @@ class AbstractDiffractionPatternCalculator(abc.ABC):
 
 
 def get_unique_families(hkls):
-    """
-    Returns unique families of Miller indices. Families must be permutations
+    """Get unique families of Miller indices. Families must be permutations
     of each other.
 
     Args:
@@ -214,9 +212,9 @@ def get_unique_families(hkls):
     def is_perm(hkl1, hkl2) -> bool:
         h1 = np.abs(hkl1)
         h2 = np.abs(hkl2)
-        return all(i == j for i, j in zip(sorted(h1), sorted(h2)))
+        return np.all(np.sort(h1) == np.sort(h2))
 
-    unique = collections.defaultdict(list)
+    unique = defaultdict(list)
     for hkl1 in hkls:
         found = False
         for hkl2, v2 in unique.items():
@@ -228,7 +226,7 @@ def get_unique_families(hkls):
             unique[hkl1].append(hkl1)
 
     pretty_unique = {}
-    for v in unique.values():
-        pretty_unique[sorted(v)[-1]] = len(v)
+    for val in unique.values():
+        pretty_unique[max(val)] = len(val)
 
     return pretty_unique
