@@ -1,12 +1,11 @@
-"""This module implements a TEM pattern calculator."""
+"""TEM pattern calculator."""
 
 from __future__ import annotations
 
 import json
 import os
-from collections import namedtuple
 from fractions import Fraction
-from typing import TYPE_CHECKING, cast
+from typing import TYPE_CHECKING, NamedTuple, cast
 
 import numpy as np
 import pandas as pd
@@ -16,8 +15,11 @@ import scipy.constants as sc
 from pymatgen.analysis.diffraction.core import AbstractDiffractionPatternCalculator
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.util.string import latexify_spacegroup, unicodeify_spacegroup
+from pymatgen.util.typing import Tuple3Ints
 
 if TYPE_CHECKING:
+    from numpy.typing import NDArray
+
     from pymatgen.core import Structure
 
 __author__ = "Frank Wan, Jason Liang"
@@ -29,13 +31,13 @@ __date__ = "03/31/2020"
 
 
 module_dir = os.path.dirname(__file__)
-with open(f"{module_dir}/atomic_scattering_params.json") as file:
+with open(f"{module_dir}/atomic_scattering_params.json", encoding="utf-8") as file:
     ATOMIC_SCATTERING_PARAMS = json.load(file)
 
 
 class TEMCalculator(AbstractDiffractionPatternCalculator):
     """
-    Computes the TEM pattern of a crystal structure for multiple Laue zones.
+    Compute the TEM pattern of a crystal structure for multiple Laue zones.
     Code partially inspired from XRD calculation implementation. X-ray factor to electron factor
         conversion based on the International Table of Crystallography.
     #TODO: Could add "number of iterations", "magnification", "critical value of beam",
@@ -46,7 +48,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         self,
         symprec: float | None = None,
         voltage: float = 200,
-        beam_direction: tuple[int, int, int] = (0, 0, 1),
+        beam_direction: Tuple3Ints = (0, 0, 1),
         camera_length: int = 160,
         debye_waller_factors: dict[str, float] | None = None,
         cs: float = 1,
@@ -88,8 +90,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
 
     @staticmethod
     def generate_points(coord_left: int = -10, coord_right: int = 10) -> np.ndarray:
-        """
-        Generates a bunch of 3D points that span a cube.
+        """Generate a bunch of 3D points that span a cube.
 
         Args:
             coord_left (int): The minimum coordinate value.
@@ -104,11 +105,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         points_matrix = (np.ravel(points[i]) for i in range(3))
         return np.vstack(list(points_matrix)).transpose()
 
-    def zone_axis_filter(
-        self, points: list[tuple[int, int, int]] | np.ndarray, laue_zone: int = 0
-    ) -> list[tuple[int, int, int]]:
-        """
-        Filters out all points that exist within the specified Laue zone according to the zone axis rule.
+    def zone_axis_filter(self, points: list[Tuple3Ints] | np.ndarray, laue_zone: int = 0) -> list[Tuple3Ints]:
+        """Filter out all points that exist within the specified Laue zone according to the zone axis rule.
 
         Args:
             points (np.ndarray): The list of points to be filtered.
@@ -123,18 +121,19 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
             return []
         filtered = np.where(np.dot(np.array(self.beam_direction), np.transpose(points)) == laue_zone)
         result = points[filtered]  # type: ignore
-        return cast(list[tuple[int, int, int]], [tuple(x) for x in result.tolist()])
+        return cast(list[Tuple3Ints], [tuple(x) for x in result.tolist()])
 
     def get_interplanar_spacings(
-        self, structure: Structure, points: list[tuple[int, int, int]] | np.ndarray
-    ) -> dict[tuple[int, int, int], float]:
+        self, structure: Structure, points: list[Tuple3Ints] | np.ndarray
+    ) -> dict[Tuple3Ints, float]:
         """
         Args:
             structure (Structure): the input structure.
             points (tuple): the desired hkl indices.
 
         Returns:
-            Dict of hkl to its interplanar spacing, in angstroms (float).
+            dict[tuple[int, int, int], float]: hkl planes mapped to
+                interplanar spacings, in angstroms (float).
         """
         points_filtered = self.zone_axis_filter(points)
         if (0, 0, 0) in points_filtered:
@@ -142,24 +141,21 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         interplanar_spacings_val = np.array([structure.lattice.d_hkl(x) for x in points_filtered])
         return dict(zip(points_filtered, interplanar_spacings_val))
 
-    def bragg_angles(
-        self, interplanar_spacings: dict[tuple[int, int, int], float]
-    ) -> dict[tuple[int, int, int], float]:
-        """
-        Gets the Bragg angles for every hkl point passed in (where n = 1).
+    def bragg_angles(self, interplanar_spacings: dict[Tuple3Ints, float]) -> dict[Tuple3Ints, float]:
+        """Get the Bragg angles for every hkl point passed in (where n = 1).
 
         Args:
             interplanar_spacings (dict): dictionary of hkl to interplanar spacing
 
         Returns:
-            dict of hkl plane (3-tuple) to Bragg angle in radians (float)
+            dict[tuple[int, int, int], float]: hkl planes mapped to Bragg angles [radians]
         """
         plane = list(interplanar_spacings)
         interplanar_spacings_val = np.array(list(interplanar_spacings.values()))
         bragg_angles_val = np.arcsin(self.wavelength_rel() / (2 * interplanar_spacings_val))
         return dict(zip(plane, bragg_angles_val))
 
-    def get_s2(self, bragg_angles: dict[tuple[int, int, int], float]) -> dict[tuple[int, int, int], float]:
+    def get_s2(self, bragg_angles: dict[Tuple3Ints, float]) -> dict[Tuple3Ints, float]:
         """
         Calculates the s squared parameter (= square of sin theta over lambda) for each hkl plane.
 
@@ -176,8 +172,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return dict(zip(plane, s2_val))
 
     def x_ray_factors(
-        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
-    ) -> dict[str, dict[tuple[int, int, int], float]]:
+        self, structure: Structure, bragg_angles: dict[Tuple3Ints, float]
+    ) -> dict[str, dict[Tuple3Ints, float]]:
         """
         Calculates x-ray factors, which are required to calculate atomic scattering factors. Method partially inspired
         by the equivalent process in the xrd module.
@@ -206,8 +202,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return x_ray_factors
 
     def electron_scattering_factors(
-        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
-    ) -> dict[str, dict[tuple[int, int, int], float]]:
+        self, structure: Structure, bragg_angles: dict[Tuple3Ints, float]
+    ) -> dict[str, dict[Tuple3Ints, float]]:
         """
         Calculates atomic scattering factors for electrons using the Mott-Bethe formula (1st order Born approximation).
 
@@ -233,8 +229,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return electron_scattering_factors
 
     def cell_scattering_factors(
-        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
-    ) -> dict[tuple[int, int, int], int]:
+        self, structure: Structure, bragg_angles: dict[Tuple3Ints, float]
+    ) -> dict[Tuple3Ints, int]:
         """
         Calculates the scattering factor for the whole cell.
 
@@ -259,9 +255,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
             scattering_factor_curr = 0
         return cell_scattering_factors
 
-    def cell_intensity(
-        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
-    ) -> dict[tuple[int, int, int], float]:
+    def cell_intensity(self, structure: Structure, bragg_angles: dict[Tuple3Ints, float]) -> dict[Tuple3Ints, float]:
         """
         Calculates cell intensity for each hkl plane. For simplicity's sake, take I = |F|**2.
 
@@ -283,8 +277,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         scaled: bool | None = None,
         two_theta_range: tuple[float, float] | None = None,
     ) -> pd.DataFrame:
-        """
-        Returns all relevant TEM DP info in a pandas dataframe.
+        """Get all relevant TEM DP info in a pandas dataframe.
 
         Args:
             structure (Structure): The input structure.
@@ -306,7 +299,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
             "Film radius",
             "Interplanar Spacing",
         ]
-        rows_list = []
+        rows = []
         for dot in tem_dots:
             dict1 = {
                 "Position": dot.position,
@@ -315,12 +308,12 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
                 "Film radius": dot.film_radius,
                 "Interplanar Spacing": dot.d_spacing,
             }
-            rows_list.append(dict1)
-        return pd.DataFrame(rows_list, columns=field_names)
+            rows.append(dict1)
+        return pd.DataFrame(rows, columns=field_names)
 
     def normalized_cell_intensity(
-        self, structure: Structure, bragg_angles: dict[tuple[int, int, int], float]
-    ) -> dict[tuple[int, int, int], float]:
+        self, structure: Structure, bragg_angles: dict[Tuple3Ints, float]
+    ) -> dict[Tuple3Ints, float]:
         """
         Normalizes the cell_intensity dict to 1, for use in plotting.
 
@@ -342,8 +335,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
     def is_parallel(
         self,
         structure: Structure,
-        plane: tuple[int, int, int],
-        other_plane: tuple[int, int, int],
+        plane: Tuple3Ints,
+        other_plane: Tuple3Ints,
     ) -> bool:
         """
         Checks if two hkl planes are parallel in reciprocal space.
@@ -359,9 +352,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         phi = self.get_interplanar_angle(structure, plane, other_plane)
         return phi in (180, 0) or np.isnan(phi)
 
-    def get_first_point(self, structure: Structure, points: list) -> dict[tuple[int, int, int], float]:
-        """
-        Gets the first point to be plotted in the 2D DP, corresponding to maximum d/minimum R.
+    def get_first_point(self, structure: Structure, points: list) -> dict[Tuple3Ints, float]:
+        """Get the first point to be plotted in the 2D DP, corresponding to maximum d/minimum R.
 
         Args:
             structure (Structure): The input structure.
@@ -381,9 +373,8 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return {max_d_plane: max_d}
 
     @staticmethod
-    def get_interplanar_angle(structure: Structure, p1: tuple[int, int, int], p2: tuple[int, int, int]) -> float:
-        """
-        Returns the interplanar angle (in degrees) between the normal of two crystal planes.
+    def get_interplanar_angle(structure: Structure, p1: Tuple3Ints, p2: Tuple3Ints) -> float:
+        """Get the interplanar angle (in degrees) between the normal of two crystal planes.
         Formulas from International Tables for Crystallography Volume C pp. 2-9.
 
         Args:
@@ -436,9 +427,9 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
 
     @staticmethod
     def get_plot_coeffs(
-        p1: tuple[int, int, int],
-        p2: tuple[int, int, int],
-        p3: tuple[int, int, int],
+        p1: Tuple3Ints,
+        p2: Tuple3Ints,
+        p3: Tuple3Ints,
     ) -> np.ndarray:
         """
         Calculates coefficients of the vector addition required to generate positions for each DP point
@@ -458,7 +449,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         x = np.dot(a_pinv, b)
         return np.ravel(x)
 
-    def get_positions(self, structure: Structure, points: list) -> dict[tuple[int, int, int], np.ndarray]:
+    def get_positions(self, structure: Structure, points: list) -> dict[Tuple3Ints, np.ndarray]:
         """
         Calculates all the positions of each hkl point in the 2D diffraction pattern by vector addition.
         Distance in centimeters.
@@ -474,12 +465,16 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         points = self.zone_axis_filter(points)
         # first is the max_d, min_r
         first_point_dict = self.get_first_point(structure, points)
+        first_point = (0, 0, 0)
+        first_d = 0.0
         for point, v in first_point_dict.items():
             first_point = point
             first_d = v
         spacings = self.get_interplanar_spacings(structure, points)
         # second is the first non-parallel-to-first-point vector when sorted.
         # note 000 is "parallel" to every plane vector.
+        second_point = (0, 0, 0)
+        second_d = 0.0
         for plane in sorted(spacings):
             second_point, second_d = plane, spacings[plane]
             if not self.is_parallel(structure, first_point, second_point):
@@ -512,8 +507,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return positions
 
     def tem_dots(self, structure: Structure, points) -> list:
-        """
-        Generates all TEM_dot as named tuples that will appear on the 2D diffraction pattern.
+        """Generate all TEM_dot as named tuples that will appear on the 2D diffraction pattern.
 
         Args:
             structure (Structure): The input structure.
@@ -522,13 +516,20 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         Returns:
             list of TEM_dots
         """
+
+        class dot(NamedTuple):
+            position: NDArray
+            hkl: Tuple3Ints
+            intensity: float
+            film_radius: float
+            d_spacing: float
+
         dots = []
         interplanar_spacings = self.get_interplanar_spacings(structure, points)
         bragg_angles = self.bragg_angles(interplanar_spacings)
         cell_intensity = self.normalized_cell_intensity(structure, bragg_angles)
         positions = self.get_positions(structure, points)
         for hkl, intensity in cell_intensity.items():
-            dot = namedtuple("dot", ["position", "hkl", "intensity", "film_radius", "d_spacing"])
             position = positions[hkl]
             film_radius = 0.91 * (10**-3 * self.cs * self.wavelength_rel() ** 3) ** Fraction("1/4")
             d_spacing = interplanar_spacings[hkl]
@@ -537,8 +538,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return dots
 
     def get_plot_2d(self, structure: Structure) -> go.Figure:
-        """
-        Generates the 2D diffraction pattern of the input structure.
+        """Generate the 2D diffraction pattern of the input structure.
 
         Args:
             structure (Structure): The input structure.
@@ -588,7 +588,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
             ),
         ]
         layout = dict(
-            title="2D Diffraction Pattern<br>Beam Direction: " + "".join(str(e) for e in self.beam_direction),
+            title="2D Diffraction Pattern<br>Beam Direction: " + "".join(map(str, self.beam_direction)),
             font={"size": 14, "color": "#7f7f7f"},
             hovermode="closest",
             xaxis={
@@ -615,8 +615,7 @@ class TEMCalculator(AbstractDiffractionPatternCalculator):
         return go.Figure(data=data, layout=layout)
 
     def get_plot_2d_concise(self, structure: Structure) -> go.Figure:
-        """
-        Generates the concise 2D diffraction pattern of the input structure of a smaller size and without layout.
+        """Generate the concise 2D diffraction pattern of the input structure of a smaller size and without layout.
         Does not display.
 
         Args:
