@@ -9,7 +9,7 @@ from __future__ import annotations
 import itertools
 import math
 import warnings
-from typing import TYPE_CHECKING, Literal
+from typing import TYPE_CHECKING
 
 import numpy as np
 import sympy as sp
@@ -25,8 +25,10 @@ from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
+    from typing import Literal
 
     from numpy.typing import ArrayLike
+    from typing_extensions import Self
 
     from pymatgen.core import Structure
 
@@ -50,7 +52,7 @@ class NthOrderElasticTensor(Tensor):
     GPa_to_eV_A3 = Unit("GPa").get_conversion_factor(Unit("eV ang^-3"))
     symbol = "C"
 
-    def __new__(cls, input_array, check_rank=None, tol: float = 1e-4):
+    def __new__(cls, input_array, check_rank=None, tol: float = 1e-4) -> Self:
         """
         Args:
             input_array ():
@@ -85,14 +87,14 @@ class NthOrderElasticTensor(Tensor):
         return Stress(stress_matrix)
 
     def energy_density(self, strain, convert_GPa_to_eV=True):
-        """Calculates the elastic energy density due to a strain."""
+        """Calculate the elastic energy density due to a strain."""
         e_density = np.sum(self.calculate_stress(strain) * strain) / self.order
         if convert_GPa_to_eV:
             e_density *= self.GPa_to_eV_A3  # Conversion factor for GPa to eV/A^3
         return e_density
 
     @classmethod
-    def from_diff_fit(cls, strains, stresses, eq_stress=None, order=2, tol: float = 1e-10):
+    def from_diff_fit(cls, strains, stresses, eq_stress=None, order=2, tol: float = 1e-10) -> Self:
         """
         Takes a list of strains and stresses, and returns a list of coefficients for a
         polynomial fit of the given order.
@@ -128,11 +130,11 @@ class ElasticTensor(NthOrderElasticTensor):
     """
     This class extends Tensor to describe the 3x3x3x3 second-order elastic tensor,
     C_{ijkl}, with various methods for estimating other properties derived from the second
-    order elastic tensor (e. g. bulk modulus, shear modulus, Young's modulus, Poisson's ratio)
+    order elastic tensor (e.g. bulk modulus, shear modulus, Young's modulus, Poisson's ratio)
     in units of eV/A^3.
     """
 
-    def __new__(cls, input_array, tol: float = 1e-4):
+    def __new__(cls, input_array, tol: float = 1e-4) -> Self:
         """
         Create an ElasticTensor object. The constructor throws an error if the shape of
         the input_matrix argument is not 3x3x3x3, i. e. in true tensor notation. Issues a
@@ -150,8 +152,7 @@ class ElasticTensor(NthOrderElasticTensor):
 
     @property
     def compliance_tensor(self):
-        """
-        Returns the Voigt notation compliance tensor, which is the matrix
+        """The Voigt notation compliance tensor, which is the matrix
         inverse of the Voigt notation elastic tensor.
         """
         s_voigt = np.linalg.inv(self.voigt)
@@ -159,24 +160,24 @@ class ElasticTensor(NthOrderElasticTensor):
 
     @property
     def k_voigt(self) -> float:
-        """Returns the K_v bulk modulus (in eV/A^3)."""
+        """The K_v bulk modulus (in eV/A^3)."""
         return self.voigt[:3, :3].mean()
 
     @property
     def g_voigt(self) -> float:
-        """Returns the G_v shear modulus (in eV/A^3)."""
+        """The G_v shear modulus (in eV/A^3)."""
         return (
             2 * self.voigt[:3, :3].trace() - np.triu(self.voigt[:3, :3]).sum() + 3 * self.voigt[3:, 3:].trace()
         ) / 15.0
 
     @property
     def k_reuss(self) -> float:
-        """Returns the K_r bulk modulus (in eV/A^3)."""
+        """The K_r bulk modulus (in eV/A^3)."""
         return 1 / self.compliance_tensor.voigt[:3, :3].sum()
 
     @property
     def g_reuss(self) -> float:
-        """Returns the G_r shear modulus (in eV/A^3)."""
+        """The G_r shear modulus (in eV/A^3)."""
         return 15 / (
             8 * self.compliance_tensor.voigt[:3, :3].trace()
             - 4 * np.triu(self.compliance_tensor.voigt[:3, :3]).sum()
@@ -185,12 +186,12 @@ class ElasticTensor(NthOrderElasticTensor):
 
     @property
     def k_vrh(self) -> float:
-        """Returns the K_vrh (Voigt-Reuss-Hill) average bulk modulus (in eV/A^3)."""
+        """The K_vrh (Voigt-Reuss-Hill) average bulk modulus (in eV/A^3)."""
         return 0.5 * (self.k_voigt + self.k_reuss)
 
     @property
     def g_vrh(self) -> float:
-        """Returns the G_vrh (Voigt-Reuss-Hill) average shear modulus (in eV/A^3)."""
+        """The G_vrh (Voigt-Reuss-Hill) average shear modulus (in eV/A^3)."""
         return 0.5 * (self.g_voigt + self.g_reuss)
 
     @property
@@ -219,7 +220,7 @@ class ElasticTensor(NthOrderElasticTensor):
         return v
 
     def directional_elastic_mod(self, n) -> float:
-        """Calculates directional elastic modulus for a specific vector."""
+        """Calculate directional elastic modulus for a specific vector."""
         n = get_uvec(n)
         return self.einsum_sequence([n] * 4)
 
@@ -264,7 +265,7 @@ class ElasticTensor(NthOrderElasticTensor):
 
     @raise_if_unphysical
     def snyder_ac(self, structure: Structure) -> float:
-        """Calculates Snyder's acoustic sound velocity.
+        """Calculate Snyder's acoustic sound velocity.
 
         Args:
             structure: pymatgen structure object
@@ -275,7 +276,7 @@ class ElasticTensor(NthOrderElasticTensor):
         n_sites = len(structure)
         n_atoms = structure.composition.num_atoms
         site_density = 1e30 * n_sites / structure.volume
-        tot_mass = sum(e.atomic_mass for e in structure.species)
+        tot_mass = sum(spec.atomic_mass for spec in structure.species)
         avg_mass = 1.6605e-27 * tot_mass / n_atoms
         return (
             0.38483
@@ -320,7 +321,7 @@ class ElasticTensor(NthOrderElasticTensor):
 
     @raise_if_unphysical
     def clarke_thermalcond(self, structure: Structure) -> float:
-        """Calculates Clarke's thermal conductivity.
+        """Calculate Clarke's thermal conductivity.
 
         Args:
             structure: pymatgen structure object
@@ -329,7 +330,7 @@ class ElasticTensor(NthOrderElasticTensor):
             float: Clarke's thermal conductivity (in SI units)
         """
         n_sites = len(structure)
-        tot_mass = sum(e.atomic_mass for e in structure.species)
+        tot_mass = sum(spec.atomic_mass for spec in structure.species)
         n_atoms = structure.composition.num_atoms
         weight = float(structure.composition.weight)
         avg_mass = 1.6605e-27 * tot_mass / n_atoms
@@ -356,7 +357,7 @@ class ElasticTensor(NthOrderElasticTensor):
     )
     @raise_if_unphysical
     def agne_diffusive_thermalcond(self, structure: Structure) -> float:
-        """Calculates Agne's diffusive thermal conductivity.
+        """Calculate Agne's diffusive thermal conductivity.
 
         Please cite the original authors if using this method
         M. T. Agne, R. Hanus, G. J. Snyder, Energy Environ. Sci. 2018, 11, 609-616.
@@ -379,8 +380,7 @@ class ElasticTensor(NthOrderElasticTensor):
 
     @raise_if_unphysical
     def debye_temperature(self, structure: Structure) -> float:
-        """
-        Estimates the Debye temperature from longitudinal and transverse sound velocities.
+        """Estimate the Debye temperature from longitudinal and transverse sound velocities.
 
         Args:
             structure: pymatgen structure object
@@ -395,21 +395,21 @@ class ElasticTensor(NthOrderElasticTensor):
 
     @property
     def universal_anisotropy(self) -> float:
-        """Returns the universal anisotropy value."""
+        """The universal anisotropy value."""
         return 5 * self.g_voigt / self.g_reuss + self.k_voigt / self.k_reuss - 6.0
 
     @property
     def homogeneous_poisson(self) -> float:
-        """Returns the homogeneous poisson ratio."""
+        """The homogeneous poisson ratio."""
         return (1 - 2 / 3 * self.g_vrh / self.k_vrh) / (2 + 2 / 3 * self.g_vrh / self.k_vrh)
 
     def green_kristoffel(self, u) -> float:
-        """Returns the Green-Kristoffel tensor for a second-order tensor."""
+        """Get the Green-Kristoffel tensor for a second-order tensor."""
         return self.einsum_sequence([u, u], "ijkl,i,l")
 
     @property
     def property_dict(self):
-        """Returns a dictionary of properties derived from the elastic tensor."""
+        """A dictionary of properties derived from the elastic tensor."""
         props = (
             "k_voigt",
             "k_reuss",
@@ -426,8 +426,7 @@ class ElasticTensor(NthOrderElasticTensor):
     def get_structure_property_dict(
         self, structure: Structure, include_base_props: bool = True, ignore_errors: bool = False
     ) -> dict[str, float | Structure | None]:
-        """
-        Returns a dictionary of properties derived from the elastic tensor
+        """Get a dictionary of properties derived from the elastic tensor
         and an associated structure.
 
         Args:
@@ -450,7 +449,7 @@ class ElasticTensor(NthOrderElasticTensor):
         )
         sp_dict: dict[str, float | Structure | None]
         if ignore_errors and (self.k_vrh < 0 or self.g_vrh < 0):
-            sp_dict = {prop: None for prop in s_props}
+            sp_dict = dict.fromkeys(s_props)
         else:
             sp_dict = {prop: getattr(self, prop)(structure) for prop in s_props}
         sp_dict["structure"] = structure
@@ -459,7 +458,7 @@ class ElasticTensor(NthOrderElasticTensor):
         return sp_dict
 
     @classmethod
-    def from_pseudoinverse(cls, strains, stresses):
+    def from_pseudoinverse(cls, strains, stresses) -> Self:
         """
         Class method to fit an elastic tensor from stress/strain
         data. Method uses Moore-Penrose pseudo-inverse to invert
@@ -483,7 +482,7 @@ class ElasticTensor(NthOrderElasticTensor):
         return cls.from_voigt(voigt_fit)
 
     @classmethod
-    def from_independent_strains(cls, strains, stresses, eq_stress=None, vasp=False, tol: float = 1e-10):
+    def from_independent_strains(cls, strains, stresses, eq_stress=None, vasp=False, tol: float = 1e-10) -> Self:
         """
         Constructs the elastic tensor least-squares fit of independent strains
 
@@ -522,7 +521,7 @@ class ComplianceTensor(Tensor):
     since the compliance tensor has a unique vscale.
     """
 
-    def __new__(cls, s_array):
+    def __new__(cls, s_array) -> Self:
         """
         Args:
             s_array ():
@@ -540,7 +539,7 @@ class ElasticTensorExpansion(TensorCollection):
     to an elastic tensor expansion, which can be used to
     calculate stress and energy density and inherits all
     of the list-based properties of TensorCollection
-    (e. g. symmetrization, voigt conversion, etc.).
+    (e.g. symmetrization, voigt conversion, etc.).
     """
 
     def __init__(self, c_list: Sequence) -> None:
@@ -555,9 +554,8 @@ class ElasticTensorExpansion(TensorCollection):
         super().__init__(c_list)
 
     @classmethod
-    def from_diff_fit(cls, strains, stresses, eq_stress=None, tol: float = 1e-10, order=3):
-        """
-        Generates an elastic tensor expansion via the fitting function
+    def from_diff_fit(cls, strains, stresses, eq_stress=None, tol: float = 1e-10, order=3) -> Self:
+        """Generate an elastic tensor expansion via the fitting function
         defined below in diff_fit.
         """
         c_list = diff_fit(strains, stresses, eq_stress, order, tol)
@@ -579,12 +577,11 @@ class ElasticTensorExpansion(TensorCollection):
         return sum(c.calculate_stress(strain) for c in self)
 
     def energy_density(self, strain, convert_GPa_to_eV=True):
-        """Calculates the elastic energy density due to a strain in eV/A^3 or GPa."""
+        """Calculate the elastic energy density due to a strain in eV/A^3 or GPa."""
         return sum(c.energy_density(strain, convert_GPa_to_eV) for c in self)
 
     def get_ggt(self, n, u):
-        """
-        Gets the Generalized Gruneisen tensor for a given
+        """Get the Generalized Gruneisen tensor for a given
         third-order elastic tensor expansion.
 
         Args:
@@ -597,8 +594,7 @@ class ElasticTensorExpansion(TensorCollection):
         )
 
     def get_tgt(self, temperature: float | None = None, structure: Structure = None, quad=None):
-        """
-        Gets the thermodynamic Gruneisen tensor (TGT) by via an
+        """Get the thermodynamic Gruneisen tensor (TGT) by via an
         integration of the GGT weighted by the directional heat
         capacity.
 
@@ -612,7 +608,7 @@ class ElasticTensorExpansion(TensorCollection):
             structure (Structure): Structure to be used in directional heat
                 capacity determination, only necessary if temperature
                 is specified
-            quad (dict): quadrature for integration, should be
+            quadct (dict): quadrature for integration, should be
                 dictionary with "points" and "weights" keys defaults
                 to quadpy.sphere.Lebedev(19) as read from file
         """
@@ -636,8 +632,7 @@ class ElasticTensorExpansion(TensorCollection):
         return SquareTensor(num / denom)
 
     def get_gruneisen_parameter(self, temperature=None, structure=None, quad=None):
-        """
-        Gets the single average gruneisen parameter from the TGT.
+        """Get the single average gruneisen parameter from the TGT.
 
         Args:
             temperature (float): Temperature in kelvin, if not specified
@@ -645,15 +640,14 @@ class ElasticTensorExpansion(TensorCollection):
             structure (float): Structure to be used in directional heat
                 capacity determination, only necessary if temperature
                 is specified
-            quad (dict): quadrature for integration, should be
+            quadct (dict): quadrature for integration, should be
                 dictionary with "points" and "weights" keys defaults
                 to quadpy.sphere.Lebedev(19) as read from file
         """
         return np.trace(self.get_tgt(temperature, structure, quad)) / 3.0
 
     def get_heat_capacity(self, temperature, structure: Structure, n, u, cutoff=1e2):
-        """
-        Gets the directional heat capacity for a higher order tensor
+        """Get the directional heat capacity for a higher order tensor
         expansion as a function of direction and polarization.
 
         Args:
@@ -676,8 +670,7 @@ class ElasticTensorExpansion(TensorCollection):
         return c * 6.022e23
 
     def omega(self, structure: Structure, n, u):
-        """
-        Finds directional frequency contribution to the heat
+        """Find directional frequency contribution to the heat
         capacity from direction and polarization.
 
         Args:
@@ -697,8 +690,7 @@ class ElasticTensorExpansion(TensorCollection):
     def thermal_expansion_coeff(
         self, structure: Structure, temperature: float, mode: Literal["dulong - petit", "debye"] = "debye"
     ):
-        """
-        Gets thermal expansion coefficient from third-order constants.
+        """Get thermal expansion coefficient from third-order constants.
 
         Args:
             temperature (float): Temperature in kelvin, if not specified
@@ -722,26 +714,24 @@ class ElasticTensorExpansion(TensorCollection):
         elif mode == "dulong-petit":
             cv = 3 * 8.314
         else:
-            raise ValueError("Mode must be debye or dulong-petit")
+            raise ValueError(f"{mode=} must be debye or dulong-petit")
         tgt = self.get_tgt(temperature, structure)
         alpha = np.einsum("ijkl,ij", soec.compliance_tensor, tgt)
         alpha *= cv / (1e9 * v0 * 6.022e23)
         return SquareTensor(alpha)
 
     def get_compliance_expansion(self):
-        """
-        Gets a compliance tensor expansion from the elastic
+        """Get a compliance tensor expansion from the elastic
         tensor expansion.
         """
         # TODO: this might have a general form
         if not self.order <= 4:
             raise ValueError("Compliance tensor expansion only supported for fourth-order and lower")
         ce_exp = [ElasticTensor(self[0]).compliance_tensor]
-        ein_string = "ijpq,pqrsuv,rskl,uvmn->ijklmn"
-        ce_exp.append(np.einsum(ein_string, -ce_exp[-1], self[1], ce_exp[-1], ce_exp[-1]))
+        ein_str = "ijpq,pqrsuv,rskl,uvmn->ijklmn"
+        ce_exp.append(np.einsum(ein_str, -ce_exp[-1], self[1], ce_exp[-1], ce_exp[-1]))
         if self.order == 4:
             # Four terms in the Fourth-Order compliance tensor
-
             einstring_1 = "pqab,cdij,efkl,ghmn,abcdefgh"
             tensors_1 = [ce_exp[0]] * 4 + [self[-1]]
             temp = -np.einsum(einstring_1, *tensors_1)
@@ -753,21 +743,18 @@ class ElasticTensorExpansion(TensorCollection):
             ce_exp.append(temp)
         return TensorCollection(ce_exp)
 
-    def get_strain_from_stress(self, stress):
-        """
-        Gets the strain from a stress state according
-        to the compliance expansion corresponding to the
-        tensor expansion.
+    def get_strain_from_stress(self, stress) -> float:
+        """Get the strain from a stress state according to the compliance
+        expansion corresponding to the tensor expansion.
         """
         compl_exp = self.get_compliance_expansion()
         strain = 0
-        for n, compl in enumerate(compl_exp):
-            strain += compl.einsum_sequence([stress] * (n + 1)) / factorial(n + 1)
+        for idx, compl in enumerate(compl_exp, start=1):
+            strain += compl.einsum_sequence([stress] * (idx)) / factorial(idx)
         return strain
 
     def get_effective_ecs(self, strain, order=2):
-        """
-        Returns the effective elastic constants
+        """Get the effective elastic constants
         from the elastic tensor expansion.
 
         Args:
@@ -781,8 +768,7 @@ class ElasticTensorExpansion(TensorCollection):
         return ec_sum
 
     def get_wallace_tensor(self, tau):
-        """
-        Gets the Wallace Tensor for determining yield strength
+        """Get the Wallace Tensor for determining yield strength
         criteria.
 
         Args:
@@ -801,8 +787,7 @@ class ElasticTensorExpansion(TensorCollection):
         return b
 
     def get_symmetric_wallace_tensor(self, tau):
-        """
-        Gets the symmetrized wallace tensor for determining
+        """Get the symmetrized wallace tensor for determining
         yield strength criteria.
 
         Args:
@@ -813,8 +798,7 @@ class ElasticTensorExpansion(TensorCollection):
         return Tensor(0.5 * (wallace + np.transpose(wallace, [2, 3, 0, 1])))
 
     def get_stability_criteria(self, s, n):
-        """
-        Gets the stability criteria from the symmetric
+        """Get the stability criteria from the symmetric
         Wallace tensor from an input vector and stress
         value.
 
@@ -830,8 +814,7 @@ class ElasticTensorExpansion(TensorCollection):
         return np.linalg.det(sym_wallace.voigt)
 
     def get_yield_stress(self, n):
-        """
-        Gets the yield stress for a given direction.
+        """Get the yield stress for a given direction.
 
         Args:
             n (3x1 array-like): direction for which to find the
@@ -889,24 +872,23 @@ def diff_fit(strains, stresses, eq_stress=None, order=2, tol: float = 1e-10):
     # Collect derivative data
     c_list = []
     dei_dsi = np.zeros((order - 1, 6, len(strain_state_dict)))
-    for n, (strain_state, data) in enumerate(strain_state_dict.items()):
+    for idx, (strain_state, data) in enumerate(strain_state_dict.items()):
         hvec = data["strains"][:, strain_state.index(1)]
-        for i in range(1, order):
-            coef = get_diff_coeff(hvec, i)
-            dei_dsi[i - 1, :, n] = np.dot(coef, data["stresses"])
+        for ord in range(1, order):
+            coef = get_diff_coeff(hvec, ord)
+            dei_dsi[ord - 1, :, idx] = np.dot(coef, data["stresses"])
 
     m, _absent = generate_pseudo(list(strain_state_dict), order)
-    for i in range(1, order):
-        cvec, carr = get_symbol_list(i + 1)
-        svec = np.ravel(dei_dsi[i - 1].T)
-        cmap = dict(zip(cvec, np.dot(m[i - 1], svec)))
+    for ord in range(1, order):
+        cvec, carr = get_symbol_list(ord + 1)
+        svec = np.ravel(dei_dsi[ord - 1].T)
+        cmap = dict(zip(cvec, np.dot(m[ord - 1], svec)))
         c_list.append(v_subs(carr, cmap))
     return [Tensor.from_voigt(c) for c in c_list]
 
 
 def find_eq_stress(strains, stresses, tol: float = 1e-10):
-    """
-    Finds stress corresponding to zero strain state in stress-strain list.
+    """Find stress corresponding to zero strain state in stress-strain list.
 
     Args:
         strains (Nx3x3 array-like): array corresponding to strains
@@ -933,8 +915,7 @@ def find_eq_stress(strains, stresses, tol: float = 1e-10):
 
 
 def get_strain_state_dict(strains, stresses, eq_stress=None, tol: float = 1e-10, add_eq=True, sort=True):
-    """
-    Creates a dictionary of voigt notation stress-strain sets
+    """Create a dictionary of voigt notation stress-strain sets
     keyed by "strain state", i. e. a tuple corresponding to
     the non-zero entries in ratios to the lowest nonzero value,
     e.g. [0, 0.1, 0, 0.2, 0, 0] -> (0,1,0,2,0,0)
@@ -979,7 +960,7 @@ def get_strain_state_dict(strains, stresses, eq_stress=None, tol: float = 1e-10,
         if add_eq:
             # add zero strain state
             mstrains = np.vstack([mstrains, np.zeros(6)])
-            mstresses = np.vstack([mstresses, veq_stress])
+            mstresses = np.vstack([mstresses, veq_stress])  # type: ignore[reportPossiblyUnboundVariable]
         # sort strains/stresses by strain values
         if sort:
             mstresses = mstresses[mstrains[:, ind[0]].argsort()]
@@ -989,12 +970,12 @@ def get_strain_state_dict(strains, stresses, eq_stress=None, tol: float = 1e-10,
 
 
 def generate_pseudo(strain_states, order=3):
-    """Generates the pseudo-inverse for a given set of strains.
+    """Generate the pseudo-inverse for a given set of strains.
 
     Args:
         strain_states (6xN array like): a list of Voigt-notation strain-states,
             i. e. perturbed indices of the strain as a function of the smallest
-            strain e. g. (0, 1, 0, 0, 1, 0)
+            strain e.g. (0, 1, 0, 0, 1, 0)
         order (int): order of pseudo-inverse to calculate
 
     Returns:
@@ -1003,44 +984,42 @@ def generate_pseudo(strain_states, order=3):
         absent_syms: symbols of the tensor absent from the PI expression
     """
     symb = sp.Symbol("s")
-    nstates = len(strain_states)
-    ni = np.array(strain_states) * symb
+    n_states = len(strain_states)
+    n_i = np.array(strain_states) * symb
     pseudo_inverses, absent_symbols = [], []
     for degree in range(2, order + 1):
-        cvec, carr = get_symbol_list(degree)
-        sarr = np.zeros((nstates, 6), dtype=object)
-        for n, strain_v in enumerate(ni):
+        c_vec, c_arr = get_symbol_list(degree)
+        s_arr = np.zeros((n_states, 6), dtype=object)
+        for n, strain_v in enumerate(n_i):
             # Get expressions
-            exps = carr.copy()
+            exps = c_arr.copy()
             for _ in range(degree - 1):
                 exps = np.dot(exps, strain_v)
             exps /= math.factorial(degree - 1)
-            sarr[n] = [sp.diff(exp, symb, degree - 1) for exp in exps]
-        svec = sarr.ravel()
-        present_symbols = set.union(*(exp.atoms(sp.Symbol) for exp in svec))
-        absent_symbols += [set(cvec) - present_symbols]
-        pseudo_mat = np.zeros((6 * nstates, len(cvec)))
-        for n, c in enumerate(cvec):
-            pseudo_mat[:, n] = v_diff(svec, c)
+            s_arr[n] = [sp.diff(exp, symb, degree - 1) for exp in exps]
+        s_vec = s_arr.ravel()
+        present_symbols = set.union(*(exp.atoms(sp.Symbol) for exp in s_vec))
+        absent_symbols += [set(c_vec) - present_symbols]
+        pseudo_mat = np.zeros((6 * n_states, len(c_vec)))
+        for n, c in enumerate(c_vec):
+            pseudo_mat[:, n] = v_diff(s_vec, c)
         pseudo_inverses.append(np.linalg.pinv(pseudo_mat))
     return pseudo_inverses, absent_symbols
 
 
 def get_symbol_list(rank, dim=6):
-    """
-    Returns a symbolic representation of the Voigt-notation
+    """Get a symbolic representation of the Voigt-notation
     tensor that places identical symbols for entries related
     by index transposition, i. e. C_1121 = C_1211 etc.
 
     Args:
-        dim (int): dimension of matrix/tensor, e. g. 6 for
+        dim (int): dimension of matrix/tensor, e.g. 6 for
             voigt notation and 3 for standard
-        rank (int): rank of tensor, e. g. 3 for third-order ECs
+        rank (int): rank of tensor, e.g. 3 for third-order ECs
 
     Returns:
-        c_vec (array): array representing distinct indices
-        c_arr (array): array representing tensor with equivalent
-            indices assigned as above
+        tuple[np.array, np.array]: tuple of arrays representing the distinct
+            indices and the tensor with equivalent indices assigned as above
     """
     indices = list(itertools.combinations_with_replacement(range(dim), r=rank))
     c_vec = np.zeros(len(indices), dtype=object)
@@ -1081,7 +1060,7 @@ def get_diff_coeff(hvec, n=1):
         hvec (1D array-like): sampling stencil
         n (int): degree of derivative to find
     """
-    hvec = np.array(hvec, dtype=np.float_)
+    hvec = np.array(hvec, dtype=np.float64)
     acc = len(hvec)
     exp = np.column_stack([np.arange(acc)] * acc)
     a = np.vstack([hvec] * acc) ** exp
