@@ -8,7 +8,7 @@ from __future__ import annotations
 
 import collections
 import itertools
-from typing import TYPE_CHECKING, Literal
+from typing import TYPE_CHECKING
 
 import numpy as np
 import scipy
@@ -18,8 +18,10 @@ from pymatgen.core.tensors import SquareTensor, symmetry_reduce
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
+    from typing import Literal
 
     from numpy.typing import ArrayLike
+    from typing_extensions import Self
 
     from pymatgen.core.structure import Structure
 
@@ -38,7 +40,7 @@ class Deformation(SquareTensor):
 
     symbol = "d"
 
-    def __new__(cls, deformation_gradient):
+    def __new__(cls, deformation_gradient) -> Self:
         """
         Create a Deformation object. Note that the constructor uses __new__ rather than
         __init__ according to the standard method of subclassing numpy ndarrays.
@@ -51,19 +53,18 @@ class Deformation(SquareTensor):
         return obj.view(cls)
 
     def is_independent(self, tol: float = 1e-8):
-        """Checks to determine whether the deformation is independent."""
+        """Check to determine whether the deformation is independent."""
         return len(self.get_perturbed_indices(tol)) == 1
 
     def get_perturbed_indices(self, tol: float = 1e-8):
-        """
-        Gets indices of perturbed elements of the deformation gradient,
+        """Get indices of perturbed elements of the deformation gradient,
         i. e. those that differ from the identity.
         """
         return list(zip(*np.where(abs(self - np.eye(3)) > tol)))
 
     @property
     def green_lagrange_strain(self):
-        """Calculates the Euler-Lagrange strain from the deformation gradient."""
+        """Calculate the Euler-Lagrange strain from the deformation gradient."""
         return Strain.from_deformation(self)
 
     def apply_to_structure(self, structure: Structure):
@@ -81,9 +82,8 @@ class Deformation(SquareTensor):
         return def_struct
 
     @classmethod
-    def from_index_amount(cls, matrix_pos, amt):
-        """
-        Factory method for constructing a Deformation object
+    def from_index_amount(cls, matrix_pos, amt) -> Self:
+        """Factory method for constructing a Deformation object
         from a matrix position and amount.
 
         Args:
@@ -158,7 +158,7 @@ class Strain(SquareTensor):
 
     symbol = "e"
 
-    def __new__(cls, strain_matrix):
+    def __new__(cls, strain_matrix) -> Self:
         """
         Create a Strain object. Note that the constructor uses __new__
         rather than __init__ according to the standard method of
@@ -185,9 +185,8 @@ class Strain(SquareTensor):
         self._vscale = getattr(obj, "_vscale", None)
 
     @classmethod
-    def from_deformation(cls, deformation: ArrayLike) -> Strain:
-        """
-        Factory method that returns a Strain object from a deformation
+    def from_deformation(cls, deformation: ArrayLike) -> Self:
+        """Factory method that returns a Strain object from a deformation
         gradient.
 
         Args:
@@ -197,7 +196,7 @@ class Strain(SquareTensor):
         return cls(0.5 * (np.dot(dfm.trans, dfm) - np.eye(3)))
 
     @classmethod
-    def from_index_amount(cls, idx, amount):
+    def from_index_amount(cls, idx: tuple | int, amount: float) -> Self:
         """
         Like Deformation.from_index_amount, except generates
         a strain from the zero 3x3 tensor or Voigt vector with
@@ -208,7 +207,7 @@ class Strain(SquareTensor):
             idx (tuple or integer): index to be perturbed, can be Voigt or full-tensor notation
             amount (float): amount to perturb selected index
         """
-        if np.array(idx).ndim == 0:
+        if isinstance(idx, int):
             v = np.zeros(6)
             v[idx] = amount
             return cls.from_voigt(v)
@@ -220,8 +219,7 @@ class Strain(SquareTensor):
         raise ValueError("Index must either be 2-tuple or integer corresponding to full-tensor or Voigt index")
 
     def get_deformation_matrix(self, shape: Literal["upper", "lower", "symmetric"] = "upper"):
-        """
-        Returns the deformation matrix.
+        """Get the deformation matrix.
 
         Args:
             shape ('upper' | 'lower' | 'symmetric'): method for determining deformation
