@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import copy
 import logging
+from typing import TYPE_CHECKING
 
 from monty.json import MSONable
 
@@ -11,6 +12,9 @@ from pymatgen.analysis.graphs import MoleculeGraph, MolGraphSplitError
 from pymatgen.analysis.local_env import OpenBabelNN, metal_edge_extender
 from pymatgen.io.babel import BabelMolAdaptor
 
+if TYPE_CHECKING:
+    from pymatgen.core.structure import Molecule
+
 __author__ = "Samuel Blau"
 __copyright__ = "Copyright 2018, The Materials Project"
 __version__ = "2.0"
@@ -27,17 +31,16 @@ class Fragmenter(MSONable):
 
     def __init__(
         self,
-        molecule,
-        edges=None,
-        depth=1,
-        open_rings=False,
-        use_metal_edge_extender=False,
-        opt_steps=10000,
-        prev_unique_frag_dict=None,
-        assume_previous_thoroughness=True,
+        molecule: Molecule,
+        edges: list | None = None,
+        depth: int = 1,
+        open_rings: bool = False,
+        use_metal_edge_extender: bool = False,
+        opt_steps: int = 10000,
+        prev_unique_frag_dict: dict | None = None,
+        assume_previous_thoroughness: bool = True,
     ):
-        """
-        Standard constructor for molecule fragmentation.
+        """Standard constructor for molecule fragmentation.
 
         Args:
             molecule (Molecule): The molecule to fragment.
@@ -76,10 +79,10 @@ class Fragmenter(MSONable):
         self.opt_steps = opt_steps
 
         if edges is None:
-            self.mol_graph = MoleculeGraph.with_local_env_strategy(molecule, OpenBabelNN())
+            self.mol_graph = MoleculeGraph.from_local_env_strategy(molecule, OpenBabelNN())
         else:
-            edges = {(e[0], e[1]): None for e in edges}
-            self.mol_graph = MoleculeGraph.with_edges(molecule, edges)
+            _edges: dict[tuple[int, int], dict | None] = {(edge[0], edge[1]): None for edge in edges}
+            self.mol_graph = MoleculeGraph.from_edges(molecule, _edges)
 
         if ("Li" in molecule.composition or "Mg" in molecule.composition) and use_metal_edge_extender:
             self.mol_graph = metal_edge_extender(self.mol_graph)
@@ -159,11 +162,11 @@ class Fragmenter(MSONable):
             for frag_key in self.unique_frag_dict:
                 self.total_unique_fragments += len(self.unique_frag_dict[frag_key])
 
-    def _fragment_one_level(self, old_frag_dict):
+    def _fragment_one_level(self, old_frag_dict: dict) -> dict:
         """
         Perform one step of iterative fragmentation on a list of molecule graphs. Loop through the graphs,
         then loop through each graph's edges and attempt to remove that edge in order to obtain two
-        disconnected subgraphs, aka two new fragments. If successful, check to see if the new fragments
+        disconnected subgraphs, aka two new fragments. If successful, check if the new fragments
         are already present in self.unique_fragments, and append them if not. If unsuccessful, we know
         that edge belongs to a ring. If we are opening rings, do so with that bond, and then again
         check if the resulting fragment is present in self.unique_fragments and add it if it is not.
@@ -210,7 +213,7 @@ class Fragmenter(MSONable):
                                         new_frag_dict[new_frag_key] = [fragment]
         return new_frag_dict
 
-    def _open_all_rings(self):
+    def _open_all_rings(self) -> None:
         """
         Having already generated all unique fragments that did not require ring opening,
         now we want to also obtain fragments that do require opening. We achieve this by
@@ -221,7 +224,7 @@ class Fragmenter(MSONable):
         alph_formula = self.mol_graph.molecule.composition.alphabetical_formula
         mol_key = f"{alph_formula} E{len(self.mol_graph.graph.edges())}"
         self.all_unique_frag_dict[mol_key] = [self.mol_graph]
-        new_frag_keys = {"0": []}
+        new_frag_keys: dict[str, list] = {"0": []}
         new_frag_key_dict = {}
         for key in self.all_unique_frag_dict:
             for fragment in self.all_unique_frag_dict[key]:
@@ -291,10 +294,9 @@ class Fragmenter(MSONable):
         self.all_unique_frag_dict.pop(mol_key)
 
 
-def open_ring(mol_graph, bond, opt_steps):
-    """
-    Function to actually open a ring using OpenBabel's local opt. Given a molecule
-    graph and a bond, convert the molecule graph into an OpenBabel molecule, remove
+def open_ring(mol_graph: MoleculeGraph, bond: list, opt_steps: int) -> MoleculeGraph:
+    """Open a ring using OpenBabel's local opt. Given a molecule graph and a bond,
+    convert the molecule graph into an OpenBabel molecule, remove
     the given bond, perform the local opt with the number of steps determined by
     self.steps, and then convert the resulting structure back into a molecule graph
     to be returned.
@@ -302,4 +304,5 @@ def open_ring(mol_graph, bond, opt_steps):
     ob_mol = BabelMolAdaptor.from_molecule_graph(mol_graph)
     ob_mol.remove_bond(bond[0][0] + 1, bond[0][1] + 1)
     ob_mol.localopt(steps=opt_steps, forcefield="uff")
-    return MoleculeGraph.with_local_env_strategy(ob_mol.pymatgen_mol, OpenBabelNN())
+
+    return MoleculeGraph.from_local_env_strategy(ob_mol.pymatgen_mol, OpenBabelNN())
