@@ -18,6 +18,7 @@ if TYPE_CHECKING:
     from collections.abc import Iterator, Sequence
 
     from pymatgen.core import Structure
+    from pymatgen.util.typing import Tuple3Ints
 
 
 class CoherentInterfaceBuilder:
@@ -30,8 +31,8 @@ class CoherentInterfaceBuilder:
         self,
         substrate_structure: Structure,
         film_structure: Structure,
-        film_miller: tuple[int, int, int],
-        substrate_miller: tuple[int, int, int],
+        film_miller: Tuple3Ints,
+        substrate_miller: Tuple3Ints,
         zslgen: ZSLGenerator | None = None,
     ):
         """
@@ -53,7 +54,7 @@ class CoherentInterfaceBuilder:
         self._find_terminations()
 
     def _find_matches(self) -> None:
-        """Finds and stores the ZSL matches."""
+        """Find and stores the ZSL matches."""
         self.zsl_matches = []
 
         film_sg = SlabGenerator(
@@ -90,20 +91,24 @@ class CoherentInterfaceBuilder:
         for match in self.zsl_matches:
             xform = get_2d_transform(film_vectors, match.film_vectors)
             strain, _rot = polar(xform)
-            (
-                assert_allclose(strain, np.round(strain), atol=1e-12),
-                "Film lattice vectors changed during ZSL match, check your ZSL Generator parameters",
+            assert_allclose(
+                strain,
+                np.round(strain),
+                atol=1e-12,
+                err_msg="Film lattice vectors changed during ZSL match, check your ZSL Generator parameters",
             )
 
             xform = get_2d_transform(substrate_vectors, match.substrate_vectors)
             strain, _rot = polar(xform)
-            (
-                assert_allclose(strain, strain.astype(int), atol=1e-12),
-                "Substrate lattice vectors changed during ZSL match, check your ZSL Generator parameters",
+            assert_allclose(
+                strain,
+                strain.astype(int),
+                atol=1e-12,
+                err_msg="Substrate lattice vectors changed during ZSL match, check your ZSL Generator parameters",
             )
 
     def _find_terminations(self):
-        """Finds all terminations."""
+        """Find all terminations."""
         film_sg = SlabGenerator(
             self.film_structure,
             self.film_miller,
@@ -129,16 +134,16 @@ class CoherentInterfaceBuilder:
         film_slabs = film_sg.get_slabs()
         sub_slabs = sub_sg.get_slabs()
 
-        film_shits = [s.shift for s in film_slabs]
-        film_terminations = [label_termination(s) for s in film_slabs]
+        film_shifts = [slab.shift for slab in film_slabs]
+        film_terminations = [label_termination(slab) for slab in film_slabs]
 
-        sub_shifts = [s.shift for s in sub_slabs]
-        sub_terminations = [label_termination(s) for s in sub_slabs]
+        sub_shifts = [slab.shift for slab in sub_slabs]
+        sub_terminations = [label_termination(slab) for slab in sub_slabs]
 
         self._terminations = {
             (film_label, sub_label): (film_shift, sub_shift)
             for (film_label, film_shift), (sub_label, sub_shift) in product(
-                zip(film_terminations, film_shits), zip(sub_terminations, sub_shifts)
+                zip(film_terminations, film_shifts), zip(sub_terminations, sub_shifts)
             )
         }
         self.terminations = list(self._terminations)
@@ -152,7 +157,7 @@ class CoherentInterfaceBuilder:
         substrate_thickness: float = 1,
         in_layers: bool = True,
     ) -> Iterator[Interface]:
-        """Generates interface structures given the film and substrate structure
+        """Generate interface structures given the film and substrate structure
         as well as the desired terminations.
 
         Args:
@@ -200,13 +205,17 @@ class CoherentInterfaceBuilder:
             ).astype(int)
             film_sl_slab = film_slab.copy()
             film_sl_slab.make_supercell(super_film_transform)
-            (
-                assert_allclose(film_sl_slab.lattice.matrix[2], film_slab.lattice.matrix[2], atol=1e-08),
-                "2D transformation affected C-axis for Film transformation",
+            assert_allclose(
+                film_sl_slab.lattice.matrix[2],
+                film_slab.lattice.matrix[2],
+                atol=1e-08,
+                err_msg="2D transformation affected C-axis for Film transformation",
             )
-            (
-                assert_allclose(film_sl_slab.lattice.matrix[:2], match.film_sl_vectors, atol=1e-08),
-                "Transformation didn't make proper supercell for film",
+            assert_allclose(
+                film_sl_slab.lattice.matrix[:2],
+                match.film_sl_vectors,
+                atol=1e-08,
+                err_msg="Transformation didn't make proper supercell for film",
             )
 
             # Build substrate superlattice
@@ -215,13 +224,17 @@ class CoherentInterfaceBuilder:
             ).astype(int)
             sub_sl_slab = sub_slab.copy()
             sub_sl_slab.make_supercell(super_sub_transform)
-            (
-                assert_allclose(sub_sl_slab.lattice.matrix[2], sub_slab.lattice.matrix[2], atol=1e-08),
-                "2D transformation affected C-axis for Film transformation",
+            assert_allclose(
+                sub_sl_slab.lattice.matrix[2],
+                sub_slab.lattice.matrix[2],
+                atol=1e-08,
+                err_msg="2D transformation affected C-axis for Film transformation",
             )
-            (
-                assert_allclose(sub_sl_slab.lattice.matrix[:2], match.substrate_sl_vectors, atol=1e-08),
-                "Transformation didn't make proper supercell for substrate",
+            assert_allclose(
+                sub_sl_slab.lattice.matrix[:2],
+                match.substrate_sl_vectors,
+                atol=1e-08,
+                err_msg="Transformation didn't make proper supercell for substrate",
             )
 
             # Add extra info
@@ -280,7 +293,7 @@ def get_2d_transform(start: Sequence, end: Sequence) -> np.ndarray:
 
 
 def from_2d_to_3d(mat: np.ndarray) -> np.ndarray:
-    """Converts a 2D matrix to a 3D matrix."""
+    """Convert a 2D matrix to a 3D matrix."""
     new_mat = np.diag([1.0, 1.0, 1.0])
     new_mat[:2, :2] = mat
     return new_mat
