@@ -11,11 +11,17 @@ comparisons without the atom order correspondence prerequisite.
 from __future__ import annotations
 
 import itertools
+from typing import TYPE_CHECKING
 
 from monty.json import MSONable
 
 from pymatgen.util.due import Doi, due
 
+if TYPE_CHECKING:
+    from typing import ClassVar
+
+    from typing_extensions import Self
+
 __author__ = "Xiaohui Qu"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "1.0"
@@ -33,7 +39,7 @@ class CovalentRadius:
     Beatriz C. et al. Dalton Trans. 2008, 2832-2838. https://doi.org/10.1039/b801115j
     """
 
-    radius = dict(
+    radius: ClassVar = dict(
         H=0.31,
         He=0.28,
         Li=1.28,
@@ -134,8 +140,7 @@ class CovalentRadius:
 
 
 class MoleculeStructureComparator(MSONable):
-    """
-    Class to check whether the connection tables of the two molecules are the
+    """Check whether the connection tables of the two molecules are the
     same. The atom in the two molecule must be paired accordingly.
     """
 
@@ -213,12 +218,12 @@ class MoleculeStructureComparator(MSONable):
             List of tuple. Each tuple correspond to a bond represented by the
             id of the two end atoms.
         """
-        num_atoms = len(mol)
+        n_atoms = len(mol)
         # index starting from 0
         if self.ignore_ionic_bond:
-            covalent_atoms = [i for i in range(num_atoms) if mol.species[i].symbol not in self.ionic_element_list]
+            covalent_atoms = [idx for idx in range(n_atoms) if mol.species[idx].symbol not in self.ionic_element_list]
         else:
-            covalent_atoms = list(range(num_atoms))
+            covalent_atoms = list(range(n_atoms))
         all_pairs = list(itertools.combinations(covalent_atoms, 2))
         pair_dists = [mol.get_distance(*p) for p in all_pairs]
         unavailable_elements = set(mol.composition.as_dict()) - set(self.covalent_radius)
@@ -251,7 +256,7 @@ class MoleculeStructureComparator(MSONable):
         return [bond for bond, dist, cap in zip(all_pairs, pair_dists, max_length) if dist <= cap]
 
     def as_dict(self):
-        """Returns: MSONable dict."""
+        """Get MSONable dict."""
         return {
             "version": __version__,
             "@module": type(self).__module__,
@@ -263,10 +268,10 @@ class MoleculeStructureComparator(MSONable):
         }
 
     @classmethod
-    def from_dict(cls, dct):
+    def from_dict(cls, dct: dict) -> Self:
         """
         Args:
-            d (dict): Dict representation.
+            dct (dict): Dict representation.
 
         Returns:
             MoleculeStructureComparator
