@@ -5,6 +5,7 @@ from __future__ import annotations
 import logging
 import re
 from itertools import chain, combinations
+from typing import TYPE_CHECKING, no_type_check, overload
 
 import numpy as np
 from monty.fractions import gcd_float
@@ -14,6 +15,14 @@ from uncertainties import ufloat
 from pymatgen.core.composition import Composition
 from pymatgen.entries.computed_entries import ComputedEntry
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    from typing_extensions import Self
+
+    from pymatgen.core import Element, Species
+    from pymatgen.util.typing import CompositionLike
+
 __author__ = "Shyue Ping Ong, Anubhav Jain"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "2.0"
@@ -27,12 +36,17 @@ logger = logging.getLogger(__name__)
 
 
 class BalancedReaction(MSONable):
-    """An object representing a complete chemical reaction."""
+    """Represent a complete chemical reaction."""
 
     # Tolerance for determining if a particular component fraction is > 0.
     TOLERANCE = 1e-6
 
-    def __init__(self, reactants_coeffs, products_coeffs):
+    @no_type_check
+    def __init__(
+        self,
+        reactants_coeffs: Mapping[CompositionLike, int | float],
+        products_coeffs: Mapping[CompositionLike, int | float],
+    ) -> None:
         """
         Reactants and products to be specified as dict of {Composition: coeff}.
 
@@ -40,28 +54,57 @@ class BalancedReaction(MSONable):
             reactants_coeffs (dict[Composition, float]): Reactants as dict of {Composition: amt}.
             products_coeffs (dict[Composition, float]): Products as dict of {Composition: amt}.
         """
+        # convert to Composition if necessary
+        reactants_coeffs = {Composition(comp): coeff for comp, coeff in reactants_coeffs.items()}
+        products_coeffs = {Composition(comp): coeff for comp, coeff in products_coeffs.items()}
+
         # sum reactants and products
-        all_reactants = sum((k * v for k, v in reactants_coeffs.items()), Composition({}))
-        all_products = sum((k * v for k, v in products_coeffs.items()), Composition({}))
+        all_reactants = sum((comp * coeff for comp, coeff in reactants_coeffs.items()), Composition())
+
+        all_products = sum((comp * coeff for comp, coeff in products_coeffs.items()), Composition())
 
         if not all_reactants.almost_equals(all_products, rtol=0, atol=self.TOLERANCE):
             raise ReactionError("Reaction is unbalanced!")
 
-        self._els = all_reactants.elements
-
-        self.reactants_coeffs = reactants_coeffs
-        self.products_coeffs = products_coeffs
+        self.reactants_coeffs: dict = reactants_coeffs
+        self.products_coeffs: dict = products_coeffs
 
         # calculate net reaction coefficients
-        self._coeffs = []
-        self._els = []
-        self._all_comp = []
+        self._coeffs: list[float] = []
+        self._els: list[Element | Species] = []
+        self._all_comp: list[Composition] = []
         for key in {*reactants_coeffs, *products_coeffs}:
             coeff = products_coeffs.get(key, 0) - reactants_coeffs.get(key, 0)
 
             if abs(coeff) > self.TOLERANCE:
-                self._all_comp.append(key)
-                self._coeffs.append(coeff)
+                self._all_comp += [key]
+                self._coeffs += [coeff]
+
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        for comp in self._all_comp:
+            coeff2 = other.get_coeff(comp) if comp in other._all_comp else 0
+            if abs(self.get_coeff(comp) - coeff2) > self.TOLERANCE:
+                return False
+        return True
+
+    def __hash__(self) -> int:
+        # Necessity for hash method is unclear (see gh-3673)
+        return hash((frozenset(self.reactants_coeffs.items()), frozenset(self.products_coeffs.items())))
+
+    def __str__(self):
+        return self._str_from_comp(self._coeffs, self._all_comp)[0]
+
+    __repr__ = __str__
+
+    @overload
+    def calculate_energy(self, energies: dict[Composition, ufloat]) -> ufloat:
+        pass
+
+    @overload
+    def calculate_energy(self, energies: dict[Composition, float]) -> float:
+        pass
 
     def calculate_energy(self, energies):
         """
@@ -76,7 +119,7 @@ class BalancedReaction(MSONable):
         """
         return sum(amt * energies[c] for amt, c in zip(self._coeffs, self._all_comp))
 
-    def normalize_to(self, comp, factor=1):
+    def normalize_to(self, comp: Composition, factor: float = 1) -> None:
         """
         Normalizes the reaction to one of the compositions.
         By default, normalizes such that the composition given has a
@@ -89,7 +132,7 @@ class BalancedReaction(MSONable):
         scale_factor = abs(1 / self._coeffs[self._all_comp.index(comp)] * factor)
         self._coeffs = [c * scale_factor for c in self._coeffs]
 
-    def normalize_to_element(self, element, factor=1):
+    def normalize_to_element(self, element: Species | Element, factor: float = 1) -> None:
         """
         Normalizes the reaction to one of the elements.
         By default, normalizes such that the amount of the element is 1.
@@ -105,9 +148,8 @@ class BalancedReaction(MSONable):
         scale_factor = factor / current_el_amount
         self._coeffs = [c * scale_factor for c in coeffs]
 
-    def get_el_amount(self, element):
-        """
-        Returns the amount of the element in the reaction.
+    def get_el_amount(self, element: Element | Species) -> float:
+        """Get the amount of the element in the reaction.
 
         Args:
             element (Element/Species): Element in the reaction
@@ -118,35 +160,35 @@ class BalancedReaction(MSONable):
         return sum(self._all_comp[i][element] * abs(self._coeffs[i]) for i in range(len(self._all_comp))) / 2
 
     @property
-    def elements(self):
+    def elements(self) -> list[Element | Species]:
         """List of elements in the reaction."""
-        return self._els[:]
+        return self._els
 
     @property
-    def coeffs(self):
+    def coeffs(self) -> list[float]:
         """Final coefficients of the calculated reaction."""
         return self._coeffs[:]
 
     @property
-    def all_comp(self):
+    def all_comp(self) -> list[Composition]:
         """List of all compositions in the reaction."""
         return self._all_comp
 
     @property
-    def reactants(self):
+    def reactants(self) -> list[Composition]:
         """List of reactants."""
         return [self._all_comp[i] for i in range(len(self._all_comp)) if self._coeffs[i] < 0]
 
     @property
-    def products(self):
+    def products(self) -> list[Composition]:
         """List of products."""
         return [self._all_comp[i] for i in range(len(self._all_comp)) if self._coeffs[i] > 0]
 
-    def get_coeff(self, comp):
-        """Returns coefficient for a particular composition."""
+    def get_coeff(self, comp: Composition) -> float:
+        """Get coefficient for a particular composition."""
         return self._coeffs[self._all_comp.index(comp)]
 
-    def normalized_repr_and_factor(self):
+    def normalized_repr_and_factor(self) -> tuple[str, float]:
         """
         Normalized representation for a reaction
         For example, ``4 Li + 2 O -> 2Li2O`` becomes ``2 Li + O -> Li2O``.
@@ -154,27 +196,15 @@ class BalancedReaction(MSONable):
         return self._str_from_comp(self._coeffs, self._all_comp, reduce=True)
 
     @property
-    def normalized_repr(self):
+    def normalized_repr(self) -> str:
         """
         A normalized representation of the reaction. All factors are converted
         to lowest common factors.
         """
         return self.normalized_repr_and_factor()[0]
 
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, type(self)):
-            return NotImplemented
-        for comp in self._all_comp:
-            coeff2 = other.get_coeff(comp) if comp in other._all_comp else 0
-            if abs(self.get_coeff(comp) - coeff2) > self.TOLERANCE:
-                return False
-        return True
-
-    def __hash__(self) -> int:
-        return 7
-
     @classmethod
-    def _str_from_formulas(cls, coeffs, formulas):
+    def _str_from_formulas(cls, coeffs, formulas) -> str:
         reactant_str = []
         product_str = []
         for amt, formula in zip(coeffs, formulas):
@@ -190,12 +220,12 @@ class BalancedReaction(MSONable):
         return f"{' + '.join(reactant_str)} -> {' + '.join(product_str)}"
 
     @classmethod
-    def _str_from_comp(cls, coeffs, compositions, reduce=False):
+    def _str_from_comp(cls, coeffs, compositions, reduce=False) -> tuple[str, float]:
         r_coeffs = np.zeros(len(coeffs))
         r_formulas = []
-        for i, (amt, comp) in enumerate(zip(coeffs, compositions)):
+        for idx, (amt, comp) in enumerate(zip(coeffs, compositions)):
             formula, factor = comp.get_reduced_formula_and_factor()
-            r_coeffs[i] = amt * factor
+            r_coeffs[idx] = amt * factor
             r_formulas.append(formula)
         if reduce:
             factor = 1 / gcd_float(np.abs(r_coeffs))
@@ -204,22 +234,16 @@ class BalancedReaction(MSONable):
             factor = 1
         return cls._str_from_formulas(r_coeffs, r_formulas), factor
 
-    def __str__(self):
-        return self._str_from_comp(self._coeffs, self._all_comp)[0]
-
-    __repr__ = __str__
-
-    def as_entry(self, energies):
-        """
-        Returns a ComputedEntry representation of the reaction.
-        """
+    def as_entry(self, energies) -> ComputedEntry:
+        """Get a ComputedEntry representation of the reaction."""
         relevant_comp = [comp * abs(coeff) for coeff, comp in zip(self._coeffs, self._all_comp)]
-        comp = sum(relevant_comp, Composition())
+        comp: Composition = sum(relevant_comp, Composition())  # type: ignore[assignment]
+
         entry = ComputedEntry(0.5 * comp, self.calculate_energy(energies))
         entry.name = str(self)
         return entry
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         Returns:
             A dictionary representation of BalancedReaction.
@@ -232,22 +256,21 @@ class BalancedReaction(MSONable):
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct: dict) -> Self:
         """
         Args:
-            d (dict): from as_dict().
+            dct (dict): from as_dict().
 
         Returns:
             A BalancedReaction object.
         """
-        reactants = {Composition(comp): coeff for comp, coeff in d["reactants"].items()}
-        products = {Composition(comp): coeff for comp, coeff in d["products"].items()}
+        reactants = {Composition(comp): coeff for comp, coeff in dct["reactants"].items()}
+        products = {Composition(comp): coeff for comp, coeff in dct["products"].items()}
         return cls(reactants, products)
 
     @classmethod
-    def from_str(cls, rxn_str):
-        """
-        Generates a balanced reaction from a string. The reaction must
+    def from_str(cls, rxn_str: str) -> Self:
+        """Generate a balanced reaction from a string. The reaction must
         already be balanced.
 
         Args:
@@ -276,10 +299,10 @@ class Reaction(BalancedReaction):
     the *FIRST* product (or products, if underdetermined) has a coefficient of one.
     """
 
-    def __init__(self, reactants, products):
+    def __init__(self, reactants: list[Composition], products: list[Composition]) -> None:
         """
         Reactants and products to be specified as list of
-        pymatgen.core.structure.Composition. e.g., [comp1, comp2].
+        pymatgen.core.structure.Composition. e.g. [comp1, comp2].
 
         Args:
             reactants ([Composition]): List of reactants.
@@ -350,11 +373,11 @@ class Reaction(BalancedReaction):
 
         return np.squeeze(best_soln)
 
-    def copy(self):
-        """Returns a copy of the Reaction object."""
+    def copy(self) -> Self:
+        """Get a copy of the Reaction object."""
         return Reaction(self.reactants, self.products)
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         Returns:
             A dictionary representation of Reaction.
@@ -367,7 +390,7 @@ class Reaction(BalancedReaction):
         }
 
     @classmethod
-    def from_dict(cls, dct):
+    def from_dict(cls, dct: dict) -> Self:
         """
         Args:
             dct (dict): from as_dict().
@@ -381,12 +404,11 @@ class Reaction(BalancedReaction):
 
 
 class ReactionError(Exception):
-    """
-    Exception class for Reactions. Allows more information in exception
+    """Exception class for Reactions. Allows more information in exception
     messages to cover situations not covered by standard exception classes.
     """
 
-    def __init__(self, msg):
+    def __init__(self, msg: str) -> None:
         """
         Create a ReactionError.
 
@@ -395,7 +417,7 @@ class ReactionError(Exception):
         """
         self.msg = msg
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.msg
 
 
@@ -406,7 +428,7 @@ class ComputedReaction(Reaction):
     energies.
     """
 
-    def __init__(self, reactant_entries, product_entries):
+    def __init__(self, reactant_entries: list[ComputedEntry], product_entries: list[ComputedEntry]) -> None:
         """
         Args:
             reactant_entries ([ComputedEntry]): List of reactant_entries.
@@ -415,33 +437,32 @@ class ComputedReaction(Reaction):
         self._reactant_entries = reactant_entries
         self._product_entries = product_entries
         self._all_entries = reactant_entries + product_entries
-        reactant_comp = [e.composition.reduced_composition for e in reactant_entries]
+        reactant_comp = [entry.composition.reduced_composition for entry in reactant_entries]
 
-        product_comp = [e.composition.reduced_composition for e in product_entries]
+        product_comp = [entry.composition.reduced_composition for entry in product_entries]
 
         super().__init__(list(reactant_comp), list(product_comp))
 
     @property
     def all_entries(self):
-        """
-        Equivalent of all_comp but returns entries, in the same order as the
+        """Equivalent of all_comp but returns entries, in the same order as the
         coefficients.
         """
         entries = []
-        for c in self._all_comp:
-            for e in self._all_entries:
-                if e.composition.reduced_formula == c.reduced_formula:
-                    entries.append(e)
+        for comp in self._all_comp:
+            for entry in self._all_entries:
+                if entry.reduced_formula == comp.reduced_formula:
+                    entries.append(entry)
                     break
         return entries
 
     @property
-    def calculated_reaction_energy(self):
+    def calculated_reaction_energy(self) -> float:
         """
-        Returns (float):
-            The calculated reaction energy.
+        Returns:
+            float: The calculated reaction energy.
         """
-        calc_energies = {}
+        calc_energies: dict[Composition, float] = {}
 
         for entry in self._reactant_entries + self._product_entries:
             comp, factor = entry.composition.get_reduced_composition_and_factor()
@@ -450,12 +471,12 @@ class ComputedReaction(Reaction):
         return self.calculate_energy(calc_energies)
 
     @property
-    def calculated_reaction_energy_uncertainty(self):
+    def calculated_reaction_energy_uncertainty(self) -> float:
         """
         Calculates the uncertainty in the reaction energy based on the uncertainty in the
         energies of the products and reactants.
         """
-        calc_energies = {}
+        calc_energies: dict[Composition, float] = {}
 
         for entry in self._reactant_entries + self._product_entries:
             comp, factor = entry.composition.get_reduced_composition_and_factor()
@@ -464,7 +485,7 @@ class ComputedReaction(Reaction):
 
         return self.calculate_energy(calc_energies).std_dev
 
-    def as_dict(self):
+    def as_dict(self) -> dict:
         """
         Returns:
             A dictionary representation of ComputedReaction.
@@ -472,20 +493,19 @@ class ComputedReaction(Reaction):
         return {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
-            "reactants": [e.as_dict() for e in self._reactant_entries],
-            "products": [e.as_dict() for e in self._product_entries],
+            "reactants": [entry.as_dict() for entry in self._reactant_entries],
+            "products": [entry.as_dict() for entry in self._product_entries],
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct: dict) -> Self:
         """
         Args:
-            d (dict): from as_dict().
+            dct (dict): from as_dict().
 
         Returns:
             A ComputedReaction object.
         """
-        dec = MontyDecoder()
-        reactants = [dec.process_decoded(e) for e in d["reactants"]]
-        products = [dec.process_decoded(e) for e in d["products"]]
+        reactants = [MontyDecoder().process_decoded(entry) for entry in dct["reactants"]]
+        products = [MontyDecoder().process_decoded(entry) for entry in dct["products"]]
         return cls(reactants, products)
