@@ -10,9 +10,10 @@ from pymatgen.analysis.structure_prediction.substitution_probability import Subs
 from pymatgen.core import Element, Species
 
 
-def get_dopants_from_substitution_probabilities(structure, num_dopants=5, threshold=0.001, match_oxi_sign=False):
-    """
-    Get dopant suggestions based on substitution probabilities.
+def get_dopants_from_substitution_probabilities(
+    structure, num_dopants=5, threshold=0.001, match_oxi_sign=False
+) -> dict:
+    """Get dopant suggestions based on substitution probabilities.
 
     Args:
         structure (Structure): A pymatgen structure decorated with
@@ -26,13 +27,13 @@ def get_dopants_from_substitution_probabilities(structure, num_dopants=5, thresh
             returned.
 
     Returns:
-        (dict): Dopant suggestions, given as a dictionary with keys "n_type" and
-        "p_type". The suggestions for each doping type are given as a list of
-        dictionaries, each with they keys:
+        dict: Dopant suggestions, given as a dictionary with keys "n_type" and
+            "p_type". The suggestions for each doping type are given as a list of
+            dictionaries, each with they keys:
 
-        - "probability": The probability of substitution.
-        - "dopant_species": The dopant species.
-        - "original_species": The substituted species.
+            - "probability": The probability of substitution.
+            - "dopant_species": The dopant species.
+            - "original_species": The substituted species.
     """
     els_have_oxi_states = [hasattr(s, "oxi_state") for s in structure.species]
 
@@ -57,8 +58,7 @@ def get_dopants_from_substitution_probabilities(structure, num_dopants=5, thresh
 
 
 def get_dopants_from_shannon_radii(bonded_structure, num_dopants=5, match_oxi_sign=False):
-    """
-    Get dopant suggestions based on Shannon radii differences.
+    """Get dopant suggestions based on Shannon radii differences.
 
     Args:
         bonded_structure (StructureGraph): A pymatgen structure graph
@@ -72,15 +72,15 @@ def get_dopants_from_shannon_radii(bonded_structure, num_dopants=5, match_oxi_si
             returned.
 
     Returns:
-        (dict): Dopant suggestions, given as a dictionary with keys "n_type" and
-        "p_type". The suggestions for each doping type are given as a list of
-        dictionaries, each with they keys:
+        dict: Dopant suggestions, given as a dictionary with keys "n_type" and
+            "p_type". The suggestions for each doping type are given as a list of
+            dictionaries, each with they keys:
 
-        - "radii_diff": The difference between the Shannon radii of the species.
-        - "dopant_spcies": The dopant species.
-        - "original_species": The substituted species.
+            - "radii_diff": The difference between the Shannon radii of the species.
+            - "dopant_species": The dopant species.
+            - "original_species": The substituted species.
     """
-    # get a list of all Species for all elements in all their common oxid states
+    # get a list of all Species for all elements in all their common oxidation states
     all_species = [Species(el, oxi) for el in Element for oxi in el.common_oxidation_states]
 
     # get a series of tuples with (coordination number, specie)
@@ -123,7 +123,7 @@ def get_dopants_from_shannon_radii(bonded_structure, num_dopants=5, match_oxi_si
     return _get_dopants(possible_dopants, num_dopants, match_oxi_sign)
 
 
-def _get_dopants(substitutions, num_dopants, match_oxi_sign):
+def _get_dopants(substitutions, num_dopants, match_oxi_sign) -> dict:
     """Utility method to get n- and p-type dopants from a list of substitutions."""
     n_type = [
         pred
@@ -164,13 +164,13 @@ def _shannon_radii_from_cn(species_list, cn_roman, radius_to_compare=0):
             shannon radii and this radius.
 
     Returns:
-        (list of dict): The Shannon radii for all Species in species. Formatted
-        as a list of dictionaries, with the keys:
+        list[dict]: The Shannon radii for all Species in species. Formatted
+            as a list of dictionaries, with the keys:
 
-        - "species": The species with charge state.
-        - "radius": The Shannon radius for the species.
-        - "radius_diff": The difference between the Shannon radius and the
-            radius_to_compare optional argument.
+            - "species": The species with charge state.
+            - "radius": The Shannon radius for the species.
+            - "radius_diff": The difference between the Shannon radius and the
+                radius_to_compare optional argument.
     """
     shannon_radii = []
 
