@@ -1,13 +1,17 @@
 """This module provides plotting capabilities for battery related applications."""
 
-
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 import matplotlib.pyplot as plt
 import plotly.graph_objects as go
 
 from pymatgen.util.plotting import pretty_plot
 
+if TYPE_CHECKING:
+    from pymatgen.apps.battery.battery_abc import AbstractElectrode
+
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "0.1"
@@ -19,7 +23,7 @@ __date__ = "Jul 12, 2012"
 class VoltageProfilePlotter:
     """A plotter to make voltage profile plots for batteries."""
 
-    def __init__(self, xaxis="capacity", hide_negative=False):
+    def __init__(self, xaxis: str = "capacity", hide_negative: bool = False) -> None:
         """
         Args:
             xaxis: The quantity to use as the xaxis. Can be either
@@ -29,11 +33,11 @@ class VoltageProfilePlotter:
             - frac_x: the atomic fraction of the working ion
             hide_negative: If True only plot the voltage steps above zero.
         """
-        self._electrodes = {}
+        self._electrodes: dict[str, AbstractElectrode] = {}
         self.xaxis = xaxis
         self.hide_negative = hide_negative
 
-    def add_electrode(self, electrode, label=None):
+    def add_electrode(self, electrode: AbstractElectrode, label: str | None = None) -> None:
         """Add an electrode to the plot.
 
         Args:
@@ -42,11 +46,11 @@ class VoltageProfilePlotter:
             label: A label for the electrode. If None, defaults to a counting
                 system, i.e. 'Electrode 1', 'Electrode 2', ...
         """
-        if not label:
+        if label is None:
             label = f"Electrode {len(self._electrodes) + 1}"
         self._electrodes[label] = electrode
 
-    def get_plot_data(self, electrode, term_zero=True):
+    def get_plot_data(self, electrode: AbstractElectrode, term_zero: bool = True) -> tuple[list, list]:
         """
         Args:
             electrode: Electrode object
@@ -83,8 +87,8 @@ class VoltageProfilePlotter:
             y.append(0)
         return x, y
 
-    def get_plot(self, width=8, height=8, term_zero=True, ax: plt.Axes = None):
-        """Returns a plot object.
+    def get_plot(self, width: float = 8, height: float = 8, term_zero: bool = True, ax: plt.Axes = None) -> plt.Axes:
+        """Get a plot object.
 
         Args:
             width: Width of the plot. Defaults to 8 in.
@@ -99,11 +103,11 @@ class VoltageProfilePlotter:
         working_ion_symbols = set()
         formula = set()
 
-        for label, electrode in self._electrodes.items():
+        for key, electrode in self._electrodes.items():
             x, y = self.get_plot_data(electrode, term_zero=term_zero)
             working_ion_symbols.add(electrode.working_ion.symbol)
             formula.add(electrode.framework_formula)
-            ax.plot(x, y, "-", linewidth=2, label=label)
+            ax.plot(x, y, "-", linewidth=2, label=key)
 
         ax.legend()
         ax.set_xlabel(self._choose_best_x_label(formula=formula, work_ion_symbol=working_ion_symbols))
@@ -113,12 +117,12 @@ class VoltageProfilePlotter:
 
     def get_plotly_figure(
         self,
-        width=800,
-        height=600,
-        font_dict=None,
-        term_zero=True,
+        width: float = 800,
+        height: float = 600,
+        font_dict: dict | None = None,
+        term_zero: bool = True,
         **kwargs,
-    ):
+    ) -> plt.Figure:
         """Return plotly Figure object.
 
         Args:
@@ -134,7 +138,7 @@ class VoltageProfilePlotter:
         data = []
         working_ion_symbols = set()
         formula = set()
-        for label, electrode in self._electrodes.items():
+        for key, electrode in self._electrodes.items():
             x, y = self.get_plot_data(electrode, term_zero=term_zero)
             working_ion_symbols.add(electrode.working_ion.symbol)
             formula.add(electrode.framework_formula)
@@ -146,7 +150,7 @@ class VoltageProfilePlotter:
                     plot_y.append(None)
                 plot_x.append(x[i])
                 plot_y.append(y[i])
-            data.append(go.Scatter(x=plot_x, y=plot_y, name=label, hovertemplate=hover_temp))
+            data.append(go.Scatter(x=plot_x, y=plot_y, name=key, hovertemplate=hover_temp))
 
         fig = go.Figure(
             data=data,
@@ -164,28 +168,28 @@ class VoltageProfilePlotter:
         fig.update_layout(template="plotly_white", title_x=0.5)
         return fig
 
-    def _choose_best_x_label(self, formula, work_ion_symbol):
+    def _choose_best_x_label(self, formula: set[str], work_ion_symbol: set[str]) -> str:
         if self.xaxis in {"capacity", "capacity_grav"}:
             return "Capacity (mAh/g)"
         if self.xaxis == "capacity_vol":
             return "Capacity (Ah/l)"
 
-        formula = formula.pop() if len(formula) == 1 else None
+        _formula: str | None = formula.pop() if len(formula) == 1 else None
 
-        work_ion_symbol = work_ion_symbol.pop() if len(work_ion_symbol) == 1 else None
+        _work_ion_symbol: str | None = work_ion_symbol.pop() if len(work_ion_symbol) == 1 else None
 
         if self.xaxis == "x_form":
-            if formula and work_ion_symbol:
-                return f"x in {work_ion_symbol}<sub>x</sub>{formula}"
+            if _formula and _work_ion_symbol:
+                return f"x in {_work_ion_symbol}<sub>x</sub>{_formula}"
             return "x Work Ion per Host F.U."
 
         if self.xaxis == "frac_x":
-            if work_ion_symbol:
-                return f"Atomic Fraction of {work_ion_symbol}"
+            if _work_ion_symbol:
+                return f"Atomic Fraction of {_work_ion_symbol}"
             return "Atomic Fraction of Working Ion"
         raise RuntimeError("No xaxis label can be determined")
 
-    def show(self, width=8, height=6):
+    def show(self, width: float = 8, height: float = 6) -> None:
         """Show the voltage profile plot.
 
         Args:
