@@ -9,10 +9,14 @@ import json
 import logging
 import os
 from multiprocessing import Manager, Pool
+from typing import TYPE_CHECKING
 
 from monty.io import zopen
 from monty.json import MontyDecoder, MontyEncoder
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 logger = logging.getLogger("BorgQueen")
 
 
@@ -40,7 +44,7 @@ class BorgQueen:
         """
         self._drone = drone
         self._num_drones = number_of_drones
-        self._data = []
+        self._data: list = []
 
         if rootpath:
             if number_of_drones > 1:
@@ -60,33 +64,33 @@ class BorgQueen:
         status["count"] = 0
         status["total"] = len(valid_paths)
         logger.info(f"{len(valid_paths)} valid paths found.")
-        with Pool(self._num_drones) as p:
-            p.map(
+        with Pool(self._num_drones) as pool:
+            pool.map(
                 order_assimilation,
                 ((path, self._drone, data, status) for path in valid_paths),
             )
-            for d in data:
-                self._data.append(json.loads(d, cls=MontyDecoder))
+            for string in data:
+                self._data.append(json.loads(string, cls=MontyDecoder))
 
-    def serial_assimilate(self, rootpath):
+    def serial_assimilate(self, root: str | Path) -> None:
         """Assimilate the entire subdirectory structure in rootpath serially."""
         valid_paths = []
-        for parent, subdirs, files in os.walk(rootpath):
+        for parent, subdirs, files in os.walk(root):
             valid_paths.extend(self._drone.get_valid_paths((parent, subdirs, files)))
-        data = []
+        data: list[str] = []
         total = len(valid_paths)
-        for idx, path in enumerate(valid_paths, 1):
+        for idx, path in enumerate(valid_paths, start=1):
             new_data = self._drone.assimilate(path)
             self._data.append(new_data)
-            logger.info(f"{idx}/{total} ({idx / total:.2%}) done")
+            logger.info(f"{idx}/{total} ({idx / total:.1%}) done")
         for json_str in data:
             self._data.append(json.loads(json_str, cls=MontyDecoder))
 
     def get_data(self):
-        """Returns an list of assimilated objects."""
+        """Get an list of assimilated objects."""
         return self._data
 
-    def save_data(self, filename):
+    def save_data(self, filename: str | Path) -> None:
         """Save the assimilated data to a file.
 
         Args:
@@ -105,7 +109,7 @@ class BorgQueen:
 
 def order_assimilation(args):
     """Internal helper method for BorgQueen to process assimilation."""
-    (path, drone, data, status) = args
+    path, drone, data, status = args
     new_data = drone.assimilate(path)
     if new_data:
         data.append(json.dumps(new_data, cls=MontyEncoder))
