@@ -36,22 +36,22 @@ def get_energies(rootdir, reanalyze, verbose, quick, sort, fmt):
         fmt (str): tablefmt passed to tabulate.
     """
     if verbose:
-        logformat = "%(relativeCreated)d msecs : %(message)s"
-        logging.basicConfig(level=logging.INFO, format=logformat)
+        log_fmt = "%(relativeCreated)d msecs : %(message)s"
+        logging.basicConfig(level=logging.INFO, format=log_fmt)
 
     if quick:
         drone = SimpleVaspToComputedEntryDrone(inc_structure=True)
     else:
         drone = VaspToComputedEntryDrone(inc_structure=True, data=["filename", "initial_structure"])
 
-    ncpus = multiprocessing.cpu_count()
-    logging.info(f"Detected {ncpus} cpus")
-    queen = BorgQueen(drone, number_of_drones=ncpus)
-    if os.path.exists(SAVE_FILE) and not reanalyze:
+    n_cpus = multiprocessing.cpu_count()
+    logging.info(f"Detected {n_cpus} cpus")
+    queen = BorgQueen(drone, number_of_drones=n_cpus)
+    if os.path.isfile(SAVE_FILE) and not reanalyze:
         msg = f"Using previously assimilated data from {SAVE_FILE}. Use -r to force re-analysis."
         queen.load_data(SAVE_FILE)
     else:
-        if ncpus > 1:
+        if n_cpus > 1:
             queen.parallel_assimilate(rootdir)
         else:
             queen.serial_assimilate(rootdir)
@@ -74,7 +74,7 @@ def get_energies(rootdir, reanalyze, verbose, quick, sort, fmt):
         all_data.append(
             (
                 e.data["filename"].replace("./", ""),
-                re.sub(r"\s+", "", e.composition.formula),
+                re.sub(r"\s+", "", e.formula),
                 f"{e.energy:.5f}",
                 f"{e.energy_per_atom:.5f}",
                 delta_vol,
@@ -104,20 +104,20 @@ def get_magnetizations(dir: str, ion_list: list[int]):
     data = []
     max_row = 0
     for parent, _subdirs, files in os.walk(dir):
-        for f in files:
-            if re.match(r"OUTCAR*", f):
+        for file in files:
+            if re.match(r"OUTCAR*", file):
                 try:
                     row = []
-                    fullpath = os.path.join(parent, f)
+                    fullpath = os.path.join(parent, file)
                     outcar = Outcar(fullpath)
                     mags = outcar.magnetization
-                    mags = [m["tot"] for m in mags]
-                    all_ions = list(range(len(mags)))
+                    _mags: list = [m["tot"] for m in mags]
+                    all_ions = list(range(len(_mags)))
                     row.append(fullpath.lstrip("./"))
                     if ion_list:
                         all_ions = ion_list
                     for ion in all_ions:
-                        row.append(str(mags[ion]))
+                        row.append(str(_mags[ion]))
                     data.append(row)
                     if len(all_ions) > max_row:
                         max_row = len(all_ions)
@@ -143,15 +143,15 @@ def analyze(args):
     default_energies = not (args.get_energies or args.ion_list)
 
     if args.get_energies or default_energies:
-        for d in args.directories:
-            return get_energies(d, args.reanalyze, args.verbose, args.quick, args.sort, args.format)
+        for folder in args.directories:
+            return get_energies(folder, args.reanalyze, args.verbose, args.quick, args.sort, args.format)
     if args.ion_list:
         if args.ion_list[0] == "All":
             ion_list = None
         else:
-            (start, end) = (int(i) for i in re.split(r"-", args.ion_list[0]))
+            start, end = (int(i) for i in re.split(r"-", args.ion_list[0]))
             ion_list = list(range(start, end + 1))
-        for d in args.directories:
-            return get_magnetizations(d, ion_list)
+        for folder in args.directories:
+            return get_magnetizations(folder, ion_list)
 
     return -1
