@@ -1,5 +1,5 @@
 """Interface with command line GULP.
-http://projects.ivec.org
+https://gulp.curtin.edu.au/index.html
 WARNING: you need to have GULP installed on your system.
 """
 
@@ -237,7 +237,7 @@ class GulpIO:
 
     @staticmethod
     def keyword_line(*args):
-        """Checks if the input args are proper gulp keywords and
+        """Check if the input args are proper gulp keywords and
         generates the 1st line of gulp input. Full keywords are expected.
 
         Args:
@@ -258,7 +258,7 @@ class GulpIO:
         cation_shell_flg: bool = False,
         symm_flg: bool = True,
     ):
-        """Generates GULP input string corresponding to pymatgen structure.
+        """Generate GULP input string corresponding to pymatgen structure.
 
         Args:
             structure: pymatgen Structure object
@@ -278,7 +278,7 @@ class GulpIO:
                 written.
 
         Returns:
-            string containing structure for GULP input
+            str: containing structure for GULP input
         """
         gin = ""
         if cell_flg:
@@ -287,7 +287,7 @@ class GulpIO:
             alpha, beta, gamma = lattice.angles
             a, b, c = lattice.lengths
             lat_str = f"{a:6f} {b:6f} {c:6f} {alpha:6f} {beta:6f} {gamma:6f}"
-            gin += lat_str + "\n"
+            gin += f"{lat_str}\n"
 
         if frac_flg:
             gin += "frac\n"
@@ -313,8 +313,7 @@ class GulpIO:
 
     @staticmethod
     def specie_potential_lines(structure, potential, **kwargs):
-        """Generates GULP input specie and potential string for pymatgen
-        structure.
+        """Generate GULP input species and potential string for pymatgen structure.
 
         Args:
             structure: pymatgen Structure object
@@ -331,14 +330,13 @@ class GulpIO:
                 cation_shell_chrg=float
 
         Returns:
-            string containing specie and potential specification for gulp
-            input.
+            str: containing species and potential for GULP input
         """
-        raise NotImplementedError("gulp_specie_potential not yet implemented.\nUse library_line instead")
+        raise NotImplementedError("gulp_specie_potential not yet implemented. Use library_line instead")
 
     @staticmethod
     def library_line(file_name):
-        """Specifies GULP library file to read species and potential parameters.
+        """Specify GULP library file to read species and potential parameters.
         If using library don't specify species and potential
         in the input file and vice versa. Make sure the elements of
         structure are in the library file.
@@ -351,27 +349,27 @@ class GulpIO:
         """
         gulp_lib_set = "GULP_LIB" in os.environ
 
-        def readable(f):
-            return os.path.isfile(f) and os.access(f, os.R_OK)
+        def readable(file):
+            return os.path.isfile(file) and os.access(file, os.R_OK)
 
         gin = ""
         dirpath, _fname = os.path.split(file_name)
         if dirpath and readable(file_name):  # Full path specified
-            gin = "library " + file_name
+            gin = f"library {file_name}"
         else:
             fpath = os.path.join(os.getcwd(), file_name)  # Check current dir
             if readable(fpath):
-                gin = "library " + fpath
+                gin = f"library {fpath}"
             elif gulp_lib_set:  # Check the GULP_LIB path
                 fpath = os.path.join(os.environ["GULP_LIB"], file_name)
                 if readable(fpath):
-                    gin = "library " + file_name
+                    gin = f"library {file_name}"
         if gin:
             return gin + "\n"
         raise GulpError("GULP library not found")
 
     def buckingham_input(self, structure: Structure, keywords, library=None, uc=True, valence_dict=None):
-        """Gets a GULP input for an oxide structure and buckingham potential
+        """Get a GULP input for an oxide structure and buckingham potential
         from library.
 
         Args:
@@ -459,7 +457,7 @@ class GulpIO:
         return gin
 
     def tersoff_input(self, structure: Structure, periodic=False, uc=True, *keywords):
-        """Gets a GULP input with Tersoff potential for an oxide structure.
+        """Get a GULP input with Tersoff potential for an oxide structure.
 
         Args:
             structure: pymatgen Structure
@@ -541,66 +539,67 @@ class GulpIO:
             gout (str): GULP output string.
 
         Returns:
-            (Structure) relaxed structure.
+            Structure: relaxed structure.
         """
         # Find the structure lines
         structure_lines = []
         cell_param_lines = []
         output_lines = gout.split("\n")
-        no_lines = len(output_lines)
-        i = 0
+        n_lines = len(output_lines)
+        idx = 0
+        a = b = c = alpha = beta = gamma = 0.0
         # Compute the input lattice parameters
-        while i < no_lines:
-            line = output_lines[i]
+        while idx < n_lines:
+            line = output_lines[idx]
             if "Full cell parameters" in line:
-                i += 2
-                line = output_lines[i]
+                idx += 2
+                line = output_lines[idx]
                 a = float(line.split()[8])
                 alpha = float(line.split()[11])
-                line = output_lines[i + 1]
+                line = output_lines[idx + 1]
                 b = float(line.split()[8])
                 beta = float(line.split()[11])
-                line = output_lines[i + 2]
+                line = output_lines[idx + 2]
                 c = float(line.split()[8])
                 gamma = float(line.split()[11])
-                i += 3
+                idx += 3
                 break
             if "Cell parameters" in line:
-                i += 2
-                line = output_lines[i]
+                idx += 2
+                line = output_lines[idx]
                 a = float(line.split()[2])
                 alpha = float(line.split()[5])
-                line = output_lines[i + 1]
+                line = output_lines[idx + 1]
                 b = float(line.split()[2])
                 beta = float(line.split()[5])
-                line = output_lines[i + 2]
+                line = output_lines[idx + 2]
                 c = float(line.split()[2])
                 gamma = float(line.split()[5])
-                i += 3
+                idx += 3
                 break
-            i += 1
+            idx += 1
 
-        while i < no_lines:
-            line = output_lines[i]
+        while idx < n_lines:
+            line = output_lines[idx]
             if "Final fractional coordinates of atoms" in line:
                 # read the site coordinates in the following lines
-                i += 6
-                line = output_lines[i]
-                while line[0:2] != "--":
+                idx += 6
+                line = output_lines[idx]
+                while line[:2] != "--":
                     structure_lines.append(line)
-                    i += 1
-                    line = output_lines[i]
+                    idx += 1
+                    line = output_lines[idx]
                     # read the cell parameters
-                i += 9
-                line = output_lines[i]
+                idx += 9
+                line = output_lines[idx]
                 if "Final cell parameters" in line:
-                    i += 3
+                    idx += 3
                     for del_i in range(6):
-                        line = output_lines[i + del_i]
+                        line = output_lines[idx + del_i]
                         cell_param_lines.append(line)
 
                 break
-            i += 1
+            idx += 1
 
         # Process the structure lines
         if structure_lines:
@@ -621,13 +620,17 @@ class GulpIO:
             alpha = float(cell_param_lines[3].split()[1])
             beta = float(cell_param_lines[4].split()[1])
             gamma = float(cell_param_lines[5].split()[1])
-        latt = Lattice.from_parameters(a, b, c, alpha, beta, gamma)
+        if not all([a, b, c, alpha, beta, gamma]):
+            raise ValueError(
+                f"Missing lattice parameters in Gulp output: {a=}, {b=}, {c=}, {alpha=}, {beta=}, {gamma=}"
+            )
+        lattice = Lattice.from_parameters(a, b, c, alpha, beta, gamma)
 
-        return Structure(latt, sp, coords)
+        return Structure(lattice, sp, coords)
 
 
 class GulpCaller:
-    """Class to run gulp from command line."""
+    """Run gulp from command line."""
 
     def __init__(self, cmd="gulp"):
         """Initialize with the executable if not in the standard path.
@@ -651,7 +654,7 @@ class GulpCaller:
                 if is_exe(file):
                     self._gulp_cmd = file
                     return
-        raise GulpError("Executable not found")
+        raise GulpError("Executable not found, please download from https://gulp.curtin.edu.au/index.html.")
 
     def run(self, gin):
         """Run GULP using the gin as input.
@@ -668,8 +671,8 @@ class GulpCaller:
                 stdout=subprocess.PIPE,
                 stdin=subprocess.PIPE,
                 stderr=subprocess.PIPE,
-            ) as p:
-                out, err = p.communicate(bytearray(gin, "utf-8"))
+            ) as p_open:
+                out, err = p_open.communicate(bytearray(gin, "utf-8"))
             out = out.decode("utf-8")
             err = err.decode("utf-8")
 
@@ -692,10 +695,10 @@ class GulpCaller:
             if conv_err_string in out:
                 raise GulpConvergenceError(out)
 
-            gout = ""
+            g_out = ""
             for line in out.split("\n"):
-                gout = gout + line + "\n"
-            return gout
+                g_out += f"{line}\n"
+            return g_out
 
 
 def get_energy_tersoff(structure, gulp_cmd="gulp"):
@@ -761,7 +764,7 @@ class GulpError(Exception):
         self.msg = msg
 
     def __str__(self):
-        return "GulpError : " + self.msg
+        return f"GulpError : {self.msg}"
 
 
 class GulpConvergenceError(Exception):
