@@ -7,24 +7,27 @@ from __future__ import annotations
 import os
 import tempfile
 import warnings
-from collections import namedtuple
 from pathlib import Path
 from shutil import which
 from subprocess import Popen, TimeoutExpired
+from typing import TYPE_CHECKING, NamedTuple
 
 from monty.dev import requires
 
 from pymatgen.core.structure import Structure
 
-Sqs = namedtuple("Sqs", "bestsqs objective_function allsqs clusters directory")
-"""
-Return type for run_mcsqs.
-bestsqs: Structure
-objective_function: float | str
-allsqs: List
-clusters: List
-directory: str
-"""
+if TYPE_CHECKING:
+    from pymatgen.core.structure import IStructure
+
+
+class Sqs(NamedTuple):
+    """Return type for run_mcsqs."""
+
+    bestsqs: Structure | IStructure
+    objective_function: float | str
+    allsqs: list
+    clusters: list | str
+    directory: str
 
 
 @requires(
@@ -50,9 +53,9 @@ def run_mcsqs(
         clusters (dict): Dictionary of cluster interactions with entries in the form
             number of atoms: cutoff in angstroms
         scaling (int or list): Scaling factor to determine supercell. Two options are possible:
-                a. (preferred) Scales number of atoms, e.g., for a structure with 8 atoms,
+                a. (preferred) Scales number of atoms, e.g. for a structure with 8 atoms,
                    scaling=4 would lead to a 32 atom supercell
-                b. A sequence of three scaling factors, e.g., [2, 1, 1], which
+                b. A sequence of three scaling factors, e.g. [2, 1, 1], which
                    specifies that the supercell should have dimensions 2a x b x c
             Defaults to 1.
         search_time (float): Time spent looking for the ideal SQS in minutes (default: 60)
@@ -71,7 +74,7 @@ def run_mcsqs(
         tuple: Pymatgen structure SQS of the input structure, the mcsqs objective function,
             list of all SQS structures, and the directory where calculations are run
     """
-    num_atoms = len(structure)
+    n_atoms = len(structure)
 
     if structure.is_ordered:
         raise ValueError("Pick a disordered structure")
@@ -87,14 +90,14 @@ def run_mcsqs(
     if isinstance(scaling, (int, float)):
         if scaling % 1 != 0:
             raise ValueError(f"{scaling=} should be an integer")
-        mcsqs_find_sqs_cmd = ["mcsqs", f"-n {scaling * num_atoms}"]
+        mcsqs_find_sqs_cmd = ["mcsqs", f"-n {scaling * n_atoms}"]
 
     else:
         # Set supercell to identity (will make supercell with pymatgen)
         with open("sqscell.out", mode="w") as file:
             file.write("1\n1 0 0\n0 1 0\n0 0 1\n")
         structure = structure * scaling
-        mcsqs_find_sqs_cmd = ["mcsqs", "-rc", f"-n {num_atoms}"]
+        mcsqs_find_sqs_cmd = ["mcsqs", "-rc", f"-n {n_atoms}"]
 
     structure.to(filename="rndstr.in")
 
@@ -132,7 +135,7 @@ def run_mcsqs(
             process = Popen(["mcsqs", "-best"])
             process.communicate()
 
-        if os.path.exists("bestsqs.out") and os.path.exists("bestcorr.out"):
+        if os.path.isfile("bestsqs.out") and os.path.isfile("bestcorr.out"):
             return _parse_sqs_path(".")
 
         raise RuntimeError("mcsqs exited before timeout reached")
@@ -144,7 +147,7 @@ def run_mcsqs(
 
         # Find the best sqs structures
         if instances and instances > 1:
-            if not os.path.exists("bestcorr1.out"):
+            if not os.path.isfile("bestcorr1.out"):
                 raise RuntimeError(
                     "mcsqs did not generate output files, "
                     "is search_time sufficient or are number of instances too high?"
@@ -153,7 +156,7 @@ def run_mcsqs(
             process = Popen(["mcsqs", "-best"])
             process.communicate()
 
-        if os.path.exists("bestsqs.out") and os.path.exists("bestcorr.out"):
+        if os.path.isfile("bestsqs.out") and os.path.isfile("bestcorr.out"):
             return _parse_sqs_path(".")
 
         os.chdir(original_directory)
@@ -258,7 +261,7 @@ def _parse_clusters(filename):
         for point in range(cluster_dict["num_points_in_cluster"]):
             line = cluster[3 + point].split(" ")
             point_dict = {}
-            point_dict["coordinates"] = [float(line) for line in line[0:3]]
+            point_dict["coordinates"] = [float(line) for line in line[:3]]
             point_dict["num_possible_species"] = int(line[3]) + 2  # see ATAT manual for why +2
             point_dict["cluster_function"] = float(line[4])  # see ATAT manual for what "function" is
             points.append(point_dict)
