@@ -1,13 +1,13 @@
-"""This class implements definitions for various kinds of bonds. Typically used in
+"""This module implements definitions for various kinds of bonds. Typically used in
 Molecule analysis.
 """
 
 from __future__ import annotations
 
-import collections
 import json
 import os
 import warnings
+from collections import defaultdict
 from typing import TYPE_CHECKING
 
 from pymatgen.core import Element
@@ -17,10 +17,13 @@ if TYPE_CHECKING:
     from pymatgen.util.typing import SpeciesLike
 
 
-def _load_bond_length_data():
-    """Loads bond length data from json file."""
-    with open(os.path.join(os.path.dirname(__file__), "bond_lengths.json")) as file:
-        data = collections.defaultdict(dict)
+def _load_bond_length_data() -> dict[tuple[str, ...], dict[float, float]]:
+    """Load bond length data from bond_lengths.json file."""
+    with open(
+        os.path.join(os.path.dirname(__file__), "bond_lengths.json"),
+        encoding="utf-8",
+    ) as file:
+        data: dict[tuple, dict] = defaultdict(dict)
         for row in json.load(file):
             els = sorted(row["elements"])
             data[tuple(els)][row["bond_order"]] = row["length"]
@@ -31,10 +34,10 @@ bond_lengths = _load_bond_length_data()
 
 
 class CovalentBond:
-    """Defines a covalent bond between two sites."""
+    """A covalent bond between two sites."""
 
     def __init__(self, site1: Site, site2: Site) -> None:
-        """Initializes a covalent bond between two sites.
+        """Initialize a covalent bond between two sites.
 
         Args:
             site1 (Site): First site.
@@ -43,12 +46,19 @@ class CovalentBond:
         self.site1 = site1
         self.site2 = site2
 
+    def __repr__(self) -> str:
+        return f"Covalent bond between {self.site1} and {self.site2}"
+
     @property
     def length(self) -> float:
         """Length of the bond."""
         return self.site1.distance(self.site2)
 
-    def get_bond_order(self, tol: float = 0.2, default_bl: float | None = None) -> float:
+    def get_bond_order(
+        self,
+        tol: float = 0.2,
+        default_bl: float | None = None,
+    ) -> float:
         """The bond order according the distance between the two sites.
 
         Args:
@@ -63,8 +73,7 @@ class CovalentBond:
                 (bond order = 1). If None, a ValueError will be thrown.
 
         Returns:
-            Float value of bond order. For example, for C-C bond in
-            benzene, return 1.7.
+            float: value of bond order. E.g. 1.7 for C-C bond in benzene.
         """
         sp1 = next(iter(self.site1.species))
         sp2 = next(iter(self.site2.species))
@@ -72,8 +81,14 @@ class CovalentBond:
         return get_bond_order(sp1, sp2, dist, tol, default_bl)
 
     @staticmethod
-    def is_bonded(site1, site2, tol: float = 0.2, bond_order: float | None = None, default_bl: float | None = None):
-        """Test if two sites are bonded, up to a certain limit.
+    def is_bonded(
+        site1: Site,
+        site2: Site,
+        tol: float = 0.2,
+        bond_order: float | None = None,
+        default_bl: float | None = None,
+    ) -> bool:
+        """Check if two sites are bonded, up to a certain limit.
 
         Args:
             site1 (Site): First site
@@ -88,7 +103,7 @@ class CovalentBond:
                 bond length. If None, a ValueError will be thrown.
 
         Returns:
-            Boolean indicating whether two sites are bonded.
+            bool: whether two sites are bonded.
         """
         sp1 = next(iter(site1.species))
         sp2 = next(iter(site2.species))
@@ -103,11 +118,12 @@ class CovalentBond:
             return dist < (1 + tol) * default_bl
         raise ValueError(f"No bond data for elements {syms[0]} - {syms[1]}")
 
-    def __repr__(self) -> str:
-        return f"Covalent bond between {self.site1} and {self.site2}"
 
-
-def obtain_all_bond_lengths(sp1, sp2, default_bl: float | None = None):
+def obtain_all_bond_lengths(
+    sp1: SpeciesLike,
+    sp2: SpeciesLike,
+    default_bl: float | None = None,
+) -> dict[float, float]:
     """Obtain bond lengths for all bond orders from bond length database.
 
     Args:
@@ -117,7 +133,7 @@ def obtain_all_bond_lengths(sp1, sp2, default_bl: float | None = None):
             bond length as a default value (bond order = 1).
             If None, a ValueError will be thrown.
 
-    Return:
+    Returns:
         A dict mapping bond order to bond length in angstrom
     """
     if isinstance(sp1, Element):
@@ -128,17 +144,23 @@ def obtain_all_bond_lengths(sp1, sp2, default_bl: float | None = None):
     if syms in bond_lengths:
         return bond_lengths[syms].copy()
     if default_bl is not None:
-        return {1: default_bl}
+        return {1.0: default_bl}
     raise ValueError(f"No bond data for elements {syms[0]} - {syms[1]}")
 
 
-def get_bond_order(sp1, sp2, dist: float, tol: float = 0.2, default_bl: float | None = None):
+def get_bond_order(
+    sp1: SpeciesLike,
+    sp2: SpeciesLike,
+    dist: float,
+    tol: float = 0.2,
+    default_bl: float | None = None,
+) -> float:
     """Calculate the bond order given the distance of 2 species.
 
     Args:
         sp1 (Species): First specie.
         sp2 (Species): Second specie.
-        dist: Their distance in angstrom
+        dist (float): Distance in angstrom
         tol (float): Relative tolerance to test. Basically, the code
             checks if the distance between the sites is larger than
             (1 + tol) * the longest bond distance or smaller than
@@ -149,31 +171,34 @@ def get_bond_order(sp1, sp2, dist: float, tol: float = 0.2, default_bl: float |
             bond length (bond order = 1). If None, a ValueError will be thrown.
 
     Returns:
-        Float value of bond order. For example, for C-C bond in benzene,
-        return 1.7.
+        float: Bond order. For example, 1.7 for C-C bond in benzene.
     """
-    all_lengths = obtain_all_bond_lengths(sp1, sp2, default_bl)
+    all_lens = obtain_all_bond_lengths(sp1, sp2, default_bl)
     # Transform bond lengths dict to list assuming bond data is successive
     # and add an imaginary bond 0 length
-    lengths_list = [all_lengths[1] * (1 + tol)] + [all_lengths[idx + 1] for idx in range(len(all_lengths))]
+    lens = [all_lens[1] * (1 + tol)] + [all_lens[idx + 1] for idx in range(len(all_lens))]
     trial_bond_order = 0
-    while trial_bond_order < len(lengths_list):
-        if lengths_list[trial_bond_order] < dist:
+    while trial_bond_order < len(lens):
+        if lens[trial_bond_order] < dist:
             if trial_bond_order == 0:
                 return trial_bond_order
-            low_bl = lengths_list[trial_bond_order]
-            high_bl = lengths_list[trial_bond_order - 1]
+            low_bl = lens[trial_bond_order]
+            high_bl = lens[trial_bond_order - 1]
             return trial_bond_order - (dist - low_bl) / (high_bl - low_bl)
         trial_bond_order += 1
     # Distance shorter than the shortest bond length stored,
     # check if the distance is too short
-    if dist < lengths_list[-1] * (1 - tol):  # too short
+    if dist < lens[-1] * (1 - tol):  # too short
         warnings.warn(f"{dist:.2f} angstrom distance is too short for {sp1} and {sp2}")
     # return the highest bond order
     return trial_bond_order - 1
 
 
-def get_bond_length(sp1: SpeciesLike, sp2: SpeciesLike, bond_order: float = 1) -> float:
+def get_bond_length(
+    sp1: SpeciesLike,
+    sp2: SpeciesLike,
+    bond_order: float = 1,
+) -> float:
     """Get the bond length between two species.
 
     Args:
@@ -185,8 +210,8 @@ def get_bond_length(sp1: SpeciesLike, sp2: SpeciesLike, bond_order: float = 1) -
             C-C bond length, this should be set to 2. Defaults to 1.
 
     Returns:
-        Bond length in Angstrom. If no data is available, the sum of the atomic
-        radius is used.
+        float: Bond length in Angstrom. If no data is available,
+            the sum of the atomic radius is used.
     """
     sp1 = Element(sp1) if isinstance(sp1, str) else sp1
     sp2 = Element(sp2) if isinstance(sp2, str) else sp2
