@@ -4,10 +4,9 @@ from __future__ import annotations
 
 import re
 import string
-import typing
 import warnings
 from math import cos, pi, sin, sqrt
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal, cast
 
 import numpy as np
 from monty.json import MSONable
@@ -20,6 +19,7 @@ if TYPE_CHECKING:
     from typing import Any
 
     from numpy.typing import ArrayLike
+    from typing_extensions import Self
 
 __author__ = "Shyue Ping Ong, Shyam Dwaraknath, Matthew Horton"
 
@@ -33,8 +33,12 @@ class SymmOp(MSONable):
         affine_matrix (np.ndarray): A 4x4 array representing the symmetry operation.
     """
 
-    def __init__(self, affine_transformation_matrix: ArrayLike, tol: float = 0.01) -> None:
-        """Initializes the SymmOp from a 4x4 affine transformation matrix.
+    def __init__(
+        self,
+        affine_transformation_matrix: ArrayLike,
+        tol: float = 0.01,
+    ) -> None:
+        """Initialize the SymmOp from a 4x4 affine transformation matrix.
         In general, this constructor should not be used unless you are
         transferring rotations. Use the static constructors instead to
         generate a SymmOp from proper rotations and translation.
@@ -54,13 +58,34 @@ class SymmOp(MSONable):
         self.affine_matrix = affine_transformation_matrix
         self.tol = tol
 
-    @staticmethod
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, type(self)):
+            return NotImplemented
+        return np.allclose(self.affine_matrix, other.affine_matrix, atol=self.tol)
+
+    def __hash__(self) -> int:
+        return 7
+
+    def __repr__(self) -> str:
+        return f"{type(self).__name__}({self.affine_matrix=})"
+
+    def __str__(self) -> str:
+        return "\n".join(["Rot:", str(self.affine_matrix[:3][:, :3]), "tau", str(self.affine_matrix[:3][:, 3])])
+
+    def __mul__(self, other) -> Self:
+        """Get a new SymmOp which is equivalent to apply the "other" SymmOp
+        followed by this one.
+        """
+        return type(self)(np.dot(self.affine_matrix, other.affine_matrix))
+
+    @classmethod
     def from_rotation_and_translation(
+        cls,
         rotation_matrix: ArrayLike = ((1, 0, 0), (0, 1, 0), (0, 0, 1)),
         translation_vec: ArrayLike = (0, 0, 0),
         tol: float = 0.1,
-    ) -> SymmOp:
-        """Creates a symmetry operation from a rotation matrix and a translation
+    ) -> Self:
+        """Create a symmetry operation from a rotation matrix and a translation
         vector.
 
         Args:
@@ -77,26 +102,11 @@ class SymmOp(MSONable):
             raise ValueError("Rotation Matrix must be a 3x3 numpy array.")
         if translation_vec.shape != (3,):
             raise ValueError("Translation vector must be a rank 1 numpy array with 3 elements.")
+
         affine_matrix = np.eye(4)
-        affine_matrix[0:3][:, 0:3] = rotation_matrix
-        affine_matrix[0:3][:, 3] = translation_vec
-        return SymmOp(affine_matrix, tol)
-
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, SymmOp):
-            return NotImplemented
-        return np.allclose(self.affine_matrix, other.affine_matrix, atol=self.tol)
-
-    def __hash__(self) -> int:
-        return 7
-
-    def __repr__(self) -> str:
-        affine_matrix = self.affine_matrix
-        return f"{type(self).__name__}({affine_matrix=})"
-
-    def __str__(self) -> str:
-        output = ["Rot:", str(self.affine_matrix[0:3][:, 0:3]), "tau", str(self.affine_matrix[0:3][:, 3])]
-        return "\n".join(output)
+        affine_matrix[:3][:, :3] = rotation_matrix
+        affine_matrix[:3][:, 3] = translation_vec
+        return cls(affine_matrix, tol)
 
     def operate(self, point: ArrayLike) -> np.ndarray:
         """Apply the operation on a point.
@@ -107,8 +117,8 @@ class SymmOp(MSONable):
         Returns:
             Coordinates of point after operation.
         """
-        affine_point = np.array([*point, 1])  # type: ignore
-        return np.dot(self.affine_matrix, affine_point)[0:3]
+        affine_point = np.array([*point, 1])
+        return np.dot(self.affine_matrix, affine_point)[:3]
 
     def operate_multi(self, points: ArrayLike) -> np.ndarray:
         """Apply the operation on a list of points.
@@ -133,7 +143,7 @@ class SymmOp(MSONable):
         return np.dot(self.rotation_matrix, vector)
 
     def transform_tensor(self, tensor: np.ndarray) -> np.ndarray:
-        """Applies rotation portion to a tensor. Note that tensor has to be in
+        """Apply rotation portion to a tensor. Note that tensor has to be in
         full form, not the Voigt form.
 
         Args:
@@ -144,7 +154,8 @@ class SymmOp(MSONable):
         """
         dim = tensor.shape
         rank = len(dim)
-        assert all(i == 3 for i in dim)
+        assert all(val == 3 for val in dim)
+
         # Build einstein sum string
         lc = string.ascii_lowercase
         indices = lc[:rank], lc[rank : 2 * rank]
@@ -154,8 +165,13 @@ class SymmOp(MSONable):
 
         return np.einsum(einsum_string, *einsum_args)
 
-    def are_symmetrically_related(self, point_a: ArrayLike, point_b: ArrayLike, tol: float = 0.001) -> bool:
-        """Checks if two points are symmetrically related.
+    def are_symmetrically_related(
+        self,
+        point_a: ArrayLike,
+        point_b: ArrayLike,
+        tol: float = 0.001,
+    ) -> bool:
+        """Check if two points are symmetrically related.
 
         Args:
             point_a (3x1 array): First point.
@@ -177,7 +193,7 @@ class SymmOp(MSONable):
         r_b: ArrayLike,
         tol: float = 0.001,
     ) -> tuple[bool, bool]:
-        """Checks if two vectors, or rather two vectors that connect two points
+        """Check if two vectors, or rather two vectors that connect two points
         each are symmetrically related. r_a and r_b give the change of unit
         cells. Two vectors are also considered symmetrically equivalent if starting
         and end point are exchanged.
@@ -192,7 +208,9 @@ class SymmOp(MSONable):
             tol (float): Absolute tolerance for checking distance.
 
         Returns:
-            (are_related, is_reversed)
+            tuple[bool, bool]: First bool indicates if the vectors are related,
+                the second if the vectors are related but the starting and end point
+                are exchanged.
         """
         from_c = self.operate(from_a)
         to_c = self.operate(to_a)
@@ -206,39 +224,32 @@ class SymmOp(MSONable):
         to_c = to_c % 1
 
         if np.allclose(from_b, from_c, atol=tol) and np.allclose(to_b, to_c) and np.allclose(r_b, r_c, atol=tol):
-            return (True, False)
+            return True, False
         if np.allclose(to_b, from_c, atol=tol) and np.allclose(from_b, to_c) and np.allclose(r_b, -r_c, atol=tol):
-            return (True, True)
-        return (False, False)
+            return True, True
+        return False, False
 
     @property
     def rotation_matrix(self) -> np.ndarray:
         """A 3x3 numpy.array representing the rotation matrix."""
-        return self.affine_matrix[0:3][:, 0:3]
+        return self.affine_matrix[:3][:, :3]
 
     @property
     def translation_vector(self) -> np.ndarray:
         """A rank 1 numpy.array of dim 3 representing the translation vector."""
-        return self.affine_matrix[0:3][:, 3]
-
-    def __mul__(self, other):
-        """Returns a new SymmOp which is equivalent to apply the "other" SymmOp
-        followed by this one.
-        """
-        new_matrix = np.dot(self.affine_matrix, other.affine_matrix)
-        return SymmOp(new_matrix)
+        return self.affine_matrix[:3][:, 3]
 
     @property
-    def inverse(self) -> SymmOp:
-        """Returns inverse of transformation."""
-        invr = np.linalg.inv(self.affine_matrix)
-        return SymmOp(invr)
+    def inverse(self) -> Self:
+        """Inverse of transformation."""
+        inverse = np.linalg.inv(self.affine_matrix)
+        return type(self)(inverse)
 
     @staticmethod
     def from_axis_angle_and_translation(
         axis: ArrayLike, angle: float, angle_in_radians: bool = False, translation_vec: ArrayLike = (0, 0, 0)
     ) -> SymmOp:
-        """Generates a SymmOp for a rotation about a given axis plus translation.
+        """Generate a SymmOp for a rotation about a given axis plus translation.
 
         Args:
             axis: The axis of rotation in Cartesian space. For example,
@@ -256,29 +267,31 @@ class SymmOp(MSONable):
 
         vec = np.array(translation_vec)
 
-        a = angle if angle_in_radians else angle * pi / 180
-        cosa = cos(a)
-        sina = sin(a)
-        u = axis / np.linalg.norm(axis)  # type: ignore
-        r = np.zeros((3, 3))
-        r[0, 0] = cosa + u[0] ** 2 * (1 - cosa)  # type: ignore
-        r[0, 1] = u[0] * u[1] * (1 - cosa) - u[2] * sina  # type: ignore
-        r[0, 2] = u[0] * u[2] * (1 - cosa) + u[1] * sina  # type: ignore
-        r[1, 0] = u[0] * u[1] * (1 - cosa) + u[2] * sina  # type: ignore
-        r[1, 1] = cosa + u[1] ** 2 * (1 - cosa)  # type: ignore
-        r[1, 2] = u[1] * u[2] * (1 - cosa) - u[0] * sina  # type: ignore
-        r[2, 0] = u[0] * u[2] * (1 - cosa) - u[1] * sina  # type: ignore
-        r[2, 1] = u[1] * u[2] * (1 - cosa) + u[0] * sina  # type: ignore
-        r[2, 2] = cosa + u[2] ** 2 * (1 - cosa)  # type: ignore
+        ang = angle if angle_in_radians else angle * pi / 180
+        cos_a = cos(ang)
+        sin_a = sin(ang)
+        unit_vec = axis / np.linalg.norm(axis)
+        rot_mat = np.zeros((3, 3))
+        rot_mat[0, 0] = cos_a + unit_vec[0] ** 2 * (1 - cos_a)
+        rot_mat[0, 1] = unit_vec[0] * unit_vec[1] * (1 - cos_a) - unit_vec[2] * sin_a
+        rot_mat[0, 2] = unit_vec[0] * unit_vec[2] * (1 - cos_a) + unit_vec[1] * sin_a
+        rot_mat[1, 0] = unit_vec[0] * unit_vec[1] * (1 - cos_a) + unit_vec[2] * sin_a
+        rot_mat[1, 1] = cos_a + unit_vec[1] ** 2 * (1 - cos_a)
+        rot_mat[1, 2] = unit_vec[1] * unit_vec[2] * (1 - cos_a) - unit_vec[0] * sin_a
+        rot_mat[2, 0] = unit_vec[0] * unit_vec[2] * (1 - cos_a) - unit_vec[1] * sin_a
+        rot_mat[2, 1] = unit_vec[1] * unit_vec[2] * (1 - cos_a) + unit_vec[0] * sin_a
+        rot_mat[2, 2] = cos_a + unit_vec[2] ** 2 * (1 - cos_a)
 
-        return SymmOp.from_rotation_and_translation(r, vec)
+        return SymmOp.from_rotation_and_translation(rot_mat, vec)
 
-    @typing.no_type_check
     @staticmethod
     def from_origin_axis_angle(
-        origin: ArrayLike, axis: ArrayLike, angle: float, angle_in_radians: bool = False
+        origin: ArrayLike,
+        axis: ArrayLike,
+        angle: float,
+        angle_in_radians: bool = False,
     ) -> SymmOp:
-        """Generates a SymmOp for a rotation about a given axis through an
+        """Generate a SymmOp for a rotation about a given axis through an
         origin.
 
         Args:
@@ -292,7 +305,7 @@ class SymmOp(MSONable):
         Returns:
             SymmOp.
         """
-        theta = angle * pi / 180 if not angle_in_radians else angle
+        theta = angle if angle_in_radians else angle * pi / 180
         a, b, c = origin
         ax_u, ax_v, ax_w = axis
         # Set some intermediate values.
@@ -337,7 +350,7 @@ class SymmOp(MSONable):
 
     @staticmethod
     def reflection(normal: ArrayLike, origin: ArrayLike = (0, 0, 0)) -> SymmOp:
-        """Returns reflection symmetry operation.
+        """Get reflection symmetry operation.
 
         Args:
             normal (3x1 array): Vector of the normal to the plane of
@@ -349,9 +362,9 @@ class SymmOp(MSONable):
             SymmOp for the reflection about the plane
         """
         # Normalize the normal vector first.
-        n = np.array(normal, dtype=float) / np.linalg.norm(normal)
+        normal = np.array(normal, dtype=float) / np.linalg.norm(normal)
 
-        u, v, w = n
+        u, v, w = normal
 
         translation = np.eye(4)
         translation[0:3, 3] = -np.array(origin)
@@ -386,7 +399,7 @@ class SymmOp(MSONable):
 
     @staticmethod
     def rotoreflection(axis: ArrayLike, angle: float, origin: ArrayLike = (0, 0, 0)) -> SymmOp:
-        """Returns a roto-reflection symmetry operation.
+        """Get a roto-reflection symmetry operation.
 
         Args:
             axis (3x1 array): Axis of rotation / mirror normal
@@ -394,13 +407,13 @@ class SymmOp(MSONable):
             origin (3x1 array): Point left invariant by roto-reflection.
                 Defaults to (0, 0, 0).
 
-        Return:
+        Returns:
             Roto-reflection operation
         """
         rot = SymmOp.from_origin_axis_angle(origin, axis, angle)
         refl = SymmOp.reflection(axis, origin)
-        m = np.dot(rot.affine_matrix, refl.affine_matrix)
-        return SymmOp(m)
+        matrix = np.dot(rot.affine_matrix, refl.affine_matrix)
+        return SymmOp(matrix)
 
     def as_dict(self) -> dict[str, Any]:
         """MSONable dict."""
@@ -412,17 +425,21 @@ class SymmOp(MSONable):
         }
 
     def as_xyz_str(self) -> str:
-        """Returns a string of the form 'x, y, z', '-x, -y, z', '-y+1/2, x+1/2, z+1/2', etc.
+        """Get a string of the form 'x, y, z', '-x, -y, z', '-y+1/2, x+1/2, z+1/2', etc.
         Only works for integer rotation matrices.
         """
-        # test for invalid rotation matrix
+        # Check for invalid rotation matrix
         if not np.all(np.isclose(self.rotation_matrix, np.round(self.rotation_matrix))):
             warnings.warn("Rotation matrix should be integer")
 
-        return transformation_to_string(self.rotation_matrix, translation_vec=self.translation_vector, delim=", ")
+        return transformation_to_string(
+            self.rotation_matrix,
+            translation_vec=self.translation_vector,
+            delim=", ",
+        )
 
     @classmethod
-    def from_xyz_str(cls, xyz_str: str) -> SymmOp:
+    def from_xyz_str(cls, xyz_str: str) -> Self:
         """
         Args:
             xyz_str: string of the form 'x, y, z', '-x, -y, z', '-2y+1/2, 3x+1/2, z-y+1/2', etc.
@@ -435,29 +452,31 @@ class SymmOp(MSONable):
         tokens = xyz_str.strip().replace(" ", "").lower().split(",")
         re_rot = re.compile(r"([+-]?)([\d\.]*)/?([\d\.]*)([x-z])")
         re_trans = re.compile(r"([+-]?)([\d\.]+)/?([\d\.]*)(?![x-z])")
-        for i, tok in enumerate(tokens):
-            # build the rotation matrix
-            for m in re_rot.finditer(tok):
-                factor = -1.0 if m.group(1) == "-" else 1.0
-                if m.group(2) != "":
-                    factor *= float(m.group(2)) / float(m.group(3)) if m.group(3) != "" else float(m.group(2))
-                j = ord(m.group(4)) - 120
-                rot_matrix[i, j] = factor
-            # build the translation vector
-            for m in re_trans.finditer(tok):
-                factor = -1 if m.group(1) == "-" else 1
-                num = float(m.group(2)) / float(m.group(3)) if m.group(3) != "" else float(m.group(2))
-                trans[i] = num * factor
+        for idx, tok in enumerate(tokens):
+            # Build the rotation matrix
+            for match in re_rot.finditer(tok):
+                factor = -1.0 if match[1] == "-" else 1.0
+                if match[2] != "":
+                    factor *= float(match[2]) / float(match[3]) if match[3] != "" else float(match[2])
+                j = ord(match[4]) - 120
+                rot_matrix[idx, j] = factor
+            # Build the translation vector
+            for match in re_trans.finditer(tok):
+                factor = -1 if match[1] == "-" else 1
+                num = float(match[2]) / float(match[3]) if match[3] != "" else float(match[2])
+                trans[idx] = num * factor
         return cls.from_rotation_and_translation(rot_matrix, trans)
 
     @classmethod
-    def from_dict(cls, d) -> SymmOp:
-        """:param d: dict
+    def from_dict(cls, dct: dict) -> Self:
+        """
+        Args:
+            dct: dict.
 
         Returns:
             SymmOp from dict representation.
         """
-        return cls(d["matrix"], d["tolerance"])
+        return cls(dct["matrix"], dct["tolerance"])
 
 
 class MagSymmOp(SymmOp):
@@ -467,8 +486,13 @@ class MagSymmOp(SymmOp):
     moment.
     """
 
-    def __init__(self, affine_transformation_matrix: ArrayLike, time_reversal: int, tol: float = 0.01) -> None:
-        """Initializes the MagSymmOp from a 4x4 affine transformation matrix and time reversal
+    def __init__(
+        self,
+        affine_transformation_matrix: ArrayLike,
+        time_reversal: Literal[-1, 1],
+        tol: float = 0.01,
+    ) -> None:
+        """Initialize the MagSymmOp from a 4x4 affine transformation matrix and time reversal
         operator. In general, this constructor should not be used unless you are transferring
         rotations. Use the static constructors instead to generate a SymmOp from proper rotations
         and translation.
@@ -479,13 +503,14 @@ class MagSymmOp(SymmOp):
             time_reversal (int): 1 or -1
             tol (float): Tolerance for determining if matrices are equal.
         """
-        SymmOp.__init__(self, affine_transformation_matrix, tol=tol)
-        if time_reversal not in (-1, 1):
-            raise Exception(f"Time reversal operator not well defined: {time_reversal}, {type(time_reversal)}")
-        self.time_reversal = time_reversal
+        super().__init__(affine_transformation_matrix, tol=tol)
+        if time_reversal in {-1, 1}:
+            self.time_reversal = time_reversal
+        else:
+            raise RuntimeError(f"Invalid {time_reversal=}, must be 1 or -1")
 
     def __eq__(self, other: object) -> bool:
-        if not isinstance(other, SymmOp):
+        if not isinstance(other, type(self)):
             return NotImplemented
         return np.allclose(self.affine_matrix, other.affine_matrix, atol=self.tol) and (
             self.time_reversal == other.time_reversal
@@ -495,18 +520,19 @@ class MagSymmOp(SymmOp):
         return self.as_xyzt_str()
 
     def __repr__(self) -> str:
-        output = [
-            "Rot:",
-            str(self.affine_matrix[0:3][:, 0:3]),
-            "tau",
-            str(self.affine_matrix[0:3][:, 3]),
-            "Time reversal:",
-            str(self.time_reversal),
-        ]
-        return "\n".join(output)
+        return "\n".join(
+            [
+                "Rot:",
+                str(self.affine_matrix[:3][:, :3]),
+                "tau",
+                str(self.affine_matrix[:3][:, 3]),
+                "Time reversal:",
+                str(self.time_reversal),
+            ]
+        )
 
     def __hash__(self) -> int:
-        # useful for obtaining a set of unique MagSymmOps
+        """Useful for obtaining a set of unique MagSymmOps."""
         hashable_value = (*tuple(self.affine_matrix.flatten()), self.time_reversal)
         return hash(hashable_value)
 
@@ -514,7 +540,7 @@ class MagSymmOp(SymmOp):
         Doi("10.1051/epjconf/20122200010"),
         description="Symmetry and magnetic structures",
     )
-    def operate_magmom(self, magmom):
+    def operate_magmom(self, magmom: Magmom) -> Magmom:
         """Apply time reversal operator on the magnetic moment. Note that
         magnetic moments transform as axial vectors, not polar vectors.
 
@@ -528,17 +554,18 @@ class MagSymmOp(SymmOp):
         Returns:
             Magnetic moment after operator applied as Magmom class
         """
-        magmom = Magmom(magmom)  # type casting to handle lists as input
+        # Type casting to handle lists as input
+        magmom = Magmom(magmom)
 
         transformed_moment = (
             self.apply_rotation_only(magmom.global_moment) * np.linalg.det(self.rotation_matrix) * self.time_reversal
         )
 
-        # retains input spin axis if different from default
+        # Retain input spin axis if different from default
         return Magmom.from_global_moment_and_saxis(transformed_moment, magmom.saxis)
 
     @classmethod
-    def from_symmop(cls, symmop: SymmOp, time_reversal) -> MagSymmOp:
+    def from_symmop(cls, symmop: SymmOp, time_reversal: Literal[-1, 1]) -> Self:
         """Initialize a MagSymmOp from a SymmOp and time reversal operator.
 
         Args:
@@ -554,10 +581,10 @@ class MagSymmOp(SymmOp):
     def from_rotation_and_translation_and_time_reversal(
         rotation_matrix: ArrayLike = ((1, 0, 0), (0, 1, 0), (0, 0, 1)),
         translation_vec: ArrayLike = (0, 0, 0),
-        time_reversal: int = 1,
+        time_reversal: Literal[-1, 1] = 1,
         tol: float = 0.1,
     ) -> MagSymmOp:
-        """Creates a symmetry operation from a rotation matrix, translation
+        """Create a symmetry operation from a rotation matrix, translation
         vector and time reversal operator.
 
         Args:
@@ -575,7 +602,7 @@ class MagSymmOp(SymmOp):
         return MagSymmOp.from_symmop(symm_op, time_reversal)
 
     @classmethod
-    def from_xyzt_str(cls, xyzt_str: str) -> MagSymmOp:
+    def from_xyzt_str(cls, xyzt_str: str) -> Self:
         """
         Args:
             xyzt_str (str): of the form 'x, y, z, +1', '-x, -y, z, -1',
@@ -588,14 +615,18 @@ class MagSymmOp(SymmOp):
         try:
             time_reversal = int(xyzt_str.rsplit(",", 1)[1])
         except Exception:
-            raise Exception("Time reversal operator could not be parsed.")
-        return cls.from_symmop(symm_op, time_reversal)
+            raise RuntimeError("Time reversal operator could not be parsed.")
+
+        if time_reversal in {-1, 1}:
+            return cls.from_symmop(symm_op, cast(Literal[-1, 1], time_reversal))
+
+        raise RuntimeError("Time reversal should be -1 or 1.")
 
     def as_xyzt_str(self) -> str:
-        """Returns a string of the form 'x, y, z, +1', '-x, -y, z, -1',
+        """Get a string of the form 'x, y, z, +1', '-x, -y, z, -1',
         '-y+1/2, x+1/2, z+1/2, +1', etc. Only works for integer rotation matrices.
         """
-        xyzt_string = SymmOp.as_xyz_str(self)
+        xyzt_string = super().as_xyz_str()
         return f"{xyzt_string}, {self.time_reversal:+}"
 
     def as_dict(self) -> dict[str, Any]:
@@ -609,10 +640,12 @@ class MagSymmOp(SymmOp):
         }
 
     @classmethod
-    def from_dict(cls, d: dict) -> MagSymmOp:
-        """:param d: dict
+    def from_dict(cls, dct: dict) -> Self:
+        """
+        Args:
+            dct: dict.
 
         Returns:
             MagneticSymmOp from dict representation.
         """
-        return cls(d["matrix"], tol=d["tolerance"], time_reversal=d["time_reversal"])
+        return cls(dct["matrix"], tol=dct["tolerance"], time_reversal=dct["time_reversal"])
