@@ -1,6 +1,6 @@
-"""This module provides a base class for tensor-like objects and methods for
-basic tensor manipulation. It also provides a class, SquareTensor,
-that provides basic methods for creating and manipulating rank 2 tensors.
+"""This module provides a base class Tensor for tensor-like objects and
+methods for basic tensor manipulation. It also provides SquareTensor,
+which provides basic methods for creating and manipulating rank 2 tensors.
 """
 
 from __future__ import annotations
@@ -24,6 +24,10 @@ from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
+    from typing import Any
+
+    from numpy.typing import NDArray
+    from typing_extensions import Self
 
     from pymatgen.core import Structure
 
@@ -31,9 +35,6 @@ __author__ = "Joseph Montoya"
 __credits__ = "Maarten de Jong, Shyam Dwaraknath, Wei Chen, Mark Asta, Anubhav Jain, Terence Lew"
 
 
-voigt_map = [(0, 0), (1, 1), (2, 2), (1, 2), (0, 2), (0, 1)]
-reverse_voigt_map = np.array([[0, 5, 4], [5, 1, 3], [4, 3, 2]])
-
 DEFAULT_QUAD = loadfn(os.path.join(os.path.dirname(__file__), "quad_data.json"))
 
 
@@ -44,14 +45,19 @@ class Tensor(np.ndarray, MSONable):
 
     symbol = "T"
 
-    def __new__(cls, input_array, vscale=None, check_rank=None):
+    def __new__(
+        cls,
+        input_array: NDArray,
+        vscale: NDArray | None = None,
+        check_rank: int | None = None,
+    ) -> Self:
         """Create a Tensor object. Note that the constructor uses __new__
         rather than __init__ according to the standard method of
         subclassing numpy ndarrays.
 
         Args:
             input_array: (array-like with shape 3^N): array-like representing
-                a tensor quantity in standard (i. e. non-voigt) notation
+                a tensor quantity in standard (i. e. non-Voigt) notation
             vscale: (N x M array-like): a matrix corresponding
                 to the coefficients of the Voigt-notation tensor
             check_rank: (int): If not None, checks that input_array's rank == check_rank.
@@ -69,7 +75,7 @@ class Tensor(np.ndarray, MSONable):
             obj._vscale = vscale
         if obj._vscale.shape != vshape:
             raise ValueError("Voigt scaling matrix must be the shape of the Voigt notation matrix or vector.")
-        if not all(dim == 3 for dim in obj.shape):
+        if any(dim != 3 for dim in obj.shape):
             raise ValueError(
                 "Pymatgen only supports 3-dimensional tensors, and default tensor constructor uses standard "
                 f"notation. To construct from Voigt notation, use {type(obj).__name__}.from_voigt"
@@ -98,22 +104,22 @@ class Tensor(np.ndarray, MSONable):
     def __repr__(self) -> str:
         return f"{type(self).__name__}({self})"
 
-    def zeroed(self, tol: float = 1e-3):
-        """Returns the matrix with all entries below a certain threshold (i.e. tol) set to zero."""
+    def zeroed(self, tol: float = 1e-3) -> Self:
+        """Get the matrix with all entries below a certain threshold (i.e. tol) set to zero."""
         new_tensor = self.copy()
         new_tensor[abs(new_tensor) < tol] = 0
         return new_tensor
 
-    def transform(self, symm_op):
-        """Applies a transformation (via a symmetry operation) to a tensor.
+    def transform(self, symm_op: SymmOp) -> Self:
+        """Apply a transformation (via a symmetry operation) to a tensor.
 
         Args:
             symm_op (SymmOp): a symmetry operation to apply to the tensor
         """
-        return self.__class__(symm_op.transform_tensor(self))
+        return type(self)(symm_op.transform_tensor(self))
 
-    def rotate(self, matrix, tol: float = 1e-3):
-        """Applies a rotation directly, and tests input matrix to ensure a valid
+    def rotate(self, matrix: NDArray, tol: float = 1e-3) -> Self:
+        """Apply a rotation directly, and tests input matrix to ensure a valid
         rotation.
 
         Args:
@@ -123,11 +129,15 @@ class Tensor(np.ndarray, MSONable):
         matrix = SquareTensor(matrix)
         if not matrix.is_rotation(tol):
             raise ValueError("Rotation matrix is not valid.")
-        sop = SymmOp.from_rotation_and_translation(matrix, [0.0, 0.0, 0.0])
-        return self.transform(sop)
+        symm_op = SymmOp.from_rotation_and_translation(matrix, [0.0, 0.0, 0.0])
+        return self.transform(symm_op)
 
-    def einsum_sequence(self, other_arrays, einsum_string=None):
-        """Calculates the result of an einstein summation expression."""
+    def einsum_sequence(
+        self,
+        other_arrays: NDArray,
+        einsum_string: str | None = None,
+    ) -> NDArray:
+        """Calculate the result of an einstein summation expression."""
         if not isinstance(other_arrays, list):
             raise ValueError("other tensors must be list of tensors or tensor input")
 
@@ -138,30 +148,28 @@ class Tensor(np.ndarray, MSONable):
             other_ranks = [len(a.shape) for a in other_arrays]
             idx = self.rank - sum(other_ranks)
             for length in other_ranks:
-                einsum_string += "," + lc[idx : idx + length]
+                einsum_string += f",{lc[idx : idx + length]}"
                 idx += length
 
         einsum_args = [self, *other_arrays]
         return np.einsum(einsum_string, *einsum_args)
 
-    def project(self, n):
-        """Convenience method for projection of a tensor into a
-        vector. Returns the tensor dotted into a unit vector
-        along the input n.
+    def project(self, n: NDArray) -> Self:
+        """Project a tensor into a vector. Returns the tensor
+        dotted into a unit vector along the input n.
 
         Args:
             n (3x1 array-like): direction to project onto
 
-        Returns (float):
-            scalar value corresponding to the projection of
-            the tensor into the vector
+        Returns:
+            float: scalar value corresponding to the projection of
+                the tensor into the vector
         """
-        n = get_uvec(n)
-        return self.einsum_sequence([n] * self.rank)
+        unit_vec = get_uvec(n)
+        return self.einsum_sequence([unit_vec] * self.rank)
 
-    def average_over_unit_sphere(self, quad=None):
-        """Method for averaging the tensor projection over the unit
-        with option for custom quadrature.
+    def average_over_unit_sphere(self, quad: dict | None = None) -> Self:
+        """Average the tensor projection over the unit with option for custom quadrature.
 
         Args:
             quad (dict): quadrature for integration, should be
@@ -175,15 +183,15 @@ class Tensor(np.ndarray, MSONable):
         weights, points = quad["weights"], quad["points"]
         return sum(w * self.project(n) for w, n in zip(weights, points))
 
-    def get_grouped_indices(self, voigt=False, **kwargs):
-        """Gets index sets for equivalent tensor values.
+    def get_grouped_indices(self, voigt: bool = False, **kwargs) -> list[list]:
+        """Get index sets for equivalent tensor values.
 
         Args:
             voigt (bool): whether to get grouped indices
                 of voigt or full notation tensor, defaults
                 to false
             **kwargs: keyword args for np.isclose. Can take atol
-                and rtol for absolute and relative tolerance, e. g.
+                and rtol for absolute and relative tolerance, e.g.
 
                 >>> tensor.group_array_indices(atol=1e-8)
 
@@ -210,8 +218,13 @@ class Tensor(np.ndarray, MSONable):
         # Don't return any empty lists
         return [g for g in grouped if g]
 
-    def get_symbol_dict(self, voigt=True, zero_index=False, **kwargs):
-        """Creates a summary dict for tensor with associated symbol.
+    def get_symbol_dict(
+        self,
+        voigt: bool = True,
+        zero_index: bool = False,
+        **kwargs,
+    ) -> dict[str, NDArray]:
+        """Create a summary dict for tensor with associated symbol.
 
         Args:
             voigt (bool): whether to get symbol dict for voigt
@@ -221,7 +234,7 @@ class Tensor(np.ndarray, MSONable):
                 defaults to false, since tensor notations tend to use
                 one-indexing, rather than zero indexing like python
             **kwargs: keyword args for np.isclose. Can take atol
-                and rtol for absolute and relative tolerance, e. g.
+                and rtol for absolute and relative tolerance, e.g.
 
                 >>> tensor.get_symbol_dict(atol=1e-8)
 
@@ -238,30 +251,30 @@ class Tensor(np.ndarray, MSONable):
         grouped = self.get_grouped_indices(voigt=voigt, **kwargs)
         p = 0 if zero_index else 1
         for indices in grouped:
-            sym_string = self.symbol + "_"
+            sym_string = f"{self.symbol}_"
             sym_string += "".join(str(i + p) for i in indices[0])
             value = array[indices[0]]
             if not np.isclose(value, 0):
                 dct[sym_string] = array[indices[0]]
         return dct
 
-    def round(self, decimals=0):
+    def round(self, decimals: int = 0) -> Self:
         """Wrapper around numpy.round to ensure object
         of same type is returned.
 
         Args:
-            decimals :Number of decimal places to round to (default: 0).
+            decimals: Number of decimal places to round to (default: 0).
                 If decimals is negative, it specifies the number of
                 positions to the left of the decimal point.
 
-        Returns (Tensor):
-            rounded tensor of same type
+        Returns:
+            Tensor: rounded tensor of same type
         """
-        return self.__class__(np.round(self, decimals=decimals))
+        return type(self)(np.round(self, decimals=decimals))
 
     @property
-    def symmetrized(self):
-        """Returns a generally symmetrized tensor, calculated by taking
+    def symmetrized(self) -> Self:
+        """A generally symmetrized tensor, calculated by taking
         the sum of the tensor and its transpose with respect to all
         possible permutations of indices.
         """
@@ -269,11 +282,11 @@ class Tensor(np.ndarray, MSONable):
         return sum(np.transpose(self, ind) for ind in perms) / len(perms)
 
     @property
-    def voigt_symmetrized(self):
-        """Returns a "voigt"-symmetrized tensor, i. e. a Voigt-notation
+    def voigt_symmetrized(self) -> Self:
+        """A "voigt"-symmetrized tensor, i. e. a Voigt-notation
         tensor such that it is invariant w.r.t. permutation of indices.
         """
-        if not (self.rank % 2 == 0 and self.rank >= 2):
+        if self.rank % 2 != 0 or self.rank < 2:
             raise ValueError("V-symmetrization requires rank even and >= 2")
 
         v = self.voigt
@@ -281,8 +294,8 @@ class Tensor(np.ndarray, MSONable):
         new_v = sum(np.transpose(v, ind) for ind in perms) / len(perms)
         return type(self).from_voigt(new_v)
 
-    def is_symmetric(self, tol: float = 1e-5):
-        """Tests whether a tensor is symmetric or not based on the residual
+    def is_symmetric(self, tol: float = 1e-5) -> bool:
+        """Test whether a tensor is symmetric or not based on the residual
         with its symmetric part, from self.symmetrized.
 
         Args:
@@ -290,8 +303,12 @@ class Tensor(np.ndarray, MSONable):
         """
         return (self - self.symmetrized < tol).all()
 
-    def fit_to_structure(self, structure: Structure, symprec: float = 0.1):
-        """Returns a tensor that is invariant with respect to symmetry
+    def fit_to_structure(
+        self,
+        structure: Structure,
+        symprec: float = 0.1,
+    ):
+        """Get a tensor that is invariant with respect to symmetry
         operations corresponding to a structure.
 
         Args:
@@ -304,8 +321,8 @@ class Tensor(np.ndarray, MSONable):
         symm_ops = sga.get_symmetry_operations(cartesian=True)
         return sum(self.transform(symm_op) for symm_op in symm_ops) / len(symm_ops)
 
-    def is_fit_to_structure(self, structure: Structure, tol: float = 1e-2):
-        """Tests whether a tensor is invariant with respect to the
+    def is_fit_to_structure(self, structure: Structure, tol: float = 1e-2) -> bool:
+        """Test whether a tensor is invariant with respect to the
         symmetry operations of a particular structure by testing
         whether the residual of the symmetric portion is below a
         tolerance.
@@ -317,22 +334,22 @@ class Tensor(np.ndarray, MSONable):
         return (self - self.fit_to_structure(structure) < tol).all()
 
     @property
-    def voigt(self):
-        """Returns the tensor in Voigt notation."""
+    def voigt(self) -> NDArray:
+        """The tensor in Voigt notation."""
         v_matrix = np.zeros(self._vscale.shape, dtype=self.dtype)
         this_voigt_map = self.get_voigt_dict(self.rank)
         for ind, v in this_voigt_map.items():
             v_matrix[v] = self[ind]
         if not self.is_voigt_symmetric():
-            warnings.warn("Tensor is not symmetric, information may be lost in voigt conversion.")
+            warnings.warn("Tensor is not symmetric, information may be lost in Voigt conversion.")
         return v_matrix * self._vscale
 
     def is_voigt_symmetric(self, tol: float = 1e-6) -> bool:
-        """Tests symmetry of tensor to that necessary for voigt-conversion
+        """Test symmetry of tensor to that necessary for voigt-conversion
         by grouping indices into pairs and constructing a sequence of
         possible permutations to be used in a tensor transpose.
         """
-        transpose_pieces = [[[0 for i in range(self.rank % 2)]]]
+        transpose_pieces = [[[0 for _ in range(self.rank % 2)]]]
         transpose_pieces += [[list(range(j, j + 2))] for j in range(self.rank % 2, self.rank, 2)]
         for n in range(self.rank % 2, len(transpose_pieces)):
             if len(transpose_pieces[n][0]) == 2:
@@ -344,24 +361,26 @@ class Tensor(np.ndarray, MSONable):
         return True
 
     @staticmethod
-    def get_voigt_dict(rank):
-        """Returns a dictionary that maps indices in the tensor to those
+    def get_voigt_dict(rank: int) -> dict[tuple[int, ...], tuple[int, ...]]:
+        """Get a dictionary that maps indices in the tensor to those
         in a voigt representation based on input rank.
 
         Args:
             rank (int): Tensor rank to generate the voigt map
         """
-        vdict = {}
+        reverse_voigt_map = np.array([[0, 5, 4], [5, 1, 3], [4, 3, 2]])
+
+        voigt_dict = {}
         for ind in itertools.product(*[range(3)] * rank):
             v_ind = ind[: rank % 2]
             for j in range(rank // 2):
                 pos = rank % 2 + 2 * j
                 v_ind += (reverse_voigt_map[ind[pos : pos + 2]],)
-            vdict[ind] = v_ind
-        return vdict
+            voigt_dict[ind] = v_ind
+        return voigt_dict
 
     @classmethod
-    def from_voigt(cls, voigt_input):
+    def from_voigt(cls, voigt_input: NDArray) -> Self:
         """Constructor based on the voigt notation vector or matrix.
 
         Args:
@@ -379,7 +398,10 @@ class Tensor(np.ndarray, MSONable):
         return cls(t)
 
     @staticmethod
-    def get_ieee_rotation(structure, refine_rotation=True):
+    def get_ieee_rotation(
+        structure: Structure,
+        refine_rotation: bool = True,
+    ) -> SquareTensor:
         """Given a structure associated with a tensor, determines
         the rotation matrix for IEEE conversion according to
         the 1987 IEEE standards.
@@ -451,7 +473,12 @@ class Tensor(np.ndarray, MSONable):
 
         return rotation
 
-    def convert_to_ieee(self, structure: Structure, initial_fit=True, refine_rotation=True):
+    def convert_to_ieee(
+        self,
+        structure: Structure,
+        initial_fit: bool = True,
+        refine_rotation: bool = True,
+    ) -> Self:
         """Given a structure associated with a tensor, attempts a
         calculation of the tensor in IEEE format according to
         the 1987 IEEE standards.
@@ -474,7 +501,12 @@ class Tensor(np.ndarray, MSONable):
             result = result.fit_to_structure(structure)
         return result.rotate(rotation, tol=1e-2)
 
-    def structure_transform(self, original_structure, new_structure, refine_rotation=True):
+    def structure_transform(
+        self,
+        original_structure: Structure,
+        new_structure: Structure,
+        refine_rotation: bool = True,
+    ) -> Self:
         """Transforms a tensor from one basis for an original structure
         into a new basis defined by a new structure.
 
@@ -503,15 +535,15 @@ class Tensor(np.ndarray, MSONable):
     @classmethod
     def from_values_indices(
         cls,
-        values,
-        indices,
-        populate=False,
-        structure=None,
-        voigt_rank=None,
-        vsym=True,
-        verbose=False,
-    ):
-        """Creates a tensor from values and indices, with options
+        values: list[float],
+        indices: NDArray,
+        populate: bool = False,
+        structure: Structure | None = None,
+        voigt_rank: int | None = None,
+        vsym: bool = True,
+        verbose: bool = False,
+    ) -> Self:
+        """Create a tensor from values and indices, with options
         for populating the remainder of the tensor.
 
         Args:
@@ -529,22 +561,25 @@ class Tensor(np.ndarray, MSONable):
                 optimization procedure
             verbose (bool): whether to populate verbosely
         """
-        # auto-detect voigt notation
+        # Auto-detect voigt notation
         # TODO: refactor rank inheritance to make this easier
         indices = np.array(indices)
         if voigt_rank:
-            shape = [3] * (voigt_rank % 2) + [6] * (voigt_rank // 2)
+            shape = np.array([3] * (voigt_rank % 2) + [6] * (voigt_rank // 2))
         else:
             shape = np.ceil(np.max(indices + 1, axis=0) / 3.0) * 3
+
         base = np.zeros(shape.astype(int))
         for v, idx in zip(values, indices):
             base[tuple(idx)] = v
         obj = cls.from_voigt(base) if 6 in shape else cls(base)
+
         if populate:
             assert structure, "Populate option must include structure input"
             obj = obj.populate(structure, vsym=vsym, verbose=verbose)
         elif structure:
             obj = obj.fit_to_structure(structure)
+
         return obj
 
     def populate(
@@ -555,7 +590,7 @@ class Tensor(np.ndarray, MSONable):
         verbose: bool = False,
         precond: bool = True,
         vsym: bool = True,
-    ) -> Tensor:
+    ) -> Self:
         """Takes a partially populated tensor, and populates the non-zero
         entries according to the following procedure, iterated until
         the desired convergence (specified via prec) is achieved.
@@ -578,7 +613,8 @@ class Tensor(np.ndarray, MSONable):
         Returns:
             Tensor: Populated tensor
         """
-        guess = Tensor(np.zeros(self.shape))
+        guess = type(self)(np.zeros(self.shape))
+        mask = None
         if precond:
             # Generate the guess from populated
             sops = SpacegroupAnalyzer(structure).get_symmetry_operations()
@@ -608,7 +644,7 @@ class Tensor(np.ndarray, MSONable):
                 for perm in perms:
                     vtrans = np.transpose(v, perm)
                     merge(v, vtrans)
-                guess = Tensor.from_voigt(v)
+                guess = type(self).from_voigt(v)
 
         assert guess.shape == self.shape, "Guess must have same shape"
         converged = False
@@ -628,18 +664,17 @@ class Tensor(np.ndarray, MSONable):
         if not converged:
             max_diff = np.max(np.abs(self - test_new))
             warnings.warn(f"Warning, populated tensor is not converged with max diff of {max_diff}")
-        return self.__class__(test_new)
+        return type(self)(test_new)
 
     def as_dict(self, voigt: bool = False) -> dict:
         """Serializes the tensor object.
 
         Args:
-            voigt (bool): flag for whether to store entries in
-                Voigt notation. Defaults to false, as information
-                may be lost in conversion.
+            voigt (bool): flag for whether to store entries in Voigt notation.
+                Defaults to false, as information may be lost in conversion.
 
-        Returns (dict):
-            serialized format tensor object
+        Returns:
+            dict: serialized format tensor object
         """
         input_array = self.voigt if voigt else self
         dct = {
@@ -652,15 +687,15 @@ class Tensor(np.ndarray, MSONable):
         return dct
 
     @classmethod
-    def from_dict(cls, d) -> Tensor:
+    def from_dict(cls, dct: dict) -> Self:
         """Instantiate Tensors from dicts (using MSONable API).
 
         Returns:
             Tensor: hydrated tensor object
         """
-        if d.get("voigt"):
-            return cls.from_voigt(d["input_array"])
-        return cls(d["input_array"])
+        if dct.get("voigt"):
+            return cls.from_voigt(dct["input_array"])
+        return cls(dct["input_array"])
 
 
 class TensorCollection(collections.abc.Sequence, MSONable):
@@ -669,8 +704,10 @@ class TensorCollection(collections.abc.Sequence, MSONable):
     """
 
     def __init__(self, tensor_list: Sequence, base_class=Tensor) -> None:
-        """:param tensor_list: List of tensors.
-        :param base_class: Class to be used.
+        """
+        Args:
+            tensor_list: List of tensors.
+            base_class: Class to be used.
         """
         self.tensors = [tensor if isinstance(tensor, base_class) else base_class(tensor) for tensor in tensor_list]
 
@@ -683,62 +720,79 @@ class TensorCollection(collections.abc.Sequence, MSONable):
     def __iter__(self):
         return iter(self.tensors)
 
-    def zeroed(self, tol: float = 1e-3):
-        """:param tol: Tolerance
+    def zeroed(self, tol: float = 1e-3) -> Self:
+        """
+        Args:
+            tol: Tolerance.
 
         Returns:
             TensorCollection where small values are set to 0.
         """
-        return self.__class__([tensor.zeroed(tol) for tensor in self])
+        return type(self)([tensor.zeroed(tol) for tensor in self])
 
-    def transform(self, symm_op):
+    def transform(self, symm_op: SymmOp) -> Self:
         """Transforms TensorCollection with a symmetry operation.
 
-        :param symm_op: SymmetryOperation.
+        Args:
+            symm_op: SymmetryOperation.
 
         Returns:
             TensorCollection.
         """
-        return self.__class__([tensor.transform(symm_op) for tensor in self])
+        return type(self)([tensor.transform(symm_op) for tensor in self])
 
-    def rotate(self, matrix, tol: float = 1e-3):
+    def rotate(self, matrix, tol: float = 1e-3) -> Self:
         """Rotates TensorCollection.
 
-        :param matrix: Rotation matrix.
-        :param tol: tolerance.
+        Args:
+            matrix: Rotation matrix.
+            tol: tolerance.
 
         Returns:
             TensorCollection.
         """
-        return self.__class__([tensor.rotate(matrix, tol) for tensor in self])
+        return type(self)([tensor.rotate(matrix, tol) for tensor in self])
 
     @property
-    def symmetrized(self):
+    def symmetrized(self) -> Self:
         """TensorCollection where all tensors are symmetrized."""
-        return self.__class__([tensor.symmetrized for tensor in self])
+        return type(self)([tensor.symmetrized for tensor in self])
 
-    def is_symmetric(self, tol: float = 1e-5):
-        """:param tol: tolerance
+    def is_symmetric(self, tol: float = 1e-5) -> bool:
+        """
+        Args:
+            tol: tolerance.
 
         Returns:
             Whether all tensors are symmetric.
         """
         return all(tensor.is_symmetric(tol) for tensor in self)
 
-    def fit_to_structure(self, structure: Structure, symprec: float = 0.1):
-        """Fits all tensors to a Structure.
+    def fit_to_structure(
+        self,
+        structure: Structure,
+        symprec: float = 0.1,
+    ) -> Self:
+        """Fit all tensors to a Structure.
 
-        :param structure: Structure
-        :param symprec: symmetry precision.
+        Args:
+            structure: Structure
+            symprec: symmetry precision.
 
         Returns:
             TensorCollection.
         """
-        return self.__class__([tensor.fit_to_structure(structure, symprec) for tensor in self])
+        return type(self)([tensor.fit_to_structure(structure, symprec) for tensor in self])
 
-    def is_fit_to_structure(self, structure: Structure, tol: float = 1e-2):
-        """:param structure: Structure
-        :param tol: tolerance
+    def is_fit_to_structure(
+        self,
+        structure: Structure,
+        tol: float = 1e-2,
+    ) -> bool:
+        """
+        Args:
+            structure: Structure
+            tol: tolerance.
 
         Returns:
             Whether all tensors are fitted to Structure.
@@ -746,17 +800,19 @@ class TensorCollection(collections.abc.Sequence, MSONable):
         return all(tensor.is_fit_to_structure(structure, tol) for tensor in self)
 
     @property
-    def voigt(self):
+    def voigt(self) -> list[NDArray]:
         """TensorCollection where all tensors are in Voigt form."""
         return [tensor.voigt for tensor in self]
 
     @property
-    def ranks(self):
+    def ranks(self) -> list:
         """Ranks for all tensors."""
         return [tensor.rank for tensor in self]
 
-    def is_voigt_symmetric(self, tol: float = 1e-6):
-        """:param tol: tolerance
+    def is_voigt_symmetric(self, tol: float = 1e-6) -> bool:
+        """
+        Args:
+            tol: tolerance.
 
         Returns:
             Whether all tensors are voigt symmetric.
@@ -764,53 +820,67 @@ class TensorCollection(collections.abc.Sequence, MSONable):
         return all(tensor.is_voigt_symmetric(tol) for tensor in self)
 
     @classmethod
-    def from_voigt(cls, voigt_input_list, base_class=Tensor):
-        """Creates TensorCollection from voigt form.
+    def from_voigt(
+        cls,
+        voigt_input_list: list[Tensor],
+        base_class=Tensor,
+    ) -> Self:
+        """Create TensorCollection from voigt form.
 
-        :param voigt_input_list: List of voigt tensors
-        :param base_class: Class for tensor.
+        Args:
+            voigt_input_list: List of voigt tensors
+            base_class: Class for tensor.
 
         Returns:
             TensorCollection.
         """
         return cls([base_class.from_voigt(v) for v in voigt_input_list])
 
-    def convert_to_ieee(self, structure: Structure, initial_fit=True, refine_rotation=True):
+    def convert_to_ieee(
+        self,
+        structure: Structure,
+        initial_fit: bool = True,
+        refine_rotation: bool = True,
+    ) -> Self:
         """Convert all tensors to IEEE.
 
-        :param structure: Structure
-        :param initial_fit: Whether to perform an initial fit.
-        :param refine_rotation: Whether to refine the rotation.
+        Args:
+            structure: Structure
+            initial_fit: Whether to perform an initial fit.
+            refine_rotation: Whether to refine the rotation.
 
         Returns:
             TensorCollection.
         """
-        return self.__class__([tensor.convert_to_ieee(structure, initial_fit, refine_rotation) for tensor in self])
+        return type(self)([tensor.convert_to_ieee(structure, initial_fit, refine_rotation) for tensor in self])
 
-    def round(self, *args, **kwargs):
+    def round(self, *args, **kwargs) -> Self:
         """Round all tensors.
 
-        :param args: Passthrough to Tensor.round
-        :param kwargs: Passthrough to Tensor.round
+        Args:
+            args: Passthrough to Tensor.round
+            kwargs: Passthrough to Tensor.round
 
         Returns:
             TensorCollection.
         """
-        return self.__class__([tensor.round(*args, **kwargs) for tensor in self])
+        return type(self)([tensor.round(*args, **kwargs) for tensor in self])
 
     @property
-    def voigt_symmetrized(self):
+    def voigt_symmetrized(self) -> Self:
         """TensorCollection where all tensors are voigt symmetrized."""
-        return self.__class__([tensor.voigt_symmetrized for tensor in self])
+        return type(self)([tensor.voigt_symmetrized for tensor in self])
 
-    def as_dict(self, voigt=False):
-        """:param voigt: Whether to use Voigt form.
+    def as_dict(self, voigt: bool = False) -> dict:
+        """
+        Args:
+            voigt: Whether to use Voigt form.
 
         Returns:
             Dict representation of TensorCollection.
         """
         tensor_list = self.voigt if voigt else self
-        dct = {
+        dct: dict[str, Any] = {
             "@module": type(self).__module__,
             "@class": type(self).__name__,
             "tensor_list": [tensor.tolist() for tensor in tensor_list],
@@ -820,18 +890,18 @@ class TensorCollection(collections.abc.Sequence, MSONable):
         return dct
 
     @classmethod
-    def from_dict(cls, d):
-        """Creates TensorCollection from dict.
+    def from_dict(cls, dct: dict) -> Self:
+        """Create TensorCollection from dict.
 
-        :param d: dict
+        Args:
+            dct: dict
 
         Returns:
             TensorCollection
         """
-        voigt = d.get("voigt")
-        if voigt:
-            return cls.from_voigt(d["tensor_list"])
-        return cls(d["tensor_list"])
+        if dct.get("voigt"):
+            return cls.from_voigt(dct["tensor_list"])
+        return cls(dct["tensor_list"])
 
 
 class SquareTensor(Tensor):
@@ -839,7 +909,11 @@ class SquareTensor(Tensor):
     (stress, strain etc.).
     """
 
-    def __new__(cls, input_array, vscale=None):
+    def __new__(
+        cls,
+        input_array: NDArray,
+        vscale: NDArray | None = None,
+    ) -> Self:
         """Create a SquareTensor object. Note that the constructor uses __new__ rather than
         __init__ according to the standard method of subclassing numpy ndarrays. Error
         is thrown when the class is initialized with non-square matrix.
@@ -854,23 +928,27 @@ class SquareTensor(Tensor):
         return obj.view(cls)
 
     @property
-    def trans(self):
+    def trans(self) -> Self:
         """Shorthand for transpose on SquareTensor."""
-        return SquareTensor(np.transpose(self))
+        return type(self)(np.transpose(self))
 
     @property
-    def inv(self):
+    def inv(self) -> Self:
         """Shorthand for matrix inverse on SquareTensor."""
         if self.det == 0:
             raise ValueError("SquareTensor is non-invertible")
-        return SquareTensor(np.linalg.inv(self))
+        return type(self)(np.linalg.inv(self))
 
     @property
-    def det(self):
+    def det(self) -> Self:
         """Shorthand for the determinant of the SquareTensor."""
         return np.linalg.det(self)
 
-    def is_rotation(self, tol: float = 1e-3, include_improper=True):
+    def is_rotation(
+        self,
+        tol: float = 1e-3,
+        include_improper: bool = True,
+    ) -> bool:
         """Test to see if tensor is a valid rotation matrix, performs a
         test to check whether the inverse is equal to the transpose
         and if the determinant is equal to one within the specified
@@ -888,7 +966,7 @@ class SquareTensor(Tensor):
             det = np.abs(det)
         return (np.abs(self.inv - self.trans) < tol).all() and (np.abs(det - 1.0) < tol)
 
-    def refine_rotation(self):
+    def refine_rotation(self) -> Self:
         """Helper method for refining rotation matrix by ensuring
         that second and third rows are perpendicular to the first.
         Gets new y vector from an orthogonal projection of x onto y
@@ -904,41 +982,44 @@ class SquareTensor(Tensor):
         # Get a projection on y
         new_y = y - np.dot(new_x, y) * new_x
         new_z = np.cross(new_x, new_y)
-        return SquareTensor([new_x, new_y, new_z])
+        return type(self)([new_x, new_y, new_z])
 
-    def get_scaled(self, scale_factor):
+    def get_scaled(self, scale_factor: float) -> Self:
         """Scales the tensor by a certain multiplicative scale factor.
 
         Args:
             scale_factor (float): scalar multiplier to be applied to the
                 SquareTensor object
         """
-        return SquareTensor(self * scale_factor)
+        return type(self)(self * scale_factor)
 
     @property
-    def principal_invariants(self):
-        """Returns a list of principal invariants for the tensor,
+    def principal_invariants(self) -> NDArray:
+        """A list of principal invariants for the tensor,
         which are the values of the coefficients of the characteristic
         polynomial for the matrix.
         """
         return np.poly(self)[1:] * np.array([-1, 1, -1])
 
-    def polar_decomposition(self, side="right"):
-        """Calculates matrices for polar decomposition."""
+    def polar_decomposition(self, side: str = "right") -> tuple:
+        """Calculate matrices for polar decomposition."""
         return polar(self, side=side)
 
 
-def get_uvec(vec):
-    """Gets a unit vector parallel to input vector."""
+def get_uvec(vec: NDArray) -> NDArray:
+    """Get a unit vector parallel to input vector."""
     norm = np.linalg.norm(vec)
-    if norm < 1e-8:
-        return vec
-    return vec / norm
+    return vec if norm < 1e-8 else vec / norm
 
 
-def symmetry_reduce(tensors, structure: Structure, tol: float = 1e-8, **kwargs):
-    """Function that converts a list of tensors corresponding to a structure
-    and returns a dictionary consisting of unique tensor keys with symmop
+def symmetry_reduce(
+    tensors,
+    structure: Structure,
+    tol: float = 1e-8,
+    **kwargs,
+) -> TensorMapping:
+    """Convert a list of tensors corresponding to a structure
+    and returns a dictionary consisting of unique tensor keys with SymmOp
     values corresponding to transformations that will result in derivative
     tensors from the original list.
 
@@ -959,9 +1040,9 @@ def symmetry_reduce(tensors, structure: Structure, tol: float = 1e-8, **kwargs):
     unique_mapping = TensorMapping([tensors[0]], [[]], tol=tol)
     for tensor in tensors[1:]:
         is_unique = True
-        for unique_tensor, symmop in itertools.product(unique_mapping, symm_ops):
-            if np.allclose(unique_tensor.transform(symmop), tensor, atol=tol):
-                unique_mapping[unique_tensor].append(symmop)
+        for unique_tensor, symm_op in itertools.product(unique_mapping, symm_ops):
+            if np.allclose(unique_tensor.transform(symm_op), tensor, atol=tol):
+                unique_mapping[unique_tensor].append(symm_op)
                 is_unique = False
                 break
         if is_unique:
@@ -980,7 +1061,12 @@ class TensorMapping(collections.abc.MutableMapping):
     and should be used with care.
     """
 
-    def __init__(self, tensors: Sequence[Tensor] = (), values: Sequence = (), tol: float = 1e-5) -> None:
+    def __init__(
+        self,
+        tensors: Sequence[Tensor] = (),
+        values: Sequence = (),
+        tol: float = 1e-5,
+    ) -> None:
         """Initialize a TensorMapping.
 
         Args:
@@ -1023,6 +1109,9 @@ class TensorMapping(collections.abc.MutableMapping):
     def __iter__(self):
         yield from self._tensor_list
 
+    def __contains__(self, item) -> bool:
+        return self._get_item_index(item) is not None
+
     def values(self):
         """Values in mapping."""
         return self._value_list
@@ -1031,9 +1120,6 @@ class TensorMapping(collections.abc.MutableMapping):
         """Items in mapping."""
         return zip(self._tensor_list, self._value_list)
 
-    def __contains__(self, item) -> bool:
-        return self._get_item_index(item) is not None
-
     def _get_item_index(self, item):
         if len(self._tensor_list) == 0:
             return None
@@ -1043,6 +1129,5 @@ class TensorMapping(collections.abc.MutableMapping):
         indices = np.where(mask)[0]
         if len(indices) > 1:
             raise ValueError("Tensor key collision.")
-        if len(indices) == 0:
-            return None
-        return indices[0]
+
+        return None if len(indices) == 0 else indices[0]
