@@ -1,22 +1,32 @@
-"""This module implements a FloatWithUnit, which is a subclass of float. It
-also defines supported units for some commonly used units for energy, length,
-temperature, time and charge. FloatWithUnit also support conversion to one
-another, and additions and subtractions perform automatic conversion if
-units are detected. An ArrayWithUnit is also implemented, which is a subclass
-of numpy's ndarray with similar unit features.
+"""This module defines commonly used units
+for energy, length, temperature, time and charge.
+
+Also defines the following classes:
+- FloatWithUnit, a subclass of float, which supports
+    conversion to another, and additions and subtractions
+    perform automatic conversion if units are detected.
+- ArrayWithUnit, a subclass of numpy's ndarray with similar unit features.
 """
 
 from __future__ import annotations
 
 import collections
-import numbers
 import re
+from collections import defaultdict
 from functools import partial
-from typing import Any
+from numbers import Number
+from typing import TYPE_CHECKING, cast
 
 import numpy as np
 import scipy.constants as const
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+    from typing import Any
+
+    from numpy.typing import NDArray
+    from typing_extensions import Self
+
 __author__ = "Shyue Ping Ong, Matteo Giantomassi"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "1.0"
@@ -24,7 +34,7 @@ __maintainer__ = "Shyue Ping Ong, Matteo Giantomassi"
 __status__ = "Production"
 __date__ = "Aug 30, 2013"
 
-"""Some conversion factors"""
+# Some conversion factors
 Ha_to_eV = 1 / const.physical_constants["electron volt-hartree relationship"][0]
 eV_to_Ha = 1 / Ha_to_eV
 Ry_to_eV = Ha_to_eV / 2
@@ -36,12 +46,10 @@ ang_to_bohr = 1 / bohr_to_ang
 kCal_to_kJ = const.calorie
 kb = const.physical_constants["Boltzmann constant in eV/K"][0]
 
-"""
-Definitions of supported units. Values below are essentially scaling and
-conversion factors. What matters is the relative values, not the absolute.
-The SI units must have factor 1.
-"""
-BASE_UNITS = {
+# Definitions of supported units. Values below are essentially scaling and
+# conversion factors. What matters is the relative values, not the absolute.
+# The SI units must have factor 1.
+BASE_UNITS: dict[str, dict] = {
     "length": {
         "m": 1,
         "km": 1000,
@@ -136,75 +144,67 @@ SUPPORTED_UNIT_NAMES = tuple(i for d in ALL_UNITS.values() for i in d)
 _UNAME2UTYPE = {uname: utype for utype, dct in ALL_UNITS.items() for uname in dct}
 
 
-def _get_si_unit(unit):
-    unit_type = _UNAME2UTYPE[unit]
-    si_unit = filter(lambda k: BASE_UNITS[unit_type][k] == 1, BASE_UNITS[unit_type])
-    return next(iter(si_unit)), BASE_UNITS[unit_type][unit]
-
-
 class UnitError(BaseException):
     """Exception class for unit errors."""
 
 
-def _check_mappings(u):
-    for v in DERIVED_UNITS.values():
-        for k2, v2 in v.items():
-            if all(v2.get(ku, 0) == vu for ku, vu in u.items()) and all(
-                u.get(kv2, 0) == vv2 for kv2, vv2 in v2.items()
-            ):
-                return {k2: 1}
-    return u
-
-
 class Unit(collections.abc.Mapping):
-    """Represents a unit, e.g., "m" for meters, etc. Supports compound units.
-    Only integer powers are supported for units.
+    """Represent a unit, e.g. "m" for meters, etc. Supports compound units.
+    Only integer powers are supported.
     """
 
-    Error = UnitError
-
-    def __init__(self, unit_def) -> None:
-        """Constructs a unit.
-
+    def __init__(self, unit_def: str | dict[str, int]) -> None:
+        """
         Args:
             unit_def: A definition for the unit. Either a mapping of unit to
-                powers, e.g., {"m": 2, "s": -1} represents "m^2 s^-1",
+                powers, e.g. {"m": 2, "s": -1} represents "m^2 s^-1",
                 or simply as a string "kg m^2 s^-1". Note that the supported
                 format uses "^" as the power operator and all units must be
                 space-separated.
         """
+
+        def check_mappings(u):
+            for v in DERIVED_UNITS.values():
+                for k2, v2 in v.items():
+                    if all(v2.get(ku, 0) == vu for ku, vu in u.items()) and all(
+                        u.get(kv2, 0) == vv2 for kv2, vv2 in v2.items()
+                    ):
+                        return {k2: 1}
+            return u
+
         if isinstance(unit_def, str):
-            unit: dict[str, int] = collections.defaultdict(int)
+            unit: dict[str, int] = defaultdict(int)
 
             for match in re.finditer(r"([A-Za-z]+)\s*\^*\s*([\-0-9]*)", unit_def):
-                val = match.group(2)
-                val = 1 if not val else int(val)
-                key = match.group(1)
+                val = match[2]
+                val = int(val) if val else 1
+                key = match[1]
                 unit[key] += val
         else:
             unit = {k: v for k, v in dict(unit_def).items() if v != 0}
-        self._unit = _check_mappings(unit)
 
-    def __mul__(self, other):
-        new_units = collections.defaultdict(int)
+        self._unit = check_mappings(unit)
+
+    def __mul__(self, other: Self) -> Self:
+        new_units: defaultdict = defaultdict(int)
         for k, v in self.items():
             new_units[k] += v
         for k, v in other.items():
             new_units[k] += v
-        return Unit(new_units)
+        return type(self)(new_units)
 
-    def __truediv__(self, other):
-        new_units = collections.defaultdict(int)
+    def __truediv__(self, other: Self) -> Self:
+        new_units: defaultdict = defaultdict(int)
         for k, v in self.items():
             new_units[k] += v
         for k, v in other.items():
             new_units[k] -= v
-        return Unit(new_units)
+        return type(self)(new_units)
 
-    def __pow__(self, i):
-        return Unit({k: v * i for k, v in self.items()})
+    def __pow__(self, i: Self) -> Self:
+        return type(self)({k: v * i for k, v in self.items()})
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator:
         return iter(self._unit)
 
     def __getitem__(self, i) -> int:
@@ -220,45 +220,55 @@ class Unit(collections.abc.Mapping):
         )
 
     @property
-    def as_base_units(self):
-        """Converts all units to base SI units, including derived units.
+    def as_base_units(self) -> tuple[dict, float]:
+        """Convert all units to base SI units, including derived units.
 
         Returns:
-            (base_units_dict, scaling factor). base_units_dict will not
-            contain any constants, which are gathered in the scaling factor.
+            tuple[dict, float]: (base_units_dict, scaling factor). base_units_dict will not
+                contain any constants, which are gathered in the scaling factor.
         """
-        b = collections.defaultdict(int)
-        factor = 1
+
+        def get_si_unit(unit):
+            unit_type = _UNAME2UTYPE[unit]
+            si_unit = filter(lambda k: BASE_UNITS[unit_type][k] == 1, BASE_UNITS[unit_type])
+            return next(iter(si_unit)), BASE_UNITS[unit_type][unit]
+
+        base_units: defaultdict = defaultdict(int)
+        factor: float = 1
         for k, v in self.items():
             derived = False
-            for d in DERIVED_UNITS.values():
-                if k in d:
-                    for k2, v2 in d[k].items():
-                        if isinstance(k2, numbers.Number):
+            for dct in DERIVED_UNITS.values():
+                if k in dct:
+                    for k2, v2 in dct[k].items():
+                        if isinstance(k2, Number):
                             factor *= k2 ** (v2 * v)
                         else:
-                            b[k2] += v2 * v
+                            base_units[k2] += v2 * v
                     derived = True
                     break
             if not derived:
-                si, f = _get_si_unit(k)
-                b[si] += v
+                si, f = get_si_unit(k)
+                base_units[si] += v
                 factor *= f**v
-        return {k: v for k, v in b.items() if v != 0}, factor
+        return {k: v for k, v in base_units.items() if v != 0}, factor
 
-    def get_conversion_factor(self, new_unit):
-        """Returns a conversion factor between this unit and a new unit.
+    def get_conversion_factor(self, new_unit: str | Unit) -> float:
+        """Get the conversion factor between this unit and a new unit.
         Compound units are supported, but must have the same powers in each
         unit type.
 
         Args:
-            new_unit: The new unit.
+            new_unit (str | Unit): The new unit.
         """
+        _new_unit: str = repr(new_unit) if isinstance(new_unit, Unit) else new_unit
+
         old_base, old_factor = self.as_base_units
-        new_base, new_factor = Unit(new_unit).as_base_units
+        new_base, new_factor = type(self)(_new_unit).as_base_units
+
         units_new = sorted(new_base.items(), key=lambda d: _UNAME2UTYPE[d[0]])
         units_old = sorted(old_base.items(), key=lambda d: _UNAME2UTYPE[d[0]])
-        factor = old_factor / new_factor
+        factor: float = old_factor / new_factor
+
         for old, new in zip(units_old, units_new):
             if old[1] != new[1]:
                 raise UnitError(f"Units {old} and {new} are not compatible!")
@@ -272,69 +282,54 @@ class FloatWithUnit(float):
     pre-defined unit type subclasses such as Energy, Length, etc. instead of
     using FloatWithUnit directly.
 
-    Supports conversion, addition and subtraction of the same unit type. E.g.,
+    Support conversion, addition and subtraction of the same unit type. e.g.
     1 m + 20 cm will be automatically converted to 1.2 m (units follow the
     leftmost quantity). Note that FloatWithUnit does not override the eq
     method for float, i.e., units are not checked when testing for equality.
     The reason is to allow this class to be used transparently wherever floats
     are expected.
 
-    >>> e = Energy(1.1, "Ha")
-    >>> a = Energy(1.1, "Ha")
-    >>> b = Energy(3, "eV")
-    >>> c = a + b
-    >>> print(c)
-    1.2102479761938871 Ha
-    >>> c.to("eV")
-    32.932522246000005 eV
+    Example usage:
+        >>> energy_a = Energy(1.1, "Ha")
+        >>> energy_b = Energy(3, "eV")
+        >>> energy_c = energy_a + energy_b
+        >>> print(energy_c)
+        1.2102479761938871 Ha
+        >>> energy_c.to("eV")
+        32.932522246000005 eV
     """
 
-    Error = UnitError
-
-    @classmethod
-    def from_str(cls, s):
-        """Parse string to FloatWithUnit.
-
-        Example: Memory.from_str("1. Mb")
-        """
-        # Extract num and unit string.
-        s = s.strip()
-        for idx, char in enumerate(s):  # noqa: B007
-            if char.isalpha() or char.isspace():
-                break
-        else:
-            raise Exception(f"Unit is missing in string {s}")
-        num, unit = float(s[:idx]), s[idx:]
-
-        # Find unit type (set it to None if it cannot be detected)
-        for unit_type, d in BASE_UNITS.items():  # noqa: B007
-            if unit in d:
-                break
-        else:
-            unit_type = None
-
-        return cls(num, unit, unit_type=unit_type)
-
-    def __new__(cls, val, unit, unit_type=None):
-        """Overrides __new__ since we are subclassing a Python primitive/."""
-        new = float.__new__(cls, val)
-        new._unit = Unit(unit)
-        new._unit_type = unit_type
-        return new
-
-    def __init__(self, val, unit, unit_type=None) -> None:
-        """Initializes a float with unit.
+    def __init__(
+        self,
+        val: float | Number,
+        unit: str | Unit,
+        unit_type: str | None = None,
+    ) -> None:
+        """Initialize a float with unit.
 
         Args:
             val (float): Value
-            unit (Unit): A unit. E.g., "C".
-            unit_type (str): A type of unit. E.g., "charge"
+            unit (str | Unit): A unit. e.g. "C".
+            unit_type (str): A type of unit. e.g. "charge"
         """
         if unit_type is not None and str(unit) not in ALL_UNITS[unit_type]:
             raise UnitError(f"{unit} is not a supported unit for {unit_type}")
-        self._unit = Unit(unit)
+
+        self._unit = unit if isinstance(unit, Unit) else Unit(unit)
         self._unit_type = unit_type
 
+    def __new__(
+        cls,
+        val,
+        unit: str | Unit,
+        unit_type: str | None = None,
+    ) -> Self:
+        """Override __new__."""
+        new = float.__new__(cls, val)
+        new._unit = unit if isinstance(unit, Unit) else Unit(unit)
+        new._unit_type = unit_type
+        return new
+
     def __str__(self) -> str:
         return f"{super().__str__()} {self._unit}"
 
@@ -346,7 +341,11 @@ class FloatWithUnit(float):
         val = other
         if other.unit != self._unit:
             val = other.to(self._unit)
-        return FloatWithUnit(float(self) + val, unit_type=self._unit_type, unit=self._unit)
+        return type(self)(
+            float(self) + val,
+            unit_type=self._unit_type,
+            unit=self._unit,
+        )
 
     def __sub__(self, other):
         if not hasattr(other, "unit_type"):
@@ -356,32 +355,57 @@ class FloatWithUnit(float):
         val = other
         if other.unit != self._unit:
             val = other.to(self._unit)
-        return FloatWithUnit(float(self) - val, unit_type=self._unit_type, unit=self._unit)
+        return type(self)(
+            float(self) - val,
+            unit_type=self._unit_type,
+            unit=self._unit,
+        )
 
     def __mul__(self, other):
-        if not isinstance(other, FloatWithUnit):
-            return FloatWithUnit(float(self) * other, unit_type=self._unit_type, unit=self._unit)
-        return FloatWithUnit(float(self) * other, unit_type=None, unit=self._unit * other._unit)
+        cls = type(self)
+        if not isinstance(other, cls):
+            return cls(
+                float(self) * other,
+                unit_type=self._unit_type,
+                unit=self._unit,
+            )
+        return cls(
+            float(self) * other,
+            unit_type=None,
+            unit=self._unit * other._unit,
+        )
 
     def __rmul__(self, other):
-        if not isinstance(other, FloatWithUnit):
-            return FloatWithUnit(float(self) * other, unit_type=self._unit_type, unit=self._unit)
-        return FloatWithUnit(float(self) * other, unit_type=None, unit=self._unit * other._unit)
+        if not isinstance(other, type(self)):
+            return type(self)(
+                float(self) * other,
+                unit_type=self._unit_type,
+                unit=self._unit,
+            )
+        return type(self)(
+            float(self) * other,
+            unit_type=None,
+            unit=self._unit * other._unit,
+        )
 
     def __pow__(self, i):
-        return FloatWithUnit(float(self) ** i, unit_type=None, unit=self._unit**i)
+        return type(self)(float(self) ** i, unit_type=None, unit=self._unit**i)
 
     def __truediv__(self, other):
         val = super().__truediv__(other)
-        if not isinstance(other, FloatWithUnit):
-            return FloatWithUnit(val, unit_type=self._unit_type, unit=self._unit)
-        return FloatWithUnit(val, unit_type=None, unit=self._unit / other._unit)
+        if not isinstance(other, type(self)):
+            return type(self)(val, unit_type=self._unit_type, unit=self._unit)
+        return type(self)(val, unit_type=None, unit=self._unit / other._unit)
 
     def __neg__(self):
-        return FloatWithUnit(super().__neg__(), unit_type=self._unit_type, unit=self._unit)
+        return type(self)(
+            super().__neg__(),
+            unit_type=self._unit_type,
+            unit=self._unit,
+        )
 
     def __getnewargs__(self):
-        """Function used by pickle to recreate object."""
+        """Used by pickle to recreate object."""
         # TODO There's a problem with _unit_type if we try to unpickle objects from file.
         # since self._unit_type might not be defined. I think this is due to
         # the use of decorators (property and unitized). In particular I have problems with "amu"
@@ -402,101 +426,116 @@ class FloatWithUnit(float):
         self._unit = state["_unit"]
 
     @property
-    def unit_type(self) -> str:
+    def unit_type(self) -> str | None:
         """The type of unit. Energy, Charge, etc."""
         return self._unit_type
 
     @property
     def unit(self) -> Unit:
-        """The unit, e.g., "eV"."""
+        """The unit, e.g. "eV"."""
         return self._unit
 
-    def to(self, new_unit):
-        """Conversion to a new_unit. Right now, only supports 1 to 1 mapping of
-        units of each type.
-
-        Args:
-            new_unit: New unit type.
-
-        Returns:
-            A FloatWithUnit object in the new units.
+    @classmethod
+    def from_str(cls, string: str) -> Self:
+        """Convert string to FloatWithUnit.
 
         Example usage:
-        >>> e = Energy(1.1, "eV")
-        >>> e = Energy(1.1, "Ha")
-        >>> e.to("eV")
+            Memory.from_str("1. Mb").
+        """
+        # Extract num and unit string.
+        string = string.strip()
+        for _idx, char in enumerate(string):
+            if char.isalpha() or char.isspace():
+                break
+        else:
+            raise ValueError(f"Unit is missing in string {string}")
+        num, unit = float(string[:_idx]), string[_idx:]
+
+        # Find unit type (set it to None if it cannot be detected)
+        for unit_type, dct in BASE_UNITS.items():
+            if unit in dct:
+                return cls(num, unit, unit_type=unit_type)
+        return cls(num, unit, unit_type=None)
+
+    def to(self, new_unit: str | Unit) -> Self:
+        """Convert to a new unit. Right now, only support
+        1 to 1 mapping of units of each type.
+
+        Args:
+            new_unit (str | Unit): New unit type.
+
+        Returns:
+            FloatWithUnit in the new unit.
+
+        Example usage:
+        >>> energy = Energy(1.1, "eV")
+        >>> energy = Energy(1.1, "Ha")
+        >>> energy.to("eV")
         29.932522246 eV
         """
-        return FloatWithUnit(
-            self * self.unit.get_conversion_factor(new_unit),
-            unit_type=self._unit_type,
-            unit=new_unit,
-        )
+        new_value = self * self.unit.get_conversion_factor(new_unit)
+        return type(self)(new_value, unit_type=self._unit_type, unit=new_unit)
 
     @property
     def as_base_units(self):
-        """Returns this FloatWithUnit in base SI units, including derived units.
+        """This FloatWithUnit in base SI units, including derived units.
 
         Returns:
-            A FloatWithUnit object in base SI units
+            FloatWithUnit in base SI units
         """
         return self.to(self.unit.as_base_units[0])
 
     @property
-    def supported_units(self):
+    def supported_units(self) -> tuple:
         """Supported units for specific unit type."""
-        return tuple(ALL_UNITS[self._unit_type])
+        if self.unit_type is None:
+            raise RuntimeError("Cannot get supported unit for None.")
+
+        return tuple(ALL_UNITS[self.unit_type])
 
 
 class ArrayWithUnit(np.ndarray):
     """Subclasses numpy.ndarray to attach a unit type. Typically, you should
     use the pre-defined unit type subclasses such as EnergyArray,
-    LengthArray, etc. instead of using ArrayWithFloatWithUnit directly.
+    LengthArray, etc. instead of using ArrayWithUnit directly.
 
-    Supports conversion, addition and subtraction of the same unit type. E.g.,
+    Support conversion, addition and subtraction of the same unit type. e.g.
     1 m + 20 cm will be automatically converted to 1.2 m (units follow the
     leftmost quantity).
 
-    >>> a = EnergyArray([1, 2], "Ha")
-    >>> b = EnergyArray([1, 2], "eV")
-    >>> c = a + b
-    >>> print(c)
+    >>> energy_arr_a = EnergyArray([1, 2], "Ha")
+    >>> energy_arr_b = EnergyArray([1, 2], "eV")
+    >>> energy_arr_c = energy_arr_a + energy_arr_b
+    >>> print(energy_arr_c)
     [ 1.03674933  2.07349865] Ha
-    >>> c.to("eV")
+    >>> energy_arr_c.to("eV")
     array([ 28.21138386,  56.42276772]) eV
     """
 
-    Error = UnitError
-
-    def __new__(cls, input_array, unit, unit_type=None):
+    def __new__(
+        cls,
+        input_array: NDArray,
+        unit: str | Unit,
+        unit_type: str | None = None,
+    ) -> Self:
         """Override __new__."""
         # Input array is an already formed ndarray instance
         # We first cast to be our class type
         obj = np.asarray(input_array).view(cls)
-        # add the new attributes to the created instance
-        obj._unit = Unit(unit)
+        # Add the new attributes to the created instance
+        obj._unit = unit if isinstance(unit, Unit) else Unit(unit)
         obj._unit_type = unit_type
         return obj
 
-    def __array_finalize__(self, obj):
-        """See http://docs.scipy.org/doc/numpy/user/basics.subclassing.html for
-        comments.
+    def __array_finalize__(self, obj) -> None:
+        """See http://docs.scipy.org/doc/numpy/user/basics.subclassing.html
+        for comments.
         """
         if obj is None:
             return
         self._unit = getattr(obj, "_unit", None)
         self._unit_type = getattr(obj, "_unit_type", None)
 
-    @property
-    def unit_type(self) -> str:
-        """The type of unit. Energy, Charge, etc."""
-        return self._unit_type
-
-    @property
-    def unit(self) -> str:
-        """The unit, e.g., "eV"."""
-        return self._unit
-
     def __reduce__(self):
         reduce = list(super().__reduce__())
         reduce[2] = {"np_state": reduce[2], "_unit": self._unit}
@@ -520,7 +559,7 @@ class ArrayWithUnit(np.ndarray):
             if other.unit != self.unit:
                 other = other.to(self.unit)
 
-        return self.__class__(np.array(self) + np.array(other), unit_type=self.unit_type, unit=self.unit)
+        return type(self)(np.array(self) + np.array(other), unit_type=self.unit_type, unit=self.unit)
 
     def __sub__(self, other):
         if hasattr(other, "unit_type"):
@@ -530,62 +569,88 @@ class ArrayWithUnit(np.ndarray):
             if other.unit != self.unit:
                 other = other.to(self.unit)
 
-        return self.__class__(np.array(self) - np.array(other), unit_type=self.unit_type, unit=self.unit)
+        return type(self)(
+            np.array(self) - np.array(other),
+            unit_type=self.unit_type,
+            unit=self.unit,
+        )
 
     def __mul__(self, other):
-        # TODO Here we have the most important difference between FloatWithUnit and
-        # ArrayWithFloatWithUnit:
-        # If other does not have units, I return an object with the same units
+        # TODO Here we have the most important difference between
+        # FloatWithUnit and ArrayWithUnit:
+        # If other does not have units, return an object with the same units
         # as self.
-        # if other *has* units, I return an object *without* units since
+        # If other *has* units, return an object *without* units since
         # taking into account all the possible derived quantities would be
         # too difficult.
         # Moreover Energy(1.0) * Time(1.0, "s") returns 1.0 Ha that is a
         # bit misleading.
         # Same protocol for __div__
         if not hasattr(other, "unit_type"):
-            return self.__class__(
+            return type(self)(
                 np.array(self) * np.array(other),
                 unit_type=self._unit_type,
                 unit=self._unit,
             )
         # Cannot use super since it returns an instance of self.__class__
         # while here we want a bare numpy array.
-        return self.__class__(np.array(self).__mul__(np.array(other)), unit=self.unit * other.unit)
+        return type(self)(
+            np.array(self).__mul__(np.array(other)),
+            unit=self.unit * other.unit,
+        )
 
     def __rmul__(self, other):
         if not hasattr(other, "unit_type"):
-            return self.__class__(
+            return type(self)(
                 np.array(self) * np.array(other),
                 unit_type=self._unit_type,
                 unit=self._unit,
             )
-        return self.__class__(np.array(self) * np.array(other), unit=self.unit * other.unit)
+        return type(self)(
+            np.array(self) * np.array(other),
+            unit=self.unit * other.unit,
+        )
 
     def __truediv__(self, other):
         if not hasattr(other, "unit_type"):
-            return self.__class__(np.array(self) / np.array(other), unit_type=self._unit_type, unit=self._unit)
-        return self.__class__(np.array(self) / np.array(other), unit=self.unit / other.unit)
+            return type(self)(
+                np.array(self) / np.array(other),
+                unit_type=self._unit_type,
+                unit=self._unit,
+            )
+        return type(self)(
+            np.array(self) / np.array(other),
+            unit=self.unit / other.unit,
+        )
 
     def __neg__(self):
-        return self.__class__(-np.array(self), unit_type=self.unit_type, unit=self.unit)
+        return type(self)(-np.array(self), unit_type=self.unit_type, unit=self.unit)
 
-    def to(self, new_unit):
-        """Conversion to a new_unit.
+    @property
+    def unit_type(self) -> str | None:
+        """The type of unit. Energy, Charge, etc."""
+        return self._unit_type
+
+    @property
+    def unit(self) -> Unit:
+        """The unit, e.g. "eV"."""
+        return cast(Unit, self._unit)
+
+    def to(self, new_unit: str | Unit) -> Self:
+        """Convert to a new unit.
 
         Args:
-            new_unit:
-                New unit type.
+            new_unit (str | Unit): New unit type.
 
         Returns:
-            A ArrayWithFloatWithUnit object in the new units.
+            ArrayWithUnit in the new unit.
 
         Example usage:
-        >>> e = EnergyArray([1, 1.1], "Ha")
-        >>> e.to("eV")
+        >>> energy = EnergyArray([1, 1.1], "Ha")
+        >>> energy.to("eV")
         array([ 27.21138386,  29.93252225]) eV
         """
-        return self.__class__(
+        return type(self)(
             np.array(self) * self.unit.get_conversion_factor(new_unit),
             unit_type=self.unit_type,
             unit=new_unit,
@@ -593,22 +658,25 @@ class ArrayWithUnit(np.ndarray):
 
     @property
     def as_base_units(self):
-        """Returns this ArrayWithUnit in base SI units, including derived units.
+        """This ArrayWithUnit in base SI units, including derived units.
 
         Returns:
-            An ArrayWithUnit object in base SI units
+            ArrayWithUnit in base SI units
         """
         return self.to(self.unit.as_base_units[0])
 
-    # TODO abstract base class property?
     @property
-    def supported_units(self):
+    def supported_units(self) -> dict:
+        # TODO abstract base class property?
         """Supported units for specific unit type."""
+        if self.unit_type is None:
+            raise RuntimeError("Cannot get supported unit for None.")
+
         return ALL_UNITS[self.unit_type]
 
-    # TODO abstract base class method?
-    def conversions(self):
-        """Returns a string showing the available conversions.
+    def conversions(self) -> str:
+        # TODO abstract base class method?
+        """Get a string showing the available conversions.
         Useful tool in interactive mode.
         """
         return "\n".join(str(self.to(unit)) for unit in self.supported_units)
@@ -631,7 +699,7 @@ A float with an energy unit.
 
 Args:
     val (float): Value
-    unit (Unit): E.g., eV, kJ, etc. Must be valid unit or UnitError is raised.
+    unit (Unit): e.g. eV, kJ, etc. Must be valid unit or UnitError is raised.
 """
 EnergyArray = partial(ArrayWithUnit, unit_type="energy")
 
@@ -641,7 +709,7 @@ A float with a length unit.
 
 Args:
     val (float): Value
-    unit (Unit): E.g., m, ang, bohr, etc. Must be valid unit or UnitError is
+    unit (Unit): e.g. m, ang, bohr, etc. Must be valid unit or UnitError is
         raised.
 """
 LengthArray = partial(ArrayWithUnit, unit_type="length")
@@ -652,7 +720,7 @@ A float with a mass unit.
 
 Args:
     val (float): Value
-    unit (Unit): E.g., amu, kg, etc. Must be valid unit or UnitError is
+    unit (Unit): e.g. amu, kg, etc. Must be valid unit or UnitError is
         raised.
 """
 MassArray = partial(ArrayWithUnit, unit_type="mass")
@@ -663,7 +731,7 @@ A float with a temperature unit.
 
 Args:
     val (float): Value
-    unit (Unit): E.g., K. Only K (kelvin) is supported.
+    unit (Unit): e.g. K. Only K (kelvin) is supported.
 """
 TempArray = partial(ArrayWithUnit, unit_type="temperature")
 
@@ -673,7 +741,7 @@ A float with a time unit.
 
 Args:
     val (float): Value
-    unit (Unit): E.g., s, min, h. Must be valid unit or UnitError is
+    unit (Unit): e.g. s, min, h. Must be valid unit or UnitError is
         raised.
 """
 TimeArray = partial(ArrayWithUnit, unit_type="time")
@@ -684,7 +752,7 @@ A float with a charge unit.
 
 Args:
     val (float): Value
-    unit (Unit): E.g., C, e (electron charge). Must be valid unit or UnitError
+    unit (Unit): e.g. C, e (electron charge). Must be valid unit or UnitError
         is raised.
 """
 ChargeArray = partial(ArrayWithUnit, unit_type="charge")
@@ -695,15 +763,18 @@ A float with a memory unit.
 
 Args:
     val (float): Value
-    unit (Unit): E.g., Kb, Mb, Gb, Tb. Must be valid unit or UnitError
+    unit (Unit): e.g. Kb, Mb, Gb, Tb. Must be valid unit or UnitError
         is raised.
 """
 
 
-def obj_with_unit(obj: Any, unit: str) -> FloatWithUnit | ArrayWithUnit | dict[str, FloatWithUnit | ArrayWithUnit]:
-    """Returns a FloatWithUnit instance if obj is scalar, a dictionary of
+def obj_with_unit(
+    obj: Any,
+    unit: str,
+) -> FloatWithUnit | ArrayWithUnit | dict[str, FloatWithUnit | ArrayWithUnit]:
+    """Get a FloatWithUnit instance if obj is scalar, a dictionary of
     objects with units if obj is a dict, else an instance of
-    ArrayWithFloatWithUnit.
+    ArrayWithUnit.
 
     Args:
         obj (Any): Object to be given a unit.
@@ -711,15 +782,17 @@ def obj_with_unit(obj: Any, unit: str) -> FloatWithUnit | ArrayWithUnit | dict[s
     """
     unit_type = _UNAME2UTYPE[unit]
 
-    if isinstance(obj, numbers.Number):
+    if isinstance(obj, Number):
         return FloatWithUnit(obj, unit=unit, unit_type=unit_type)
+
     if isinstance(obj, collections.abc.Mapping):
-        return {k: obj_with_unit(v, unit) for k, v in obj.items()}  # type: ignore
+        return {k: obj_with_unit(v, unit) for k, v in obj.items()}  # type: ignore[misc]
+
     return ArrayWithUnit(obj, unit=unit, unit_type=unit_type)
 
 
 def unitized(unit):
-    """Useful decorator to assign units to the output of a function. You can also
+    """Decorator to assign units to the output of a function. You can also
     use it to standardize the output units of a function that already returns
     a FloatWithUnit or ArrayWithUnit. For sequences, all values in the sequences
     are assigned the same unit. It works with Python sequences only. The creation
@@ -751,7 +824,7 @@ def unitized(unit):
             if isinstance(val, collections.abc.Mapping):
                 for k, v in val.items():
                     val[k] = FloatWithUnit(v, unit_type=unit_type, unit=unit)
-            elif isinstance(val, numbers.Number):
+            elif isinstance(val, Number):
                 return FloatWithUnit(val, unit_type=unit_type, unit=unit)
             elif val is None:
                 pass
