@@ -1,17 +1,22 @@
-"""This module provides."""
+"""This module provides class for XC correlation functional."""
 
 from __future__ import annotations
 
-from collections import namedtuple
+from typing import TYPE_CHECKING, NamedTuple
 
 from monty.functools import lazy_property
 from monty.json import MSONable
 
 from pymatgen.core.libxcfunc import LibxcFunc
 
+if TYPE_CHECKING:
+    from typing import Any, ClassVar, Literal
+
+    from typing_extensions import Self
+
 __author__ = "Matteo Giantomassi"
 __copyright__ = "Copyright 2016, The Materials Project"
-__version__ = "3.0.0"  # The libxc version used to generate this file!
+__version__ = "3.0.0"  # The libxc version used to generate this file
 __maintainer__ = "Matteo Giantomassi"
 __email__ = "gmatteo@gmail.com"
 __status__ = "Production"
@@ -19,7 +24,7 @@ __date__ = "May 16, 2016"
 
 
 class XcFunc(MSONable):
-    """This object stores information about the XC correlation functional.
+    """Store information about the XC correlation functional.
 
     Client code usually creates the object by calling the class methods:
 
@@ -69,11 +74,15 @@ class XcFunc(MSONable):
     GGA     BLYP    GGA_X_B88+GGA_C_LYP          Becke, PRA 38, 3098 (1988); Lee, Yang, Parr, PRB 37, 785
     """
 
-    type_name = namedtuple("type_name", "type, name")
+    class type_name(NamedTuple):
+        """Type and name of the XcFunc."""
+
+        type: Literal["LDA", "GGA"]
+        name: str
 
     xcf = LibxcFunc
-    defined_aliases = {
-        # (x, c) --> type_name
+    defined_aliases: ClassVar[dict[tuple[LibxcFunc, LibxcFunc], type_name]] = {
+        # (X, C) --> type_name
         # LDAs
         (xcf.LDA_X, xcf.LDA_C_PW): type_name("LDA", "PW"),  # ixc 7
         (xcf.LDA_X, xcf.LDA_C_PW_MOD): type_name("LDA", "PW_MOD"),
@@ -92,13 +101,11 @@ class XcFunc(MSONable):
         (xcf.GGA_X_B88, xcf.GGA_C_LYP): type_name("GGA", "BLYP"),
     }
 
-    del type_name
-
     # Correspondence between Abinit ixc notation and libxc notation.
     # see: http://www.abinit.org/doc/helpfiles/for-v7.8/input_variables/varbas.html#ixc
     # and 42_libpaw/m_pawpsp.F90 for the implementation.
     # Fortunately, all the other cases are handled with libxc.
-    abinitixc_to_libxc = {
+    abinitixc_to_libxc: ClassVar[dict[int, dict[str, LibxcFunc]]] = {
         1: {"xc": xcf.LDA_XC_TETER93},
         2: {"x": xcf.LDA_X, "c": xcf.LDA_C_PZ},  # PZ  001009
         4: {"x": xcf.LDA_X, "c": xcf.LDA_C_WIGNER},  # W
@@ -109,87 +116,12 @@ class XcFunc(MSONable):
         15: {"x": xcf.GGA_X_RPBE, "c": xcf.GGA_C_PBE},  # RPBE
     }
 
-    del xcf
-
-    @classmethod
-    def aliases(cls):
-        """List of registered names."""
-        return [nt.name for nt in cls.defined_aliases.values()]
-
-    @classmethod
-    def asxc(cls, obj):
-        """Convert object into Xcfunc."""
-        if isinstance(obj, cls):
-            return obj
-        if isinstance(obj, str):
-            return cls.from_name(obj)
-        raise TypeError(f"Don't know how to convert <{type(obj)}:{obj}> to Xcfunc")
-
-    @classmethod
-    def from_abinit_ixc(cls, ixc):
-        """Build the object from Abinit ixc (integer)."""
-        ixc = int(ixc)
-        if ixc == 0:
-            return None
-        if ixc > 0:
-            return cls(**cls.abinitixc_to_libxc[ixc])
-
-        # libxc notation employed in Abinit: a six-digit number in the form XXXCCC or CCCXXX
-        ixc = abs(ixc)
-        first = ixc // 1000
-        last = ixc - first * 1000
-        x, c = LibxcFunc(int(first)), LibxcFunc(int(last))
-        if not x.is_x_kind:
-            x, c = c, x  # Swap
-        assert x.is_x_kind
-        assert c.is_c_kind
-        return cls(x=x, c=c)
-
-    @classmethod
-    def from_name(cls, name):
-        """Build the object from one of the registered names."""
-        return cls.from_type_name(None, name)
-
-    @classmethod
-    def from_type_name(cls, typ, name):
-        """Build the object from (type, name)."""
-        # Try aliases first.
-        for k, nt in cls.defined_aliases.items():
-            if typ is not None and typ != nt.type:
-                continue
-            if name == nt.name:
-                if len(k) == 1:
-                    return cls(xc=k)
-                if len(k) == 2:
-                    return cls(x=k[0], c=k[1])
-                raise ValueError(f"Wrong key: {k}")
-
-        # At this point, we should have something in the form
-        # name="GGA_X_PBE+GGA_C_PBE" or name=""LDA_XC_TETER93"
-        if "+" in name:
-            x, c = (s.strip() for s in name.split("+"))
-            x, c = LibxcFunc[x], LibxcFunc[c]
-            return cls(x=x, c=c)
-        xc = LibxcFunc[name]
-        return cls(xc=xc)
-
-    @classmethod
-    def from_dict(cls, d):
-        """Makes XcFunc obey the general json interface used in pymatgen for easier serialization."""
-        return cls(xc=d.get("xc"), x=d.get("x"), c=d.get("c"))
-
-    def as_dict(self):
-        """Makes XcFunc obey the general json interface used in pymatgen for easier serialization."""
-        dct = {"@module": type(self).__module__, "@class": type(self).__name__}
-        if self.x is not None:
-            dct["x"] = self.x.as_dict()
-        if self.c is not None:
-            dct["c"] = self.c.as_dict()
-        if self.xc is not None:
-            dct["xc"] = self.xc.as_dict()
-        return dct
-
-    def __init__(self, xc=None, x=None, c=None) -> None:
+    def __init__(
+        self,
+        xc: LibxcFunc | None = None,
+        x: LibxcFunc | None = None,
+        c: LibxcFunc | None = None,
+    ) -> None:
         """
         Args:
             xc: LibxcFunc for XC functional.
@@ -205,34 +137,6 @@ class XcFunc(MSONable):
 
         self.xc, self.x, self.c = xc, x, c
 
-    @lazy_property
-    def type(self):
-        """The type of the functional."""
-        if self.xc in self.defined_aliases:
-            return self.defined_aliases[self.xc].type
-        xc = self.x, self.c
-        if xc in self.defined_aliases:
-            return self.defined_aliases[xc].type
-
-        # If self is not in defined_aliases, use LibxcFunc family
-        if self.xc is not None:
-            return self.xc.family
-        return f"{self.x.family}+{self.c.family}"
-
-    @lazy_property
-    def name(self) -> str:
-        """The name of the functional. If the functional is not found in the aliases,
-        the string has the form X_NAME+C_NAME.
-        """
-        if self.xc in self.defined_aliases:
-            return self.defined_aliases[self.xc].name
-        xc = (self.x, self.c)
-        if xc in self.defined_aliases:
-            return self.defined_aliases[xc].name
-        if self.xc is not None:
-            return self.xc.name
-        return f"{self.x.name}+{self.c.name}"
-
     def __repr__(self) -> str:
         return str(self.name)
 
@@ -240,9 +144,125 @@ class XcFunc(MSONable):
         return hash(self.name)
 
     def __eq__(self, other: object) -> bool:
-        if not isinstance(other, (str, XcFunc)):
+        if not isinstance(other, (str, type(self))):
             return NotImplemented
-        if isinstance(other, XcFunc):
+        if isinstance(other, type(self)):
             return self.name == other.name
-        # assume other is a string
+        # Assume other is a string
         return self.name == other
+
+    @classmethod
+    def aliases(cls) -> list[str]:
+        """List of registered names."""
+        return [nt.name for nt in cls.defined_aliases.values()]
+
+    @classmethod
+    def asxc(cls, obj) -> Self:
+        """Convert to XcFunc."""
+        if isinstance(obj, cls):
+            return obj
+        if isinstance(obj, str):
+            return cls.from_name(obj)
+        raise TypeError(f"Don't know how to convert <{type(obj)}:{obj}> to XcFunc")
+
+    @classmethod
+    def from_abinit_ixc(cls, ixc: int) -> Self | None:
+        """Build the object from Abinit ixc (integer)."""
+        if ixc == 0:
+            return None
+        if ixc > 0:
+            return cls(**cls.abinitixc_to_libxc[ixc])
+
+        # libxc notation employed in Abinit: a six-digit number
+        # in the form XXXCCC or CCCXXX
+        ixc = abs(ixc)
+        first = ixc // 1000
+        last = ixc - first * 1000
+        x, c = LibxcFunc(int(first)), LibxcFunc(int(last))
+        if not x.is_x_kind:
+            x, c = c, x  # Swap
+        assert x.is_x_kind
+        assert c.is_c_kind
+        return cls(x=x, c=c)
+
+    @classmethod
+    def from_name(cls, name: str) -> Self:
+        """Build the object from one of the registered names."""
+        return cls.from_type_name(None, name)
+
+    @classmethod
+    def from_type_name(cls, typ: str | None, name: str) -> Self:
+        """Build the object from (type, name)."""
+        # Try aliases first
+        for k, nt in cls.defined_aliases.items():
+            if typ is not None and typ != nt.type:
+                continue
+            if name == nt.name:
+                if len(k) == 1:
+                    return cls(xc=k)
+                if len(k) == 2:
+                    return cls(x=k[0], c=k[1])
+                raise ValueError(f"Wrong key: {k}")
+
+        # At this point, we should have something in the form
+        # name="GGA_X_PBE+GGA_C_PBE" or name=""LDA_XC_TETER93"
+        if "+" in name:
+            x, c = (s.strip() for s in name.split("+"))
+            return cls(x=LibxcFunc[x], c=LibxcFunc[c])
+
+        return cls(xc=LibxcFunc[name])
+
+    def as_dict(self) -> dict:
+        """Serialize to MSONable dict representation e.g. to write to disk as JSON."""
+        dct: dict[str, Any] = {"@module": type(self).__module__, "@class": type(self).__name__}
+        if self.x is not None:
+            dct["x"] = self.x.as_dict()
+        if self.c is not None:
+            dct["c"] = self.c.as_dict()
+        if self.xc is not None:
+            dct["xc"] = self.xc.as_dict()
+        return dct
+
+    @classmethod
+    def from_dict(cls, dct: dict) -> Self:
+        """Deserialize from MSONable dict representation."""
+        return cls(xc=dct.get("xc"), x=dct.get("x"), c=dct.get("c"))
+
+    @lazy_property
+    def type(self) -> str | None:
+        """The type of the functional."""
+        if self.xc in self.defined_aliases and self.xc is not None:
+            return self.defined_aliases[self.xc].type  # type: ignore[index]
+
+        xc = self.x, self.c
+        if xc in self.defined_aliases:
+            return self.defined_aliases[xc].type  # type: ignore[index]
+
+        # If self is not in defined_aliases, use LibxcFunc family
+        if self.xc is not None:
+            return self.xc.family
+
+        if self.x is not None and self.c is not None:
+            return f"{self.x.family}+{self.c.family}"
+
+        return None
+
+    @lazy_property
+    def name(self) -> str | None:
+        """The name of the functional. If the functional is not found in the aliases,
+        the string has the form X_NAME+C_NAME.
+        """
+        if self.xc in self.defined_aliases:
+            return self.defined_aliases[self.xc].name  # type: ignore[index]
+
+        xc = (self.x, self.c)
+        if xc in self.defined_aliases:
+            return self.defined_aliases[xc].name  # type: ignore[index]
+
+        if self.xc is not None:
+            return self.xc.name
+
+        if self.x is not None and self.c is not None:
+            return f"{self.x.name}+{self.c.name}"
+
+        return None
