@@ -9,7 +9,7 @@ http://www.icams.de/content/research/software-development/boltztrap/
 
 You need version 1.2.3 or higher
 
-References are::
+References are:
 
     Madsen, G. K. H., and Singh, D. J. (2006).
     BoltzTraP. A code for calculating band-structure dependent quantities.
@@ -44,7 +44,10 @@ from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.symmetry.bandstructure import HighSymmKpath
 
 if TYPE_CHECKING:
+    from typing import Literal
+
     from numpy.typing import ArrayLike
+    from typing_extensions import Self
 
     from pymatgen.core.sites import PeriodicSite
     from pymatgen.core.structure import Structure
@@ -250,9 +253,10 @@ class BoltztrapRunner(MSONable):
         return self._nelec
 
     def write_energy(self, output_file) -> None:
-        """Writes the energy to an output file.
+        """Write the energy to an output file.
 
-        :param output_file: Filename
+        Args:
+            output_file: Filename
         """
         with open(output_file, mode="w") as file:
             file.write("test\n")
@@ -282,7 +286,7 @@ class BoltztrapRunner(MSONable):
                         # use 90% of bottom bands since highest eigenvalues
                         # are usually incorrect
                         # ask Geoffroy Hautier for more details
-                        nb_bands = int(math.floor(self._bs.nb_bands * (1 - self.cb_cut)))
+                        nb_bands = math.floor(self._bs.nb_bands * (1 - self.cb_cut))
                         for j in range(nb_bands):
                             eigs.append(
                                 Energy(
@@ -302,20 +306,19 @@ class BoltztrapRunner(MSONable):
                         file.write(f"{float(e):18.8f}\n")
 
     def write_struct(self, output_file) -> None:
-        """Writes the structure to an output file.
+        """Write the structure to an output file.
 
-        :param output_file: Filename
+        Args:
+            output_file: Filename
         """
         if self._symprec is not None:
             sym = SpacegroupAnalyzer(self._bs.structure, symprec=self._symprec)
-        elif self._symprec is None:
-            pass
 
-        with open(output_file, mode="w") as file:
+        with open(output_file, mode="w", encoding="utf-8") as file:
             if self._symprec is not None:
-                file.write(f"{self._bs.structure.composition.formula} {sym.get_space_group_symbol()}\n")
-            elif self._symprec is None:
-                file.write(f"{self._bs.structure.composition.formula} symmetries disabled\n")
+                file.write(f"{self._bs.structure.formula} {sym.get_space_group_symbol()}\n")  # type: ignore[reportPossiblyUnboundVariable]
+            else:
+                file.write(f"{self._bs.structure.formula} symmetries disabled\n")
 
             file.write(
                 "\n".join(
@@ -325,10 +328,8 @@ class BoltztrapRunner(MSONable):
                 + "\n"
             )
 
-            if self._symprec is not None:
-                ops = sym.get_symmetry_dataset()["rotations"]
-            elif self._symprec is None:
-                ops = [[[1, 0, 0], [0, 1, 0], [0, 0, 1]]]
+            ops = [np.eye(3)] if self._symprec is None else sym.get_symmetry_dataset()["rotations"]  # type: ignore[reportPossiblyUnboundVariable]
+
             file.write(f"{len(ops)}\n")
 
             for op in ops:
@@ -336,9 +337,10 @@ class BoltztrapRunner(MSONable):
                     file.write(f"{' '.join(map(str, row))}\n")
 
     def write_def(self, output_file) -> None:
-        """Writes the def to an output file.
+        """Write the def to an output file.
 
-        :param output_file: Filename
+        Args:
+            output_file: Filename
         """
         # This function is useless in std version of BoltzTraP code
         # because x_trans script overwrite BoltzTraP.def
@@ -363,23 +365,25 @@ class BoltztrapRunner(MSONable):
                 "'formatted',0\n"
             )
 
-    def write_proj(self, output_file_proj, output_file_def) -> None:
-        """Writes the projections to an output file.
+    def write_proj(self, output_file_proj: str, output_file_def: str) -> None:
+        """Write the projections to an output file.
 
-        :param output_file: Filename
+        Args:
+            output_file_proj: output file name
+            output_file_def: output file name
         """
         # This function is useless in std version of BoltzTraP code
         # because x_trans script overwrite BoltzTraP.def
-        for oi, o in enumerate(Orbital):
+        for orb_idx, orb in enumerate(Orbital):
             for site_nb in range(len(self._bs.structure)):
-                if oi < len(self._bs.projections[Spin.up][0][0]):
-                    with open(f"{output_file_proj}_{site_nb}_{o}", mode="w") as file:
-                        file.write(self._bs.structure.composition.formula + "\n")
-                        file.write(str(len(self._bs.kpoints)) + "\n")
-                        for i, kpt in enumerate(self._bs.kpoints):
+                if orb_idx < len(self._bs.projections[Spin.up][0][0]):
+                    with open(f"{output_file_proj}_{site_nb}_{orb}", mode="w") as file:
+                        file.write(f"{self._bs.structure.formula}\n")
+                        file.write(f"{len(self._bs.kpoints)}\n")
+                        for kpt_idx, kpt in enumerate(self._bs.kpoints):
                             tmp_proj = []
-                            for j in range(int(math.floor(self._bs.nb_bands * (1 - self.cb_cut)))):
-                                tmp_proj.append(self._bs.projections[Spin(self.spin)][j][i][oi][site_nb])
+                            for j in range(math.floor(self._bs.nb_bands * (1 - self.cb_cut))):
+                                tmp_proj.append(self._bs.projections[Spin(self.spin)][j][kpt_idx][orb_idx][site_nb])
                             # TODO deal with the sorting going on at
                             # the energy level!!!
                             # tmp_proj.sort()
@@ -411,17 +415,18 @@ class BoltztrapRunner(MSONable):
                 "'formatted',0\n30,'boltztrap_BZ.cube',           'unknown',    "
                 "'formatted',0\n"
             )
-            i = 1000
-            for oi, o in enumerate(Orbital):
+            kpt_idx = 1000
+            for orb_idx, orb in enumerate(Orbital):
                 for site_nb in range(len(self._bs.structure)):
-                    if oi < len(self._bs.projections[Spin.up][0][0]):
-                        file.write(f"{i},'boltztrap.proj_{site_nb}_{o.name}old', 'formatted',0\n")
-                        i += 1
+                    if orb_idx < len(self._bs.projections[Spin.up][0][0]):
+                        file.write(f"{kpt_idx},'boltztrap.proj_{site_nb}_{orb.name}old', 'formatted',0\n")
+                        kpt_idx += 1
 
     def write_intrans(self, output_file) -> None:
-        """Writes the intrans to an output file.
+        """Write the intrans to an output file.
 
-        :param output_file: Filename
+        Args:
+            output_file: Filename
         """
         setgap = 1 if self.scissor > 0.0001 else 0
 
@@ -443,7 +448,7 @@ class BoltztrapRunner(MSONable):
                 fout.write(".15                       # (efcut) energy range of chemical potential\n")
                 fout.write(f"{self.tmax} {self.tgrid}                  # Tmax, temperature grid\n")
                 fout.write("-1.  # energyrange of bands given DOS output sig_xxx and dos_xxx (xxx is band number)\n")
-                fout.write(self.dos_type + "\n")  # e.g., HISTO or TETRA
+                fout.write(self.dos_type + "\n")  # e.g. HISTO or TETRA
                 fout.write(f"{self.tauref} {self.tauexp} {self.tauen} 0 0 0\n")
                 fout.write(f"{2 * len(self.doping)}\n")
 
@@ -495,9 +500,10 @@ class BoltztrapRunner(MSONable):
                     fout.write("\n")
 
     def write_input(self, output_dir) -> None:
-        """Writes the input files.
+        """Write the input files.
 
-        :param output_dir: Directory to write the input files.
+        Args:
+            output_dir: Directory to write the input files.
         """
         if self._bs.is_spin_polarized or self.soc:
             self.write_energy(f"{output_dir}/boltztrap.energyso")
@@ -619,7 +625,7 @@ class BoltztrapRunner(MSONable):
 
                     warning = ""
 
-                    with open(os.path.join(path_dir, dir_bz_name + ".outputtrans")) as file:
+                    with open(os.path.join(path_dir, f"{dir_bz_name}.outputtrans")) as file:
                         for line in file:
                             if "Option unknown" in line:
                                 raise BoltztrapError("DOS mode needs a custom version of BoltzTraP code is needed")
@@ -707,7 +713,7 @@ class BoltztrapError(Exception):
 
 
 class BoltztrapAnalyzer:
-    """Class used to store all the data from a boltztrap run."""
+    """Store all the data from a boltztrap run."""
 
     def __init__(
         self,
@@ -836,14 +842,13 @@ class BoltztrapAnalyzer:
         self.fermi_surface_data = fermi_surface_data
 
     def get_symm_bands(self, structure: Structure, efermi, kpt_line=None, labels_dict=None):
-        """Function useful to read bands from Boltztrap output and get a
-        BandStructureSymmLine object comparable with that one from a DFT
-        calculation (if the same kpt_line is provided). Default kpt_line
-        and labels_dict is the standard path of high symmetry k-point for
-        the specified structure. They could be extracted from the
-        BandStructureSymmLine object that you want to compare with. efermi
-        variable must be specified to create the BandStructureSymmLine
-        object (usually it comes from DFT or Boltztrap calc).
+        """Useful to read bands from Boltztrap output and get a BandStructureSymmLine object
+        comparable with that one from a DFT calculation (if the same kpt_line is
+        provided). Default kpt_line and labels_dict is the standard path of high symmetry
+        k-point for the specified structure. They could be extracted from the
+        BandStructureSymmLine object that you want to compare with. efermi variable must
+        be specified to create the BandStructureSymmLine object (usually it comes from DFT
+        or Boltztrap calc).
         """
         try:
             if kpt_line is None:
@@ -892,6 +897,7 @@ class BoltztrapAnalyzer:
         around the gap (semiconductors) or Fermi level (metals).
         warn_thr is a threshold to get a warning in the accuracy of Boltztap
         interpolated bands.
+
         Return a dictionary with these keys:
         - "N": the index of the band compared; inside each there are:
             - "Corr": correlation coefficient for the 8 compared bands
@@ -951,7 +957,7 @@ class BoltztrapAnalyzer:
         return bcheck
 
     def get_seebeck(self, output="eigs", doping_levels=True):
-        """Gives the seebeck coefficient (microV/K) in either a
+        """Get the seebeck coefficient (microV/K) in either a
         full 3x3 tensor form, as 3 eigenvalues, or as the average value
         (trace/3.0) If doping_levels=True, the results are given at
         different p and n doping
@@ -982,7 +988,7 @@ class BoltztrapAnalyzer:
         return BoltztrapAnalyzer._format_to_output(self._seebeck, self._seebeck_doping, output, doping_levels, 1e6)
 
     def get_conductivity(self, output="eigs", doping_levels=True, relaxation_time=1e-14):
-        """Gives the conductivity (1/Ohm*m) in either a full 3x3 tensor
+        """Get the conductivity (1/Ohm*m) in either a full 3x3 tensor
         form, as 3 eigenvalues, or as the average value
         (trace/3.0) If doping_levels=True, the results are given at
         different p and n doping
@@ -1017,7 +1023,7 @@ class BoltztrapAnalyzer:
         )
 
     def get_power_factor(self, output="eigs", doping_levels=True, relaxation_time=1e-14):
-        """Gives the power factor (Seebeck^2 * conductivity) in units
+        """Get the power factor (Seebeck^2 * conductivity) in units
         microW/(m*K^2) in either a full 3x3 tensor form,
         as 3 eigenvalues, or as the average value (trace/3.0) If
         doping_levels=True, the results are given at
@@ -1079,7 +1085,7 @@ class BoltztrapAnalyzer:
         )
 
     def get_thermal_conductivity(self, output="eigs", doping_levels=True, k_el=True, relaxation_time=1e-14):
-        """Gives the electronic part of the thermal conductivity in either a
+        """Get the electronic part of the thermal conductivity in either a
         full 3x3 tensor form,
         as 3 eigenvalues, or as the average value (trace/3.0) If
         doping_levels=True, the results are given at
@@ -1144,7 +1150,7 @@ class BoltztrapAnalyzer:
         return BoltztrapAnalyzer._format_to_output(result, result_doping, output, doping_levels, multi=relaxation_time)
 
     def get_zt(self, output="eigs", doping_levels=True, relaxation_time=1e-14, k_l=1):
-        """Gives the ZT coefficient (S^2*cond*T/thermal cond) in either a full
+        """Get the ZT coefficient (S^2*cond*T/thermal cond) in either a full
         3x3 tensor form,
         as 3 eigenvalues, or as the average value (trace/3.0) If
         doping_levels=True, the results are given at
@@ -1216,7 +1222,7 @@ class BoltztrapAnalyzer:
         return BoltztrapAnalyzer._format_to_output(result, result_doping, output, doping_levels)
 
     def get_average_eff_mass(self, output="eigs", doping_levels=True):
-        """Gives the average effective mass tensor. We call it average because
+        """Get the average effective mass tensor. We call it average because
         it takes into account all the bands
         and regions in the Brillouin zone. This is different than the standard
         textbook effective mass which relates
@@ -1282,6 +1288,7 @@ class BoltztrapAnalyzer:
                             pass
         else:
             result = {t: [] for t in self._seebeck}
+            cond_inv = None
             for temp in result:
                 for i in range(len(self.mu_steps)):
                     try:
@@ -1322,33 +1329,37 @@ class BoltztrapAnalyzer:
         if doping_levels:
             sbk_mass = {}
             for dt in ("n", "p"):
-                conc = self.doping[dt]
+                concentrations = self.doping[dt]
                 seebeck = self.get_seebeck(output=output, doping_levels=True)[dt][temp]
                 sbk_mass[dt] = []
-                for i, c in enumerate(conc):
+                for idx, concen in enumerate(concentrations):
                     if output == "average":
-                        sbk_mass[dt].append(seebeck_eff_mass_from_seebeck_carr(abs(seebeck[i]), c, temp, Lambda))
+                        sbk_mass[dt].append(seebeck_eff_mass_from_seebeck_carr(abs(seebeck[idx]), concen, temp, Lambda))
                     elif output == "tensor":
                         sbk_mass[dt].append([])
                         for j in range(3):
                             sbk_mass[dt][-1].append(
-                                seebeck_eff_mass_from_seebeck_carr(abs(seebeck[i][j][j]), c, temp, Lambda)
+                                seebeck_eff_mass_from_seebeck_carr(abs(seebeck[idx][j][j]), concen, temp, Lambda)
                             )
 
         else:
             seebeck = self.get_seebeck(output=output, doping_levels=False)[temp]
-            conc = self.get_carrier_concentration()[temp]
+            concentrations = self.get_carrier_concentration()[temp]
             sbk_mass = []
-            for i, c in enumerate(conc):
+            for idx, concen in enumerate(concentrations):
                 if output == "average":
-                    sbk_mass.append(seebeck_eff_mass_from_seebeck_carr(abs(seebeck[i]), c, temp, Lambda))
+                    sbk_mass.append(seebeck_eff_mass_from_seebeck_carr(abs(seebeck[idx]), concen, temp, Lambda))
                 elif output == "tensor":
                     sbk_mass.append([])
                     for j in range(3):
-                        sbk_mass[-1].append(seebeck_eff_mass_from_seebeck_carr(abs(seebeck[i][j][j]), c, temp, Lambda))
+                        sbk_mass[-1].append(
+                            seebeck_eff_mass_from_seebeck_carr(abs(seebeck[idx][j][j]), concen, temp, Lambda)
+                        )
         return sbk_mass
 
-    def get_complexity_factor(self, output="average", temp=300, doping_levels=False, Lambda=0.5):
+    def get_complexity_factor(
+        self, output: Literal["average", "tensor"] = "average", temp=300, doping_levels=False, Lambda=0.5
+    ):
         """Fermi surface complexity factor respect to calculated as explained in Ref.
         Gibbs, Z. M. et al., Effective mass and fermi surface complexity factor
         from ab initio band structure calculations.
@@ -1383,27 +1394,29 @@ class BoltztrapAnalyzer:
 
                 if output == "average":
                     cmplx_fact[dt] = [(m_s / abs(m_c)) ** 1.5 for m_s, m_c in zip(sbk_mass, cond_mass)]
-                elif output == "tensor":
+
+                else:
                     cmplx_fact[dt] = []
                     for i, sm in enumerate(sbk_mass):
                         cmplx_fact[dt].append([])
                         for j in range(3):
                             cmplx_fact[dt][-1].append((sm[j] / abs(cond_mass[i][j][j])) ** 1.5)
 
-        else:
-            sbk_mass = self.get_seebeck_eff_mass(output, temp, doping_levels=False, Lambda=Lambda)
-            cond_mass = self.get_average_eff_mass(output=output, doping_levels=False)[temp]
+            return cmplx_fact
 
-            if output == "average":
-                cmplx_fact = [(m_s / abs(m_c)) ** 1.5 for m_s, m_c in zip(sbk_mass, cond_mass)]
-            elif output == "tensor":
-                cmplx_fact = []
-                for i, sm in enumerate(sbk_mass):
-                    cmplx_fact.append([])
-                    for j in range(3):
-                        cmplx_fact[-1].append((sm[j] / abs(cond_mass[i][j][j])) ** 1.5)
+        sbk_mass = self.get_seebeck_eff_mass(output, temp, doping_levels=False, Lambda=Lambda)
+        cond_mass = self.get_average_eff_mass(output=output, doping_levels=False)[temp]
 
-        return cmplx_fact
+        if output == "average":
+            return [(m_s / abs(m_c)) ** 1.5 for m_s, m_c in zip(sbk_mass, cond_mass)]
+
+        cmplx_fact_list: list = []
+        for i, sm in enumerate(sbk_mass):
+            cmplx_fact_list.append([])
+            for j in range(3):
+                cmplx_fact_list[-1].append((sm[j] / abs(cond_mass[i][j][j])) ** 1.5)
+
+        return cmplx_fact_list
 
     def get_extreme(
         self,
@@ -1416,14 +1429,12 @@ class BoltztrapAnalyzer:
         isotropy_tolerance=0.05,
         use_average=True,
     ):
-        """This method takes in eigenvalues over a range of carriers,
-        temperatures, and doping levels, and tells you what is the "best"
+        """Use eigenvalues over a range of carriers, temperatures, and doping levels, to estimate the "best"
         value that can be achieved for the given target_property. Note that
         this method searches the doping dict only, not the full mu dict.
 
         Args:
-            target_prop: target property, i.e. "seebeck", "power factor",
-                         "conductivity", "kappa", or "zt"
+            target_prop: target property, i.e. "seebeck", "power factor", "conductivity", "kappa", or "zt"
             maximize: True to maximize, False to minimize (e.g. kappa)
             min_temp: minimum temperature allowed
             max_temp: maximum temperature allowed
@@ -1470,9 +1481,9 @@ class BoltztrapAnalyzer:
             d = self.get_zt(output="eigs", doping_levels=True)
 
         else:
-            raise ValueError(f"Target property: {target_prop} not recognized!")
+            raise ValueError(f"Unrecognized {target_prop=}")
 
-        absval = True  # take the absolute value of properties
+        abs_val = True  # take the absolute value of properties
 
         x_val = x_temp = x_doping = x_isotropic = None
         output = {}
@@ -1489,7 +1500,7 @@ class BoltztrapAnalyzer:
                         doping_lvl = self.doping[pn][didx]
                         if min_doping <= doping_lvl <= max_doping:
                             isotropic = is_isotropic(evs, isotropy_tolerance)
-                            if absval:
+                            if abs_val:
                                 evs = [abs(x) for x in evs]
                             val = float(sum(evs)) / len(evs) if use_average else max(evs)
                             if x_val is None or (val > x_val and maximize) or (val < x_val and not maximize):
@@ -1560,7 +1571,7 @@ class BoltztrapAnalyzer:
         return result
 
     def get_complete_dos(self, structure: Structure, analyzer_for_second_spin=None):
-        """Gives a CompleteDos object with the DOS from the interpolated projected band structure.
+        """Get a CompleteDos object with the DOS from the interpolated projected band structure.
 
         Args:
             structure: necessary to identify sites for projection
@@ -1581,12 +1592,12 @@ class BoltztrapAnalyzer:
         """
         pdoss: dict[PeriodicSite, dict[Orbital, dict[Spin, ArrayLike]]] = {}
         spin_1 = next(iter(self.dos.densities))
+        spin_2 = next(iter(analyzer_for_second_spin.dos.densities))
 
         if analyzer_for_second_spin:
             if not np.all(self.dos.energies == analyzer_for_second_spin.dos.energies):
                 raise BoltztrapError("Dos merging error: energies of the two dos are different")
 
-            spin_2 = next(iter(analyzer_for_second_spin.dos.densities))
             if spin_1 == spin_2:
                 raise BoltztrapError("Dos merging error: spin component are the same")
 
@@ -1600,6 +1611,7 @@ class BoltztrapAnalyzer:
                 pdoss[structure[idx]][Orbital[o]][spin_1] = self._dos_partial[s][o]
                 if analyzer_for_second_spin:
                     pdoss[structure[idx]][Orbital[o]][spin_2] = analyzer_for_second_spin._dos_partial[s][o]
+
         if analyzer_for_second_spin:
             total_dos = Dos(
                 self.dos.efermi,
@@ -1612,7 +1624,9 @@ class BoltztrapAnalyzer:
         return CompleteDos(structure, total_dos=total_dos, pdoss=pdoss)
 
     def get_mu_bounds(self, temp=300):
-        """:param temp: Temperature.
+        """
+        Args:
+            temp: Temperature.
 
         Returns:
             The chemical potential bounds at that temperature.
@@ -1620,7 +1634,7 @@ class BoltztrapAnalyzer:
         return min(self.mu_doping["p"][temp]), max(self.mu_doping["n"][temp])
 
     def get_carrier_concentration(self):
-        """Gives the carrier concentration (in cm^-3).
+        """Get the carrier concentration (in cm^-3).
 
         Returns:
             a dictionary {temp:[]} with an array of carrier concentration
@@ -1630,7 +1644,7 @@ class BoltztrapAnalyzer:
         return {temp: [1e24 * i / self.vol for i in self._carrier_conc[temp]] for temp in self._carrier_conc}
 
     def get_hall_carrier_concentration(self):
-        """Gives the Hall carrier concentration (in cm^-3). This is the trace of
+        """Get the Hall carrier concentration (in cm^-3). This is the trace of
         the Hall tensor (see Boltztrap source code) Hall carrier concentration
         are not always exactly the same than carrier concentration.
 
@@ -1651,7 +1665,7 @@ class BoltztrapAnalyzer:
 
     @staticmethod
     def parse_outputtrans(path_dir):
-        """Parses .outputtrans file.
+        """Parse .outputtrans file.
 
         Args:
             path_dir: dir containing boltztrap.outputtrans
@@ -1679,7 +1693,7 @@ class BoltztrapAnalyzer:
 
     @staticmethod
     def parse_transdos(path_dir, efermi, dos_spin=1, trim_dos=False):
-        """Parses .transdos (total DOS) and .transdos_x_y (partial DOS) files.
+        """Parse .transdos (total DOS) and .transdos_x_y (partial DOS) files.
 
         Args:
             path_dir: (str) dir containing DOS files
@@ -1754,15 +1768,14 @@ class BoltztrapAnalyzer:
 
     @staticmethod
     def parse_intrans(path_dir):
-        """Parses boltztrap.intrans mainly to extract the value of scissor applied
+        """Parse boltztrap.intrans mainly to extract the value of scissor applied
         to the bands or some other inputs.
 
         Args:
             path_dir: (str) dir containing the boltztrap.intrans file
 
         Returns:
-            intrans (dict): a dictionary containing various inputs that had
-                been used in the Boltztrap run.
+            dict: various inputs that had been used in the Boltztrap run.
         """
         intrans = {}
         with open(f"{path_dir}/boltztrap.intrans") as file:
@@ -1775,13 +1788,13 @@ class BoltztrapAnalyzer:
 
     @staticmethod
     def parse_struct(path_dir):
-        """Parses boltztrap.struct file (only the volume).
+        """Parse boltztrap.struct file (only the volume).
 
         Args:
             path_dir: (str) dir containing the boltztrap.struct file
 
         Returns:
-            (float) volume
+            float: volume of the structure in Angstrom^3
         """
         with open(f"{path_dir}/boltztrap.struct") as file:
             tokens = file.readlines()
@@ -1791,7 +1804,7 @@ class BoltztrapAnalyzer:
 
     @staticmethod
     def parse_cond_and_hall(path_dir, doping_levels=None):
-        """Parses the conductivity and Hall tensors.
+        """Parse the conductivity and Hall tensors.
 
         Args:
             path_dir: Path containing .condtens / .halltens files
@@ -1923,7 +1936,7 @@ class BoltztrapAnalyzer:
         )
 
     @classmethod
-    def from_files(cls, path_dir, dos_spin=1):
+    def from_files(cls, path_dir: str, dos_spin: Literal[-1, 1] = 1) -> Self:
         """Get a BoltztrapAnalyzer object from a set of files.
 
         Args:
@@ -1937,20 +1950,20 @@ class BoltztrapAnalyzer:
 
         vol = cls.parse_struct(path_dir)
 
-        intrans = cls.parse_intrans(path_dir)
+        in_trans = cls.parse_intrans(path_dir)
 
         if run_type == "BOLTZ":
-            dos, pdos = cls.parse_transdos(path_dir, efermi, dos_spin=dos_spin, trim_dos=False)
+            dos, partial_dos = cls.parse_transdos(path_dir, efermi, dos_spin=dos_spin, trim_dos=False)
 
             *cond_and_hall, carrier_conc = cls.parse_cond_and_hall(path_dir, doping_levels)
 
-            return cls(gap, *cond_and_hall, intrans, dos, pdos, carrier_conc, vol, warning)
+            return cls(gap, *cond_and_hall, in_trans, dos, partial_dos, carrier_conc, vol, warning)  # type: ignore[call-arg]
 
         if run_type == "DOS":
-            trim = intrans["dos_type"] == "HISTO"
-            dos, pdos = cls.parse_transdos(path_dir, efermi, dos_spin=dos_spin, trim_dos=trim)
+            trim = in_trans["dos_type"] == "HISTO"
+            dos, partial_dos = cls.parse_transdos(path_dir, efermi, dos_spin=dos_spin, trim_dos=trim)
 
-            return cls(gap=gap, dos=dos, dos_partial=pdos, warning=warning, vol=vol)
+            return cls(gap=gap, dos=dos, dos_partial=partial_dos, warning=warning, vol=vol)
 
         if run_type == "BANDS":
             bz_kpoints = np.loadtxt(f"{path_dir}/boltztrap_band.dat")[:, -3:]
@@ -1958,9 +1971,9 @@ class BoltztrapAnalyzer:
             return cls(bz_bands=bz_bands, bz_kpoints=bz_kpoints, warning=warning, vol=vol)
 
         if run_type == "FERMI":
-            if os.path.exists(f"{path_dir}/boltztrap_BZ.cube"):
+            if os.path.isfile(f"{path_dir}/boltztrap_BZ.cube"):
                 fs_data = read_cube_file(f"{path_dir}/boltztrap_BZ.cube")
-            elif os.path.exists(f"{path_dir}/fort.30"):
+            elif os.path.isfile(f"{path_dir}/fort.30"):
                 fs_data = read_cube_file(f"{path_dir}/fort.30")
             else:
                 raise BoltztrapError("No data file found for fermi surface")
@@ -1992,9 +2005,11 @@ class BoltztrapAnalyzer:
         }
         return jsanitize(results)
 
-    @staticmethod
-    def from_dict(data):
-        """:param data: Dict representation.
+    @classmethod
+    def from_dict(cls, data: dict) -> Self:
+        """
+        Args:
+            data: Dict representation.
 
         Returns:
             BoltztrapAnalyzer
@@ -2110,7 +2125,7 @@ class BoltztrapAnalyzer:
         vol = data.get("vol")
         warning = data.get("warning")
 
-        return BoltztrapAnalyzer(
+        return cls(
             gap=gap,
             mu_steps=mu_steps,
             cond=cond,
@@ -2132,13 +2147,15 @@ class BoltztrapAnalyzer:
 
 
 def read_cube_file(filename):
-    """:param filename: Cube filename
+    """
+    Args:
+        filename: Cube filename.
 
     Returns:
         Energy data.
     """
-    with open(filename) as file:
-        natoms = 0
+    with open(filename, encoding="utf-8") as file:
+        n_atoms = n1 = n2 = n3 = None
         for idx, line in enumerate(file):
             line = line.rstrip("\n")
             if idx == 0 and "CUBE" not in line:
@@ -2146,7 +2163,7 @@ def read_cube_file(filename):
 
             if idx == 2:
                 tokens = line.split()
-                natoms = int(tokens[0])
+                n_atoms = int(tokens[0])
             if idx == 3:
                 tokens = line.split()
                 n1 = int(tokens[0])
@@ -2160,12 +2177,16 @@ def read_cube_file(filename):
                 break
 
     if "fort.30" in filename:
-        energy_data = np.genfromtxt(filename, skip_header=natoms + 6, skip_footer=1)
-        nlines_data = len(energy_data)
-        last_line = np.genfromtxt(filename, skip_header=nlines_data + natoms + 6)
+        energy_data = np.genfromtxt(filename, skip_header=n_atoms + 6, skip_footer=1)
+        n_lines_data = len(energy_data)
+        last_line = np.genfromtxt(filename, skip_header=n_lines_data + n_atoms + 6)
         energy_data = np.append(energy_data.flatten(), last_line).reshape(n1, n2, n3)
+
     elif "boltztrap_BZ.cube" in filename:
-        energy_data = np.loadtxt(filename, skiprows=natoms + 6).reshape(n1, n2, n3)
+        energy_data = np.loadtxt(filename, skiprows=n_atoms + 6).reshape(n1, n2, n3)
+
+    else:
+        raise RuntimeError("Cannot read cube file.")
 
     energy_data /= Energy(1, "eV").to("Ry")
 
@@ -2253,7 +2274,7 @@ def seebeck_spb(eta, Lambda=0.5):
     )
 
 
-def eta_from_seebeck(seeb, Lambda):
+def eta_from_seebeck(seeb, Lambda) -> float:
     """It takes a value of seebeck and adjusts the analytic seebeck until it's equal.
 
     Returns:
@@ -2263,7 +2284,7 @@ def eta_from_seebeck(seeb, Lambda):
     return out[0][0]
 
 
-def seebeck_eff_mass_from_carr(eta, n, T, Lambda):
+def seebeck_eff_mass_from_carr(eta, n, T, Lambda) -> float:
     """Calculate seebeck effective mass at a certain carrier concentration
     eta in kB*T units, n in cm-3, T in K, returns mass in m0 units.
     """
@@ -2279,7 +2300,7 @@ def seebeck_eff_mass_from_carr(eta, n, T, Lambda):
     )
 
 
-def seebeck_eff_mass_from_seebeck_carr(seeb, n, T, Lambda):
+def seebeck_eff_mass_from_seebeck_carr(seeb, n, T, Lambda) -> float:
     """Find the chemical potential where analytic and calculated seebeck are identical
     and then calculate the seebeck effective mass at that chemical potential and
     a certain carrier concentration n.
