@@ -13,6 +13,7 @@ from __future__ import annotations
 import re
 import sys
 import warnings
+from typing import TYPE_CHECKING
 
 import numpy as np
 from monty.json import MSONable
@@ -27,6 +28,11 @@ from pymatgen.util.coord import get_linear_interpolated_value
 from pymatgen.util.due import Doi, due
 from pymatgen.util.num import round_to_sigfigs
 
+if TYPE_CHECKING:
+    from typing import Any
+
+    from typing_extensions import Self
+
 __author__ = "Marco Esters, Janine George"
 __copyright__ = "Copyright 2017, The Materials Project"
 __version__ = "0.2"
@@ -43,11 +49,14 @@ due.cite(
 class Cohp(MSONable):
     """Basic COHP object."""
 
-    def __init__(self, efermi, energies, cohp, are_coops=False, are_cobis=False, icohp=None) -> None:
+    def __init__(
+        self, efermi, energies, cohp, are_coops=False, are_cobis=False, are_multi_center_cobis=False, icohp=None
+    ) -> None:
         """
         Args:
             are_coops: Indicates whether this object describes COOPs.
             are_cobis: Indicates whether this object describes COBIs.
+            are_multi_center_cobis: Indicates whether this object describes multi-center COBIs
             efermi: Fermi energy.
             energies: A sequence of energies.
             cohp ({Spin: np.array}): representing the COHP for each spin.
@@ -55,19 +64,21 @@ class Cohp(MSONable):
         """
         self.are_coops = are_coops
         self.are_cobis = are_cobis
+        self.are_multi_center_cobis = are_multi_center_cobis
         self.efermi = efermi
         self.energies = np.array(energies)
         self.cohp = cohp
         self.icohp = icohp
 
     def __repr__(self) -> str:
-        """Returns a string that can be easily plotted (e.g. using gnuplot)."""
+        """Get a string that can be easily plotted (e.g. using gnuplot)."""
         if self.are_coops:
             cohp_str = "COOP"
-        elif self.are_cobis:
+        elif self.are_cobis or self.are_multi_center_cobis:
             cohp_str = "COBI"
         else:
             cohp_str = "COHP"
+
         header = ["Energy", f"{cohp_str}Up"]
         data = [self.energies, self.cohp[Spin.up]]
         if Spin.down in self.cohp:
@@ -93,6 +104,7 @@ class Cohp(MSONable):
             "@class": type(self).__name__,
             "are_coops": self.are_coops,
             "are_cobis": self.are_cobis,
+            "are_multi_center_cobis": self.are_multi_center_cobis,
             "efermi": self.efermi,
             "energies": self.energies.tolist(),
             "COHP": {str(spin): pops.tolist() for spin, pops in self.cohp.items()},
@@ -102,7 +114,7 @@ class Cohp(MSONable):
         return dct
 
     def get_cohp(self, spin=None, integrated=False):
-        """Returns the COHP or ICOHP for a particular spin.
+        """Get the COHP or ICOHP for a particular spin.
 
         Args:
             spin: Spin. Can be parsed as spin object, integer (-1/1)
@@ -131,7 +143,7 @@ class Cohp(MSONable):
         return self.get_cohp(spin=spin, integrated=True)
 
     def get_interpolated_value(self, energy, integrated=False):
-        """Returns the COHP for a particular energy.
+        """Get the COHP for a particular energy.
 
         Args:
             energy: Energy to return the COHP value for.
@@ -148,19 +160,19 @@ class Cohp(MSONable):
         return inter
 
     def has_antibnd_states_below_efermi(self, spin=None, limit=0.01):
-        """Returns dict indicating if there are antibonding states below the Fermi level depending on the spin
+        """Get dict indicating if there are antibonding states below the Fermi level depending on the spin
         spin: Spin
         limit: -COHP smaller -limit will be considered.
         """
         populations = self.cohp
-        number_energies_below_efermi = len([x for x in self.energies if x <= self.efermi])
+        n_energies_below_efermi = len([energy for energy in self.energies if energy <= self.efermi])
 
         if populations is None:
             return None
         if spin is None:
             dict_to_return = {}
-            for sp, cohpvalues in populations.items():
-                if (max(cohpvalues[0:number_energies_below_efermi])) > limit:
+            for sp, cohp_vals in populations.items():
+                if (max(cohp_vals[0:n_energies_below_efermi])) > limit:
                     dict_to_return[sp] = True
                 else:
                     dict_to_return[sp] = False
@@ -169,9 +181,8 @@ class Cohp(MSONable):
             if isinstance(spin, int):
                 spin = Spin(spin)
             elif isinstance(spin, str):
-                s = {"up": 1, "down": -1}[spin.lower()]
-                spin = Spin(s)
-            if (max(populations[spin][0:number_energies_below_efermi])) > limit:
+                spin = Spin({"up": 1, "down": -1}[spin.lower()])
+            if (max(populations[spin][0:n_energies_below_efermi])) > limit:
                 dict_to_return[spin] = True
             else:
                 dict_to_return[spin] = False
@@ -179,17 +190,19 @@ class Cohp(MSONable):
         return dict_to_return
 
     @classmethod
-    def from_dict(cls, dct):
-        """Returns a COHP object from a dict representation of the COHP."""
+    def from_dict(cls, dct: dict[str, Any]) -> Self:
+        """Get a COHP object from a dict representation of the COHP."""
         icohp = {Spin(int(key)): np.array(val) for key, val in dct["ICOHP"].items()} if "ICOHP" in dct else None
         are_cobis = dct.get("are_cobis", False)
-        return Cohp(
+        are_multi_center_cobis = dct.get("are_multi_center_cobis", False)
+        return cls(
             dct["efermi"],
             dct["energies"],
             {Spin(int(key)): np.array(val) for key, val in dct["COHP"].items()},
             icohp=icohp,
             are_coops=dct["are_coops"],
             are_cobis=are_cobis,
+            are_multi_center_cobis=are_multi_center_cobis,
         )
 
 
@@ -216,6 +229,7 @@ class CompleteCohp(Cohp):
         bonds=None,
         are_coops=False,
         are_cobis=False,
+        are_multi_center_cobis=False,
         orb_res_cohp=None,
     ) -> None:
         """
@@ -233,21 +247,29 @@ class CompleteCohp(Cohp):
                 Defaults to False for COHPs.
             are_cobis: indicates whether the Cohp objects are COBIs.
                 Defaults to False for COHPs.
+            are_multi_center_cobis: indicates whether the Cohp objects are multi-center COBIs.
+                Defaults to False for COHPs.
             orb_res_cohp: Orbital-resolved COHPs.
         """
-        if are_coops and are_cobis:
-            raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
+        if (
+            (are_coops and are_cobis)
+            or (are_coops and are_multi_center_cobis)
+            or (are_cobis and are_multi_center_cobis)
+        ):
+            raise ValueError("You cannot have info about COOPs, COBIs and/or multi-center COBIS in the same file.")
         super().__init__(
             avg_cohp.efermi,
             avg_cohp.energies,
             avg_cohp.cohp,
             are_coops=are_coops,
             are_cobis=are_cobis,
+            are_multi_center_cobis=are_multi_center_cobis,
             icohp=avg_cohp.icohp,
         )
         self.structure = structure
         self.are_coops = are_coops
         self.are_cobis = are_cobis
+        self.are_multi_center_cobis = are_multi_center_cobis
         self.all_cohps = cohp_dict
         self.orb_res_cohp = orb_res_cohp
         self.bonds = bonds or {label: {} for label in self.all_cohps}
@@ -266,6 +288,7 @@ class CompleteCohp(Cohp):
             "@class": type(self).__name__,
             "are_coops": self.are_coops,
             "are_cobis": self.are_cobis,
+            "are_multi_center_cobis": self.are_multi_center_cobis,
             "efermi": self.efermi,
             "structure": self.structure.as_dict(),
             "energies": self.energies.tolist(),
@@ -346,7 +369,7 @@ class CompleteCohp(Cohp):
         )
 
     def get_summed_cohp_by_label_list(self, label_list, divisor=1, summed_spin_channels=False):
-        """Returns a COHP object that includes a summed COHP divided by divisor.
+        """Get a COHP object that includes a summed COHP divided by divisor.
 
         Args:
             label_list: list of labels for the COHP that should be included in the summed cohp
@@ -401,7 +424,7 @@ class CompleteCohp(Cohp):
     def get_summed_cohp_by_label_and_orbital_list(
         self, label_list, orbital_list, divisor=1, summed_spin_channels=False
     ):
-        """Returns a COHP object that includes a summed COHP divided by divisor.
+        """Get a COHP object that includes a summed COHP divided by divisor.
 
         Args:
             label_list: list of labels for the COHP that should be included in the summed cohp
@@ -420,7 +443,7 @@ class CompleteCohp(Cohp):
         first_cohpobject = self.get_orbital_resolved_cohp(label_list[0], orbital_list[0])
         summed_cohp = first_cohpobject.cohp.copy()
         summed_icohp = first_cohpobject.icohp.copy()
-        for ilabel, label in enumerate(label_list[1:], 1):
+        for ilabel, label in enumerate(label_list[1:], start=1):
             cohp_here = self.get_orbital_resolved_cohp(label, orbital_list[ilabel])
             summed_cohp[Spin.up] = np.sum([summed_cohp[Spin.up], cohp_here.cohp.copy()[Spin.up]], axis=0)
             if Spin.down in summed_cohp:
@@ -524,50 +547,65 @@ class CompleteCohp(Cohp):
         )
 
     @classmethod
-    def from_dict(cls, d):
-        """Returns CompleteCohp object from dict representation."""
+    def from_dict(cls, dct: dict) -> Self:
+        """Get CompleteCohp object from dict representation."""
+        # TODO: clean that mess up?
         cohp_dict = {}
-        efermi = d["efermi"]
-        energies = d["energies"]
-        structure = Structure.from_dict(d["structure"])
-        if "bonds" in d:
+        efermi = dct["efermi"]
+        energies = dct["energies"]
+        structure = Structure.from_dict(dct["structure"])
+        are_cobis = dct.get("are_cobis", False)
+        are_multi_center_cobis = dct.get("are_multi_center_cobis", False)
+        are_coops = dct["are_coops"]
+        avg_cohp = None
+
+        if "bonds" in dct:
             bonds = {
                 bond: {
-                    "length": d["bonds"][bond]["length"],
-                    "sites": tuple(PeriodicSite.from_dict(site) for site in d["bonds"][bond]["sites"]),
+                    "length": dct["bonds"][bond]["length"],
+                    "sites": tuple(PeriodicSite.from_dict(site) for site in dct["bonds"][bond]["sites"]),
+                    "cells": dct["bonds"][bond].get("cells", None),
                 }
-                for bond in d["bonds"]
+                for bond in dct["bonds"]
             }
         else:
             bonds = None
-        for label in d["COHP"]:
-            cohp = {Spin(int(spin)): np.array(d["COHP"][label][spin]) for spin in d["COHP"][label]}
+        for label in dct["COHP"]:
+            cohp = {Spin(int(spin)): np.array(dct["COHP"][label][spin]) for spin in dct["COHP"][label]}
             try:
-                icohp = {Spin(int(spin)): np.array(d["ICOHP"][label][spin]) for spin in d["ICOHP"][label]}
+                icohp = {Spin(int(spin)): np.array(dct["ICOHP"][label][spin]) for spin in dct["ICOHP"][label]}
             except KeyError:
                 icohp = None
             if label == "average":
-                avg_cohp = Cohp(efermi, energies, cohp, icohp=icohp)
+                avg_cohp = Cohp(
+                    efermi,
+                    energies,
+                    cohp,
+                    icohp=icohp,
+                    are_coops=are_coops,
+                    are_cobis=are_cobis,
+                    are_multi_center_cobis=are_multi_center_cobis,
+                )
             else:
                 cohp_dict[label] = Cohp(efermi, energies, cohp, icohp=icohp)
 
-        if "orb_res_cohp" in d:
-            orb_cohp = {}
-            for label in d["orb_res_cohp"]:
+        if "orb_res_cohp" in dct:
+            orb_cohp: dict[str, dict] = {}
+            for label in dct["orb_res_cohp"]:
                 orb_cohp[label] = {}
-                for orb in d["orb_res_cohp"][label]:
+                for orb in dct["orb_res_cohp"][label]:
                     cohp = {
-                        Spin(int(s)): np.array(d["orb_res_cohp"][label][orb]["COHP"][s], dtype=float)
-                        for s in d["orb_res_cohp"][label][orb]["COHP"]
+                        Spin(int(s)): np.array(dct["orb_res_cohp"][label][orb]["COHP"][s], dtype=float)
+                        for s in dct["orb_res_cohp"][label][orb]["COHP"]
                     }
                     try:
                         icohp = {
-                            Spin(int(s)): np.array(d["orb_res_cohp"][label][orb]["ICOHP"][s], dtype=float)
-                            for s in d["orb_res_cohp"][label][orb]["ICOHP"]
+                            Spin(int(s)): np.array(dct["orb_res_cohp"][label][orb]["ICOHP"][s], dtype=float)
+                            for s in dct["orb_res_cohp"][label][orb]["ICOHP"]
                         }
                     except KeyError:
                         icohp = None
-                    orbitals = [(int(o[0]), Orbital[o[1]]) for o in d["orb_res_cohp"][label][orb]["orbitals"]]
+                    orbitals = [(int(o[0]), Orbital[o[1]]) for o in dct["orb_res_cohp"][label][orb]["orbitals"]]
                     orb_cohp[label][orb] = {
                         "COHP": cohp,
                         "ICOHP": icohp,
@@ -575,9 +613,9 @@ class CompleteCohp(Cohp):
                     }
                 # If no total COHPs are present, calculate the total
                 # COHPs from the single-orbital populations. Total COHPs
-                # may not be present when the cohpgenerator keyword is used
+                # may not be present when the COHP generator keyword is used
                 # in LOBSTER versions 2.2.0 and earlier.
-                if label not in d["COHP"] or d["COHP"][label] is None:
+                if label not in dct["COHP"] or dct["COHP"][label] is None:
                     cohp = {
                         Spin.up: np.sum(
                             np.array([orb_cohp[label][orb]["COHP"][Spin.up] for orb in orb_cohp[label]]),
@@ -593,7 +631,7 @@ class CompleteCohp(Cohp):
                         pass
 
                 orb_res_icohp = None in [orb_cohp[label][orb]["ICOHP"] for orb in orb_cohp[label]]
-                if (label not in d["ICOHP"] or d["ICOHP"][label] is None) and orb_res_icohp:
+                if (label not in dct["ICOHP"] or dct["ICOHP"][label] is None) and orb_res_icohp:
                     icohp = {
                         Spin.up: np.sum(
                             np.array([orb_cohp[label][orb]["ICOHP"][Spin.up] for orb in orb_cohp[label]]),
@@ -608,32 +646,27 @@ class CompleteCohp(Cohp):
                     except KeyError:
                         pass
         else:
-            orb_cohp = None
+            orb_cohp = {}
 
-        if "average" not in d["COHP"]:
-            # calculate average
-            cohp = np.array([np.array(c) for c in d["COHP"].values()]).mean(axis=0)
-            try:
-                icohp = np.array([np.array(c) for c in d["ICOHP"].values()]).mean(axis=0)
-            except KeyError:
-                icohp = None
-            avg_cohp = Cohp(efermi, energies, cohp, icohp=icohp)
+        are_cobis = dct.get("are_cobis", False)
 
-        are_cobis = d.get("are_cobis", False)
-
-        return CompleteCohp(
+        return cls(
             structure,
             avg_cohp,
             cohp_dict,
             bonds=bonds,
-            are_coops=d["are_coops"],
+            are_coops=dct["are_coops"],
             are_cobis=are_cobis,
+            are_multi_center_cobis=are_multi_center_cobis,
             orb_res_cohp=orb_cohp,
         )
 
     @classmethod
-    def from_file(cls, fmt, filename=None, structure_file=None, are_coops=False, are_cobis=False):
-        """Creates a CompleteCohp object from an output file of a COHP
+    def from_file(
+        cls, fmt, filename=None, structure_file=None, are_coops=False, are_cobis=False, are_multi_center_cobis=False
+    ) -> Self:
+        """
+        Creates a CompleteCohp object from an output file of a COHP
         calculation. Valid formats are either LMTO (for the Stuttgart
         LMTO-ASA code) or LOBSTER (for the LOBSTER code).
 
@@ -650,6 +683,8 @@ class CompleteCohp(Cohp):
                 COHPs. Defaults to False for COHPs.
             are_cobis: Indicates whether the populations are COBIs or
                 COHPs. Defaults to False for COHPs.
+            are_multi_center_cobis: Indicates whether this file
+                includes information on multi-center COBIs
 
         Returns:
             A CompleteCohp object.
@@ -666,20 +701,29 @@ class CompleteCohp(Cohp):
                 structure_file = "CTRL"
             if filename is None:
                 filename = "COPL"
-            cohp_file = LMTOCopl(filename=filename, to_eV=True)
+            cohp_file: LMTOCopl | Cohpcar = LMTOCopl(filename=filename, to_eV=True)
         elif fmt == "LOBSTER":
-            if are_coops and are_cobis:
-                raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
+            if (
+                (are_coops and are_cobis)
+                or (are_coops and are_multi_center_cobis)
+                or (are_cobis and are_multi_center_cobis)
+            ):
+                raise ValueError("You cannot have info about COOPs, COBIs and/or multi-center COBIS in the same file.")
             if structure_file is None:
                 structure_file = "POSCAR"
             if filename is None and filename is None:
                 if are_coops:
                     filename = "COOPCAR.lobster"
-                elif are_cobis:
+                elif are_cobis or are_multi_center_cobis:
                     filename = "COBICAR.lobster"
                 else:
                     filename = "COHPCAR.lobster"
-            cohp_file = Cohpcar(filename=filename, are_coops=are_coops, are_cobis=are_cobis)
+            cohp_file = Cohpcar(
+                filename=filename,
+                are_coops=are_coops,
+                are_cobis=are_cobis,
+                are_multi_center_cobis=are_multi_center_cobis,
+            )
             orb_res_cohp = cohp_file.orb_res_cohp
         else:
             raise ValueError(f"Unknown format {fmt}. Valid formats are LMTO and LOBSTER.")
@@ -724,15 +768,15 @@ class CompleteCohp(Cohp):
         if fmt == "LMTO":
             # Calculate the average COHP for the LMTO file to be
             # consistent with LOBSTER output.
-            avg_data = {"COHP": {}, "ICOHP": {}}
+            avg_data: dict[str, dict] = {"COHP": {}, "ICOHP": {}}
             for i in avg_data:
                 for spin in spins:
                     rows = np.array([v[i][spin] for v in cohp_data.values()])
-                    avg = np.average(rows, axis=0)
+                    avg = np.mean(rows, axis=0)
                     # LMTO COHPs have 5 significant figures
                     avg_data[i].update({spin: np.array([round_to_sigfigs(a, 5) for a in avg], dtype=float)})
             avg_cohp = Cohp(efermi, energies, avg_data["COHP"], icohp=avg_data["ICOHP"])
-        else:
+        elif not are_multi_center_cobis:
             avg_cohp = Cohp(
                 efermi,
                 energies,
@@ -740,23 +784,67 @@ class CompleteCohp(Cohp):
                 icohp=cohp_data["average"]["ICOHP"],
                 are_coops=are_coops,
                 are_cobis=are_cobis,
+                are_multi_center_cobis=are_multi_center_cobis,
             )
             del cohp_data["average"]
+        else:
+            # only include two-center cobis in average
+            # do this for both spin channels
+            cohp = {}
+            cohp[Spin.up] = np.array(
+                [np.array(c["COHP"][Spin.up]) for c in cohp_file.cohp_data.values() if len(c["sites"]) <= 2]
+            ).mean(axis=0)
+            try:
+                cohp[Spin.down] = np.array(
+                    [np.array(c["COHP"][Spin.down]) for c in cohp_file.cohp_data.values() if len(c["sites"]) <= 2]
+                ).mean(axis=0)
+            except KeyError:
+                pass
+            try:
+                icohp = {}
+                icohp[Spin.up] = np.array(
+                    [np.array(c["ICOHP"][Spin.up]) for c in cohp_file.cohp_data.values() if len(c["sites"]) <= 2]
+                ).mean(axis=0)
+                try:
+                    icohp[Spin.down] = np.array(
+                        [np.array(c["ICOHP"][Spin.down]) for c in cohp_file.cohp_data.values() if len(c["sites"]) <= 2]
+                    ).mean(axis=0)
+                except KeyError:
+                    pass
+            except KeyError:
+                icohp = None
+            avg_cohp = Cohp(
+                efermi,
+                energies,
+                cohp,
+                icohp=icohp,
+                are_coops=are_coops,
+                are_cobis=are_cobis,
+                are_multi_center_cobis=are_multi_center_cobis,
+            )
 
         cohp_dict = {
-            label: Cohp(efermi, energies, v["COHP"], icohp=v["ICOHP"], are_coops=are_coops, are_cobis=are_cobis)
-            for label, v in cohp_data.items()
+            key: Cohp(
+                efermi,
+                energies,
+                dct["COHP"],
+                icohp=dct["ICOHP"],
+                are_coops=are_coops,
+                are_cobis=are_cobis,
+                are_multi_center_cobis=are_multi_center_cobis,
+            )
+            for key, dct in cohp_data.items()
         }
 
         bond_dict = {
-            label: {
-                "length": v["length"],
-                "sites": [structure[site] for site in v["sites"]],
+            key: {
+                "length": dct["length"],
+                "sites": [structure[site] for site in dct["sites"]],
             }
-            for label, v in cohp_data.items()
+            for key, dct in cohp_data.items()
         }
 
-        return CompleteCohp(
+        return cls(
             structure,
             avg_cohp,
             cohp_dict,
@@ -768,7 +856,7 @@ class CompleteCohp(Cohp):
 
 
 class IcohpValue(MSONable):
-    """Class to store information on an ICOHP or ICOOP value.
+    """Store information on an ICOHP or ICOOP value.
 
     Attributes:
         energies (ndarray): Energy values for the COHP/ICOHP/COOP/ICOOP.
@@ -797,7 +885,6 @@ class IcohpValue(MSONable):
             are_cobis: if True, this are COBIs
             orbitals: {[str(Orbital1)-str(Orbital2)]: {"icohp":{Spin.up: icohpvalue for spin.up, Spin.down:
                 icohpvalue for spin.down}, "orbitals":[Orbital1, Orbital2]}}.
-
         """
         if are_coops and are_cobis:
             raise ValueError("You cannot have info about COOPs and COBIs in the same file.")
@@ -893,21 +980,21 @@ class IcohpValue(MSONable):
             spin: Spin.up or Spin.down.
 
         Returns:
-            icohpvalue (float) corresponding to chosen spin.
+            float: corresponding to chosen spin.
         """
         if not self.is_spin_polarized and spin == Spin.down:
             raise ValueError("The calculation was not performed with spin polarization")
 
         return self._icohp[spin]
 
-    def icohpvalue_orbital(self, orbitals, spin=Spin.up):
+    def icohpvalue_orbital(self, orbitals, spin=Spin.up) -> float:
         """
         Args:
             orbitals: List of Orbitals or "str(Orbital1)-str(Orbital2)"
             spin: Spin.up or Spin.down.
 
         Returns:
-            icohpvalue (float) corresponding to chosen spin.
+            float: corresponding to chosen spin.
         """
         if not self.is_spin_polarized and spin == Spin.down:
             raise ValueError("The calculation was not performed with spin polarization")
@@ -917,8 +1004,9 @@ class IcohpValue(MSONable):
 
     @property
     def icohp(self):
-        """Dict with icohps for spinup and spindown
-        Return:
+        """Dict with ICOHPs for spin up and spin down.
+
+        Returns:
             dict={Spin.up: icohpvalue for spin.up, Spin.down: icohpvalue for spin.down}.
         """
         return self._icohp
@@ -934,11 +1022,10 @@ class IcohpValue(MSONable):
 
     @property
     def summed_orbital_icohp(self):
-        """Sums orbitals-resolved ICOHPs of both spin channels for spin-plarized compounds.
+        """Sums orbital-resolved ICOHPs of both spin channels for spin-polarized compounds.
 
         Returns:
-            {"str(Orbital1)-str(Ortibal2)": icohp value in eV}.
-
+            dict[str, float]: "str(Orbital1)-str(Ortibal2)" mapped to ICOHP value in eV.
         """
         orbital_icohp = {}
         for orb, item in self._orbitals.items():
@@ -949,7 +1036,7 @@ class IcohpValue(MSONable):
 
 
 class IcohpCollection(MSONable):
-    """Class to store IcohpValues.
+    """Store IcohpValues.
 
     Attributes:
         are_coops (bool): Boolean to indicate if these are ICOOPs.
@@ -1017,12 +1104,12 @@ class IcohpCollection(MSONable):
             )
 
     def __str__(self) -> str:
-        joinstr = []
+        lst = []
         for value in self._icohplist.values():
-            joinstr.append(str(value))
-        return "\n".join(joinstr)
+            lst.append(str(value))
+        return "\n".join(lst)
 
-    def get_icohp_by_label(self, label, summed_spin_channels=True, spin=Spin.up, orbitals=None):
+    def get_icohp_by_label(self, label, summed_spin_channels=True, spin=Spin.up, orbitals=None) -> float:
         """Get an icohp value for a certain bond as indicated by the label (bond labels starting by "1" as in
         ICOHPLIST/ICOOPLIST).
 
@@ -1033,9 +1120,9 @@ class IcohpCollection(MSONable):
             orbitals: List of Orbital or "str(Orbital1)-str(Orbital2)"
 
         Returns:
-            float describing ICOHP/ICOOP value
+            float: ICOHP/ICOOP value
         """
-        icohp_here = self._icohplist[label]
+        icohp_here: IcohpValue = self._icohplist[label]
         if orbitals is None:
             if summed_spin_channels:
                 return icohp_here.summed_icohp
@@ -1048,7 +1135,7 @@ class IcohpCollection(MSONable):
 
         return icohp_here.icohpvalue_orbital(spin=spin, orbitals=orbitals)
 
-    def get_summed_icohp_by_label_list(self, label_list, divisor=1.0, summed_spin_channels=True, spin=Spin.up):
+    def get_summed_icohp_by_label_list(self, label_list, divisor=1.0, summed_spin_channels=True, spin=Spin.up) -> float:
         """Get the sum of several ICOHP values that are indicated by a list of labels
         (labels of the bonds are the same as in ICOHPLIST/ICOOPLIST).
 
@@ -1059,7 +1146,7 @@ class IcohpCollection(MSONable):
             spin: if summed_spin_channels is equal to False, this spin indicates which spin channel should be returned
 
         Returns:
-            float that is a sum of all ICOHPs/ICOOPs as indicated with label_list
+            float: sum of all ICOHPs/ICOOPs as indicated with label_list
         """
         sum_icohp = 0
         for label in label_list:
@@ -1194,14 +1281,14 @@ class IcohpCollection(MSONable):
 def get_integrated_cohp_in_energy_range(
     cohp, label, orbital=None, energy_range=None, relative_E_Fermi=True, summed_spin_channels=True
 ):
-    """Method that can integrate completecohp objects which include data on integrated COHPs
+    """Integrate CompleteCohp objects which include data on integrated COHPs
     Args:
-        cohp: CompleteCOHP object
+        cohp: CompleteCohp object
         label: label of the COHP data
         orbital: If not None, a orbital resolved integrated COHP will be returned
-        energy_range:   if None, returns icohp value at Fermi level;
-                        if float, integrates from this float up to the Fermi level;
-                        if [float,float], will integrate in between
+        energy_range: If None, returns icohp value at Fermi level.
+            If float, integrates from this float up to the Fermi level.
+            If [float,float], will integrate in between.
         relative_E_Fermi: if True, energy scale with E_Fermi at 0 eV is chosen
         summed_spin_channels: if True, Spin channels will be summed.
 
