@@ -13,6 +13,10 @@ from monty.json import MSONable
 if TYPE_CHECKING:
     from collections.abc import Sequence
 
+    from typing_extensions import Self
+
+    from pymatgen.core import Lattice
+
 
 @unique
 class Spin(Enum):
@@ -74,7 +78,7 @@ class Orbital(Enum):
 
     @property
     def orbital_type(self):
-        """Returns OrbitalType of an orbital."""
+        """OrbitalType of an orbital."""
         return OrbitalType[self.name[0]]
 
 
@@ -125,9 +129,11 @@ class Magmom(MSONable):
     def __init__(
         self, moment: float | Sequence[float] | np.ndarray | Magmom, saxis: Sequence[float] = (0, 0, 1)
     ) -> None:
-        """:param moment: magnetic moment, supplied as float or list/np.ndarray
-        :param saxis: spin axis, supplied as list/np.ndarray, parameter will
-            be converted to unit vector (default is [0, 0, 1])
+        """
+        Args:
+            moment: magnetic moment, supplied as float or list/np.ndarray
+            saxis: spin axis, supplied as list/np.ndarray, parameter will
+                be converted to unit vector (default is [0, 0, 1]).
 
         Returns:
             Magmom object
@@ -148,7 +154,7 @@ class Magmom(MSONable):
         self.saxis = saxis / np.linalg.norm(saxis)
 
     @classmethod
-    def from_global_moment_and_saxis(cls, global_moment, saxis):
+    def from_global_moment_and_saxis(cls, global_moment, saxis) -> Self:
         """Convenience method to initialize Magmom from a given global
         magnetic moment, i.e. magnetic moment with saxis=(0,0,1), and
         provided saxis.
@@ -156,8 +162,9 @@ class Magmom(MSONable):
         Method is useful if you do not know the components of your
         magnetic moment in frame of your desired saxis.
 
-        :param global_moment:
-        :param saxis: desired saxis
+        Args:
+            global_moment: global magnetic moment
+            saxis: desired saxis
         """
         magmom = Magmom(global_moment)
         return cls(magmom.get_moment(saxis=saxis), saxis=saxis)
@@ -204,18 +211,19 @@ class Magmom(MSONable):
         Magmom's internal spin quantization axis, i.e. equivalent to
         Magmom.moment.
 
-        :param saxis: (list/numpy array) spin quantization axis
+        Args:
+            saxis: (list/numpy array) spin quantization axis
 
         Returns:
             np.ndarray of length 3
         """
         # transform back to moment with spin axis [0, 0, 1]
-        m_inv = self._get_transformation_matrix_inv(self.saxis)
-        moment = np.matmul(self.moment, m_inv)
+        trafo_mat_inv = self._get_transformation_matrix_inv(self.saxis)
+        moment = np.matmul(self.moment, trafo_mat_inv)
 
         # transform to new saxis
-        m = self._get_transformation_matrix(saxis)
-        moment = np.matmul(moment, m)
+        trafo_mat = self._get_transformation_matrix(saxis)
+        moment = np.matmul(moment, trafo_mat)
 
         # round small values to zero
         moment[np.abs(moment) < 1e-8] = 0
@@ -223,12 +231,8 @@ class Magmom(MSONable):
         return moment
 
     @property
-    def global_moment(self):
-        """Get the magnetic moment defined in an arbitrary global reference frame.
-
-        Returns:
-            np.ndarray of length 3
-        """
+    def global_moment(self) -> np.ndarray:
+        """The magnetic moment defined in an arbitrary global reference frame as an np.array of length 3."""
         return self.get_moment()
 
     @property
@@ -242,7 +246,7 @@ class Magmom(MSONable):
         return np.dot(self.moment, self.saxis)
 
     def get_xyz_magmom_with_001_saxis(self):
-        """Returns a Magmom in the default setting of saxis = [0, 0, 1] and
+        """Get a Magmom in the default setting of saxis = [0, 0, 1] and
         the magnetic moment rotated as required.
 
         Returns:
@@ -289,13 +293,13 @@ class Magmom(MSONable):
 
     @staticmethod
     def have_consistent_saxis(magmoms) -> bool:
-        """This method checks that all Magmom objects in a list have a
-        consistent spin quantization axis. To write MAGMOM tags to a
-        VASP INCAR, a global SAXIS value for all magmoms has to be used.
+        """Check that all Magmom objects in a list have a consistent spin quantization axis.
+        To write MAGMOM tags to a VASP INCAR, a global SAXIS value for all magmoms has to be used.
         If saxis are inconsistent, can create consistent set with:
         Magmom.get_consistent_set(magmoms).
 
-        :param magmoms: list of magmoms (Magmoms, scalars or vectors)
+        Args:
+            magmoms: list of magmoms (Magmoms, scalars or vectors)
 
         Returns:
             bool
@@ -303,20 +307,19 @@ class Magmom(MSONable):
         magmoms = [Magmom(magmom) for magmom in magmoms]
         ref_saxis = magmoms[0].saxis
         match_ref = [magmom.saxis == ref_saxis for magmom in magmoms]
-        if np.all(match_ref):
-            return True
-        return False
+        return np.all(match_ref)
 
     @staticmethod
     def get_consistent_set_and_saxis(magmoms, saxis=None):
-        """Method to ensure a list of magmoms use the same spin axis.
+        """Ensure a list of magmoms use the same spin axis.
         Returns a tuple of a list of Magmoms and their global spin axis.
 
-        :param magmoms: list of magmoms (Magmoms, scalars or vectors)
-        :param saxis: can provide a specific global spin axis
+        Args:
+            magmoms: list of magmoms (Magmoms, scalars or vectors)
+            saxis: can provide a specific global spin axis
 
         Returns:
-            (list of Magmoms, global spin axis) tuple
+            tuple[list[Magmom], np.ndarray]: (list of Magmoms, global spin axis)
         """
         magmoms = [Magmom(magmom) for magmom in magmoms]
         saxis = Magmom.get_suggested_saxis(magmoms) if saxis is None else saxis / np.linalg.norm(saxis)
@@ -325,12 +328,13 @@ class Magmom(MSONable):
 
     @staticmethod
     def get_suggested_saxis(magmoms):
-        """This method returns a suggested spin axis for a set of magmoms,
+        """Get a suggested spin axis for a set of magmoms,
         taking the largest magnetic moment as the reference. For calculations
         with collinear spins, this would give a sensible saxis for a ncl
         calculation.
 
-        :param magmoms: list of magmoms (Magmoms, scalars or vectors)
+        Args:
+            magmoms: list of magmoms (Magmoms, scalars or vectors)
 
         Returns:
             np.ndarray of length 3
@@ -351,9 +355,10 @@ class Magmom(MSONable):
 
     @staticmethod
     def are_collinear(magmoms) -> bool:
-        """Method checks to see if a set of magnetic moments are collinear
-        with each other.
-        :param magmoms: list of magmoms (Magmoms, scalars or vectors).
+        """Check if a set of magnetic moments are collinear with each other.
+
+        Args:
+            magmoms: list of magmoms (Magmoms, scalars or vectors).
 
         Returns:
             bool.
@@ -375,13 +380,15 @@ class Magmom(MSONable):
         return num_ncl == 0
 
     @classmethod
-    def from_moment_relative_to_crystal_axes(cls, moment, lattice):
+    def from_moment_relative_to_crystal_axes(cls, moment: list[float], lattice: Lattice) -> Self:
         """Obtaining a Magmom object from a magnetic moment provided
         relative to crystal axes.
 
         Used for obtaining moments from magCIF file.
-        :param moment: list of floats specifying vector magmom
-        :param lattice: Lattice
+
+        Args:
+            moment: list of floats specifying vector magmom
+            lattice: Lattice
 
         Returns:
             Magmom
@@ -397,7 +404,8 @@ class Magmom(MSONable):
         """If scalar magmoms, moments will be given arbitrarily along z.
         Used for writing moments to magCIF file.
 
-        :param lattice: Lattice
+        Args:
+            lattice: Lattice
 
         Returns:
             vector as list of floats
@@ -438,7 +446,7 @@ class Magmom(MSONable):
         return hash(tuple(self.moment) + tuple(self.saxis))
 
     def __float__(self) -> float:
-        """Returns magnitude of magnetic moment with a sign with respect to
+        """Get magnitude of magnetic moment with a sign with respect to
         an arbitrary direction.
 
         Should give unsurprising output if Magmom is treated like a
