@@ -9,7 +9,7 @@ import copy
 import os
 import warnings
 from collections import defaultdict
-from typing import TYPE_CHECKING, Literal, Union
+from typing import TYPE_CHECKING, Union
 
 import numpy as np
 from monty.design_patterns import cached_class
@@ -19,7 +19,7 @@ from tqdm import tqdm
 from uncertainties import ufloat
 
 from pymatgen.analysis.structure_analyzer import oxide_type, sulfide_type
-from pymatgen.core import SETTINGS, Element
+from pymatgen.core import SETTINGS, Composition, Element
 from pymatgen.entries.computed_entries import (
     CompositionEnergyAdjustment,
     ComputedEntry,
@@ -33,6 +33,10 @@ from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
+    from typing import Literal
+
+    from pymatgen.util.typing import CompositionLike
+
 
 __author__ = "Amanda Wang, Ryan Kingsbury, Shyue Ping Ong, Anubhav Jain, Stephen Dacek, Sai Jayaraman"
 __copyright__ = "Copyright 2012-2020, The Materials Project"
@@ -43,6 +47,29 @@ __date__ = "April 2020"
 
 MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
 MU_H2O = -2.4583  # Free energy of formation of water, eV/H2O, used by MaterialsProjectAqueousCompatibility
+MP2020_COMPAT_CONFIG = loadfn(f"{MODULE_DIR}/MP2020Compatibility.yaml")
+MP_COMPAT_CONFIG = loadfn(f"{MODULE_DIR}/MPCompatibility.yaml")
+
+# This was compiled by cross-referencing structures in Materials Project from exp_compounds.json.gz
+# used in the fitting of the MP2020 correction scheme, and applying the BVAnalyzer algorithm to
+# determine oxidation state. O and S are not included since these are treated separately.
+MP2020_ANION_OXIDATION_STATE_RANGES = {
+    "Br": (-1, -1),
+    "Cl": (-1, -1),
+    "F": (-1, -1),
+    "H": (-1, -1),
+    "I": (-1, -1),
+    "N": (-3, -2),
+    "Sb": (-3, -2),
+    "Se": (-2, -1),
+    "Si": (-4, -1),
+    "Te": (-2, -1),
+}
+
+assert (  # ping @janosh @rkingsbury on GitHub if this fails
+    MP2020_COMPAT_CONFIG["Corrections"]["GGAUMixingCorrections"]["O"]
+    == MP2020_COMPAT_CONFIG["Corrections"]["GGAUMixingCorrections"]["F"]
+), "MP2020Compatibility.yaml expected to have the same Hubbard U corrections for O and F"
 
 AnyComputedEntry = Union[ComputedEntry, ComputedStructureEntry]
 
@@ -53,7 +80,7 @@ class CompatibilityError(Exception):
     """
 
 
-class Correction(metaclass=abc.ABCMeta):
+class Correction(abc.ABC):
     """A Correction class is a pre-defined scheme for correction a computed
     entry based on the type and chemistry of the structure and the
     calculation parameters. All Correction classes must implement a
@@ -62,7 +89,7 @@ class Correction(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get_correction(self, entry: AnyComputedEntry) -> EnergyAdjustment:
-        """Returns correction and uncertainty for a single entry.
+        """Get correction and uncertainty for a single entry.
 
         Args:
             entry: A ComputedEntry object.
@@ -104,7 +131,7 @@ class Correction(metaclass=abc.ABCMeta):
 
 
 class PotcarCorrection(Correction):
-    """Checks that POTCARs are valid within a pre-defined input set. This
+    """Check that POTCARs are valid within a pre-defined input set. This
     ensures that calculations performed using different InputSets are not
     compared against each other.
 
@@ -189,12 +216,14 @@ class GasCorrection(Correction):
         Args:
             config_file: Path to the selected compatibility.yaml config file.
         """
-        c = loadfn(config_file)
-        self.name = c["Name"]
-        self.cpd_energies = c["Advanced"]["CompoundEnergies"]
+        config = loadfn(config_file)
+        self.name = config["Name"]
+        self.cpd_energies = config["Advanced"]["CompoundEnergies"]
 
     def get_correction(self, entry) -> ufloat:
-        """:param entry: A ComputedEntry/ComputedStructureEntry
+        """
+        Args:
+            entry: A ComputedEntry/ComputedStructureEntry.
 
         Returns:
             Correction.
@@ -203,7 +232,7 @@ class GasCorrection(Correction):
         # set error to 0 because old MPCompatibility doesn't have errors
         correction = ufloat(0.0, 0.0)
 
-        rform = entry.composition.reduced_formula
+        rform = entry.reduced_formula
         if rform in self.cpd_energies:
             correction += self.cpd_energies[rform] * comp.num_atoms - entry.uncorrected_energy
 
@@ -228,14 +257,16 @@ class AnionCorrection(Correction):
             correct_peroxide: Specify whether peroxide/superoxide/ozonide
                 corrections are to be applied or not.
         """
-        c = loadfn(config_file)
-        self.oxide_correction = c["OxideCorrections"]
-        self.sulfide_correction = c.get("SulfideCorrections", defaultdict(float))
-        self.name = c["Name"]
+        config = loadfn(config_file)
+        self.oxide_correction = config["OxideCorrections"]
+        self.sulfide_correction = config.get("SulfideCorrections", defaultdict(float))
+        self.name = config["Name"]
         self.correct_peroxide = correct_peroxide
 
     def get_correction(self, entry) -> ufloat:
-        """:param entry: A ComputedEntry/ComputedStructureEntry
+        """
+        Args:
+            entry: A ComputedEntry/ComputedStructureEntry.
 
         Returns:
             Correction.
@@ -283,9 +314,9 @@ class AnionCorrection(Correction):
                 else:
                     warnings.warn(
                         "No structure or oxide_type parameter present. Note that peroxide/superoxide corrections "
-                        "are not as reliable and relies only on detection of special formulas, e.g., Li2O2."
+                        "are not as reliable and relies only on detection of special formulas, e.g. Li2O2."
                     )
-                    rform = entry.composition.reduced_formula
+                    rform = entry.reduced_formula
                     if rform in UCorrection.common_peroxides:
                         correction += self.oxide_correction["peroxide"] * comp["O"]
                     elif rform in UCorrection.common_superoxides:
@@ -317,14 +348,14 @@ class AqueousCorrection(Correction):
             config_file: Path to the selected compatibility.yaml config file.
             error_file: Path to the selected compatibilityErrors.yaml config file.
         """
-        c = loadfn(config_file)
-        self.cpd_energies = c["AqueousCompoundEnergies"]
+        config = loadfn(config_file)
+        self.cpd_energies = config["AqueousCompoundEnergies"]
         # there will either be a CompositionCorrections OR an OxideCorrections key,
         # but not both, depending on the compatibility scheme we are using.
         # MITCompatibility only uses OxideCorrections, and hence self.comp_correction is none.
-        self.comp_correction = c.get("CompositionCorrections", defaultdict(float))
-        self.oxide_correction = c.get("OxideCorrections", defaultdict(float))
-        self.name = c["Name"]
+        self.comp_correction = config.get("CompositionCorrections", defaultdict(float))
+        self.oxide_correction = config.get("OxideCorrections", defaultdict(float))
+        self.name = config["Name"]
         if error_file:
             e = loadfn(error_file)
             self.cpd_errors = e.get("AqueousCompoundEnergies", defaultdict(float))
@@ -332,7 +363,9 @@ class AqueousCorrection(Correction):
             self.cpd_errors = defaultdict(float)
 
     def get_correction(self, entry) -> ufloat:
-        """:param entry: A ComputedEntry/ComputedStructureEntry
+        """
+        Args:
+            entry: A ComputedEntry/ComputedStructureEntry.
 
         Returns:
             Correction, Uncertainty.
@@ -426,27 +459,29 @@ class UCorrection(Correction):
         if compat_type not in ["GGA", "Advanced"]:
             raise CompatibilityError(f"Invalid {compat_type=}")
 
-        c = loadfn(config_file)
+        config = loadfn(config_file)
 
         self.input_set = input_set
         if compat_type == "Advanced":
             self.u_settings = self.input_set.CONFIG["INCAR"]["LDAUU"]
-            self.u_corrections = c["Advanced"]["UCorrections"]
+            self.u_corrections = config["Advanced"]["UCorrections"]
         else:
             self.u_settings = {}
             self.u_corrections = {}
 
-        self.name = c["Name"]
+        self.name = config["Name"]
         self.compat_type = compat_type
 
         if error_file:
-            e = loadfn(error_file)
-            self.u_errors = e["Advanced"]["UCorrections"]
+            err = loadfn(error_file)
+            self.u_errors = err["Advanced"]["UCorrections"]
         else:
             self.u_errors = {}
 
     def get_correction(self, entry) -> ufloat:
-        """:param entry: A ComputedEntry/ComputedStructureEntry
+        """
+        Args:
+            entry: A ComputedEntry/ComputedStructureEntry.
 
         Returns:
             Correction, Uncertainty.
@@ -455,12 +490,12 @@ class UCorrection(Correction):
         comp = entry.composition
 
         elements = sorted((el for el in comp.elements if comp[el] > 0), key=lambda el: el.X)
-        most_electroneg = elements[-1].symbol
+        most_electro_neg = elements[-1].symbol
         correction = ufloat(0.0, 0.0)
 
-        u_corr = self.u_corrections.get(most_electroneg, {})
-        u_settings = self.u_settings.get(most_electroneg, {})
-        u_errors = self.u_errors.get(most_electroneg, defaultdict(float))
+        u_corr = self.u_corrections.get(most_electro_neg, {})
+        u_settings = self.u_settings.get(most_electro_neg, {})
+        u_errors = self.u_errors.get(most_electro_neg, defaultdict(float))
 
         for el in comp.elements:
             sym = el.symbol
@@ -476,7 +511,7 @@ class UCorrection(Correction):
         return f"{self.name} {self.compat_type} Correction"
 
 
-class Compatibility(MSONable, metaclass=abc.ABCMeta):
+class Compatibility(MSONable, abc.ABC):
     """Abstract Compatibility class, not intended for direct use.
     Compatibility classes are used to correct the energies of an entry or a set
     of entries. All Compatibility classes must implement get_adjustments() method.
@@ -663,7 +698,7 @@ class CorrectionsList(Compatibility):
         return adjustment_list
 
     def get_corrections_dict(self, entry: AnyComputedEntry) -> tuple[dict[str, float], dict[str, float]]:
-        """Returns the correction values and uncertainties applied to a particular entry.
+        """Get the correction values and uncertainties applied to a particular entry.
 
         Args:
             entry: A ComputedEntry object.
@@ -682,21 +717,20 @@ class CorrectionsList(Compatibility):
         return corrections, uncertainties
 
     def get_explanation_dict(self, entry):
-        """Provides an explanation dict of the corrections that are being applied
-        for a given compatibility scheme. Inspired by the "explain" methods
-        in many database methodologies.
+        """Explain the corrections applied for a given compatibility scheme. Inspired by the
+        "explain" methods in many database methodologies.
 
         Args:
             entry: A ComputedEntry.
 
         Returns:
-            (dict) of the form
-            {"Compatibility": "string",
-            "Uncorrected_energy": float,
-            "Corrected_energy": float,
-            "correction_uncertainty:" float,
-            "Corrections": [{"Name of Correction": {
-            "Value": float, "Explanation": "string", "Uncertainty": float}]}
+            dict[str, str | float | list[dict[str, Union[str, float]]]: of the form
+                {"Compatibility": "string",
+                "Uncorrected_energy": float,
+                "Corrected_energy": float,
+                "correction_uncertainty:" float,
+                "Corrections": [{"Name of Correction": {
+                "Value": float, "Explanation": "string", "Uncertainty": float}]}
         """
         corr_entry = self.process_entry(entry)
         uncorrected_energy = (corr_entry or entry).uncorrected_energy
@@ -734,27 +768,26 @@ class CorrectionsList(Compatibility):
         Args:
             entry: A ComputedEntry.
         """
-        d = self.get_explanation_dict(entry)
-        print(f"The uncorrected value of the energy of {entry.composition} is {d['uncorrected_energy']:f} eV")
-        print(f"The following corrections / screening are applied for {d['compatibility']}:\n")
-        for c in d["corrections"]:
-            print(f"{c['name']} correction: {c['description']}\n")
-            print(f"For the entry, this correction has the value {c['value']:f} eV.")
-            if c["uncertainty"] != 0 or c["value"] == 0:
-                print(f"This correction has an uncertainty value of {c['uncertainty']:f} eV.")
+        dct = self.get_explanation_dict(entry)
+        print(f"The uncorrected value of the energy of {entry.composition} is {dct['uncorrected_energy']:f} eV")
+        print(f"The following corrections / screening are applied for {dct['compatibility']}:\n")
+        for corr in dct["corrections"]:
+            print(f"{corr['name']} correction: {corr['description']}\n")
+            print(f"For the entry, this correction has the value {corr['value']:f} eV.")
+            if corr["uncertainty"] != 0 or corr["value"] == 0:
+                print(f"This correction has an uncertainty value of {corr['uncertainty']:f} eV.")
             else:
                 print("This correction does not have uncertainty data available")
             print("-" * 30)
 
-        print(f"The final energy after corrections is {d['corrected_energy']:f}")
+        print(f"The final energy after corrections is {dct['corrected_energy']:f}")
 
 
 class MaterialsProjectCompatibility(CorrectionsList):
     """This class implements the GGA/GGA+U mixing scheme, which allows mixing of
     entries. Note that this should only be used for VASP calculations using the
     MaterialsProject parameters (see pymatgen.io.vasp.sets.MPVaspInputSet).
-    Using this compatibility scheme on runs with different parameters is not
-    valid.
+    Using this compatibility scheme on runs with different parameters is not valid.
     """
 
     def __init__(
@@ -782,27 +815,25 @@ class MaterialsProjectCompatibility(CorrectionsList):
         self.compat_type = compat_type
         self.correct_peroxide = correct_peroxide
         self.check_potcar_hash = check_potcar_hash
-        fp = f"{MODULE_DIR}/MPCompatibility.yaml"
+        file_path = f"{MODULE_DIR}/MPCompatibility.yaml"
         super().__init__(
             [
                 PotcarCorrection(MPRelaxSet, check_hash=check_potcar_hash),
-                GasCorrection(fp),
-                AnionCorrection(fp, correct_peroxide=correct_peroxide),
-                UCorrection(fp, MPRelaxSet, compat_type),
+                GasCorrection(file_path),
+                AnionCorrection(file_path, correct_peroxide=correct_peroxide),
+                UCorrection(file_path, MPRelaxSet, compat_type),
             ]
         )
 
 
-"""
-Note from Ryan Kingsbury (2022-10-14): MaterialsProject2020Compatibility inherits from Compatibility
-instead of CorrectionsList which came before it because CorrectionsList had technical limitations.
-When we did the new scheme (MP2020) we decided to refactor the base Compatibility class to not
-require CorrectionsList.
+# Note from Ryan Kingsbury (2022-10-14): MaterialsProject2020Compatibility inherits from Compatibility
+# instead of CorrectionsList which came before it because CorrectionsList had technical limitations.
+# When we did the new scheme (MP2020) we decided to refactor the base Compatibility class to not
+# require CorrectionsList.
 
-This was particularly helpful for the AqueousCorrection class. The new system gives complete
-flexibility to process entries however needed inside the get_adjustments() method, rather than
-having to create a list of separate correction classes.
-"""
+# This was particularly helpful for the AqueousCorrection class. The new system gives complete
+# flexibility to process entries however needed inside the get_adjustments() method, rather than
+# having to create a list of separate correction classes.
 
 
 @cached_class
@@ -815,6 +846,10 @@ class MaterialsProject2020Compatibility(Compatibility):
     Materials Project input set parameters (see pymatgen.io.vasp.sets.MPRelaxSet). Using
     this compatibility scheme on calculations with different parameters is not valid.
 
+    The option `strict_anions` was added due to a bug. See PR #3803 (May 2024) for
+    related discussion. This behavior may change in subsequent versions as a more comprehensive
+    fix for this issue may be found.
+
     Note: While the correction scheme is largely composition-based, the energy corrections
     applied to ComputedEntry and ComputedStructureEntry can differ for O and S-containing
     structures if entry.data['oxidation_states'] is not populated or explicitly set. This
@@ -828,6 +863,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         self,
         compat_type: str = "Advanced",
         correct_peroxide: bool = True,
+        strict_anions: Literal["require_exact", "require_bound", "no_check"] = "require_bound",
         check_potcar: bool = True,
         check_potcar_hash: bool = False,
         config_file: str | None = None,
@@ -854,6 +890,15 @@ class MaterialsProject2020Compatibility(Compatibility):
             correct_peroxide: Specify whether peroxide/superoxide/ozonide
                 corrections are to be applied or not. If false, all oxygen-containing
                 compounds are assigned the 'oxide' correction. Default: True
+            strict_anions: only apply the anion corrections to anions. The option
+                "require_exact" will only apply anion corrections in cases where the
+                anion oxidation state is between the oxidation states used
+                in the experimental fitting data. The option "require_bound" will
+                define an anion as any species with an oxidation state value of <= -1.
+                This prevents the anion correction from being applied to unrealistic
+                hypothetical structures containing large proportions of very electronegative
+                elements, thus artificially over-stabilizing the compound. Set to "no_check"
+                to restore the original behavior described in the associated publication. Default: True
             check_potcar (bool): Check that the POTCARs used in the calculation are consistent
                 with the Materials Project parameters. False bypasses this check altogether. Default: True
                 Can also be disabled globally by running `pmg config --add PMG_POTCAR_CHECKS false`.
@@ -878,6 +923,7 @@ class MaterialsProject2020Compatibility(Compatibility):
 
         self.compat_type = compat_type
         self.correct_peroxide = correct_peroxide
+        self.strict_anions = strict_anions
         self.check_potcar = check_potcar
         self.check_potcar_hash = check_potcar_hash
 
@@ -885,21 +931,22 @@ class MaterialsProject2020Compatibility(Compatibility):
         if config_file:
             if os.path.isfile(config_file):
                 self.config_file: str | None = config_file
-                c = loadfn(self.config_file)
+                config = loadfn(self.config_file)
             else:
                 raise ValueError(f"Custom MaterialsProject2020Compatibility {config_file=} does not exist.")
         else:
             self.config_file = None
-            c = loadfn(f"{MODULE_DIR}/MP2020Compatibility.yaml")
 
-        self.name = c["Name"]
-        self.comp_correction = c["Corrections"].get("CompositionCorrections", defaultdict(float))
-        self.comp_errors = c["Uncertainties"].get("CompositionCorrections", defaultdict(float))
+            config = MP2020_COMPAT_CONFIG
+
+        self.name = config["Name"]
+        self.comp_correction = config["Corrections"].get("CompositionCorrections", defaultdict(float))
+        self.comp_errors = config["Uncertainties"].get("CompositionCorrections", defaultdict(float))
 
         if self.compat_type == "Advanced":
             self.u_settings = MPRelaxSet.CONFIG["INCAR"]["LDAUU"]
-            self.u_corrections = c["Corrections"].get("GGAUMixingCorrections", defaultdict(float))
-            self.u_errors = c["Uncertainties"].get("GGAUMixingCorrections", defaultdict(float))
+            self.u_corrections = config["Corrections"].get("GGAUMixingCorrections", defaultdict(float))
+            self.u_errors = config["Uncertainties"].get("GGAUMixingCorrections", defaultdict(float))
         else:
             self.u_settings = {}
             self.u_corrections = {}
@@ -939,7 +986,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         comp = entry.composition
         rform = comp.reduced_formula
         # sorted list of elements, ordered by electronegativity
-        elements = sorted((el for el in comp.elements if comp[el] > 0), key=lambda el: el.X)
+        sorted_elements = sorted((el for el in comp.elements if comp[el] > 0), key=lambda el: el.X)
 
         # Skip single elements
         if len(comp) == 1:
@@ -979,7 +1026,7 @@ class MaterialsProject2020Compatibility(Compatibility):
                 else:
                     warnings.warn(
                         "No structure or oxide_type parameter present. Note that peroxide/superoxide corrections "
-                        "are not as reliable and relies only on detection of special formulas, e.g., Li2O2."
+                        "are not as reliable and relies only on detection of special formulas, e.g. Li2O2."
                     )
 
                     common_peroxides = "Li2O2 Na2O2 K2O2 Cs2O2 Rb2O2 BeO2 MgO2 CaO2 SrO2 BaO2".split()
@@ -1028,22 +1075,39 @@ class MaterialsProject2020Compatibility(Compatibility):
         if entry.data["oxidation_states"] == {}:
             warnings.warn(
                 f"Failed to guess oxidation states for Entry {entry.entry_id} "
-                f"({entry.composition.reduced_formula}). Assigning anion correction to "
+                f"({entry.reduced_formula}). Assigning anion correction to "
                 "only the most electronegative atom."
             )
 
-        for anion in "Br I Se Si Sb Te H N F Cl".split():
+        for anion in ("Br", "I", "Se", "Si", "Sb", "Te", "H", "N", "F", "Cl"):
             if Element(anion) in comp and anion in self.comp_correction:
                 apply_correction = False
+                oxidation_state = entry.data["oxidation_states"].get(anion, 0)
                 # if the oxidation_states key is not populated, only apply the correction if the anion
                 # is the most electronegative element
-                if entry.data["oxidation_states"].get(anion, 0) < 0:
+                if oxidation_state < 0:
                     apply_correction = True
+                    if self.strict_anions == "require_bound" and oxidation_state > -1:
+                        # This is not an anion. Noting that the rare case of a fractional
+                        # oxidation state in range [-1, 0] might be considered an anionic.
+                        # This could include suboxides or metal-rich pnictides, chalcogenides etc.
+                        # However! these cases are not included in the experimental fitting data
+                        # used for the correction scheme, and so there is no information for
+                        # whether the corrections are appropriate in this instance, and likely
+                        # may.
+                        apply_correction = False
                 else:
-                    most_electroneg = elements[-1].symbol
+                    most_electroneg = sorted_elements[-1].symbol
                     if anion == most_electroneg:
                         apply_correction = True
 
+                if self.strict_anions == "require_exact":
+                    apply_correction = False
+                    if (oxi_range := MP2020_ANION_OXIDATION_STATE_RANGES.get(anion)) and (
+                        oxi_range[0] <= oxidation_state <= oxi_range[1]
+                    ):
+                        apply_correction = True
+
                 if apply_correction:
                     adjustments.append(
                         CompositionEnergyAdjustment(
@@ -1058,7 +1122,7 @@ class MaterialsProject2020Compatibility(Compatibility):
         # GGA / GGA+U mixing scheme corrections
         calc_u = entry.parameters.get("hubbards")
         calc_u = defaultdict(int) if calc_u is None else calc_u
-        most_electroneg = elements[-1].symbol
+        most_electroneg = sorted_elements[-1].symbol
         u_corrections = self.u_corrections.get(most_electroneg, defaultdict(float))
         u_settings = self.u_settings.get(most_electroneg, defaultdict(float))
         u_errors = self.u_errors.get(most_electroneg, defaultdict(float))
@@ -1066,10 +1130,10 @@ class MaterialsProject2020Compatibility(Compatibility):
         for el in comp.elements:
             symbol = el.symbol
             # Check for bad U values
-            expected_u = u_settings.get(symbol, 0)
-            actual_u = calc_u.get(symbol, 0)
+            expected_u = float(u_settings.get(symbol, 0))
+            actual_u = float(calc_u.get(symbol, 0))
             if actual_u != expected_u:
-                raise CompatibilityError(f"Invalid U value of {actual_u:.1f} on {symbol}, expected {expected_u:.1f}")
+                raise CompatibilityError(f"Invalid U value of {actual_u:.3} on {symbol}, expected {expected_u:.3}")
             if symbol in u_corrections:
                 adjustments.append(
                     CompositionEnergyAdjustment(
@@ -1261,7 +1325,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         super().__init__()
 
     def get_adjustments(self, entry: ComputedEntry) -> list[EnergyAdjustment]:
-        """Returns the corrections applied to a particular entry.
+        """Get the corrections applied to a particular entry.
 
         Args:
             entry: A ComputedEntry object.
@@ -1338,7 +1402,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         # TODO - detection of embedded water molecules is not very sophisticated
         # Should be replaced with some kind of actual structure detection
 
-        # For any compound except water, check to see if it is a hydrate (contains
+        # For any compound except water, check if it is a hydrate (contains
         # H2O in its structure). If so, adjust the energy to remove MU_H2O eV per
         # embedded water molecule.
         # in other words, we assume that the DFT energy of such a compound is really
@@ -1420,7 +1484,7 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
 
         # when processing single entries, all H2 polymorphs will get assigned the
         # same energy
-        if len(entries) == 1 and entries[0].composition.reduced_formula == "H2":
+        if len(entries) == 1 and entries[0].reduced_formula == "H2":
             warnings.warn(
                 "Processing single H2 entries will result in the all polymorphs "
                 "being assigned the same energy. This should not cause problems "
@@ -1434,20 +1498,46 @@ class MaterialsProjectAqueousCompatibility(Compatibility):
         # results
         if len(entries) > 1:
             if not self.o2_energy:
-                o2_entries = [e for e in entries if e.composition.reduced_formula == "O2"]
+                o2_entries = [e for e in entries if e.reduced_formula == "O2"]
                 if o2_entries:
                     self.o2_energy = min(e.energy_per_atom for e in o2_entries)
 
             if not self.h2o_energy and not self.h2o_adjustments:
-                h2o_entries = [e for e in entries if e.composition.reduced_formula == "H2O"]
+                h2o_entries = [e for e in entries if e.reduced_formula == "H2O"]
                 if h2o_entries:
                     h2o_entries = sorted(h2o_entries, key=lambda e: e.energy_per_atom)
                     self.h2o_energy = h2o_entries[0].energy_per_atom
                     self.h2o_adjustments = h2o_entries[0].correction / h2o_entries[0].composition.num_atoms
 
-        h2_entries = [e for e in entries if e.composition.reduced_formula == "H2"]
+        h2_entries = [e for e in entries if e.reduced_formula == "H2"]
         if h2_entries:
             h2_entries = sorted(h2_entries, key=lambda e: e.energy_per_atom)
             self.h2_energy = h2_entries[0].energy_per_atom  # type: ignore[assignment]
 
         return super().process_entries(entries, clean=clean, verbose=verbose, inplace=inplace, on_error=on_error)
+
+
+def needs_u_correction(
+    comp: CompositionLike,
+    u_config: dict[str, dict[str, float]] = MP2020_COMPAT_CONFIG["Corrections"]["GGAUMixingCorrections"],
+) -> set[str]:
+    """Check if a composition is Hubbard U-corrected in the Materials Project 2020
+    GGA/GGA+U mixing scheme.
+
+    Args:
+        comp (CompositionLike): The formula/composition to check.
+        u_config (dict): The U-correction configuration to use. Default is the
+            Materials Project 2020 configuration.
+
+    Returns:
+        set[str]: The subset of elements whose combination requires a U-correction. Pass
+            return value to bool(ret_val) if you just want True/False.
+    """
+    elements = set(map(str, Composition(comp).elements))
+    has_u_anion = set(u_config) & elements
+
+    u_corrected_cations = set(u_config["O"])
+    has_u_cation = u_corrected_cations & elements
+    if has_u_cation and has_u_anion:
+        return has_u_cation | has_u_anion
+    return set()
