@@ -13,7 +13,7 @@ import math
 import os
 import warnings
 from itertools import combinations
-from typing import TYPE_CHECKING, Literal, cast
+from typing import TYPE_CHECKING, cast
 
 import numpy as np
 from monty.json import MontyDecoder, MontyEncoder, MSONable
@@ -25,6 +25,10 @@ from pymatgen.entries import Entry
 from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
+    from typing import Literal
+
+    from typing_extensions import Self
+
     from pymatgen.core import Structure
 
 __author__ = "Ryan Kingsbury, Matt McDermott, Shyue Ping Ong, Anubhav Jain"
@@ -68,12 +72,12 @@ class EnergyAdjustment(MSONable):
 
     @property
     def value(self):
-        """Return the value of the energy correction in eV."""
+        """The value of the energy correction in eV."""
         return self._value
 
     @property
     def uncertainty(self):
-        """Return the uncertainty in the value of the energy adjustment in eV."""
+        """The uncertainty in the value of the energy adjustment in eV."""
         return self._uncertainty
 
     @abc.abstractmethod
@@ -127,13 +131,15 @@ class ConstantEnergyAdjustment(EnergyAdjustment):
 
     @property
     def explain(self):
-        """Return an explanation of how the energy adjustment is calculated."""
+        """An explanation of how the energy adjustment is calculated."""
         return f"{self.description} ({self.value:.3f} eV)"
 
-    def normalize(self, factor):
+    def normalize(self, factor: float) -> None:
         """Normalize energy adjustment (in place), dividing value/uncertainty by a
         factor.
-        :param factor: factor to divide by.
+
+        Args:
+            factor: factor to divide by.
         """
         self._value /= factor
         self._uncertainty /= factor
@@ -187,23 +193,25 @@ class CompositionEnergyAdjustment(EnergyAdjustment):
 
     @property
     def value(self):
-        """Return the value of the energy adjustment in eV."""
+        """The value of the energy adjustment in eV."""
         return self._adj_per_atom * self.n_atoms
 
     @property
     def uncertainty(self):
-        """Return the value of the energy adjustment in eV."""
+        """The value of the energy adjustment in eV."""
         return self.uncertainty_per_atom * self.n_atoms
 
     @property
     def explain(self):
-        """Return an explanation of how the energy adjustment is calculated."""
+        """An explanation of how the energy adjustment is calculated."""
         return f"{self.description} ({self._adj_per_atom:.3f} eV/atom x {self.n_atoms} atoms)"
 
-    def normalize(self, factor):
+    def normalize(self, factor: float) -> None:
         """Normalize energy adjustment (in place), dividing value/uncertainty by a
         factor.
-        :param factor: factor to divide by.
+
+        Args:
+            factor: factor to divide by.
         """
         self.n_atoms /= factor
 
@@ -246,23 +254,25 @@ class TemperatureEnergyAdjustment(EnergyAdjustment):
 
     @property
     def value(self):
-        """Return the value of the energy correction in eV."""
+        """The value of the energy correction in eV."""
         return self._adj_per_deg * self.temp * self.n_atoms
 
     @property
     def uncertainty(self):
-        """Return the value of the energy adjustment in eV."""
+        """The value of the energy adjustment in eV."""
         return self.uncertainty_per_deg * self.temp * self.n_atoms
 
     @property
     def explain(self):
-        """Return an explanation of how the energy adjustment is calculated."""
+        """An explanation of how the energy adjustment is calculated."""
         return f"{self.description} ({self._adj_per_deg:.4f} eV/K/atom x {self.temp} K x {self.n_atoms} atoms)"
 
-    def normalize(self, factor):
+    def normalize(self, factor: float) -> None:
         """Normalize energy adjustment (in place), dividing value/uncertainty by a
         factor.
-        :param factor: factor to divide by.
+
+        Args:
+            factor: factor to divide by.
         """
         self.n_atoms /= factor
 
@@ -281,9 +291,9 @@ class ComputedEntry(Entry):
         energy_adjustments: list | None = None,
         parameters: dict | None = None,
         data: dict | None = None,
-        entry_id: object | None = None,
+        entry_id: str | None = None,
     ):
-        """Initializes a ComputedEntry.
+        """Initialize a ComputedEntry.
 
         Args:
             composition (Composition): Composition of the entry. For
@@ -319,7 +329,7 @@ class ComputedEntry(Entry):
         self.parameters = parameters or {}
         self.data = data or {}
         self.entry_id = entry_id
-        self.name = self.composition.reduced_formula
+        self.name = self.reduced_formula
 
     @property
     def uncorrected_energy(self) -> float:
@@ -416,8 +426,7 @@ class ComputedEntry(Entry):
     def __repr__(self) -> str:
         n_atoms = self.composition.num_atoms
         output = [
-            f"{self.entry_id} {type(self).__name__:<10} "
-            f"- {self.composition.formula:<12} ({self.composition.reduced_formula})",
+            f"{self.entry_id} {type(self).__name__:<10} - {self.formula:<12} ({self.reduced_formula})",
             f"{'Energy (Uncorrected)':<24} = {self._energy:<9.4f} eV ({self._energy / n_atoms:<8.4f} eV/atom)",
             f"{'Correction':<24} = {self.correction:<9.4f} eV ({self.correction / n_atoms:<8.4f} eV/atom)",
             f"{'Energy (Final)':<24} = {self.energy:<9.4f} eV ({self.energy_per_atom:<8.4f} eV/atom)",
@@ -461,42 +470,40 @@ class ComputedEntry(Entry):
         if not math.isclose(self.energy, other.energy):
             return False
 
-        if self.composition != other.composition:
-            return False
-
         # assumes that data, parameters are equivalent
-        return True
+        return self.composition == other.composition
 
     @classmethod
-    def from_dict(cls, d) -> ComputedEntry:
-        """:param d: Dict representation.
+    def from_dict(cls, dct: dict) -> Self:
+        """
+        Args:
+           dct (dict): Dict representation.
 
         Returns:
             ComputedEntry
         """
-        dec = MontyDecoder()
         # the first block here is for legacy ComputedEntry that were
         # serialized before we had the energy_adjustments attribute.
-        if d["correction"] != 0 and not d.get("energy_adjustments"):
+        if dct["correction"] != 0 and not dct.get("energy_adjustments"):
             return cls(
-                d["composition"],
-                d["energy"],
-                d["correction"],
-                parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
-                data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
-                entry_id=d.get("entry_id"),
+                dct["composition"],
+                dct["energy"],
+                dct["correction"],
+                parameters={k: MontyDecoder().process_decoded(v) for k, v in dct.get("parameters", {}).items()},
+                data={k: MontyDecoder().process_decoded(v) for k, v in dct.get("data", {}).items()},
+                entry_id=dct.get("entry_id"),
             )
         # this is the preferred / modern way of instantiating ComputedEntry
         # we don't pass correction explicitly because it will be calculated
         # on the fly from energy_adjustments
         return cls(
-            d["composition"],
-            d["energy"],
+            dct["composition"],
+            dct["energy"],
             correction=0,
-            energy_adjustments=[dec.process_decoded(e) for e in d.get("energy_adjustments", {})],
-            parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
-            data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
-            entry_id=d.get("entry_id"),
+            energy_adjustments=[MontyDecoder().process_decoded(e) for e in dct.get("energy_adjustments", {})],
+            parameters={k: MontyDecoder().process_decoded(v) for k, v in dct.get("parameters", {}).items()},
+            data={k: MontyDecoder().process_decoded(v) for k, v in dct.get("data", {}).items()},
+            entry_id=dct.get("entry_id"),
         )
 
     def as_dict(self) -> dict:
@@ -522,7 +529,7 @@ class ComputedEntry(Entry):
         return super().__hash__()
 
     def copy(self) -> ComputedEntry:
-        """Returns a copy of the ComputedEntry."""
+        """Get a copy of the ComputedEntry."""
         return ComputedEntry(
             composition=self.composition,
             energy=self.uncorrected_energy,
@@ -547,9 +554,9 @@ class ComputedStructureEntry(ComputedEntry):
         energy_adjustments: list | None = None,
         parameters: dict | None = None,
         data: dict | None = None,
-        entry_id: object | None = None,
+        entry_id: str | None = None,
     ) -> None:
-        """Initializes a ComputedStructureEntry.
+        """Initialize a ComputedStructureEntry.
 
         Args:
             structure (Structure): The actual structure of an entry.
@@ -603,40 +610,44 @@ class ComputedStructureEntry(ComputedEntry):
         return dct
 
     @classmethod
-    def from_dict(cls, d) -> ComputedStructureEntry:
-        """:param d: Dict representation.
+    def from_dict(cls, dct: dict) -> Self:
+        """
+        Args:
+            dct (dict): Dict representation.
 
         Returns:
             ComputedStructureEntry
         """
-        dec = MontyDecoder()
         # the first block here is for legacy ComputedEntry that were
         # serialized before we had the energy_adjustments attribute.
-        if d["correction"] != 0 and not d.get("energy_adjustments"):
-            struct = dec.process_decoded(d["structure"])
+        if dct["correction"] != 0 and not dct.get("energy_adjustments"):
+            struct = MontyDecoder().process_decoded(dct["structure"])
             return cls(
                 struct,
-                d["energy"],
-                correction=d["correction"],
-                parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
-                data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
-                entry_id=d.get("entry_id"),
+                dct["energy"],
+                correction=dct["correction"],
+                parameters={k: MontyDecoder().process_decoded(v) for k, v in dct.get("parameters", {}).items()},
+                data={k: MontyDecoder().process_decoded(v) for k, v in dct.get("data", {}).items()},
+                entry_id=dct.get("entry_id"),
             )
         # this is the preferred / modern way of instantiating ComputedEntry
         # we don't pass correction explicitly because it will be calculated
         # on the fly from energy_adjustments
         return cls(
-            dec.process_decoded(d["structure"]),
-            d["energy"],
-            composition=d.get("composition"),
+            MontyDecoder().process_decoded(dct["structure"]),
+            dct["energy"],
+            composition=dct.get("composition"),
             correction=0,
-            energy_adjustments=[dec.process_decoded(e) for e in d.get("energy_adjustments", {})],
-            parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
-            data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
-            entry_id=d.get("entry_id"),
+            energy_adjustments=[MontyDecoder().process_decoded(e) for e in dct.get("energy_adjustments", {})],
+            parameters={k: MontyDecoder().process_decoded(v) for k, v in dct.get("parameters", {}).items()},
+            data={k: MontyDecoder().process_decoded(v) for k, v in dct.get("data", {}).items()},
+            entry_id=dct.get("entry_id"),
         )
 
-    def normalize(self, mode: Literal["formula_unit", "atom"] = "formula_unit") -> ComputedStructureEntry:
+    def normalize(
+        self,
+        mode: Literal["formula_unit", "atom"] = "formula_unit",
+    ) -> ComputedStructureEntry:
         """Normalize the entry's composition and energy. The structure remains unchanged.
 
         Args:
@@ -659,7 +670,7 @@ class ComputedStructureEntry(ComputedEntry):
         return entry
 
     def copy(self) -> ComputedStructureEntry:
-        """Returns a copy of the ComputedStructureEntry."""
+        """Get a copy of the ComputedStructureEntry."""
         return ComputedStructureEntry(
             structure=self.structure.copy(),
             energy=self.uncorrected_energy,
@@ -687,7 +698,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         energy_adjustments: list | None = None,
         parameters: dict | None = None,
         data: dict | None = None,
-        entry_id: object | None = None,
+        entry_id: str | None = None,
     ):
         """
         Args:
@@ -767,7 +778,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
 
         Returns:
             float: the difference between formation enthalpy (T=0 K, Materials
-            Project) and the predicted Gibbs free energy of formation  (eV)
+            Project) and the predicted Gibbs free energy of formation (eV)
         """
         comp = self.composition
 
@@ -786,8 +797,8 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
 
             gibbs_energy = energy * factor
         else:
-            num_atoms = len(self.structure)
-            vol_per_atom = self.structure.volume / num_atoms
+            n_atoms = len(self.structure)
+            vol_per_atom = self.structure.volume / n_atoms
             reduced_mass = self._reduced_mass(self.structure)
 
             gibbs_energy = (
@@ -831,10 +842,10 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
             float: reduced mass (amu)
         """
         reduced_comp = structure.composition.reduced_composition
-        num_elems = len(reduced_comp.elements)
+        n_elems = len(reduced_comp.elements)
         elem_dict = reduced_comp.get_el_amt_dict()
 
-        denominator = (num_elems - 1) * reduced_comp.num_atoms
+        denominator = (n_elems - 1) * reduced_comp.num_atoms
 
         all_pairs = combinations(elem_dict.items(), 2)
         mass_sum = 0
@@ -870,7 +881,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         )
 
     @classmethod
-    def from_pd(cls, pd, temp=300, gibbs_model="SISSO") -> list[GibbsComputedStructureEntry]:
+    def from_pd(cls, pd, temp=300, gibbs_model="SISSO") -> list[Self]:
         """Constructor method for initializing a list of GibbsComputedStructureEntry
         objects from an existing T = 0 K phase diagram composed of
         ComputedStructureEntry objects, as acquired from a thermochemical database;
@@ -904,7 +915,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         return gibbs_entries
 
     @classmethod
-    def from_entries(cls, entries, temp=300, gibbs_model="SISSO") -> list[GibbsComputedStructureEntry]:
+    def from_entries(cls, entries, temp=300, gibbs_model="SISSO") -> list[Self]:
         """Constructor method for initializing GibbsComputedStructureEntry objects from
         T = 0 K ComputedStructureEntry objects, as acquired from a thermochemical
         database e.g. The Materials Project.
@@ -916,7 +927,7 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
             gibbs_model (str): Gibbs model to use; currently the only option is "SISSO".
 
         Returns:
-            [GibbsComputedStructureEntry]: list of new entries which replace the orig.
+            list[GibbsComputedStructureEntry]: new entries which replace the orig.
                 entries with inclusion of Gibbs free energy of formation at the
                 specified temperature.
         """
@@ -935,29 +946,30 @@ class GibbsComputedStructureEntry(ComputedStructureEntry):
         return dct
 
     @classmethod
-    def from_dict(cls, d) -> GibbsComputedStructureEntry:
-        """:param d: Dict representation.
+    def from_dict(cls, dct: dict) -> Self:
+        """
+        Args:
+            dct (dict): Dict representation.
 
         Returns:
             GibbsComputedStructureEntry
         """
         dec = MontyDecoder()
         return cls(
-            dec.process_decoded(d["structure"]),
-            d["formation_enthalpy_per_atom"],
-            d["temp"],
-            d["gibbs_model"],
-            composition=d.get("composition"),
-            correction=d["correction"],
-            energy_adjustments=[dec.process_decoded(e) for e in d.get("energy_adjustments", {})],
-            parameters={k: dec.process_decoded(v) for k, v in d.get("parameters", {}).items()},
-            data={k: dec.process_decoded(v) for k, v in d.get("data", {}).items()},
-            entry_id=d.get("entry_id"),
+            dec.process_decoded(dct["structure"]),
+            dct["formation_enthalpy_per_atom"],
+            dct["temp"],
+            dct["gibbs_model"],
+            composition=dct.get("composition"),
+            correction=dct["correction"],
+            energy_adjustments=[dec.process_decoded(e) for e in dct.get("energy_adjustments", {})],
+            parameters={k: dec.process_decoded(v) for k, v in dct.get("parameters", {}).items()},
+            data={k: dec.process_decoded(v) for k, v in dct.get("data", {}).items()},
+            entry_id=dct.get("entry_id"),
         )
 
     def __repr__(self):
-        output = [
-            f"GibbsComputedStructureEntry {self.entry_id} - {self.composition.formula}",
-            f"Gibbs Free Energy (Formation) = {self.energy:.4f}",
-        ]
-        return "\n".join(output)
+        return (
+            f"GibbsComputedStructureEntry {self.entry_id} - {self.formula}\n"
+            f"Gibbs Free Energy (Formation) = {self.energy:.4f}"
+        )
