@@ -16,7 +16,7 @@ import sys
 import warnings
 from enum import Enum, unique
 from time import sleep
-from typing import TYPE_CHECKING, Any, Literal
+from typing import TYPE_CHECKING
 
 import requests
 from monty.json import MontyDecoder, MontyEncoder
@@ -34,9 +34,13 @@ from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
+    from typing import Any, Literal
+
+    from typing_extensions import Self
 
     from pymatgen.phonon.bandstructure import PhononBandStructureSymmLine
     from pymatgen.phonon.dos import CompletePhononDos
+
 logger = logging.getLogger(__name__)
 MP_LOG_FILE = os.path.join(os.path.expanduser("~"), ".mprester.log.yaml")
 
@@ -233,7 +237,7 @@ class _MPResterLegacy:
             except Exception:
                 pass
 
-    def __enter__(self):
+    def __enter__(self) -> Self:
         """Support for "with" context."""
         return self
 
@@ -286,26 +290,26 @@ class _MPResterLegacy:
         dct = self._make_request("/api_check")
         return dct["version"]["db"]
 
-    def get_materials_id_from_task_id(self, task_id):
-        """Returns a new MP materials id from a task id (which can be
+    def get_materials_id_from_task_id(self, task_id) -> str:
+        """Get a new MP materials id from a task id (which can be
         equivalent to an old materials id).
 
         Args:
             task_id (str): A task id.
 
         Returns:
-            materials_id (str)
+            str: An MP material id.
         """
         return self._make_request(f"/materials/mid_from_tid/{task_id}")
 
     def get_materials_id_references(self, material_id):
-        """Returns all references for a materials id.
+        """Get all references for a materials id.
 
         Args:
             material_id (str): A material id.
 
         Returns:
-            BibTeX (str)
+            str: A BibTeX formatted string.
         """
         return self._make_request(f"/materials/{material_id}/refs")
 
@@ -357,10 +361,10 @@ class _MPResterLegacy:
         REST Endpoint: https://materialsproject.org/materials/<mp-id>/doc.
 
         Args:
-            materials_id (str): E.g., mp-1143 for Al2O3
+            materials_id (str): e.g. mp-1143 for Al2O3
 
         Returns:
-            Dict of json document of all data that is displayed on a materials
+            Dict of JSON document of all data that is displayed on a materials
             details page.
         """
         return self._make_request(f"/materials/{materials_id}/doc", mp_decode=False)
@@ -374,9 +378,9 @@ class _MPResterLegacy:
         https://materialsproject.org/materials/<mp-id>/xas/<absorbing_element>.
 
         Args:
-            material_id (str): E.g., mp-1143 for Al2O3
+            material_id (str): e.g. mp-1143 for Al2O3
             absorbing_element (str): The absorbing element in the corresponding
-                structure. E.g., Al in Al2O3
+                structure. e.g. Al in Al2O3
         """
         element_list = self.get_data(material_id, prop="elements")[0]["elements"]
         if absorbing_element not in element_list:
@@ -430,7 +434,7 @@ class _MPResterLegacy:
         return [d[prop] for d in data]
 
     def find_structure(self, filename_or_structure):
-        """Finds matching structures on the Materials Project site.
+        """Find matching structures on the Materials Project site.
 
         Args:
             filename_or_structure: filename or Structure object
@@ -450,10 +454,10 @@ class _MPResterLegacy:
         payload = {"structure": json.dumps(struct.as_dict(), cls=MontyEncoder)}
         response = self.session.post(f"{self.preamble}/find_structure", data=payload)
         if response.status_code in [200, 400]:
-            resp = json.loads(response.text, cls=MontyDecoder)
-            if resp["valid_response"]:
-                return resp["response"]
-            raise MPRestError(resp["error"])
+            response = json.loads(response.text, cls=MontyDecoder)
+            if response["valid_response"]:
+                return response["response"]
+            raise MPRestError(response["error"])
         raise MPRestError(f"REST error with status code {response.status_code} and error {response.text}")
 
     def get_entries(
@@ -572,8 +576,8 @@ class _MPResterLegacy:
 
         Args:
             chemsys (str or [str]): Chemical system string comprising element
-                symbols separated by dashes, e.g., "Li-Fe-O" or List of element
-                symbols, e.g., ["Li", "Fe", "O"].
+                symbols separated by dashes, e.g. "Li-Fe-O" or List of element
+                symbols, e.g. ["Li", "Fe", "O"].
             solid_compat: Compatibility scheme used to pre-process solid DFT energies prior to applying aqueous
                 energy adjustments. May be passed as a class (e.g. MaterialsProject2020Compatibility) or an instance
                 (e.g., MaterialsProject2020Compatibility()). If None, solid DFT energies are used as-is.
@@ -636,10 +640,10 @@ class _MPResterLegacy:
         # position the ion energies relative to most stable reference state
         for n, i_d in enumerate(ion_data):
             ion = Ion.from_formula(i_d["Name"])
-            refs = [e for e in ion_ref_entries if e.composition.reduced_formula == i_d["Reference Solid"]]
+            refs = [e for e in ion_ref_entries if e.reduced_formula == i_d["Reference Solid"]]
             if not refs:
                 raise ValueError("Reference solid not contained in entry list")
-            stable_ref = sorted(refs, key=lambda x: x.data["e_above_hull"])[0]
+            stable_ref = min(refs, key=lambda x: x.data["e_above_hull"])
             rf = stable_ref.composition.get_reduced_composition_and_factor()[1]
 
             solid_diff = ion_ref_pd.get_form_energy(stable_ref) - i_d["Reference solid energy"] * rf
@@ -715,7 +719,7 @@ class _MPResterLegacy:
 
         Args:
             material_id (str): Materials Project material_id (a string,
-                e.g., mp-1234).
+                e.g. mp-1234).
             compatible_only (bool): Whether to return only "compatible"
                 entries. Compatible entries are entries that have been
                 processed using the MaterialsProject2020Compatibility class,
@@ -757,7 +761,7 @@ class _MPResterLegacy:
 
         Args:
             material_id (str): Materials Project material_id (a string,
-                e.g., mp-1234).
+                e.g. mp-1234).
 
         Returns:
             A Dos object.
@@ -833,8 +837,8 @@ class _MPResterLegacy:
 
         Args:
             elements (str or [str]): Chemical system string comprising element
-                symbols separated by dashes, e.g., "Li-Fe-O" or List of element
-                symbols, e.g., ["Li", "Fe", "O"].
+                symbols separated by dashes, e.g. "Li-Fe-O" or List of element
+                symbols, e.g. ["Li", "Fe", "O"].
             compatible_only (bool): Whether to return only "compatible"
                 entries. Compatible entries are entries that have been
                 processed using the MaterialsProject2020Compatibility class,
@@ -890,7 +894,7 @@ class _MPResterLegacy:
         return self.get_data(formula, data_type="exp")
 
     def get_exp_entry(self, formula):
-        """Returns an ExpEntry object, which is the experimental equivalent of a
+        """Get an ExpEntry object, which is the experimental equivalent of a
         ComputedEntry and can be used for analyses using experimental data.
 
         Args:
@@ -910,7 +914,7 @@ class _MPResterLegacy:
         mp_decode: bool = True,
         show_progress_bar: bool = True,
     ):
-        r"""Performs an advanced query using MongoDB-like syntax for directly
+        r"""Perform an advanced query using MongoDB-like syntax for directly
         querying the Materials Project database. This allows one to perform
         queries which are otherwise too cumbersome to perform using the standard
         convenience methods.
@@ -935,9 +939,9 @@ class _MPResterLegacy:
                 mongo-style dict.
 
                 If string, it supports a powerful but simple string criteria.
-                E.g., "Fe2O3" means search for materials with reduced_formula
-                Fe2O3. Wild cards are also supported. E.g., "\\*2O" means get
-                all materials whose formula can be formed as \\*2O, e.g.,
+                e.g. "Fe2O3" means search for materials with reduced_formula
+                Fe2O3. Wild cards are also supported. e.g. "\\*2O" means get
+                all materials whose formula can be formed as \\*2O, e.g.
                 Li2O, K2O, etc.
 
                 Other syntax examples:
@@ -970,7 +974,7 @@ class _MPResterLegacy:
                 Defaults to True. Set to False to reduce visual noise.
 
         Returns:
-            List of results. E.g.,
+            List of results. e.g.
             [{u'formula': {u'O': 1, u'Li': 2.0}},
             {u'formula': {u'Na': 2.0, u'O': 2.0}},
             {u'formula': {u'K': 1, u'O': 3.0}},
@@ -992,30 +996,27 @@ class _MPResterLegacy:
             return self._make_request("/query", payload=payload, method="POST", mp_decode=mp_decode)
 
         data = []
-        mids = [d["material_id"] for d in self.query(criteria, ["material_id"], chunk_size=0)]
+        mids = [dct["material_id"] for dct in self.query(criteria, ["material_id"], chunk_size=0)]
         chunks = get_chunks(mids, size=chunk_size)
         progress_bar = tqdm(total=len(mids), disable=not show_progress_bar)
         for chunk in chunks:
             chunk_criteria = criteria.copy()
             chunk_criteria.update({"material_id": {"$in": chunk}})
-            num_tries = 0
-            while num_tries < max_tries_per_chunk:
+            n_tries = 0
+            while n_tries < max_tries_per_chunk:
                 try:
-                    data.extend(
-                        self.query(
-                            chunk_criteria,
-                            properties,
-                            chunk_size=0,
-                            mp_decode=mp_decode,
-                        )
+                    data += self.query(
+                        chunk_criteria,
+                        properties,
+                        chunk_size=0,
+                        mp_decode=mp_decode,
                     )
                     break
-                except MPRestError as e:
-                    match = re.search(r"error status code (\d+)", str(e))
-                    if match:
+                except MPRestError as exc:
+                    if match := re.search(r"error status code (\d+)", str(exc)):
                         if not match.group(1).startswith("5"):
-                            raise e
-                        num_tries += 1
+                            raise exc
+                        n_tries += 1
                         print(
                             "Unknown server error. Trying again in five "
                             f"seconds (will try at most {max_tries_per_chunk} times)..."
@@ -1098,16 +1099,16 @@ class _MPResterLegacy:
             MPRestError
         """
         snl = snl if isinstance(snl, list) else [snl]
-        jsondata = [s.as_dict() for s in snl]
-        payload = {"snl": json.dumps(jsondata, cls=MontyEncoder)}
+        json_data = [s.as_dict() for s in snl]
+        payload = {"snl": json.dumps(json_data, cls=MontyEncoder)}
         response = self.session.post(f"{self.preamble}/snl/submit", data=payload)
         if response.status_code in [200, 400]:
-            resp = json.loads(response.text, cls=MontyDecoder)
-            if resp["valid_response"]:
-                if resp.get("warning"):
-                    warnings.warn(resp["warning"])
-                return resp["inserted_ids"]
-            raise MPRestError(resp["error"])
+            response = json.loads(response.text, cls=MontyDecoder)
+            if response["valid_response"]:
+                if response.get("warning"):
+                    warnings.warn(response["warning"])
+                return response["inserted_ids"]
+            raise MPRestError(response["error"])
 
         raise MPRestError(f"REST error with status code {response.status_code} and error {response.text}")
 
@@ -1128,12 +1129,12 @@ class _MPResterLegacy:
         response = self.session.post(f"{self.preamble}/snl/delete", data=payload)
 
         if response.status_code in [200, 400]:
-            resp = json.loads(response.text, cls=MontyDecoder)
-            if resp["valid_response"]:
-                if resp.get("warning"):
-                    warnings.warn(resp["warning"])
-                return resp
-            raise MPRestError(resp["error"])
+            response = json.loads(response.text, cls=MontyDecoder)
+            if response["valid_response"]:
+                if response.get("warning"):
+                    warnings.warn(response["warning"])
+                return response
+            raise MPRestError(response["error"])
 
         raise MPRestError(f"REST error with status code {response.status_code} and error {response.text}")
 
@@ -1156,12 +1157,12 @@ class _MPResterLegacy:
         payload = {"criteria": json.dumps(criteria)}
         response = self.session.post(f"{self.preamble}/snl/query", data=payload)
         if response.status_code in [200, 400]:
-            resp = json.loads(response.text)
-            if resp["valid_response"]:
-                if resp.get("warning"):
-                    warnings.warn(resp["warning"])
-                return resp["response"]
-            raise MPRestError(resp["error"])
+            response = json.loads(response.text)
+            if response["valid_response"]:
+                if response.get("warning"):
+                    warnings.warn(response["warning"])
+                return response["response"]
+            raise MPRestError(response["error"])
 
         raise MPRestError(f"REST error with status code {response.status_code} and error {response.text}")
 
@@ -1177,7 +1178,7 @@ class _MPResterLegacy:
         created_at=None,
         ncpus=None,
     ):
-        """Assimilates all vasp run directories beneath a particular
+        """Assimilate all vasp run directories beneath a particular
         directory using BorgQueen to obtain structures, and then submits thhem
         to the Materials Project as SNL files. VASP related meta data like
         initial structure and final energies are automatically incorporated.
@@ -1219,7 +1220,7 @@ class _MPResterLegacy:
         histories = []
         for e in queen.get_data():
             structures.append(e.structure)
-            m = {
+            meta_dict = {
                 "_vasp": {
                     "parameters": e.parameters,
                     "final_energy": e.energy,
@@ -1230,8 +1231,8 @@ class _MPResterLegacy:
             if "history" in e.parameters:
                 histories.append(e.parameters["history"])
             if master_data is not None:
-                m.update(master_data)
-            metadata.append(m)
+                meta_dict.update(master_data)
+            metadata.append(meta_dict)
         if master_history is not None:
             histories = master_history * len(structures)
 
@@ -1247,23 +1248,23 @@ class _MPResterLegacy:
         )
 
     def get_stability(self, entries):
-        """Returns the stability of all entries."""
+        """Get the stability of all entries."""
         payload = {"entries": json.dumps(entries, cls=MontyEncoder)}
         response = self.session.post(
             f"{self.preamble}/phase_diagram/calculate_stability",
             data=payload,
         )
         if response.status_code in [200, 400]:
-            resp = json.loads(response.text, cls=MontyDecoder)
-            if resp["valid_response"]:
-                if resp.get("warning"):
-                    warnings.warn(resp["warning"])
-                return resp["response"]
-            raise MPRestError(resp["error"])
+            response = json.loads(response.text, cls=MontyDecoder)
+            if response["valid_response"]:
+                if response.get("warning"):
+                    warnings.warn(response["warning"])
+                return response["response"]
+            raise MPRestError(response["error"])
         raise MPRestError(f"REST error with status code {response.status_code} and error {response.text}")
 
     def get_cohesive_energy(self, material_id, per_atom=False):
-        """Gets the cohesive for a material (eV per formula unit). Cohesive energy
+        """Get the cohesive for a material (eV per formula unit). Cohesive energy
             is defined as the difference between the bulk energy and the sum of
             total DFT energy of isolated atoms for atom elements in the bulk.
 
@@ -1275,19 +1276,19 @@ class _MPResterLegacy:
             Cohesive energy (eV).
         """
         entry = self.get_entry_by_material_id(material_id)
-        ebulk = entry.energy / entry.composition.get_integer_formula_and_factor()[1]
+        e_bulk = entry.energy / entry.composition.get_integer_formula_and_factor()[1]
         comp_dict = entry.composition.reduced_composition.as_dict()
 
-        isolated_atom_e_sum, n = 0, 0
+        isolated_atom_e_sum = 0
         for el in comp_dict:
-            e = self._make_request(f"/element/{el}/tasks/isolated_atom", mp_decode=False)[0]
-            isolated_atom_e_sum += e["output"]["final_energy_per_atom"] * comp_dict[el]
-            n += comp_dict[el]
-        ecoh_per_formula = isolated_atom_e_sum - ebulk
-        return ecoh_per_formula / n if per_atom else ecoh_per_formula
+            ent = self._make_request(f"/element/{el}/tasks/isolated_atom", mp_decode=False)[0]
+            isolated_atom_e_sum += ent["output"]["final_energy_per_atom"] * comp_dict[el]
+        e_coh_per_formula = isolated_atom_e_sum - e_bulk
+        n_atoms = entry.composition.num_atoms
+        return e_coh_per_formula / n_atoms if per_atom else e_coh_per_formula
 
     def get_reaction(self, reactants, products):
-        """Gets a reaction from the Materials Project.
+        """Get a reaction from the Materials Project.
 
         Args:
             reactants ([str]): List of formulas
@@ -1323,7 +1324,7 @@ class _MPResterLegacy:
         return self._make_request(req)
 
     def get_all_substrates(self):
-        """Gets the list of all possible substrates considered in the
+        """Get the list of all possible substrates considered in the
         Materials Project substrate database.
 
         Returns:
@@ -1336,7 +1337,7 @@ class _MPResterLegacy:
         description="Data Descriptor: Surface energies of elemental crystals. Scientific Data",
     )
     def get_surface_data(self, material_id, miller_index=None, inc_structures=False):
-        """Gets surface data for a material. Useful for Wulff shapes.
+        """Get surface data for a material. Useful for Wulff shapes.
 
         Reference for surface data:
 
@@ -1348,7 +1349,7 @@ class _MPResterLegacy:
         Args:
             material_id (str): Materials Project material_id, e.g. 'mp-123'.
             miller_index (list of integer): The miller index of the surface.
-            e.g., [3, 2, 1]. If miller_index is provided, only one dictionary
+            e.g. [3, 2, 1]. If miller_index is provided, only one dictionary
             of this specific plane will be returned.
             inc_structures (bool): Include final surface slab structures.
                 These are unnecessary for Wulff shape construction.
@@ -1372,7 +1373,7 @@ class _MPResterLegacy:
         return self._make_request(req)
 
     def get_wulff_shape(self, material_id):
-        """Constructs a Wulff shape for a material.
+        """Construct a Wulff shape for a material.
 
         Args:
             material_id (str): Materials Project material_id, e.g. 'mp-123'.
@@ -1405,15 +1406,15 @@ class _MPResterLegacy:
         rotation_axis=None,
         include_work_of_separation=False,
     ):
-        """Gets grain boundary data for a material.
+        """Get grain boundary data for a material.
 
         Args:
-            material_id (str): Materials Project material_id, e.g., 'mp-129'.
-            pretty_formula (str): The formula of metals. e.g., 'Fe'
-            chemsys (str): The chemical system. e.g., 'Fe-O'
+            material_id (str): Materials Project material_id, e.g. 'mp-129'.
+            pretty_formula (str): The formula of metals. e.g. 'Fe'
+            chemsys (str): The chemical system. e.g. 'Fe-O'
             sigma (int): The sigma value of a certain type of grain boundary
-            gb_plane (list of integer): The Miller index of grain boundary plane. e.g., [1, 1, 1]
-            rotation_axis (list of integer): The Miller index of rotation axis. e.g.,
+            gb_plane (list of integer): The Miller index of grain boundary plane. e.g. [1, 1, 1]
+            rotation_axis (list of integer): The Miller index of rotation axis. e.g.
                 [1, 0, 0], [1, 1, 0], and [1, 1, 1] Sigma value is determined by the combination of
                 rotation axis and rotation angle. The five degrees of freedom (DOF) of one grain boundary
                 include: rotation axis (2 DOFs), rotation angle (1 DOF), and grain boundary plane (2 DOFs).
@@ -1461,7 +1462,7 @@ class _MPResterLegacy:
         relative_mu=None,
         use_hull_energy=False,
     ):
-        """Gets critical reactions between two reactants.
+        """Get critical reactions between two reactants.
 
         Get critical reactions ("kinks" in the mixing ratio where
         reaction products change) between two reactants. See the
@@ -1569,7 +1570,7 @@ class _MPResterLegacy:
 
     @staticmethod
     def _check_nomad_exist(url) -> bool:
-        response = requests.get(url=url)
+        response = requests.get(url=url, timeout=600)
         if response.status_code != 200:
             return False
         content = json.loads(response.text)
@@ -1577,12 +1578,12 @@ class _MPResterLegacy:
 
     @staticmethod
     def parse_criteria(criteria_string):
-        """Parses a powerful and simple string criteria and generates a proper
+        """Parse a powerful and simple string criteria and generates a proper
         mongo syntax criteria.
 
         Args:
             criteria_string (str): A string representing a search criteria.
-                Also supports wild cards. E.g.,
+                Also supports wild cards. e.g.
                 something like "*2O" gets converted to
                 {'pretty_formula': {'$in': [u'B2O', u'Xe2O', u"Li2O", ...]}}
 
@@ -1592,7 +1593,7 @@ class _MPResterLegacy:
                     Li-Fe-O or *-Fe-O: Interpreted as chemical systems.
 
                 You can mix and match with spaces, which are interpreted as
-                "OR". E.g., "mp-1234 FeO" means query for all compounds with
+                "OR". e.g. "mp-1234 FeO" means query for all compounds with
                 reduced formula FeO or with materials_id mp-1234.
 
         Returns:
@@ -1603,9 +1604,9 @@ class _MPResterLegacy:
         def parse_sym(sym):
             if sym == "*":
                 return [el.symbol for el in Element]
-            m = re.match(r"\{(.*)\}", sym)
-            if m:
-                return [s.strip() for s in m.group(1).split(",")]
+
+            if match := re.match(r"\{(.*)\}", sym):
+                return [s.strip() for s in match.group(1).split(",")]
             return [sym]
 
         def parse_tok(t):
@@ -1627,13 +1628,13 @@ class _MPResterLegacy:
                 if ("*" in sym) or ("{" in sym):
                     wild_card_els.append(sym)
                 else:
-                    m = re.match(r"([A-Z][a-z]*)[\.\d]*", sym)
-                    explicit_els.append(m.group(1))
+                    match = re.match(r"([A-Z][a-z]*)[\.\d]*", sym)
+                    explicit_els.append(match[1])
             n_elements = len(wild_card_els) + len(set(explicit_els))
             parts = re.split(r"(\*|\{.*\})", t)
             parts = [parse_sym(s) for s in parts if s != ""]
-            for f in itertools.product(*parts):
-                comp = Composition("".join(f))
+            for formula in itertools.product(*parts):
+                comp = Composition("".join(formula))
                 if len(comp) == n_elements:
                     # Check for valid Elements in keys.
                     for elem in comp:
@@ -1659,5 +1660,5 @@ def get_chunks(sequence: Sequence[Any], size=1):
     Returns:
         list[Sequence[Any]]: input sequence in chunks of length size.
     """
-    chunks = int(math.ceil(len(sequence) / float(size)))
+    chunks = math.ceil(len(sequence) / float(size))
     return [sequence[i * size : (i + 1) * size] for i in range(chunks)]
