@@ -1,15 +1,13 @@
-#
-
-"""Low-level objects providing an abstraction for the objects involved in the calculation."""
+"""Low-level classes and functions to work with Abinit input files."""
 
 from __future__ import annotations
 
 import abc
 from collections import namedtuple
 from collections.abc import Iterable
-from enum import Enum
+from enum import Enum, unique
 from pprint import pformat
-from typing import cast
+from typing import TYPE_CHECKING, cast
 
 import numpy as np
 from monty.collections import AttrDict
@@ -18,12 +16,16 @@ from monty.json import MontyDecoder, MontyEncoder, MSONable
 
 from pymatgen.core import ArrayWithUnit, Lattice, Species, Structure, units
 
+if TYPE_CHECKING:
+    from typing import Any, ClassVar
+
+    from typing_extensions import Self
+
 
 def lattice_from_abivars(cls=None, *args, **kwargs):
-    """
-    Returns a `Lattice` object from a dictionary
-    with the Abinit variables `acell` and either `rprim` in Bohr or `angdeg`
-    If acell is not given, the Abinit default is used i.e. [1,1,1] Bohr.
+    """Get a `Lattice` object from a dictionary with the Abinit variables `acell`
+    and either `rprim` in Bohr or `angdeg`. If acell is not given, the Abinit default
+    of [1, 1, 1] Bohr is used.
 
     Args:
         cls: Lattice class to be instantiated. Defaults to pymatgen.core.Lattice.
@@ -158,13 +160,11 @@ def structure_from_abivars(cls=None, *args, **kwargs) -> Structure:
         validate_proximity=False,
         to_unit_cell=False,
         coords_are_cartesian=coords_are_cartesian,
-        properties=kwargs.get("properties"),
     )
 
 
 def species_by_znucl(structure: Structure) -> list[Species]:
-    """
-    Return list of unique specie found in structure **ordered according to sites**.
+    """Get list of unique specie found in structure **ordered according to sites**.
 
     Example:
         Site0: 0.5 0 0 O
@@ -251,7 +251,6 @@ def structure_to_abivars(
         "typat": typat,
         "znucl": znucl_type,
         "xred": x_red,
-        "properties": structure.properties,
     }
 
     # Add info on the lattice.
@@ -305,14 +304,14 @@ def contract(string):
     return " ".join(f"{c}*{t}" for c, t in count)
 
 
-class AbivarAble(metaclass=abc.ABCMeta):
+class AbivarAble(abc.ABC):
     """
     An AbivarAble object provides a method to_abivars that returns a dictionary with the abinit variables.
     """
 
     @abc.abstractmethod
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables."""
+        """Get a dictionary with the abinit variables."""
 
     # @abc.abstractmethod
     # def from_abivars(cls, vars):
@@ -345,7 +344,7 @@ MANDATORY = MandatoryVariable()
 DEFAULT = DefaultVariable()
 
 
-class SpinMode(namedtuple("SpinMode", "mode nsppol nspinor nspden"), AbivarAble, MSONable):
+class SpinMode(namedtuple("SpinMode", "mode nsppol nspinor nspden"), AbivarAble, MSONable):  # noqa: PYI024
     """
     Different configurations of the electron density as implemented in abinit:
     One can use as_spinmode to construct the object via SpinMode.as_spinmode
@@ -362,7 +361,7 @@ class SpinMode(namedtuple("SpinMode", "mode nsppol nspinor nspden"), AbivarAble,
 
     @classmethod
     def as_spinmode(cls, obj):
-        """Converts obj into a `SpinMode` instance."""
+        """Convert obj into a `SpinMode` instance."""
         if isinstance(obj, cls):
             return obj
 
@@ -377,15 +376,15 @@ class SpinMode(namedtuple("SpinMode", "mode nsppol nspinor nspden"), AbivarAble,
         return {"nsppol": self.nsppol, "nspinor": self.nspinor, "nspden": self.nspden}
 
     def as_dict(self):
-        """Convert object to dict."""
+        """JSON-friendly dict representation of SpinMode."""
         out = {k: getattr(self, k) for k in self._fields}
         out.update({"@module": type(self).__module__, "@class": type(self).__name__})
         return out
 
     @classmethod
-    def from_dict(cls, d):
-        """Build object from dict."""
-        return cls(**{k: d[k] for k in d if k in cls._fields})
+    def from_dict(cls, dct: dict) -> Self:
+        """Build from dict."""
+        return cls(**{key: dct[key] for key in dct if key in cls._fields})
 
 
 # An handy Multiton
@@ -404,8 +403,8 @@ class Smearing(AbivarAble, MSONable):
     a `Smearing` object is via the class method Smearing.as_smearing(string).
     """
 
-    #: Mapping string_mode --> occopt
-    _mode2occopt = dict(
+    # Map string_mode to occopt
+    _mode2occopt: ClassVar[dict[str, int]] = dict(
         nosmearing=1,
         fermi_dirac=3,
         marzari4=4,
@@ -415,15 +414,19 @@ class Smearing(AbivarAble, MSONable):
     )
 
     def __init__(self, occopt, tsmear):
-        """Build object with occopt and tsmear."""
+        """
+        Args:
+            occopt: Integer specifying the smearing technique.
+            tsmear: Smearing parameter in Hartree units.
+        """
         self.occopt = occopt
         self.tsmear = tsmear
 
     def __str__(self):
-        s = f"occopt {self.occopt} # {self.mode} Smearing\n"
+        string = f"occopt {self.occopt} # {self.mode} Smearing\n"
         if self.tsmear:
-            s += f"tsmear {self.tsmear}"
-        return s
+            string += f"tsmear {self.tsmear}"
+        return string
 
     def __eq__(self, other: object) -> bool:
         needed_attrs = ("occopt", "tsmear")
@@ -479,7 +482,7 @@ class Smearing(AbivarAble, MSONable):
 
     @staticmethod
     def nosmearing():
-        """Build object for calculations without smearing."""
+        """For calculations without smearing."""
         return Smearing(1, 0.0)
 
     def to_abivars(self):
@@ -497,17 +500,17 @@ class Smearing(AbivarAble, MSONable):
             "tsmear": self.tsmear,
         }
 
-    @staticmethod
-    def from_dict(d):
-        """Build object from dict."""
-        return Smearing(d["occopt"], d["tsmear"])
+    @classmethod
+    def from_dict(cls, dct: dict) -> Self:
+        """Build from dict."""
+        return cls(dct["occopt"], dct["tsmear"])
 
 
 class ElectronsAlgorithm(dict, AbivarAble, MSONable):
     """Variables controlling the SCF/NSCF algorithm."""
 
-    # None indicates that we use abinit defaults.
-    _DEFAULT = dict(
+    # None indicates that we use abinit defaults
+    _DEFAULT: ClassVar[dict[str, int | None]] = dict(
         iprcell=None,
         iscf=None,
         diemac=None,
@@ -521,7 +524,19 @@ class ElectronsAlgorithm(dict, AbivarAble, MSONable):
     )
 
     def __init__(self, *args, **kwargs):
-        """Initialize object."""
+        """
+        Args:
+            iprcell: 1 if the cell is fixed, 2 if the cell is relaxed.
+            iscf: SCF algorithm.
+            diemac: Macroscopic dielectric constant.
+            diemix: Mixing parameter for the electric field.
+            diemixmag: Mixing parameter for the magnetic field.
+            dielam: Damping factor for the electric field.
+            diegap: Energy gap for the dielectric function.
+            dielng: Length of the electric field.
+            diecut: Cutoff for the dielectric function.
+            nstep: Maximum number of SCF iterations.
+        """
         super().__init__(*args, **kwargs)
 
         for key in self:
@@ -533,16 +548,16 @@ class ElectronsAlgorithm(dict, AbivarAble, MSONable):
         return self.copy()
 
     def as_dict(self):
-        """Convert object to dict."""
+        """Get JSON-able dict representation."""
         return {"@module": type(self).__module__, "@class": type(self).__name__, **self.copy()}
 
     @classmethod
-    def from_dict(cls, d):
-        """Build object from dict."""
-        d = d.copy()
-        d.pop("@module", None)
-        d.pop("@class", None)
-        return cls(**d)
+    def from_dict(cls, dct: dict) -> Self:
+        """Build from dict."""
+        dct = dct.copy()
+        dct.pop("@module", None)
+        dct.pop("@class", None)
+        return cls(**dct)
 
 
 class Electrons(AbivarAble, MSONable):
@@ -576,7 +591,7 @@ class Electrons(AbivarAble, MSONable):
         self.algorithm = algorithm
 
     @property
-    def nsppol(self):
+    def nsppol(self) -> int:
         """Number of independent spin polarizations."""
         return self.spin_mode.nsppol
 
@@ -591,7 +606,7 @@ class Electrons(AbivarAble, MSONable):
         return self.spin_mode.nspden
 
     def as_dict(self):
-        """Json friendly dict representation."""
+        """JSON friendly dict representation."""
         dct = {}
         dct["@module"] = type(self).__module__
         dct["@class"] = type(self).__name__
@@ -605,15 +620,14 @@ class Electrons(AbivarAble, MSONable):
         return dct
 
     @classmethod
-    def from_dict(cls, dct):
-        """Build object from dictionary."""
+    def from_dict(cls, dct: dict) -> Self:
+        """Build from dict."""
         dct = dct.copy()
         dct.pop("@module", None)
         dct.pop("@class", None)
-        dec = MontyDecoder()
-        dct["spin_mode"] = dec.process_decoded(dct["spin_mode"])
-        dct["smearing"] = dec.process_decoded(dct["smearing"])
-        dct["algorithm"] = dec.process_decoded(dct["algorithm"]) if dct["algorithm"] else None
+        dct["spin_mode"] = MontyDecoder().process_decoded(dct["spin_mode"])
+        dct["smearing"] = MontyDecoder().process_decoded(dct["smearing"])
+        dct["algorithm"] = MontyDecoder().process_decoded(dct["algorithm"]) if dct["algorithm"] else None
         return cls(**dct)
 
     def to_abivars(self):
@@ -638,6 +652,7 @@ class Electrons(AbivarAble, MSONable):
         return abivars
 
 
+@unique
 class KSamplingModes(Enum):
     """Enum if the different samplings of the BZ."""
 
@@ -683,7 +698,7 @@ class KSampling(AbivarAble, MSONable):
                 Not used for the other modes
             kpts: Number of divisions. Even when only a single specification is
                 required, e.g. in the automatic scheme, the kpts should still
-                be specified as a 2D array. e.g., [[20]] or [[2,2,2]].
+                be specified as a 2D array. e.g. [[20]] or [[2,2,2]].
             kpt_shifts: Shifts for Kpoints.
             use_symmetries: False if spatial symmetries should not be used
                 to reduce the number of independent k-points.
@@ -721,11 +736,11 @@ class KSampling(AbivarAble, MSONable):
 
             if use_symmetries and use_time_reversal:
                 kptopt = 1
-            if not use_symmetries and use_time_reversal:
+            elif not use_symmetries and use_time_reversal:
                 kptopt = 2
-            if not use_symmetries and not use_time_reversal:
+            elif not use_symmetries and not use_time_reversal:
                 kptopt = 3
-            if use_symmetries and not use_time_reversal:
+            else:  # use_symmetries and not use_time_reversal
                 kptopt = 4
 
             abivars.update(
@@ -777,7 +792,7 @@ class KSampling(AbivarAble, MSONable):
     @property
     def is_homogeneous(self) -> bool:
         """Homogeneous sampling."""
-        return self.mode not in ["path"]
+        return self.mode != "path"
 
     @classmethod
     def gamma_only(cls):
@@ -878,8 +893,7 @@ class KSampling(AbivarAble, MSONable):
 
     @classmethod
     def _path(cls, ndivsm, structure=None, kpath_bounds=None, comment=None):
-        """
-        Static constructor for path in k-space.
+        """Static constructor for path in k-space.
 
         Args:
             structure: Structure object.
@@ -914,7 +928,7 @@ class KSampling(AbivarAble, MSONable):
         )
 
     @classmethod
-    def path_from_structure(cls, ndivsm, structure):
+    def path_from_structure(cls, ndivsm, structure) -> Self:
         """See _path for the meaning of the variables."""
         return cls._path(
             ndivsm,
@@ -937,8 +951,7 @@ class KSampling(AbivarAble, MSONable):
         use_time_reversal=True,
         shifts=(0.5, 0.5, 0.5),
     ):
-        """
-        Returns an automatic Kpoint object based on a structure and a kpoint
+        """Get an automatic Kpoint object based on a structure and a kpoint
         density. Uses Gamma centered meshes for hexagonal cells and Monkhorst-Pack grids otherwise.
 
         Algorithm:
@@ -978,7 +991,7 @@ class KSampling(AbivarAble, MSONable):
         return self.abivars
 
     def as_dict(self):
-        """Convert object to dict."""
+        """Get JSON-able dict representation."""
         enc = MontyEncoder()
         return {
             "mode": self.mode.name,
@@ -995,18 +1008,17 @@ class KSampling(AbivarAble, MSONable):
         }
 
     @classmethod
-    def from_dict(cls, d):
-        """Build object from dict."""
-        d = d.copy()
-        d.pop("@module", None)
-        d.pop("@class", None)
-        dec = MontyDecoder()
-        d["kpts"] = dec.process_decoded(d["kpts"])
-        return cls(**d)
+    def from_dict(cls, dct: dict) -> Self:
+        """Build from dict."""
+        dct = dct.copy()
+        dct.pop("@module", None)
+        dct.pop("@class", None)
+        dct["kpts"] = MontyDecoder().process_decoded(dct["kpts"])
+        return cls(**dct)
 
 
 class Constraints(AbivarAble):
-    """This object defines the constraints for structural relaxation."""
+    """Define the constraints for structural relaxation."""
 
     def to_abivars(self):
         """Dictionary with Abinit variables."""
@@ -1023,7 +1035,7 @@ class RelaxationMethod(AbivarAble, MSONable):
     The set of variables are constructed in to_abivars depending on ionmov and optcell.
     """
 
-    _default_vars = dict(
+    _default_vars: ClassVar[dict[str, Any]] = dict(
         ionmov=MANDATORY,
         optcell=MANDATORY,
         ntime=80,
@@ -1039,7 +1051,18 @@ class RelaxationMethod(AbivarAble, MSONable):
     OPTCELL_DEFAULT = 2
 
     def __init__(self, *args, **kwargs):
-        """Initialize object."""
+        """
+        Args:
+            ionmov: The type of relaxation for the ions.
+            optcell: The type of relaxation for the unit cell.
+            ntime: Maximum number of iterations.
+            dilatmx: Maximum allowed cell volume change.
+            ecutsm: Energy convergence criterion.
+            strfact: Stress convergence criterion.
+            tolmxf: Force convergence criterion.
+            strtarget: Target stress.
+            atoms_constraints: Constraints for the atoms.
+        """
         # Initialize abivars with the default values.
         self.abivars = {**self._default_vars}
 
@@ -1085,7 +1108,7 @@ class RelaxationMethod(AbivarAble, MSONable):
         return self.abivars.optcell != 0
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables."""
+        """Get a dictionary with the abinit variables."""
         # These variables are always present.
         out_vars = {
             "ionmov": self.abivars.ionmov,
@@ -1118,22 +1141,23 @@ class RelaxationMethod(AbivarAble, MSONable):
         return out_vars
 
     def as_dict(self):
-        """Convert object to dict."""
+        """Convert to dictionary."""
         dct = dict(self._default_vars)
         dct["@module"] = type(self).__module__
         dct["@class"] = type(self).__name__
         return dct
 
     @classmethod
-    def from_dict(cls, d):
-        """Build object from dictionary."""
-        d = d.copy()
-        d.pop("@module", None)
-        d.pop("@class", None)
+    def from_dict(cls, dct: dict) -> Self:
+        """Build from dictionary."""
+        dct = dct.copy()
+        dct.pop("@module", None)
+        dct.pop("@class", None)
 
-        return cls(**d)
+        return cls(**dct)
 
 
+@unique
 class PPModelModes(Enum):
     """Different kind of plasmon-pole models."""
 
@@ -1219,7 +1243,7 @@ class PPModel(AbivarAble, MSONable):
         return cls(mode="noppmodel", plasmon_freq=None)
 
     def as_dict(self):
-        """Convert object to dictionary."""
+        """Get JSON-able dict representation."""
         return {
             "mode": self.mode.name,
             "plasmon_freq": self.plasmon_freq,
@@ -1227,10 +1251,10 @@ class PPModel(AbivarAble, MSONable):
             "@class": type(self).__name__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        """Build object from dictionary."""
-        return PPModel(mode=d["mode"], plasmon_freq=d["plasmon_freq"])
+    @classmethod
+    def from_dict(cls, dct: dict) -> Self:
+        """Build from dict."""
+        return cls(mode=dct["mode"], plasmon_freq=dct["plasmon_freq"])
 
 
 class HilbertTransform(AbivarAble):
@@ -1272,7 +1296,7 @@ class HilbertTransform(AbivarAble):
         self.nfreqim = nfreqim
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables."""
+        """Get a dictionary with the abinit variables."""
         return {
             # Spectral function
             "nomegasf": self.nomegasf,
@@ -1313,10 +1337,14 @@ class Screening(AbivarAble):
     """
 
     # Approximations used for W
-    _WTYPES = dict(RPA=0)
+    _WTYPES: ClassVar[dict[str, int]] = dict(RPA=0)
 
-    # Self-consistecy modes
-    _SC_MODES = dict(one_shot=0, energy_only=1, wavefunctions=2)
+    # Self-consistency modes
+    _SC_MODES: ClassVar[dict[str, int]] = dict(
+        one_shot=0,
+        energy_only=1,
+        wavefunctions=2,
+    )
 
     def __init__(
         self,
@@ -1376,7 +1404,7 @@ class Screening(AbivarAble):
     #    return dig1.strip() + dig0.strip()
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables."""
+        """Get a dictionary with the abinit variables."""
         abivars = {
             "ecuteps": self.ecuteps,
             "ecutwfn": self.ecutwfn,
@@ -1398,9 +1426,9 @@ class Screening(AbivarAble):
 
 
 class SelfEnergy(AbivarAble):
-    """This object defines the parameters used for the computation of the self-energy."""
+    """Define the parameters used for the computation of the self-energy."""
 
-    _SIGMA_TYPES = dict(
+    _SIGMA_TYPES: ClassVar[dict[str, int]] = dict(
         gw=0,
         hartree_fock=5,
         sex=6,
@@ -1409,7 +1437,7 @@ class SelfEnergy(AbivarAble):
         model_gw_cd=9,
     )
 
-    _SC_MODES = dict(
+    _SC_MODES: ClassVar[dict[str, int]] = dict(
         one_shot=0,
         energy_only=1,
         wavefunctions=2,
@@ -1457,7 +1485,7 @@ class SelfEnergy(AbivarAble):
         self.gwpara = gwpara
 
         if ppmodel is not None:
-            assert not screening.use_hilbert
+            assert screening.use_hilbert is False
             self.ppmodel = PPModel.as_ppmodel(ppmodel)
 
         self.ecuteps = ecuteps if ecuteps is not None else screening.ecuteps
@@ -1493,7 +1521,7 @@ class SelfEnergy(AbivarAble):
 
     @property
     def gwcalctyp(self):
-        """Returns the value of the gwcalctyp input variable."""
+        """The value of the gwcalctyp input variable."""
         dig0 = str(self._SIGMA_TYPES[self.type])
         dig1 = str(self._SC_MODES[self.sc_mode])
         return dig1.strip() + dig0.strip()
@@ -1504,7 +1532,7 @@ class SelfEnergy(AbivarAble):
         return 1 if self.sc_mode == "one_shot" else 0
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables."""
+        """Get a dictionary with the abinit variables."""
         abivars = {
             "gwcalctyp": self.gwcalctyp,
             "ecuteps": self.ecuteps,
@@ -1531,17 +1559,21 @@ class SelfEnergy(AbivarAble):
 
 
 class ExcHamiltonian(AbivarAble):
-    """This object contains the parameters for the solution of the Bethe-Salpeter equation."""
+    """Contain parameters for the solution of the Bethe-Salpeter equation."""
 
     # Types of excitonic Hamiltonian.
-    _EXC_TYPES = dict(
+    _EXC_TYPES: ClassVar[dict[str, int]] = dict(
         TDA=0,  # Tamm-Dancoff approximation.
         coupling=1,  # Calculation with coupling.
     )
 
     # Algorithms used to compute the macroscopic dielectric function
     # and/or the exciton wavefunctions.
-    _ALGO2VAR = dict(direct_diago=1, haydock=2, cg=3)
+    _ALGO2VAR: ClassVar[dict[str, int]] = dict(
+        direct_diago=1,
+        haydock=2,
+        cg=3,
+    )
 
     # Options specifying the treatment of the Coulomb term.
     _COULOMB_MODES = ("diago", "full", "model_df")
@@ -1638,7 +1670,7 @@ class ExcHamiltonian(AbivarAble):
         return self.algo == "direct_diago"
 
     def to_abivars(self):
-        """Returns a dictionary with the abinit variables."""
+        """Get a dictionary with the abinit variables."""
         abivars = {
             "bs_calctype": 1,
             "bs_loband": self.bs_loband,
