@@ -1,21 +1,24 @@
 """AIMS output parser, taken from ASE with modifications."""
+
 from __future__ import annotations
 
 import gzip
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, cast
 
 import numpy as np
 
 from pymatgen.core import Lattice, Molecule, Structure
 from pymatgen.core.tensors import Tensor
+from pymatgen.util.typing import Tuple3Floats
 
 if TYPE_CHECKING:
     from collections.abc import Generator, Sequence
     from io import TextIOWrapper
+    from typing import Any
 
-    from emmet.core.math import Matrix3D, Vector3D
+    from pymatgen.util.typing import Matrix3D, Vector3D
 
 __author__ = "Thomas A. R. Purcell and Andrey Sobolev"
 __version__ = "1.0"
@@ -79,9 +82,9 @@ class AimsOutChunk:
         Returns:
             The last time one of the keys appears in self.lines
         """
-        for ll, line in enumerate(self.lines[line_start:][::-1]):
+        for idx, line in enumerate(self.lines[line_start:][::-1]):
             if any(key in line for key in keys):
-                return len(self.lines) - ll - 1
+                return len(self.lines) - idx - 1
 
         return LINE_NOT_FOUND
 
@@ -200,7 +203,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
 
     @property
     def linked_against(self) -> list[str]:
-        """Get all libraries used to link the FHI-aims executable."""
+        """All libraries used to link the FHI-aims executable."""
         line_start = self.reverse_search_for(["Linking against:"])
         if line_start == LINE_NOT_FOUND:
             return []
@@ -487,7 +490,7 @@ class AimsOutCalcChunk(AimsOutChunk):
         """
         species, coords, velocities, lattice = self._parse_lattice_atom_pos()
 
-        site_properties: dict[str, Sequence[Any]] = dict()
+        site_properties: dict[str, Sequence[Any]] = {}
         if len(velocities) > 0:
             site_properties["velocity"] = np.array(velocities)
 
@@ -565,9 +568,9 @@ class AimsOutCalcChunk(AimsOutChunk):
             elif "atom   " in line:
                 line_split = line.split()
                 species.append(line_split[4])
-                coords.append([float(inp) for inp in line_split[1:4]])
+                coords.append(cast(Tuple3Floats, tuple(float(inp) for inp in line_split[1:4])))
             elif "velocity   " in line:
-                velocities.append([float(inp) for inp in line.split()[1:]])
+                velocities.append(cast(Tuple3Floats, tuple(float(inp) for inp in line.split()[1:4])))
 
         lattice = Lattice(lattice_vectors) if len(lattice_vectors) == 3 else None
         return species, coords, velocities, lattice
@@ -576,48 +579,36 @@ class AimsOutCalcChunk(AimsOutChunk):
     def species(self) -> list[str]:
         """The list of atomic symbols for all atoms in the structure"""
         if "species" not in self._cache:
-            (
-                self._cache["species"],
-                self._cache["coords"],
-                self._cache["velocities"],
-                self._cache["lattice"],
-            ) = self._parse_lattice_atom_pos()
+            self._cache["species"], self._cache["coords"], self._cache["velocities"], self._cache["lattice"] = (
+                self._parse_lattice_atom_pos()
+            )
         return self._cache["species"]
 
     @property
     def coords(self) -> list[Vector3D]:
         """The cartesian coordinates of the atoms"""
         if "coords" not in self._cache:
-            (
-                self._cache["species"],
-                self._cache["coords"],
-                self._cache["velocities"],
-                self._cache["lattice"],
-            ) = self._parse_lattice_atom_pos()
+            self._cache["species"], self._cache["coords"], self._cache["velocities"], self._cache["lattice"] = (
+                self._parse_lattice_atom_pos()
+            )
         return self._cache["coords"]
 
     @property
     def velocities(self) -> list[Vector3D]:
         """The velocities of the atoms"""
         if "velocities" not in self._cache:
-            (
-                self._cache["species"],
-                self._cache["coords"],
-                self._cache["velocities"],
-                self._cache["lattice"],
-            ) = self._parse_lattice_atom_pos()
+            self._cache["species"], self._cache["coords"], self._cache["velocities"], self._cache["lattice"] = (
+                self._parse_lattice_atom_pos()
+            )
         return self._cache["velocities"]
 
     @property
     def lattice(self) -> Lattice:
         """The Lattice object for the structure"""
         if "lattice" not in self._cache:
-            (
-                self._cache["species"],
-                self._cache["coords"],
-                self._cache["velocities"],
-                self._cache["lattice"],
-            ) = self._parse_lattice_atom_pos()
+            self._cache["species"], self._cache["coords"], self._cache["velocities"], self._cache["lattice"] = (
+                self._parse_lattice_atom_pos()
+            )
         return self._cache["lattice"]
 
     @property
