@@ -1,11 +1,9 @@
 """
 This module implements input and output for Fiesta (http://perso.neel.cnrs.fr/xavier.blase/fiesta/index.html).
 
-and
-
--Nwchem2Fiesta class: to create the input files needed for a Fiesta run
--Fiesta_run: run gw_fiesta and bse_fiesta
--Localised Basis set reader
+- Nwchem2Fiesta: create the input files needed for a Fiesta run
+- FiestaRun: run gw_fiesta and bse_fiesta
+- Localized BasisSetReader
 """
 
 from __future__ import annotations
@@ -15,12 +13,20 @@ import re
 import shutil
 import subprocess
 from string import Template
+from typing import TYPE_CHECKING
 
 from monty.io import zopen
 from monty.json import MSONable
 
 from pymatgen.core.structure import Molecule
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from typing_extensions import Self
+
+    from pymatgen.util.typing import Tuple3Ints
+
 __author__ = "ndardenne"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "0.1"
@@ -29,8 +35,7 @@ __date__ = "24/5/15"
 
 
 class Nwchem2Fiesta(MSONable):
-    """
-    To run NWCHEM2FIESTA inside python:
+    """To run NWCHEM2FIESTA inside python:
 
     If nwchem.nw is the input, nwchem.out the output, and structure.movecs the
     "movecs" file, the syntax to run NWCHEM2FIESTA is: NWCHEM2FIESTA
@@ -39,23 +44,22 @@ class Nwchem2Fiesta(MSONable):
 
     def __init__(self, folder, filename="nwchem", log_file="log_n2f"):
         """
-        folder: where are stored the nwchem
-        filename: name of nwchem files read by NWCHEM2FIESTA (filename.nw, filename.nwout and filename.movecs)
-        logfile: logfile of NWCHEM2FIESTA.
-
-        the run method launches NWCHEM2FIESTA
+        Args:
+            folder: where are stored the nwchem
+            filename: name of nwchem files read by NWCHEM2FIESTA (filename.nw, filename.nwout and filename.movecs)
+            logfile: logfile of NWCHEM2FIESTA.
         """
         self.folder = folder
         self.filename = filename
         self.log_file = log_file
 
         self._NWCHEM2FIESTA_cmd = "NWCHEM2FIESTA"
-        self._nwcheminput_fn = filename + ".nw"
-        self._nwchemoutput_fn = filename + ".nwout"
-        self._nwchemmovecs_fn = filename + ".movecs"
+        self._nwcheminput_fn = f"{filename}.nw"
+        self._nwchemoutput_fn = f"{filename}.nwout"
+        self._nwchemmovecs_fn = f"{filename}.movecs"
 
     def run(self):
-        """Performs actual NWCHEM2FIESTA run."""
+        """Perform actual NWCHEM2FIESTA run."""
         init_folder = os.getcwd()
         os.chdir(self.folder)
 
@@ -82,14 +86,15 @@ class Nwchem2Fiesta(MSONable):
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct: dict) -> Self:
         """
-        :param d: Dict representation.
+        Args:
+            dct (dict): Dict representation.
 
         Returns:
             Nwchem2Fiesta
         """
-        return cls(folder=d["folder"], filename=d["filename"])
+        return cls(folder=dct["folder"], filename=dct["filename"])
 
 
 class FiestaRun(MSONable):
@@ -100,9 +105,7 @@ class FiestaRun(MSONable):
         otherwise it breaks.
     """
 
-    def __init__(
-        self, folder: str | None = None, grid: tuple[int, int, int] = (2, 2, 2), log_file: str = "log"
-    ) -> None:
+    def __init__(self, folder: str | None = None, grid: Tuple3Ints = (2, 2, 2), log_file: str = "log") -> None:
         """
         Args:
             folder: Folder to look for runs.
@@ -114,7 +117,7 @@ class FiestaRun(MSONable):
         self.grid = grid
 
     def run(self):
-        """Performs FIESTA (gw) run."""
+        """Perform FIESTA (gw) run."""
         if len(self.grid) == 3:
             self.mpi_procs = self.grid[0] * self.grid[1] * self.grid[2]
             self._gw_run()
@@ -125,9 +128,9 @@ class FiestaRun(MSONable):
             raise ValueError("Wrong grid size: must be [nrow, ncolumn, nslice] for gw of [nrow, nslice] for bse")
 
     def _gw_run(self):
-        """Performs FIESTA (gw) run."""
-        if self.folder != os.getcwd():
-            init_folder = os.getcwd()
+        """Perform FIESTA (gw) run."""
+        init_folder = os.getcwd()
+        if self.folder != init_folder:
             os.chdir(self.folder)
 
         with zopen(self.log_file, mode="w") as fout:
@@ -144,13 +147,13 @@ class FiestaRun(MSONable):
                 stdout=fout,
             )
 
-        if self.folder != os.getcwd():
+        if self.folder != init_folder:
             os.chdir(init_folder)
 
     def bse_run(self):
-        """Performs BSE run."""
-        if self.folder != os.getcwd():
-            init_folder = os.getcwd()
+        """Perform BSE run."""
+        init_folder = os.getcwd()
+        if self.folder != init_folder:
             os.chdir(self.folder)
 
         with zopen(self.log_file, mode="w") as fout:
@@ -166,7 +169,7 @@ class FiestaRun(MSONable):
                 stdout=fout,
             )
 
-        if self.folder != os.getcwd():
+        if self.folder != init_folder:
             os.chdir(init_folder)
 
     def as_dict(self):
@@ -180,14 +183,15 @@ class FiestaRun(MSONable):
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct: dict) -> Self:
         """
-        :param d: Dict representation
+        Args:
+            dct (dict): Dict representation
 
         Returns:
             FiestaRun
         """
-        return cls(folder=d["folder"], grid=d["grid"], log_file=d["log_file"])
+        return cls(folder=dct["folder"], grid=dct["grid"], log_file=dct["log_file"])
 
 
 class BasisSetReader:
@@ -213,7 +217,7 @@ class BasisSetReader:
         self.data.update(n_nlmo=self.set_n_nlmo())
 
     @staticmethod
-    def _parse_file(input):
+    def _parse_file(lines):
         lmax_nnlo_patt = re.compile(r"\s* (\d+) \s+ (\d+) \s+ \# .* ", re.VERBOSE)
 
         nl_orbital_patt = re.compile(r"\s* (\d+) \s+ (\d+) \s+ (\d+) \s+ \# .* ", re.VERBOSE)
@@ -227,25 +231,25 @@ class BasisSetReader:
         parse_nl_orbital = False
         nnlo = None
         lmax = None
+        l_angular = zeta = ng = None
 
-        for line in input.split("\n"):
+        for line in lines.split("\n"):
             if parse_nl_orbital:
                 match_orb = nl_orbital_patt.search(line)
                 match_alpha = coef_alpha_patt.search(line)
                 if match_orb:
-                    l_angular = match_orb.group(1)
-                    zeta = match_orb.group(2)
-                    ng = match_orb.group(3)
+                    l_angular = match_orb[1]
+                    zeta = match_orb[2]
+                    ng = match_orb[3]
                     basis_set[f"{l_angular}_{zeta}_{ng}"] = []
                 elif match_alpha:
-                    alpha = match_alpha.group(1)
-                    coef = match_alpha.group(2)
+                    alpha = match_alpha[1]
+                    coef = match_alpha[2]
                     basis_set[f"{l_angular}_{zeta}_{ng}"].append((alpha, coef))
             elif parse_lmax_nnlo:
-                match_orb = lmax_nnlo_patt.search(line)
-                if match_orb:
-                    lmax = match_orb.group(1)
-                    nnlo = match_orb.group(2)
+                if match_orb := lmax_nnlo_patt.search(line):
+                    lmax = match_orb[1]
+                    nnlo = match_orb[2]
                     parse_lmax_nnlo = False
                     parse_nl_orbital = True
             elif parse_preamble:
@@ -301,12 +305,13 @@ class FiestaInput(MSONable):
         bse_tddft_options: dict[str, str] | None = None,
     ):
         """
-        :param mol: pymatgen mol
-        :param correlation_grid: dict
-        :param Exc_DFT_option: dict
-        :param COHSEX_options: dict
-        :param GW_options: dict
-        :param BSE_TDDFT_options: dict
+        Args:
+            mol: pymatgen mol
+            correlation_grid: dict
+            Exc_DFT_option: dict
+            COHSEX_options: dict
+            GW_options: dict
+            BSE_TDDFT_options: dict
         """
         self._mol = mol
         self.correlation_grid = correlation_grid or {"dE_grid": "0.500", "n_grid": "14"}
@@ -333,24 +338,27 @@ class FiestaInput(MSONable):
     def set_auxiliary_basis_set(self, folder, auxiliary_folder, auxiliary_basis_set_type="aug_cc_pvtz"):
         """
         copy in the desired folder the needed auxiliary basis set "X2.ion" where X is a specie.
-        :param auxiliary_folder: folder where the auxiliary basis sets are stored
-        :param auxiliary_basis_set_type: type of basis set (string to be found in the extension of the file name; must
-            be in lower case). ex: C2.ion_aug_cc_pvtz_RI_Weigend find "aug_cc_pvtz".
+
+        Args:
+            auxiliary_folder: folder where the auxiliary basis sets are stored
+            auxiliary_basis_set_type: type of basis set (string to be found in the extension of the file name; must
+                be in lower case). ex: C2.ion_aug_cc_pvtz_RI_Weigend find "aug_cc_pvtz".
         """
         list_files = os.listdir(auxiliary_folder)
 
         for specie in self._mol.symbol_set:
             for file in list_files:
-                if file.upper().find(specie.upper() + "2") != -1 and file.lower().find(auxiliary_basis_set_type) != -1:
+                if file.upper().find(f"{specie.upper()}2") != -1 and file.lower().find(auxiliary_basis_set_type) != -1:
                     shutil.copyfile(f"{auxiliary_folder}/{file}", f"{folder}/{specie}2.ion")
 
     def set_gw_options(self, nv_band=10, nc_band=10, n_iteration=5, n_grid=6, dE_grid=0.5):
-        """
-        Set parameters in cell.in for a GW computation
-        :param nv__band: number of valence bands to correct with GW
-        :param nc_band: number of conduction bands to correct with GW
-        :param n_iteration: number of iteration
-        :param n_grid and dE_grid:: number of points and spacing in eV for correlation grid.
+        """Set parameters in cell.in for a GW computation
+
+        Args:
+            nv__band: number of valence bands to correct with GW
+            nc_band: number of conduction bands to correct with GW
+            n_iteration: number of iteration
+            n_grid and dE_grid: number of points and spacing in eV for correlation grid.
         """
         self.GW_options.update(nv_corr=nv_band, nc_corr=nc_band, nit_gw=n_iteration)
         self.correlation_grid.update(dE_grid=dE_grid, n_grid=n_grid)
@@ -358,25 +366,27 @@ class FiestaInput(MSONable):
     @staticmethod
     def make_full_bse_densities_folder(folder):
         """Mkdir "FULL_BSE_Densities" folder (needed for bse run) in the desired folder."""
-        if os.path.exists(f"{folder}/FULL_BSE_Densities"):
+        if os.path.isfile(f"{folder}/FULL_BSE_Densities"):
             return "FULL_BSE_Densities folder already exists"
 
         os.makedirs(f"{folder}/FULL_BSE_Densities")
         return "makedirs FULL_BSE_Densities folder"
 
     def set_bse_options(self, n_excitations=10, nit_bse=200):
-        """
-        Set parameters in cell.in for a BSE computation
-        :param nv_bse: number of valence bands
-        :param nc_bse: number of conduction bands
-        :param n_excitations: number of excitations
-        :param nit_bse: number of iterations.
+        """Set parameters in cell.in for a BSE computation
+
+        Args:
+            nv_bse: number of valence bands
+            nc_bse: number of conduction bands
+            n_excitations: number of excitations
+            nit_bse: number of iterations.
         """
         self.bse_tddft_options.update(npsi_bse=n_excitations, nit_bse=nit_bse)
 
     def dump_bse_data_in_gw_run(self, BSE_dump=True):
         """
-        :param BSE_dump: boolean
+        Args:
+            BSE_dump: bool
 
         Returns:
             set the "do_bse" variable to one in cell.in
@@ -386,18 +396,19 @@ class FiestaInput(MSONable):
         else:
             self.bse_tddft_options.update(do_bse=0, do_tddft=0)
 
-    def dump_tddft_data_in_gw_run(self, tddft_dump=True):
+    def dump_tddft_data_in_gw_run(self, tddft_dump: bool = True):
         """
-        :param TDDFT_dump: boolean
+        Args:
+            TDDFT_dump: bool
 
         Returns:
             set the do_tddft variable to one in cell.in
         """
-        self.bse_tddft_options.update(do_bse=0, do_tddft=1 if tddft_dump else 0)
+        self.bse_tddft_options.update(do_bse="0", do_tddft="1" if tddft_dump else "0")
 
     @property
     def infos_on_system(self):
-        """Returns infos on initial parameters as in the log file of Fiesta."""
+        """Infos on initial parameters as in the log file of Fiesta."""
         lst = [
             "=========================================",
             "Reading infos on system:",
@@ -449,15 +460,13 @@ class FiestaInput(MSONable):
 
     @property
     def molecule(self):
-        """Returns molecule associated with this FiestaInput."""
+        """Molecule associated with this FiestaInput."""
         return self._mol
 
     def __str__(self):
         symbols = list(self._mol.symbol_set)
 
-        geometry = []
-        for site in self._mol:
-            geometry.append(f" {site.x} {site.y} {site.z} {int(symbols.index(site.specie.symbol)) + 1}")
+        geometry = [f" {site.x} {site.y} {site.z} {symbols.index(site.specie.symbol) + 1}" for site in self._mol]
 
         t = Template(
             """# number of atoms and species
@@ -518,10 +527,11 @@ $geometry
             geometry="\n".join(geometry),
         )
 
-    def write_file(self, filename):
-        """
-        Write FiestaInput to a file
-        :param filename: Filename.
+    def write_file(self, filename: str | Path) -> None:
+        """Write FiestaInput to a file
+
+        Args:
+            filename: Filename.
         """
         with zopen(filename, mode="w") as file:
             file.write(str(self))
@@ -538,24 +548,25 @@ $geometry
         }
 
     @classmethod
-    def from_dict(cls, d):
+    def from_dict(cls, dct: dict) -> Self:
         """
-        :param d: Dict representation
+        Args:
+            dct (dict): Dict representation
 
         Returns:
             FiestaInput
         """
         return cls(
-            Molecule.from_dict(d["mol"]),
-            correlation_grid=d["correlation_grid"],
-            Exc_DFT_option=d["Exc_DFT_option"],
-            COHSEX_options=d["geometry_options"],
-            GW_options=d["symmetry_options"],
-            BSE_TDDFT_options=d["memory_options"],
+            mol=Molecule.from_dict(dct["mol"]),
+            correlation_grid=dct["correlation_grid"],
+            exc_dft_option=dct["Exc_DFT_option"],
+            cohsex_options=dct["geometry_options"],
+            gw_options=dct["symmetry_options"],
+            bse_tddft_options=dct["memory_options"],
         )
 
     @classmethod
-    def from_str(cls, string_input):
+    def from_str(cls, string_input: str) -> Self:
         """
         Read an FiestaInput from a string. Currently tested to work with
         files generated from this class itself.
@@ -674,7 +685,7 @@ $geometry
         while i != 0:
             line = lines.pop(0).strip()
             tokens = line.split()
-            coords.append([float(j) for j in tokens[0:3]])
+            coords.append([float(j) for j in tokens[:3]])
             species.append(atname[int(tokens[3]) - 1])
             i -= 1
 
@@ -690,7 +701,7 @@ $geometry
         )
 
     @classmethod
-    def from_file(cls, filename):
+    def from_file(cls, filename: str | Path) -> Self:
         """
         Read an Fiesta input from a file. Currently tested to work with
         files generated from this class itself.
@@ -755,13 +766,11 @@ class FiestaOutput:
 
         for line in output.split("\n"):
             if parse_total_time:
-                m = end_patt.search(line)
-                if m:
+                if match := end_patt.search(line):
                     GW_results.update(end_normally=True)
 
-                m = total_time_patt.search(line)
-                if m:
-                    GW_results.update(total_time=m.group(1))
+                if match := total_time_patt.search(line):
+                    GW_results.update(total_time=match[1])
 
             if parse_gw_results:
                 if line.find("Dumping eigen energies") != -1:
@@ -769,29 +778,27 @@ class FiestaOutput:
                     parse_gw_results = False
                     continue
 
-                m = GW_BANDS_results_patt.search(line)
-                if m:
+                if match := GW_BANDS_results_patt.search(line):
                     dct = {}
                     dct.update(
-                        band=m.group(1).strip(),
-                        eKS=m.group(2),
-                        eXX=m.group(3),
-                        eQP_old=m.group(4),
-                        z=m.group(5),
-                        sigma_c_Linear=m.group(6),
-                        eQP_Linear=m.group(7),
-                        sigma_c_SCF=m.group(8),
-                        eQP_SCF=m.group(9),
+                        band=match[1].strip(),
+                        eKS=match[2],
+                        eXX=match[3],
+                        eQP_old=match[4],
+                        z=match[5],
+                        sigma_c_Linear=match[6],
+                        eQP_Linear=match[7],
+                        sigma_c_SCF=match[8],
+                        eQP_SCF=match[9],
                     )
-                    GW_results[m.group(1).strip()] = dct
+                    GW_results[match[1].strip()] = dct
 
-                n = GW_GAPS_results_patt.search(line)
-                if n:
+                if n := GW_GAPS_results_patt.search(line):
                     dct = {}
                     dct.update(
-                        Egap_KS=n.group(1),
-                        Egap_QP_Linear=n.group(2),
-                        Egap_QP_SCF=n.group(3),
+                        Egap_KS=n[1],
+                        Egap_QP_Linear=n[2],
+                        Egap_QP_SCF=n[3],
                     )
                     GW_results["Gaps"] = dct
 
@@ -838,13 +845,11 @@ class BSEOutput:
 
         for line in output.split("\n"):
             if parse_total_time:
-                m = end_patt.search(line)
-                if m:
+                if match := end_patt.search(line):
                     BSE_results.update(end_normally=True)
 
-                m = total_time_patt.search(line)
-                if m:
-                    BSE_results.update(total_time=m.group(1))
+                if match := total_time_patt.search(line):
+                    BSE_results.update(total_time=match[1])
 
             if parse_BSE_results:
                 if line.find("FULL BSE main valence -> conduction transitions weight:") != -1:
@@ -852,11 +857,10 @@ class BSEOutput:
                     parse_BSE_results = False
                     continue
 
-                m = BSE_exitons_patt.search(line)
-                if m:
+                if match := BSE_exitons_patt.search(line):
                     dct = {}
-                    dct.update(bse_eig=m.group(2), osc_strength=m.group(3))
-                    BSE_results[str(m.group(1).strip())] = dct
+                    dct.update(bse_eig=match[2], osc_strength=match[3])
+                    BSE_results[str(match[1].strip())] = dct
 
             if line.find("FULL BSE eig.(eV), osc. strength and dipoles:") != -1:
                 parse_BSE_results = True
