@@ -20,7 +20,7 @@ import re
 import warnings
 from io import StringIO
 from pathlib import Path
-from typing import TYPE_CHECKING, Literal
+from typing import TYPE_CHECKING
 
 import numpy as np
 import pandas as pd
@@ -35,7 +35,9 @@ from pymatgen.util.io_utils import clean_lines
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
-    from typing import Any
+    from typing import Any, Literal
+
+    from typing_extensions import Self
 
     from pymatgen.core.sites import Site
     from pymatgen.core.structure import SiteCollection
@@ -151,16 +153,11 @@ class LammpsBox(MSONable):
         return np.dot(np.cross(matrix[0], matrix[1]), matrix[2])
 
     def get_str(self, significant_figures: int = 6) -> str:
-        """
-        Returns the string representation of simulation box in LAMMPS
-        data file format.
+        """Get the string representation of simulation box in LAMMPS data file format.
 
         Args:
             significant_figures (int): No. of significant figures to
                 output for box settings. Default to 6.
-
-        Returns:
-            String representation
         """
         ph = f"{{:.{significant_figures}f}}"
         lines = []
@@ -187,8 +184,7 @@ class LammpsBox(MSONable):
         return np.inner(i, self._matrix.T)
 
     def to_lattice(self) -> Lattice:
-        """
-        Converts the simulation box to a more powerful Lattice backend.
+        """Convert the simulation box to a more powerful Lattice backend.
         Note that Lattice is always periodic in 3D space while a
         simulation box is not necessarily periodic in all dimensions.
 
@@ -209,19 +205,19 @@ def lattice_2_lmpbox(lattice: Lattice, origin: Sequence = (0, 0, 0)) -> tuple[La
             simulation box. Default to (0, 0, 0).
 
     Returns:
-        LammpsBox, SymmOp
+        tuple[LammpsBox, SymmOp]
     """
     a, b, c = lattice.abc
     xlo, ylo, zlo = origin
     xhi = a + xlo
-    m = lattice.matrix
-    xy = np.dot(m[1], m[0] / a)
+    matrix = lattice.matrix
+    xy = np.dot(matrix[1], matrix[0] / a)
     yhi = np.sqrt(b**2 - xy**2) + ylo
-    xz = np.dot(m[2], m[0] / a)
-    yz = (np.dot(m[1], m[2]) - xy * xz) / (yhi - ylo)
+    xz = np.dot(matrix[2], matrix[0] / a)
+    yz = (np.dot(matrix[1], matrix[2]) - xy * xz) / (yhi - ylo)
     zhi = np.sqrt(c**2 - xz**2 - yz**2) + zlo
     tilt = None if lattice.is_orthogonal else [xy, xz, yz]
-    rot_matrix = np.linalg.solve([[xhi - xlo, 0, 0], [xy, yhi - ylo, 0], [xz, yz, zhi - zlo]], m)
+    rot_matrix = np.linalg.solve([[xhi - xlo, 0, 0], [xy, yhi - ylo, 0], [xz, yz, zhi - zlo]], matrix)
     bounds = [[xlo, xhi], [ylo, yhi], [zlo, zhi]]
     symm_op = SymmOp.from_rotation_and_translation(rot_matrix, origin)
     return LammpsBox(bounds, tilt), symm_op
@@ -240,10 +236,8 @@ class LammpsData(MSONable):
         topology: dict[str, pd.DataFrame] | None = None,
         atom_style: str = "full",
     ) -> None:
-        """
-        This is a low level constructor designed to work with parsed
-        data or other bridging objects (ForceField and Topology). Not
-        recommended to use directly.
+        """Low level constructor designed to work with parsed data or other bridging
+        objects (ForceField and Topology). Not recommended to use directly.
 
         Args:
             box (LammpsBox): Simulation box.
@@ -255,7 +249,7 @@ class LammpsData(MSONable):
                 ["vx", "vy", "vz"] for Velocities section. Optional
                 with default to None. If not None, its index should be
                 consistent with atoms.
-            force_field (dict): Data for force field sections. Optional
+            force_fieldct (dict): Data for force field sections. Optional
                 with default to None. Only keywords in force field and
                 class 2 force field are valid keys, and each value is a
                 DataFrame.
@@ -290,11 +284,10 @@ class LammpsData(MSONable):
 
     @property
     def structure(self) -> Structure:
-        """
-        Exports a periodic structure object representing the simulation
+        """Exports a periodic structure object representing the simulation
         box.
 
-        Return:
+        Returns:
             Structure
         """
         masses = self.masses
@@ -302,19 +295,19 @@ class LammpsData(MSONable):
         if "nx" in atoms.columns:
             atoms = atoms.drop(["nx", "ny", "nz"], axis=1)
         atoms["molecule-ID"] = 1
-        ld_copy = self.__class__(self.box, masses, atoms)
+        ld_copy = type(self)(self.box, masses, atoms)
         topologies = ld_copy.disassemble()[-1]
         molecule = topologies[0].sites
         coords = molecule.cart_coords - np.array(self.box.bounds)[:, 0]
         species = molecule.species
-        latt = self.box.to_lattice()
+        lattice = self.box.to_lattice()
         site_properties = {}
         if "q" in atoms:
             site_properties["charge"] = atoms["q"].to_numpy()
         if self.velocities is not None:
             site_properties["velocities"] = self.velocities.to_numpy()
         return Structure(
-            latt,
+            lattice,
             species,
             coords,
             coords_are_cartesian=True,
@@ -322,10 +315,8 @@ class LammpsData(MSONable):
         )
 
     def get_str(self, distance: int = 6, velocity: int = 8, charge: int = 4, hybrid: bool = True) -> str:
-        """
-        Returns the string representation of LammpsData, essentially
-        the string to be written to a file. Support hybrid style
-        coeffs read and write.
+        """Get the string representation of LammpsData, essentially the string
+        to be written to a file. Supports hybrid style coeffs read and write.
 
         Args:
             distance (int): No. of significant figures to output for
@@ -342,7 +333,7 @@ class LammpsData(MSONable):
                 default is recommended.
 
         Returns:
-            String representation
+            str: String representation of LammpsData.
         """
         file_template = """Generated by pymatgen.io.lammps.data.LammpsData
 
@@ -460,8 +451,7 @@ class LammpsData(MSONable):
         return file_template.format(stats=stats, box=box, body=body)
 
     def write_file(self, filename: str, distance: int = 6, velocity: int = 8, charge: int = 4) -> None:
-        """
-        Writes LammpsData to file.
+        """Write LammpsData to file.
 
         Args:
             filename (str): Filename.
@@ -473,7 +463,7 @@ class LammpsData(MSONable):
             charge (int): No. of significant figures to output for
                 charges. Default to 4.
         """
-        with open(filename, mode="w") as file:
+        with open(filename, mode="w", encoding="utf-8") as file:
             file.write(self.get_str(distance=distance, velocity=velocity, charge=charge))
 
     def disassemble(
@@ -629,7 +619,7 @@ class LammpsData(MSONable):
         return self.box, ff, topo_list
 
     @classmethod
-    def from_file(cls, filename: str, atom_style: str = "full", sort_id: bool = False) -> LammpsData:
+    def from_file(cls, filename: str, atom_style: str = "full", sort_id: bool = False) -> Self:
         """
         Constructor that parses a file.
 
@@ -653,19 +643,19 @@ class LammpsData(MSONable):
         header_pattern["tilt"] = r"^\s*{}$".format(r"\s+".join([float_group] * 3 + ["xy xz yz"]))
 
         header: dict[str, Any] = {"counts": {}, "types": {}}
-        bounds = {}
+        bounds: dict[str, list[float]] = {}
         for line in clean_lines(parts[0][1:]):  # skip the 1st line
             match = None
-            for k, v in header_pattern.items():  # noqa: B007
-                match = re.match(v, line)
-                if match:
+            key = None
+            for key, val in header_pattern.items():  # noqa: B007
+                if match := re.match(val, line):
                     break
-            if match and k in ["counts", "types"]:
-                header[k][match.group(2)] = int(match.group(1))
-            elif match and k == "bounds":
+            if match and key in {"counts", "types"}:
+                header[key][match[2]] = int(match[1])
+            elif match and key == "bounds":
                 g = match.groups()
                 bounds[g[2]] = [float(i) for i in g[:2]]
-            elif match and k == "tilt":
+            elif match and key == "tilt":
                 header["tilt"] = [float(i) for i in match.groups()]
         header["bounds"] = [bounds.get(i, [-0.5, 0.5]) for i in "xyz"]
         box = LammpsBox(header["bounds"], header.get("tilt"))
@@ -673,17 +663,17 @@ class LammpsData(MSONable):
         def parse_section(sec_lines) -> tuple[str, pd.DataFrame]:
             title_info = sec_lines[0].split("#", 1)
             kw = title_info[0].strip()
-            sio = StringIO("".join(sec_lines[2:]))  # skip the 2nd line
+            str_io = StringIO("".join(sec_lines[2:]))  # skip the 2nd line
             if kw.endswith("Coeffs") and not kw.startswith("PairIJ"):
                 df_list = [
-                    pd.read_csv(StringIO(line), header=None, comment="#", delim_whitespace=True)
+                    pd.read_csv(StringIO(line), header=None, comment="#", sep=r"\s+")
                     for line in sec_lines[2:]
                     if line.strip()
                 ]
                 df = pd.concat(df_list, ignore_index=True)
                 names = ["id"] + [f"coeff{i}" for i in range(1, df.shape[1])]
             else:
-                df = pd.read_csv(sio, header=None, comment="#", delim_whitespace=True)
+                df = pd.read_csv(str_io, header=None, comment="#", sep=r"\s+")
                 if kw == "PairIJ Coeffs":
                     names = ["id1", "id2"] + [f"coeff{i}" for i in range(1, df.shape[1] - 1)]
                     df.index.name = None
@@ -719,16 +709,18 @@ class LammpsData(MSONable):
                 name in ["Velocities"] + SECTION_KEYWORDS["topology"] and not seen_atoms
             ):  # Atoms must appear earlier than these
                 raise RuntimeError(f"{err_msg}{name} section appears before Atoms section")
-            body.update({name: section})
+            body[name] = section
 
         err_msg += "Nos. of {} do not match between header and {} section"
         assert len(body["Masses"]) == header["types"]["atom"], err_msg.format("atom types", "Masses")
         atom_sections = ["Atoms", "Velocities"] if "Velocities" in body else ["Atoms"]
-        for s in atom_sections:
-            assert len(body[s]) == header["counts"]["atoms"], err_msg.format("atoms", s)
-        for s in SECTION_KEYWORDS["topology"]:
-            if header["counts"].get(s.lower(), 0) > 0:
-                assert len(body[s]) == header["counts"][s.lower()], err_msg.format(s.lower(), s)
+        for atom_sec in atom_sections:
+            assert len(body[atom_sec]) == header["counts"]["atoms"], err_msg.format("atoms", atom_sec)
+        for atom_sec in SECTION_KEYWORDS["topology"]:
+            if header["counts"].get(atom_sec.lower(), 0) > 0:
+                assert len(body[atom_sec]) == header["counts"][atom_sec.lower()], err_msg.format(
+                    atom_sec.lower(), atom_sec
+                )
 
         items = {k.lower(): body[k] for k in ["Masses", "Atoms"]}
         items["velocities"] = body.get("Velocities")
@@ -743,7 +735,7 @@ class LammpsData(MSONable):
     @classmethod
     def from_ff_and_topologies(
         cls, box: LammpsBox, ff: ForceField, topologies: Sequence[Topology], atom_style: str = "full"
-    ):
+    ) -> Self:
         """
         Constructor building LammpsData from a ForceField object and a
         list of Topology objects. Do not support intermolecular
@@ -770,7 +762,7 @@ class LammpsData(MSONable):
         v_collector: list | None = [] if topologies[0].velocities else None
         topo_collector: dict[str, list] = {"Bonds": [], "Angles": [], "Dihedrals": [], "Impropers": []}
         topo_labels: dict[str, list] = {"Bonds": [], "Angles": [], "Dihedrals": [], "Impropers": []}
-        for i, topo in enumerate(topologies):
+        for idx, topo in enumerate(topologies):
             if topo.topologies:
                 shift = len(labels)
                 for k, v in topo.topologies.items():
@@ -778,11 +770,10 @@ class LammpsData(MSONable):
                     topo_labels[k].extend([tuple(topo.type_by_sites[j] for j in t) for t in v])
             if isinstance(v_collector, list):
                 v_collector.append(topo.velocities)
-            mol_ids.extend([i + 1] * len(topo.sites))
+            mol_ids.extend([idx + 1] * len(topo.sites))
             labels.extend(topo.type_by_sites)
             coords.append(topo.sites.cart_coords)
-            q = [0.0] * len(topo.sites) if not topo.charges else topo.charges
-            charges.extend(q)
+            charges.extend(topo.charges or [0.0] * len(topo.sites))
 
         atoms = pd.DataFrame(np.concatenate(coords), columns=["x", "y", "z"])
         atoms["molecule-ID"] = mol_ids
@@ -818,9 +809,8 @@ class LammpsData(MSONable):
         ff_elements: Sequence[str] | None = None,
         atom_style: Literal["atomic", "charge"] = "charge",
         is_sort: bool = False,
-    ):
-        """
-        Simple constructor building LammpsData from a structure without
+    ) -> Self:
+        """Simple constructor building LammpsData from a structure without
         force field parameters and topologies.
 
         Args:
@@ -859,12 +849,11 @@ class LammpsData(MSONable):
         return cls.from_ff_and_topologies(box=box, ff=ff, topologies=[topo], atom_style=atom_style)
 
     def set_charge_atom(self, charges: dict[int, float]) -> None:
-        """
-        Set the charges of specific atoms of the data.
+        """Set the charges of specific atoms of the data.
 
         Args:
             charges: A dictionary with atom indexes as keys and
-                charges as values, e.g., to set the charge
+                charges as values, e.g. to set the charge
                 of the atom with index 3 to -2, use `{3: -2}`.
         """
         for iat, q in charges.items():
@@ -889,8 +878,7 @@ class LammpsData(MSONable):
 
 
 class Topology(MSONable):
-    """
-    Class carrying most data in Atoms, Velocities and molecular topology sections for
+    """Carry most data in Atoms, Velocities and Molecular Topology sections for
     ONE SINGLE Molecule or Structure object, or a plain list of Sites.
     """
 
@@ -969,12 +957,12 @@ class Topology(MSONable):
         dihedral: bool = True,
         tol: float = 0.1,
         **kwargs,
-    ):
+    ) -> Self:
         """
         Another constructor that creates an instance from a molecule.
         Covalent bonds and other bond-based topologies (angles and
         dihedrals) can be automatically determined. Cannot be used for
-        non bond-based topologies, e.g., improper dihedrals.
+        non bond-based topologies, e.g. improper dihedrals.
 
         Args:
             molecule (Molecule): Input molecule.
@@ -996,8 +984,8 @@ class Topology(MSONable):
         dests, freq = np.unique(bond_list, return_counts=True)
         hubs = dests[np.where(freq > 1)].tolist()
         bond_arr = np.array(bond_list)
+        hub_spokes = {}
         if len(hubs) > 0:
-            hub_spokes = {}
             for hub in hubs:
                 ix = np.any(np.isin(bond_arr, hub), axis=1)
                 bonds = np.unique(bond_arr[ix]).tolist()
@@ -1025,11 +1013,11 @@ class Topology(MSONable):
 
 class ForceField(MSONable):
     """
-    Class carrying most data in Masses and force field sections.
+    Class carrying most data in masses and force field sections.
 
     Attributes:
-        masses (pandas.DataFrame): DataFrame for Masses section.
-        force_field (dict): Force field section keywords (keys) and
+        masses (pandas.DataFrame): DataFrame for masses section.
+        force_fieldct (dict): Force field section keywords (keys) and
             data (values) as DataFrames.
         maps (dict): Dict for labeling atoms and topologies.
     """
@@ -1090,12 +1078,12 @@ class ForceField(MSONable):
             )
 
         index, masses, self.mass_info, atoms_map = [], [], [], {}
-        for i, m in enumerate(mass_info):
-            index.append(i + 1)
+        for idx, m in enumerate(mass_info, start=1):
+            index.append(idx)
             mass = map_mass(m[1])
             masses.append(mass)
             self.mass_info.append((m[0], mass))
-            atoms_map[m[0]] = i + 1
+            atoms_map[m[0]] = idx
         self.masses = pd.DataFrame({"mass": masses}, index=index)
         self.maps = {"Atoms": atoms_map}
 
@@ -1115,25 +1103,27 @@ class ForceField(MSONable):
                 ff_dfs.update(coeffs)
                 self.maps.update(mapper)
 
-        self.force_field = None if len(ff_dfs) == 0 else ff_dfs
+        self.force_field = ff_dfs or None
 
     def _process_nonbond(self) -> dict:
         pair_df = pd.DataFrame(self.nonbond_coeffs)
         assert self._is_valid(pair_df), "Invalid nonbond coefficients with rows varying in length"
         n_pair, n_coeff = pair_df.shape
         pair_df.columns = [f"coeff{i}" for i in range(1, n_coeff + 1)]
-        nm = len(self.mass_info)
-        n_comb = int(nm * (nm + 1) / 2)
-        if n_pair == nm:
+        n_mass = len(self.mass_info)
+        n_comb = int(n_mass * (n_mass + 1) / 2)
+        if n_pair == n_mass:
             kw = "Pair Coeffs"
-            pair_df.index = range(1, nm + 1)
+            pair_df.index = range(1, n_mass + 1)
         elif n_pair == n_comb:
             kw = "PairIJ Coeffs"
-            ids = list(itertools.combinations_with_replacement(range(1, nm + 1), 2))
+            ids = list(itertools.combinations_with_replacement(range(1, n_mass + 1), 2))
             id_df = pd.DataFrame(ids, columns=["id1", "id2"])
             pair_df = pd.concat([id_df, pair_df], axis=1)
         else:
-            raise ValueError(f"Expecting {nm} Pair Coeffs or {n_comb} PairIJ Coeffs for {nm} atom types, got {n_pair}")
+            raise ValueError(
+                f"Expecting {n_mass} Pair Coeffs or {n_comb} PairIJ Coeffs for {n_mass} atom types, got {n_pair}"
+            )
         return {kw: pair_df}
 
     def _process_topo(self, kw: str, topo_coeffs: dict) -> tuple[dict, dict]:
@@ -1158,9 +1148,9 @@ class ForceField(MSONable):
         atoms = set(np.ravel(list(itertools.chain(*distinct_types))))
         assert atoms.issubset(self.maps["Atoms"]), f"Undefined atom type found in {kw}"
         mapper = {}
-        for i, dt in enumerate(distinct_types):
+        for i, dt in enumerate(distinct_types, start=1):
             for t in dt:
-                mapper[t] = i + 1
+                mapper[t] = i
 
         def process_data(data) -> pd.DataFrame:
             df = pd.DataFrame(data)
@@ -1173,11 +1163,10 @@ class ForceField(MSONable):
         all_data = {kw: process_data(main_data)}
         if class2_data:
             all_data.update({k: process_data(v) for k, v in class2_data.items()})
-        return all_data, {kw[:-7] + "s": mapper}
+        return all_data, {f"{kw[:-7]}s": mapper}
 
     def to_file(self, filename: str) -> None:
-        """
-        Saves object to a file in YAML format.
+        """Save force field to a file in YAML format.
 
         Args:
             filename (str): Filename.
@@ -1187,37 +1176,36 @@ class ForceField(MSONable):
             "nonbond_coeffs": self.nonbond_coeffs,
             "topo_coeffs": self.topo_coeffs,
         }
-        with open(filename, mode="w") as file:
+        with open(filename, mode="w", encoding="utf-8") as file:
             yaml = YAML()
             yaml.dump(dct, file)
 
     @classmethod
-    def from_file(cls, filename: str) -> ForceField:
-        """
-        Constructor that reads in a file in YAML format.
+    def from_file(cls, filename: str) -> Self:
+        """Constructor that reads in a file in YAML format.
 
         Args:
             filename (str): Filename.
         """
-        with open(filename) as file:
+        with open(filename, encoding="utf-8") as file:
             yaml = YAML()
             d = yaml.load(file)
         return cls.from_dict(d)
 
     @classmethod
-    def from_dict(cls, d: dict) -> ForceField:
+    def from_dict(cls, dct: dict) -> Self:
         """
         Constructor that reads in a dictionary.
 
         Args:
-            d (dict): Dictionary to read.
+            dct (dict): Dictionary to read.
         """
-        d["mass_info"] = [tuple(m) for m in d["mass_info"]]
-        if d.get("topo_coeffs"):
-            for v in d["topo_coeffs"].values():
+        dct["mass_info"] = [tuple(m) for m in dct["mass_info"]]
+        if dct.get("topo_coeffs"):
+            for v in dct["topo_coeffs"].values():
                 for c in v:
                     c["types"] = [tuple(t) for t in c["types"]]
-        return cls(d["mass_info"], d["nonbond_coeffs"], d["topo_coeffs"])
+        return cls(dct["mass_info"], dct["nonbond_coeffs"], dct["topo_coeffs"])
 
 
 class CombinedData(LammpsData):
@@ -1324,11 +1312,10 @@ class CombinedData(LammpsData):
 
     @property
     def structure(self) -> Structure:
-        """
-        Exports a periodic structure object representing the simulation
+        """Exports a periodic structure object representing the simulation
         box.
 
-        Return:
+        Returns:
             Structure
         """
         ld_cp = self.as_lammpsdata()
@@ -1371,13 +1358,14 @@ class CombinedData(LammpsData):
             for mol in self.mols
         ]
 
+    # NOTE (@janosh): The following two methods for override parent class LammpsData
     @classmethod
-    def from_ff_and_topologies(cls):
+    def from_ff_and_topologies(cls) -> None:  # type: ignore[override]
         """Unsupported constructor for CombinedData objects."""
         raise AttributeError("Unsupported constructor for CombinedData objects")
 
     @classmethod
-    def from_structure(cls):
+    def from_structure(cls) -> None:  # type: ignore[override]
         """Unsupported constructor for CombinedData objects."""
         raise AttributeError("Unsupported constructor for CombinedData objects")
 
@@ -1392,45 +1380,50 @@ class CombinedData(LammpsData):
         with zopen(filename, mode="rt") as file:
             lines = file.readlines()
 
-        sio = StringIO("".join(lines[2:]))  # skip the 2nd line
+        str_io = StringIO("".join(lines[2:]))  # skip the 2nd line
         df = pd.read_csv(
-            sio,
+            str_io,
             header=None,
             comment="#",
-            delim_whitespace=True,
+            sep=r"\s+",
             names=["atom", "x", "y", "z"],
         )
         df.index += 1
         return df
 
     @classmethod
-    def from_files(cls, coordinate_file: str, list_of_numbers: list, *filenames) -> CombinedData:
+    def from_files(cls, coordinate_file: str, list_of_numbers: list[int], *filenames: str) -> Self:
         """
         Constructor that parse a series of data file.
 
         Args:
             coordinate_file (str): The filename of xyz coordinates.
-            list_of_numbers (list): A list of numbers specifying counts for each
+            list_of_numbers (list[int]): A list of numbers specifying counts for each
                 clusters parsed from files.
             filenames (str): A series of LAMMPS data filenames in string format.
         """
         names = []
         mols = []
         styles = []
-        coordinates = cls.parse_xyz(filename=coordinate_file)
-        for idx in range(1, len(filenames) + 1):
-            exec(f"cluster{idx} = LammpsData.from_file(filenames[{idx - 1}])")
+        clusters = []
+
+        for idx, filename in enumerate(filenames, start=1):
+            cluster = LammpsData.from_file(filename)
+            clusters.append(cluster)
             names.append(f"cluster{idx}")
-            mols.append(eval(f"cluster{idx}"))
-            styles.append(eval(f"cluster{idx}").atom_style)
-        style = set(styles)
-        assert len(style) == 1, "Files have different atom styles."
-        return cls.from_lammpsdata(mols, names, list_of_numbers, coordinates, style.pop())
+            mols.append(cluster)
+            styles.append(cluster.atom_style)
+
+        if len(set(styles)) != 1:
+            raise ValueError("Files have different atom styles.")
+
+        coordinates = cls.parse_xyz(filename=coordinate_file)
+        return cls.from_lammpsdata(mols, names, list_of_numbers, coordinates, styles.pop())
 
     @classmethod
     def from_lammpsdata(
         cls, mols: list, names: list, list_of_numbers: list, coordinates: pd.DataFrame, atom_style: str | None = None
-    ) -> CombinedData:
+    ) -> Self:
         """
         Constructor that can infer atom_style.
         The input LammpsData objects are used non-destructively.
@@ -1444,19 +1437,19 @@ class CombinedData(LammpsData):
                 columns of ["x", "y", "z"] for coordinates of atoms.
             atom_style (str): Output atom_style. Default to "full".
         """
-        styles = []
-        for mol in mols:
-            styles.append(mol.atom_style)
-        style = set(styles)
-        assert len(style) == 1, "Data have different atom_style."
-        style_return = style.pop()
-        if atom_style:
-            assert atom_style == style_return, "Data have different atom_style as specified."
+        styles = [mol.atom_style for mol in mols]
+
+        if len(set(styles)) != 1:
+            raise ValueError("Data have different atom_style.")
+        style_return = styles.pop()
+
+        if atom_style and atom_style != style_return:
+            raise ValueError("Data have different atom_style as specified.")
+
         return cls(mols, names, list_of_numbers, coordinates, style_return)
 
     def get_str(self, distance: int = 6, velocity: int = 8, charge: int = 4, hybrid: bool = True) -> str:
-        """
-        Returns the string representation of CombinedData, essentially
+        """Get the string representation of CombinedData, essentially
         the string to be written to a file. Combination info is included
         as a comment. For single molecule ID data, the info format is:
             num name
@@ -1478,7 +1471,7 @@ class CombinedData(LammpsData):
                 default is recommended.
 
         Returns:
-            String representation
+            str: String representation of CombinedData.
         """
         lines = LammpsData.get_str(self, distance, velocity, charge, hybrid).splitlines()
         info = "# " + " + ".join(
@@ -1492,7 +1485,7 @@ class CombinedData(LammpsData):
         Convert a CombinedData object to a LammpsData object. attributes are deep-copied.
 
         box (LammpsBox): Simulation box.
-        force_field (dict): Data for force field sections. Optional
+        force_fieldct (dict): Data for force field sections. Optional
             with default to None. Only keywords in force field and
             class 2 force field are valid keys, and each value is a
             DataFrame.
