@@ -4,7 +4,7 @@ from __future__ import annotations
 
 import logging
 import re
-from typing import TYPE_CHECKING, Literal
+from typing import TYPE_CHECKING
 
 from monty.io import zopen
 
@@ -15,6 +15,9 @@ from .utils import lower_and_check_unique, read_pattern, read_table_pattern
 
 if TYPE_CHECKING:
     from pathlib import Path
+    from typing import Literal
+
+    from typing_extensions import Self
 
 __author__ = "Brandon Wood, Samuel Blau, Shyam Dwaraknath, Julian Self, Evan Spotte-Smith, Ryan Kingsbury"
 __copyright__ = "Copyright 2018-2022, The Materials Project"
@@ -61,7 +64,7 @@ class QCInput(InputFile):
                 Molecule objects, or as the string "read". "read" can be used in multi_job QChem input
                 files where the molecule is read in from the previous calculation.
             rem (dict):
-                A dictionary of all the input parameters for the rem section of QChem input file.
+                A dictionary of all the input parameters for the REM section of QChem input file.
                 Ex. rem = {'method': 'rimp2', 'basis': '6-31*G++' ... }
             opt (dict of lists):
                 A dictionary of opt sections, where each opt section is a key and the corresponding
@@ -241,8 +244,8 @@ class QCInput(InputFile):
         """Return a string representation of an entire input file."""
         return str(self)
 
-    def __str__(self):
-        combined_list = []
+    def __str__(self) -> str:
+        combined_list: list = []
         # molecule section
         combined_list.extend((self.molecule_template(self.molecule), "", self.rem_template(self.rem), ""))
         # opt section
@@ -292,18 +295,18 @@ class QCInput(InputFile):
             job_list (): List of jobs.
 
         Returns:
-            (str) String representation of multi job input file.
+            str: String representation of a multi-job input file.
         """
         multi_job_string = ""
-        for i, job_i in enumerate(job_list):
-            if i < len(job_list) - 1:
+        for i, job_i in enumerate(job_list, start=1):
+            if i < len(job_list):
                 multi_job_string += str(job_i) + "\n@@@\n\n"
             else:
                 multi_job_string += str(job_i)
         return multi_job_string
 
     @classmethod
-    def from_str(cls, string: str) -> QCInput:
+    def from_str(cls, string: str) -> Self:  # type: ignore[override]
         """
         Read QcInput from string.
 
@@ -367,8 +370,7 @@ class QCInput(InputFile):
 
     @staticmethod
     def write_multi_job_file(job_list: list[QCInput], filename: str):
-        """
-        Write a multijob file.
+        """Write a multijob file.
 
         Args:
             job_list (): List of jobs.
@@ -378,7 +380,7 @@ class QCInput(InputFile):
             file.write(QCInput.multi_job_string(job_list))
 
     @classmethod
-    def from_file(cls, filename: str | Path) -> QCInput:
+    def from_file(cls, filename: str | Path) -> Self:  # type: ignore[override]
         """
         Create QcInput from file.
 
@@ -392,7 +394,7 @@ class QCInput(InputFile):
             return cls.from_str(file.read())
 
     @classmethod
-    def from_multi_jobs_file(cls, filename: str) -> list[QCInput]:
+    def from_multi_jobs_file(cls, filename: str) -> list[Self]:
         """
         Create list of QcInput from a file.
 
@@ -415,8 +417,7 @@ class QCInput(InputFile):
             molecule (Molecule, list of Molecules, or "read").
 
         Returns:
-            (str) Molecule template.
-
+            str: Molecule template.
         """
         # TODO: add ghost atoms
         mol_list = []
@@ -457,7 +458,7 @@ class QCInput(InputFile):
             rem ():
 
         Returns:
-            (str)
+            str: REM template.
         """
         rem_list = []
         rem_list.append("$rem")
@@ -475,7 +476,7 @@ class QCInput(InputFile):
             opt ():
 
         Returns:
-            (str)
+            str: Optimization template.
         """
         opt_list = []
         opt_list.append("$opt")
@@ -494,13 +495,13 @@ class QCInput(InputFile):
     @staticmethod
     def pcm_template(pcm: dict) -> str:
         """
-        Pcm run template.
+        PCM run template.
 
         Args:
             pcm ():
 
         Returns:
-            (str)
+            str: PCM template.
         """
         pcm_list = []
         pcm_list.append("$pcm")
@@ -511,14 +512,13 @@ class QCInput(InputFile):
 
     @staticmethod
     def solvent_template(solvent: dict) -> str:
-        """
-        Solvent template.
+        """Solvent template.
 
         Args:
             solvent ():
 
         Returns:
-            (str)
+            str: Solvent section.
         """
         solvent_list = []
         solvent_list.append("$solvent")
@@ -534,7 +534,7 @@ class QCInput(InputFile):
             smx ():
 
         Returns:
-            (str)
+            str: Solvation model with short-range corrections.
         """
         smx_list = []
         smx_list.append("$smx")
@@ -551,13 +551,11 @@ class QCInput(InputFile):
 
     @staticmethod
     def scan_template(scan: dict[str, list]) -> str:
-        """
+        """Get string representing Q-Chem input format for scan section.
+
         Args:
             scan (dict): Dictionary with scan section information.
                 Ex: {"stre": ["3 6 1.5 1.9 0.1"], "tors": ["1 2 3 4 -180 180 15"]}.
-
-        Returns:
-            String representing Q-Chem input format for scan section
         """
         scan_list = []
         scan_list.append("$scan")
@@ -586,7 +584,7 @@ class QCInput(InputFile):
                 **NOTE: keys must be given as strings even though they are numbers!**.
 
         Returns:
-            String representing Q-Chem input format for van_der_waals section
+            str: representing Q-Chem input format for van_der_waals section
         """
         vdw_list = []
         vdw_list.append("$van_der_waals")
@@ -609,14 +607,13 @@ class QCInput(InputFile):
             plots ():
 
         Returns:
-            (str)
+            str: Plots section.
         """
-        plots_list = []
-        plots_list.append("$plots")
+        out = ["$plots"]
         for key, value in plots.items():
-            plots_list.append(f"   {key} {value}")
-        plots_list.append("$end")
-        return "\n".join(plots_list)
+            out.append(f"   {key} {value}")
+        out += ["$end"]
+        return "\n".join(out)
 
     @staticmethod
     def nbo_template(nbo: dict) -> str:
@@ -625,7 +622,7 @@ class QCInput(InputFile):
             nbo ():
 
         Returns:
-            (str)
+            str: NBO section.
         """
         nbo_list = []
         nbo_list.append("$nbo")
@@ -661,7 +658,7 @@ class QCInput(InputFile):
             geom_opt ():
 
         Returns:
-            (str) geom_opt parameters.
+            str: Geometry optimization section.
         """
         geom_opt_list = []
         geom_opt_list.append("$geom_opt")
@@ -677,11 +674,11 @@ class QCInput(InputFile):
             cdft: list of lists of dicts.
 
         Returns:
-            (str)
+            str: CDFT section.
         """
         cdft_list = []
         cdft_list.append("$cdft")
-        for ii, state in enumerate(cdft):
+        for ii, state in enumerate(cdft, start=1):
             for constraint in state:
                 types = constraint["types"]
                 cdft_list.append(f"   {constraint['value']}")
@@ -702,7 +699,7 @@ class QCInput(InputFile):
                         cdft_list.append(f"   {coef} {first} {last} {type_string}")
                     else:
                         cdft_list.append(f"   {coef} {first} {last}")
-            if len(cdft) != 1 and ii + 1 < len(state):
+            if len(cdft) != 1 and ii < len(state):
                 cdft_list.append("--------------")
 
         # Ensure that you don't have a line indicating a state that doesn't exist
@@ -719,7 +716,7 @@ class QCInput(InputFile):
             almo: list of lists of int 2-tuples.
 
         Returns:
-            (str)
+            str: ALMO coupling section.
         """
         almo_list = []
         almo_list.append("$almo_coupling")
@@ -761,21 +758,23 @@ class QCInput(InputFile):
             }
 
         Returns:
-            (str)
+            str: the $pcm_nonels section. Note that all parameters will be concatenated onto
+                a single line formatted as a FORTRAN namelist. This is necessary
+                because the non-electrostatic part of the CMIRS solvation model in Q-Chem
+                calls a secondary code.
         """
-        pcm_nonels_list = []
-        pcm_nonels_list.append("$pcm_nonels")
+        pcm_non_electros = []
+        pcm_non_electros.append("$pcm_nonels")
         for key, value in pcm_nonels.items():
             # if the value is None, don't write it to output
             if value is not None:
-                pcm_nonels_list.append(f"   {key} {value}")
-        pcm_nonels_list.append("$end")
-        return "\n".join(pcm_nonels_list)
+                pcm_non_electros.append(f"   {key} {value}")
+        pcm_non_electros.append("$end")
+        return "\n".join(pcm_non_electros)
 
     @staticmethod
     def find_sections(string: str) -> list:
-        """
-        Find sections in the string.
+        """Find sections in the string.
 
         Args:
             string (str): String
@@ -795,7 +794,7 @@ class QCInput(InputFile):
         if "molecule" not in sections:
             raise ValueError("Output file does not contain a molecule section")
         if "rem" not in sections:
-            raise ValueError("Output file does not contain a rem section")
+            raise ValueError("Output file does not contain a REM section")
         return sections
 
     @staticmethod
@@ -860,14 +859,13 @@ class QCInput(InputFile):
 
     @staticmethod
     def read_rem(string: str) -> dict:
-        """
-        Parse rem from string.
+        """Parse rem from string.
 
         Args:
             string (str): String
 
         Returns:
-            (dict) rem
+            dict[str, str]: REM section
         """
         header = r"^\s*\$rem"
         row = r"\s*([a-zA-Z\_\d]+)\s*=?\s*(\S+)"
@@ -884,7 +882,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) Opt section
+            dict[str, list]: Opt section
         """
         patterns = {
             "CONSTRAINT": r"^\s*CONSTRAINT",
@@ -945,7 +943,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) PCM parameters
+            dict[str, str]: PCM parameters
         """
         header = r"^\s*\$pcm"
         row = r"\s*([a-zA-Z\_]+)\s+(\S+)"
@@ -966,7 +964,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (str, dict) vdW mode ('atomic' or 'sequential') and dict of van der Waals radii.
+            tuple[str, dict]: (vdW mode ('atomic' or 'sequential'), dict of van der Waals radii)
         """
         header = r"^\s*\$van_der_waals"
         row = r"[^\d]*(\d+).?(\d+.\d+)?.*"
@@ -989,7 +987,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) Solvent parameters
+            dict[str, str]: Solvent parameters
         """
         header = r"^\s*\$solvent"
         row = r"\s*([a-zA-Z\_]+)\s+(\S+)"
@@ -1010,7 +1008,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) SMX parameters.
+            dict[str, str] SMX parameters.
         """
         header = r"^\s*\$smx"
         row = r"\s*([a-zA-Z\_]+)\s+(\S+)"
@@ -1071,7 +1069,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) plots parameters.
+            dict[str, str]: plots parameters.
         """
         header = r"^\s*\$plots"
         row = r"\s*([a-zA-Z\_]+)\s+(\S+)"
@@ -1091,7 +1089,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) nbo parameters.
+            dict[str, str]: nbo parameters.
         """
         header = r"^\s*\$nbo"
         row = r"\s*([a-zA-Z\_\d]+)\s*=?\s*(\S+)"
@@ -1111,7 +1109,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) geom_opt parameters.
+            dict[str, str]: geom_opt parameters.
         """
         header = r"^\s*\$geom_opt"
         row = r"\s*([a-zA-Z\_]+)\s*=?\s*(\S+)"
@@ -1189,7 +1187,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (list of lists of int 2-tuples) almo_coupling parameters
+            list[list[tuple[int, int]]]: ALMO coupling parameters
         """
         pattern = {
             "key": r"\$almo_coupling\s*\n((?:\s*[\-0-9]+\s+[\-0-9]+\s*\n)+)\s*\-\-"
@@ -1243,7 +1241,7 @@ class QCInput(InputFile):
             string (str): String
 
         Returns:
-            (dict) PCM parameters
+            dict[str, str]: PCM parameters
         """
         header = r"^\s*\$pcm_nonels"
         row = r"\s*([a-zA-Z\_]+)\s+(.+)"
