@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 import warnings
-from typing import Any
+from typing import TYPE_CHECKING
 
 import numpy as np
 from monty.dev import requires
@@ -17,6 +17,11 @@ try:
 except ImportError:
     f90nml = None
 
+if TYPE_CHECKING:
+    from typing import Any
+
+    from typing_extensions import Self
+
 __author__ = "Rees Chang, Alex Ganose"
 __copyright__ = "Copyright 2019, The Materials Project"
 __version__ = "0.1"
@@ -25,9 +30,8 @@ __date__ = "June 27, 2019"
 
 
 class Control(MSONable, dict):
-    """
-    Class for reading, updating, and writing ShengBTE CONTROL files.
-    See  https://bitbucket.org/sousaw/shengbte/src/master/ for more
+    """Read, update, and write ShengBTE CONTROL files.
+    See https://bitbucket.org/sousaw/shengbte/src/master/ for more
     detailed description and default values of CONTROL arguments.
     """
 
@@ -124,7 +128,7 @@ class Control(MSONable, dict):
         f90nml,
         "ShengBTE Control object requires f90nml to be installed. Please get it at https://pypi.org/project/f90nml.",
     )
-    def from_file(cls, filepath: str):
+    def from_file(cls, filepath: str) -> Self:
         """
         Read a CONTROL namelist file and output a 'Control' object.
 
@@ -147,9 +151,8 @@ class Control(MSONable, dict):
         return cls.from_dict(all_dict)
 
     @classmethod
-    def from_dict(cls, control_dict: dict):
-        """
-        Write a CONTROL file from a Python dictionary. Description and default
+    def from_dict(cls, control_dict: dict) -> Self:
+        """Write a CONTROL file from a Python dictionary. Description and default
         parameters can be found at
         https://bitbucket.org/sousaw/shengbte/src/master/.
         Note some parameters are mandatory. Optional parameters default here to
@@ -164,9 +167,8 @@ class Control(MSONable, dict):
         f90nml,
         "ShengBTE Control object requires f90nml to be installed. Please get it at https://pypi.org/project/f90nml.",
     )
-    def to_file(self, filename: str = "CONTROL"):
-        """
-        Writes ShengBTE CONTROL file from 'Control' object.
+    def to_file(self, filename: str = "CONTROL") -> None:
+        """Write ShengBTE CONTROL file from 'Control' object.
 
         Args:
             filename: A file name.
@@ -191,13 +193,12 @@ class Control(MSONable, dict):
         flags_nml = f90nml.Namelist({"flags": flags_dict})
         control_str += str(flags_nml) + "\n"
 
-        with open(filename, mode="w") as file:
+        with open(filename, mode="w", encoding="utf-8") as file:
             file.write(control_str)
 
     @classmethod
-    def from_structure(cls, structure: Structure, reciprocal_density: int | None = 50000, **kwargs):
-        """
-        Get a ShengBTE control object from a structure.
+    def from_structure(cls, structure: Structure, reciprocal_density: int | None = 50000, **kwargs) -> Self:
+        """Get a ShengBTE control object from a structure.
 
         Args:
             structure: A structure object.
@@ -235,8 +236,7 @@ class Control(MSONable, dict):
         return Control(**control_dict)
 
     def get_structure(self) -> Structure:
-        """
-        Get a pymatgen Structure from a ShengBTE control object.
+        """Get a pymatgen Structure from a ShengBTE control object.
 
         The control object must have the "lattvec", "types", "elements", and
         "positions" settings otherwise an error will be thrown.
@@ -261,7 +261,7 @@ class Control(MSONable, dict):
         return Structure(cell, species, self["positions"])
 
     def as_dict(self):
-        """Returns: MSONable dict."""
+        """Get MSONable dict."""
         return dict(self)
 
 
