@@ -5,17 +5,23 @@ from __future__ import annotations
 import re
 
 import requests
-from bs4 import BeautifulSoup
+from monty.dev import requires
+
+try:
+    from bs4 import BeautifulSoup
+except ImportError:
+    BeautifulSoup = None
 
 
 class VaspDoc:
     """A VASP documentation helper."""
 
-    def __init__(self):
+    @requires(BeautifulSoup, "BeautifulSoup must be installed to fetch from the VASP wiki.")
+    def __init__(self) -> None:
         """Init for VaspDoc."""
         self.url_template = "http://www.vasp.at/wiki/index.php/%s"
 
-    def print_help(self, tag):
+    def print_help(self, tag: str) -> None:
         """
         Print the help for a TAG.
 
@@ -24,7 +30,7 @@ class VaspDoc:
         """
         print(self.get_help(tag))
 
-    def print_jupyter_help(self, tag):
+    def print_jupyter_help(self, tag: str) -> None:
         """
         Display HTML help in ipython notebook.
 
@@ -37,19 +43,18 @@ class VaspDoc:
         display(HTML(html_str))
 
     @classmethod
-    def get_help(cls, tag, fmt="text"):
-        """
-        Get help on a VASP tag.
+    def get_help(cls, tag: str, fmt: str = "text") -> str:
+        """Get help on a VASP tag.
 
         Args:
-            tag (str): VASP tag, e.g., ISYM.
+            tag (str): VASP tag, e.g. ISYM.
 
         Returns:
             Help text.
         """
         tag = tag.upper()
-        r = requests.get(f"https://www.vasp.at/wiki/index.php/{tag}", verify=False)
-        soup = BeautifulSoup(r.text)
+        response = requests.get(f"https://www.vasp.at/wiki/index.php/{tag}", verify=False, timeout=600)
+        soup = BeautifulSoup(response.text)
         main_doc = soup.find(id="mw-content-text")
         if fmt == "text":
             output = main_doc.text
@@ -60,15 +65,15 @@ class VaspDoc:
         return output
 
     @classmethod
-    def get_incar_tags(cls):
-        """Returns: All incar tags."""
+    def get_incar_tags(cls) -> list[str]:
+        """Get a list of all INCAR tags from the VASP wiki."""
         tags = []
         for page in [
             "https://www.vasp.at/wiki/index.php/Category:INCAR",
             "https://www.vasp.at/wiki/index.php?title=Category:INCAR&pagefrom=ML+FF+LCONF+DISCARD#mw-pages",
         ]:
-            r = requests.get(page, verify=False)
-            soup = BeautifulSoup(r.text)
+            response = requests.get(page, verify=False, timeout=600)
+            soup = BeautifulSoup(response.text)
             for div in soup.findAll("div", {"class": "mw-category-group"}):
                 children = div.findChildren("li")
                 for child in children:
