@@ -80,11 +80,11 @@ class CRESTInput(MSONable):
         atoms_for_mtd = [idx for idx in range(1, len(mol) + 1) if idx not in atoms_to_constrain]
         # Write as 1-3,5 instead of 1,2,3,5
         interval_list = [atoms_for_mtd[0]]
-        for i, v in enumerate(atoms_for_mtd):
-            if v + 1 not in atoms_for_mtd:
-                interval_list.append(v)
-                if i != len(atoms_for_mtd) - 1:
-                    interval_list.append(atoms_for_mtd[i + 1])
+        for idx, val in enumerate(atoms_for_mtd, start=1):
+            if val + 1 not in atoms_for_mtd:
+                interval_list.append(val)
+                if idx != len(atoms_for_mtd):
+                    interval_list.append(atoms_for_mtd[idx])
         allowed_mtd_string = ",".join(
             [f"{interval_list[i]}-{interval_list[i + 1]}" for i in range(len(interval_list)) if i % 2 == 0]
         )
