@@ -19,15 +19,16 @@ from pymatgen.phonon.dos import PhononDos
 try:
     import phonopy
     from phonopy.phonon.dos import TotalDos
-except ImportError as exc:
-    print(exc)
+except ImportError:
     phonopy = None
+    TotalDos = None
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
     from typing import Literal
 
     from numpy.typing import ArrayLike
+    from typing_extensions import Self
 
 __author__ = "A. Bonkowski, J. George, G. Petretto"
 __copyright__ = "Copyright 2021, The Materials Project"
@@ -39,7 +40,7 @@ __date__ = "Apr 11, 2021"
 
 
 class GruneisenParameter(MSONable):
-    """Class for Grueneisen parameters on a regular grid."""
+    """Store the Gruneisen parameter for a single q-point on a regular grid."""
 
     def __init__(
         self,
@@ -73,11 +74,11 @@ class GruneisenParameter(MSONable):
         squared: bool = True,
         limit_frequencies: Literal["debye", "acoustic"] | None = None,
     ) -> float:
-        """Calculates the average of the Gruneisen based on the values on the regular grid.
-        If squared is True the average will use the squared value of the Gruneisen and a squared root
+        """Calculate the average of the Gruneisen based on the values on the regular grid.
+        If squared is True, the average will use the squared value of the Gruneisen and a squared root
         is performed on the final result.
-        Values associated to negative frequencies will be ignored.
-        See Scripta Materialia 129, 88 for definitions.
+        Values associated with negative frequencies will be ignored.
+        See Nath et al. _Scripta Materialia_ **2017**, _129_, 88 for the definitions.
         Adapted from classes in abipy that have been written by Guido Petretto (UCLouvain).
 
         Args:
@@ -133,12 +134,11 @@ class GruneisenParameter(MSONable):
         theta_d: float | None = None,
         t: float | None = None,
     ) -> float:
-        """Calculates the thermal conductivity at the acoustic Debye temperature with the Slack formula,
-        using the average Gruneisen.
-        Adapted from abipy.
+        """Calculate the thermal conductivity at the acoustic Debye temperature with the Slack formula,
+        using the average Gruneisen. Adapted from abipy.
 
         Args:
-            squared (bool): if True the average is performed on the squared values of the Gruenisen
+            squared (bool): if True the average is performed on the squared values of the Gruneisen
             limit_frequencies: if None (default) no limit on the frequencies will be applied.
                 Possible values are "debye" (only modes with frequencies lower than the acoustic Debye
                 temperature) and "acoustic" (only the acoustic modes, i.e. the first three modes).
@@ -162,12 +162,12 @@ class GruneisenParameter(MSONable):
         f1 = 0.849 * 3 * (4 ** (1 / 3)) / (20 * np.pi**3 * (1 - 0.514 * mean_g**-1 + 0.228 * mean_g**-2))
         f2 = (const.k * theta_d / const.hbar) ** 2
         f3 = const.k * average_mass * self.structure.volume ** (1 / 3) * 1e-10 / (const.hbar * mean_g**2)
-        k = f1 * f2 * f3
+        thermal_cond = f1 * f2 * f3
 
         if t is not None:
-            k *= theta_d / t
+            thermal_cond *= theta_d / t
 
-        return k
+        return thermal_cond
 
     @property  # type: ignore
     @requires(phonopy, "This method requires phonopy to be installed")
@@ -178,18 +178,18 @@ class GruneisenParameter(MSONable):
         class TempMesh:
             """Temporary Class."""
 
-        a = TempMesh()
-        a.frequencies = np.transpose(self.frequencies)
-        a.weights = self.multiplicities
+        tmp_mesh = TempMesh()
+        tmp_mesh.frequencies = np.transpose(self.frequencies)
+        tmp_mesh.weights = self.multiplicities
 
-        b = TotalDos(a)
-        b.run()
+        dos_tot = TotalDos(tmp_mesh)
+        dos_tot.run()
 
-        return b
+        return dos_tot
 
     @property
     def phdos(self) -> PhononDos:
-        """Returns: PhononDos object."""
+        """The phonon DOS (re)constructed from the gruneisen.yaml file."""
         return PhononDos(self.tdos.frequency_points, self.tdos.dos)
 
     @property
@@ -291,7 +291,7 @@ class GruneisenPhononBandStructure(PhononBandStructure):
     def as_dict(self) -> dict:
         """
         Returns:
-            MSONable (dict).
+            dict[str, Any]: MSONable dict.
         """
         dct = {
             "@module": type(self).__module__,
@@ -312,7 +312,7 @@ class GruneisenPhononBandStructure(PhononBandStructure):
         return dct
 
     @classmethod
-    def from_dict(cls, dct: dict) -> GruneisenPhononBandStructure:
+    def from_dict(cls, dct: dict) -> Self:
         """
         Args:
             dct (dict): Dict representation.
@@ -337,7 +337,7 @@ class GruneisenPhononBandStructure(PhononBandStructure):
 
 
 class GruneisenPhononBandStructureSymmLine(GruneisenPhononBandStructure, PhononBandStructureSymmLine):
-    """This object stores a GruneisenPhononBandStructureSymmLine together with Grueneisen parameters
+    """Store a GruneisenPhononBandStructureSymmLine together with Grueneisen parameters
     for every frequency.
     """
 
@@ -393,10 +393,10 @@ class GruneisenPhononBandStructureSymmLine(GruneisenPhononBandStructure, PhononB
         )
 
     @classmethod
-    def from_dict(cls, dct: dict) -> GruneisenPhononBandStructureSymmLine:
+    def from_dict(cls, dct: dict) -> Self:
         """
         Args:
-            dct: Dict representation.
+            dct (dict): Dict representation.
 
         Returns:
             GruneisenPhononBandStructureSymmLine
