@@ -31,8 +31,8 @@ class InsertSitesTransformation(AbstractTransformation):
     def __init__(self, species, coords, coords_are_cartesian=False, validate_proximity=True):
         """
         Args:
-            species: A list of species. e.g., ["Li", "Fe"]
-            coords: A list of coords corresponding to those species. e.g.,
+            species: A list of species. e.g. ["Li", "Fe"]
+            coords: A list of coords corresponding to those species. e.g.
                 [[0,0,0],[0.5,0.5,0.5]].
             coords_are_cartesian (bool): Set to True if coords are given in
                 Cartesian coords. Defaults to False.
@@ -49,12 +49,12 @@ class InsertSitesTransformation(AbstractTransformation):
     def apply_transformation(self, structure: Structure):
         """Apply the transformation.
 
-        Arg:
+        Args:
             structure (Structure): A structurally similar structure in
                 regards to crystal and site positions.
 
-        Return:
-            Returns a copy of structure with sites inserted.
+        Returns:
+            A copy of structure with sites inserted.
         """
         struct = structure.copy()
         for idx, sp in enumerate(self.species):
@@ -70,16 +70,6 @@ class InsertSitesTransformation(AbstractTransformation):
     def __repr__(self):
         return f"InsertSiteTransformation : species {self.species}, coords {self.coords}"
 
-    @property
-    def inverse(self):
-        """Return: None."""
-        return
-
-    @property
-    def is_one_to_many(self) -> bool:
-        """Return: False."""
-        return False
-
 
 class ReplaceSiteSpeciesTransformation(AbstractTransformation):
     """This transformation substitutes certain sites with certain species."""
@@ -88,7 +78,7 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
         """
         Args:
             indices_species_map: A dict containing the species mapping in
-                int-string pairs. E.g., { 1:"Na"} or {2:"Mn2+"}. Multiple
+                int-string pairs. e.g. { 1:"Na"} or {2:"Mn2+"}. Multiple
                 substitutions can be done. Overloaded to accept sp_and_occu
                 dictionary. E.g. {1: {"Ge":0.75, "C":0.25} }, which
                 substitutes a single species with multiple species to generate a
@@ -99,33 +89,23 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
     def apply_transformation(self, structure: Structure):
         """Apply the transformation.
 
-        Arg:
+        Args:
             structure (Structure): A structurally similar structure in
                 regards to crystal and site positions.
 
-        Return:
-            Returns a copy of structure with sites replaced.
+        Returns:
+            A copy of structure with sites replaced.
         """
         struct = structure.copy()
-        for i, sp in self.indices_species_map.items():
-            struct[int(i)] = sp
+        for idx, sp in self.indices_species_map.items():
+            struct[int(idx)] = sp
         return struct
 
     def __repr__(self):
         return "ReplaceSiteSpeciesTransformation :" + ", ".join(
-            [f"{k}->{v}" + v for k, v in self.indices_species_map.items()]
+            [f"{key}->{val}" + val for key, val in self.indices_species_map.items()]
         )
 
-    @property
-    def inverse(self):
-        """Return: None."""
-        return
-
-    @property
-    def is_one_to_many(self) -> bool:
-        """Return: False."""
-        return False
-
 
 class RemoveSitesTransformation(AbstractTransformation):
     """Remove certain sites in a structure."""
@@ -133,19 +113,19 @@ class RemoveSitesTransformation(AbstractTransformation):
     def __init__(self, indices_to_remove):
         """
         Args:
-            indices_to_remove: List of indices to remove. E.g., [0, 1, 2].
+            indices_to_remove: List of indices to remove. e.g. [0, 1, 2].
         """
         self.indices_to_remove = indices_to_remove
 
     def apply_transformation(self, structure: Structure):
         """Apply the transformation.
 
-        Arg:
+        Args:
             structure (Structure): A structurally similar structure in
                 regards to crystal and site positions.
 
-        Return:
-            Returns a copy of structure with sites removed.
+        Returns:
+            A copy of structure with sites removed.
         """
         struct = structure.copy()
         struct.remove_sites(self.indices_to_remove)
@@ -154,16 +134,6 @@ class RemoveSitesTransformation(AbstractTransformation):
     def __repr__(self):
         return "RemoveSitesTransformation :" + ", ".join(map(str, self.indices_to_remove))
 
-    @property
-    def inverse(self):
-        """Return: None."""
-        return
-
-    @property
-    def is_one_to_many(self) -> bool:
-        """Return: False."""
-        return False
-
 
 class TranslateSitesTransformation(AbstractTransformation):
     """This class translates a set of sites by a certain vector."""
@@ -187,12 +157,12 @@ class TranslateSitesTransformation(AbstractTransformation):
     def apply_transformation(self, structure: Structure):
         """Apply the transformation.
 
-        Arg:
+        Args:
             structure (Structure): A structurally similar structure in
                 regards to crystal and site positions.
 
-        Return:
-            Returns a copy of structure with sites translated.
+        Returns:
+            A copy of structure with sites translated.
         """
         struct = structure.copy()
         if self.translation_vector.shape == (len(self.indices_to_move), 3):
@@ -210,18 +180,10 @@ class TranslateSitesTransformation(AbstractTransformation):
         )
 
     @property
-    def inverse(self):
-        """
-        Returns:
-            TranslateSitesTransformation with the reverse translation.
-        """
+    def inverse(self) -> TranslateSitesTransformation:
+        """TranslateSitesTransformation with the reverse translation."""
         return TranslateSitesTransformation(self.indices_to_move, -self.translation_vector, self.vector_in_frac_coords)
 
-    @property
-    def is_one_to_many(self) -> bool:
-        """Return: False."""
-        return False
-
     def as_dict(self):
         """JSON-serializable dict representation."""
         dct = MSONable.as_dict(self)
@@ -276,11 +238,10 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         """
         Args:
             indices:
-                A list of list of indices.
-                e.g. [[0, 1], [2, 3, 4, 5]]
+                A list of list of indices, e.g. [[0, 1], [2, 3, 4, 5]].
             fractions:
                 The corresponding fractions to remove. Must be same length as
-                indices. e.g., [0.5, 0.25]
+                indices. e.g. [0.5, 0.25]
             algo:
                 This parameter allows you to choose the algorithm to perform
                 ordering. Use one of PartialRemoveSpecieTransformation.ALGO_*
@@ -303,7 +264,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         to_delete = []
 
         total_removals = sum(num_remove_dict.values())
-        removed = {k: 0 for k in num_remove_dict}
+        removed = dict.fromkeys(num_remove_dict, 0)
         for _ in range(total_removals):
             max_idx = None
             max_ene = float("-inf")
@@ -342,7 +303,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
 
         all_combis = [list(itertools.combinations(ind, num)) for ind, num in num_remove_dict.items()]
 
-        for idx, all_indices in enumerate(itertools.product(*all_combis), 1):
+        for idx, all_indices in enumerate(itertools.product(*all_combis), start=1):
             sites_to_remove = []
             indices_list = []
             for indices in all_indices:
@@ -373,7 +334,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
         return sorted(all_structures, key=lambda s: s["energy"])
 
     def _fast_ordering(self, structure: Structure, num_remove_dict, num_to_return=1):
-        """This method uses the matrix form of Ewald sum to calculate the ewald
+        """Use the matrix form of Ewald sum to calculate the Ewald
         sums of the potential structures. This is on the order of 4 orders of
         magnitude faster when there are large numbers of permutations to
         consider. There are further optimizations possible (doing a smarter
@@ -409,13 +370,8 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
                     struct.replace(manipulation[0], manipulation[1])
             struct.remove_sites(del_indices)
             struct = struct.get_sorted_structure()
-            all_structures.append(
-                {
-                    "energy": output[0],
-                    "energy_above_minimum": (output[0] - lowest_energy) / num_atoms,
-                    "structure": struct,
-                }
-            )
+            e_above_min = (output[0] - lowest_energy) / num_atoms
+            all_structures.append({"energy": output[0], "energy_above_minimum": e_above_min, "structure": struct})
 
         return all_structures
 
@@ -452,19 +408,19 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
             transmuted structure class.
         """
         num_remove_dict = {}
-        total_combis = 0
-        for indices, frac in zip(self.indices, self.fractions):
-            num_to_remove = len(indices) * frac
-            if abs(num_to_remove - int(round(num_to_remove))) > 1e-3:
+        total_combos = 0
+        for idx, frac in zip(self.indices, self.fractions):
+            n_to_remove = len(idx) * frac
+            if abs(n_to_remove - int(round(n_to_remove))) > 1e-3:
                 raise ValueError("Fraction to remove must be consistent with integer amounts in structure.")
-            num_to_remove = int(round(num_to_remove))
-            num_remove_dict[tuple(indices)] = num_to_remove
-            n = len(indices)
-            total_combis += int(
-                round(math.factorial(n) / math.factorial(num_to_remove) / math.factorial(n - num_to_remove))
+            n_to_remove = int(round(n_to_remove))
+            num_remove_dict[tuple(idx)] = n_to_remove
+            n = len(idx)
+            total_combos += int(
+                round(math.factorial(n) / math.factorial(n_to_remove) / math.factorial(n - n_to_remove))
             )
 
-        self.logger.debug(f"Total combinations = {total_combis}")
+        self.logger.debug(f"Total combinations = {total_combos}")
 
         try:
             num_to_return = int(return_ranked_list)
@@ -491,14 +447,9 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
     def __repr__(self):
         return f"PartialRemoveSitesTransformation : Indices and fraction to remove = {self.indices}, ALGO = {self.algo}"
 
-    @property
-    def inverse(self):
-        """Return: None."""
-        return
-
     @property
     def is_one_to_many(self) -> bool:
-        """Return: True."""
+        """Transform one structure to many."""
         return True
 
 
@@ -515,27 +466,17 @@ class AddSitePropertyTransformation(AbstractTransformation):
     def apply_transformation(self, structure: Structure):
         """Apply the transformation.
 
-        Arg:
+        Args:
             structure (Structure): A structurally similar structure in
                 regards to crystal and site positions.
 
-        Return:
-            Returns a copy of structure with sites properties added.
+        Returns:
+            A copy of structure with sites properties added.
         """
-        new_structure = structure.copy()
+        new_struct = structure.copy()
         for prop in self.site_properties:
-            new_structure.add_site_property(prop, self.site_properties[prop])
-        return new_structure
-
-    @property
-    def inverse(self):
-        """Return: None."""
-        return
-
-    @property
-    def is_one_to_many(self) -> bool:
-        """Return: False."""
-        return False
+            new_struct.add_site_property(prop, self.site_properties[prop])
+        return new_struct
 
 
 class RadialSiteDistortionTransformation(AbstractTransformation):
@@ -543,14 +484,14 @@ class RadialSiteDistortionTransformation(AbstractTransformation):
     point defect.
     """
 
-    def __init__(self, site_index, displacement=0.1, nn_only=False):
+    def __init__(self, site_index: int, displacement: float = 0.1, nn_only: bool = False) -> None:
         """
         Args:
             site_index (int): index of the site in structure to place at the center of the distortion (will
                 not be distorted). This index must be provided before the structure is provided in
                 apply_transformation in order to keep in line with the base class.
             displacement (float): distance to perturb the atoms around the objective site
-            nn_only (bool): Whether or not to perturb beyond the nearest neighbors. If True, then only the
+            nn_only (bool): Whether to perturb beyond the nearest neighbors. If True, then only the
                 nearest neighbors will be perturbed, leaving the other sites undisturbed. If False, then
                 the nearest neighbors will receive the full displacement, and then subsequent sites will receive
                 a displacement=0.1 / r, where r is the distance each site to the origin site. For small displacements,
@@ -573,40 +514,36 @@ class RadialSiteDistortionTransformation(AbstractTransformation):
         structure = structure.copy()
         site = structure[self.site_index]
 
-        def f(x, r, r0):
+        def displace_dist(x, r, r0):
             return x * r0 / r
 
         r0 = max(site.distance(_["site"]) for _ in MinimumDistanceNN().get_nn_info(structure, self.site_index))
         if hasattr(structure, "lattice"):
-            m = structure.lattice.matrix
-            m = (abs(m) > 1e-5) * m
-            a, b, c = m[0], m[1], m[2]
+            latt_mat = structure.lattice.matrix
+            latt_mat = (abs(latt_mat) > 1e-5) * latt_mat  # round small values to 0
+            a, b, c = latt_mat[0], latt_mat[1], latt_mat[2]
             x = abs(np.dot(a, np.cross(b, c)) / np.linalg.norm(np.cross(b, c)))
             y = abs(np.dot(b, np.cross(a, c)) / np.linalg.norm(np.cross(a, c)))
             z = abs(np.dot(c, np.cross(a, b)) / np.linalg.norm(np.cross(a, b)))
-            rmax = np.floor(min([x, y, z]) / 2)
+            r_max = np.floor(min([x, y, z]) / 2)
         else:
-            rmax = np.max(structure.distance_matrix)
+            r_max = np.max(structure.distance_matrix)
 
-        for vals in structure.get_neighbors(site, r=r0 if self.nn_only else rmax):
+        for vals in structure.get_neighbors(site, r=r0 if self.nn_only else r_max):
             site2, distance, index = vals[:3]
-            v = site2.coords - site.coords
-            kwargs = {"indices": [index], "vector": v * f(self.displacement, distance, r0) / np.linalg.norm(v)}
+            vec = site2.coords - site.coords
+            kwargs = {
+                "indices": [index],
+                "vector": vec * displace_dist(self.displacement, distance, r0) / np.linalg.norm(vec),
+            }
             if hasattr(structure, "lattice"):
                 kwargs["frac_coords"] = False
             structure.translate_sites(**kwargs)
         return structure
 
-    @property
-    def inverse(self):
-        """Returns the inverse transformation if available.
-        Otherwise, should return None.
-        """
-        return False
-
     @property
     def is_one_to_many(self) -> bool:
-        """Determines if a Transformation is a one-to-many transformation. If a
+        """Determine if a Transformation is a one-to-many transformation. If a
         Transformation is a one-to-many transformation, the
         apply_transformation method should have a keyword arg
         "return_ranked_list" which allows for the transformed structures to be
