@@ -10,10 +10,9 @@ from pymatgen.util.plotting import pretty_plot
 
 
 class SpectrumPlotter:
-    """
-    Class for plotting Spectrum objects and subclasses. Note that the interface
+    """Plot Spectrum objects and subclasses. Note that the interface
     is extremely flexible given that there are many different ways in which
-    people want to view spectra. The typical usage is::
+    people want to view spectra. The typical usage is:
 
         # Initializes plotter with some optional args. Defaults are usually
         # fine,
@@ -31,7 +30,7 @@ class SpectrumPlotter:
         """
         Args:
             xshift (float): A shift that is applied to the x values. This is
-                commonly used to shift to an arbitrary zero. E.g., zeroing at the
+                commonly used to shift to an arbitrary zero. e.g. zeroing at the
                 Fermi energy in DOS, or at the absorption edge in XAS spectra. The
                 same xshift is applied to all spectra.
             yshift (float): A shift that is applied to the y values. This is
@@ -49,8 +48,8 @@ class SpectrumPlotter:
 
         mod = importlib.import_module(f"palettable.colorbrewer.{color_cycle[0]}")
         self.colors_cycle = getattr(mod, color_cycle[1]).mpl_colors
-        self.colors = []
-        self._spectra = {}
+        self.colors: list = []
+        self._spectra: dict = {}
 
     def add_spectrum(self, label, spectrum, color=None):
         """
@@ -59,7 +58,7 @@ class SpectrumPlotter:
         Args:
             label (str): Label for the Spectrum. Must be unique.
             spectrum: Spectrum object
-            color (str): This is passed on to matplotlib. E.g., "k--" indicates
+            color (str): This is passed on to matplotlib. e.g. "k--" indicates
                 a dashed black line. If None, a color will be chosen based on
                 the default color cycle.
         """
@@ -83,8 +82,7 @@ class SpectrumPlotter:
             self.add_spectrum(label, spectra_dict[label])
 
     def get_plot(self, xlim=None, ylim=None):
-        """
-        Get a matplotlib plot showing the DOS.
+        """Get a matplotlib plot showing the DOS.
 
         Args:
             xlim: Specifies the x-axis limits. Set to None for automatic
@@ -127,8 +125,7 @@ class SpectrumPlotter:
         return ax
 
     def save_plot(self, filename: str, **kwargs):
-        """
-        Save matplotlib plot to a file.
+        """Save matplotlib plot to a file.
 
         Args:
             filename (str): Filename to write to. Must include extension to specify image format.
